require(data.table)

readCropProd = function(filename) {
	crop_prod_data = fread(filename)
	crop_prod_data[, Value := as.numeric(Value) / 1000000] # convert to Mt and Mha
	crop_prod_data[, Year := as.numeric(Year)]
	result = data.table(dcast(crop_prod_data, Area + Year + Item ~ Element, value.var = 'Value'))
	result[is.na(result)] = 0
	result[, list(Country=Area, Year, Item, area=get("Area harvested"), prod=get("Production"))]
}

crop_prod = readCropProd("/Users/peteralexander/Downloads/Production_Crops_E_All_Data_(Normalized).csv")

# returns our original manual query
crop_prod[Country == "China" & Year == 2017 & Item =="Cereals,Total"]


require(ggplot2)
ggplot(crop_prod[Country %in% c("China", "United States of America", "Kenya", "Brazil") & Item =="Cereals,Total"], aes(x=Year, y=prod/area, colour=Country)) + geom_line()




processCommoditiyBalance = function(fao_file) {
	fao_data =fread(fao_file)
	setnames(fao_data, gsub(' ', '', (names(fao_data))))  
	fao_data[, Value := as.numeric(Value) / 1000000]
	fao_data[, Year := as.numeric(Year)]
	
	# Need to aggregate for mainland China, Hong Kong, etc.
	fao_data = rbind(fao_data, fao_data[Area %like% 'China', list(AreaCode=9999, Area="China", Value=sum(Value), Flag="X"), by=list(ItemCode, Item, ElementCode, Element, YearCode, Year, Unit)])
	
	result = data.table(dcast(fao_data, Area + Year + Item ~ Element, value.var = 'Value'))
	result[is.na(result)] = 0
	setnames(result, c("Area", "Domestic supply quantity", "Seed","Processing","Food supply quantity (tonnes)","Feed","Production","Stock Variation","Import Quantity","Export Quantity","Other uses"),
			c("Country", "supply", "seed", "processing", "food", "feed", "prod", "stockvar", "import", "export", "other"))
	result
}

com_bal = processCommoditiyBalance("/Users/peteralexander/Downloads/CommodityBalances_Crops_E_All_Data_(Normalized).csv")

world_avg_yields = crop_prod[Country == "World" & Year == 2013, list(Item, world_yield=prod/area)]

com_bal[, Item := gsub(' and products', '', (Item))]

mergedDt = merge(com_bal[Country %in% c("China", "United States of America", "Kenya", "Brazil") & Year == 2013], world_avg_yields, by="Item")

mergedDt = merge(mergedDt, crop_prod[, list(Country, Year, Item, area)], by=c("Country", "Year", "Item"))
mergedDt[, list(area_from_global_avg_yield=sum(food / world_yield, na.rm=TRUE), area_from_domestic_yield=sum(area*food/prod, na.rm=TRUE)), by=Country]
