library(raster)
library(data.table)

data_dir_root <-"/Users/peteralexander/Documents/LURG/Model Comp/Phase1/LUC4C MIP"

################################################################################################################
## EXTRACT GLOBAL VALUES
################################################################################################################

# create EU27 mask from DynaCLUE data
dynaclue_data <- list.files(file.path(data_dir_root, 'DynaCLUE'),pattern ='hdr.adf$',full.names=TRUE,recursive=TRUE)
dyna <- stack(dynaclue_data)
names(dyna) <- gsub('.*/[A-z]+_[A-Z][0-9]/(.*)/hdr.adf', '\\1', dynaclue_data)
dynaMask = subset(dyna, "ref_a1_2020")

DynaRclMatrixI <- matrix(c(c(seq(0,17,1),255), c(0,1,2,4,4,4,1,4,1,1,3,4,4,4,4,4,4,1,NA)), ncol=2)
dynaMaskRecl <- reclassify(dynaMask, rcl=DynaRclMatrixI)
names(dynaMaskRecl) <- names(dynaMask)
euDynaMask = !is.na(dynaMaskRecl)

## stack fractional grids per category and year
CLUfrac <- list.files(file.path(data_dir_root,'CLUMondo'), pattern='(tree|cropland|pasture).*\\.asc$', full.names=TRUE, recursive=TRUE)

CLUFracStack <- stack(CLUfrac)
crs(CLUFracStack) <- '+proj=eck4 +lon_0=0 +x_0=0 +y_0=0 +ellps=WGS84 +datum=WGS84 +units=m +no_defs'
names(CLUFracStack) <- gsub('.*/CLUMondo/CLUMondo_(.*)_fractional/(.*).asc', '\\1_\\2', CLUfrac)

eu27_clu = projectRaster(euDynaMask, CLUFracStack) > 0 

# calculate global sums by cellStats and write into data.table  
CLUglobalAreas <- NULL
for (layerName in names(CLUFracStack)){
	print (paste("Processing CLUglobal: ", layerName))
	scenarioId <- gsub('([A-Z0-9]+)_([a-z]+)_([0-9]+).*', '\\1', layerName) # extract scenario
	lctype <- gsub('([A-Z0-9]+)_([a-z]+)_([0-9]+).*', '\\2', layerName)  # extract land type
	year <- gsub('([A-Z0-9]+)_([a-z]+)_([0-9]+).*', '\\3', layerName) # extract year
	globalArea <- (cellStats(subset(CLUFracStack, layerName), sum)*(9.25*9.25))/10000 # calculate sum and convert to Mha
	euArea = (cellStats(subset(CLUFracStack, layerName)*eu27_clu, sum)*(9.25*9.25))/10000
	
	gdt <- data.table(unit='Mha',year=as.numeric(year), location='Global', land_type=lctype, value=globalArea, model='CLUMondo', scenarioId=scenarioId)
	CLUglobalAreas <- rbind(CLUglobalAreas, gdt)
	
	edt <- data.table(unit='Mha',year=as.numeric(year), location='EU27', land_type=lctype, value=euArea, model='CLUMondo', scenarioId=scenarioId)
	CLUglobalAreas <- rbind(CLUglobalAreas, edt)
}

CLUglobalAreas[land_type=='bare', land_type:='u']
CLUglobalAreas[land_type=='built', land_type:='b']
CLUglobalAreas[land_type=='cropland', land_type:='c']
CLUglobalAreas[land_type=='pasture', land_type:='p']
CLUglobalAreas[land_type=='tree', land_type:='f']

write.table(CLUglobalAreas,file.path(data_dir_root, 'CLUMondo/CLUglobal.csv'),row.names=FALSE)

