require(data.table)
require(car)
require(lme4)

#allNonGriddedData = fread("/Users/peteralexander/Documents/LURG/Model Comp/Phase1/LUC4C MIP/allNonGriddedData.csv", sep=',')

decompCutDown = function(loc, yr, ltype, removeExtremes = FALSE) {
	
	formula_all = formula("value ~ pop_2100 + gdp_rate_to_2100 + inequality_2100 + co2_2100 + modelType + numCellsLog + scenDelta + tech_change + trade")
	
	dt = allNonGriddedData[location == loc & land_type == ltype & year == yr]
	
	if (removeExtremes) {
		# did this with sd (could use mad), but lets just remove the ones we know are most dubious
		dt = dt[!(model == "MAgPIE" & scenarioId %in% c('AFF', 'AFF+BECCS'))]
	}
			
	ret = list()
	
	# comparison of mad and sd
	ret$dtSummary = dt[, list(location=loc, year=yr, land_type = ltype, 
					mean=mean(value), sd=sd(value),
					median=median(value), mad=mad(value, constant=1/quantile((value-median(value))/sd(value), probs=0.75)))]
	ret$dtSummary[, c('rel_sd', 'rel_mad') := list( sd/mean, mad/median)]	
			
	
	if (yr != 2010) { # errors at 2010 due to  perfect fit to scenDelta at this year
		reg_all = lm(formula_all, data=dt)
		reg_signif = step(reg_all, direction="backward", trace=0)  
		
		mixed_formula = update(formula(reg_signif), .~. + (1|model) + (1|economicScenario) + (1|climateScenario))
		mixed_reg = lmer(mixed_formula, dt)
		ret$summaryMixed = summary(mixed_reg)
		
		ret$anovaMixed = Anova(mixed_reg, type = "II")
		ret$anovaFixed = Anova(reg_signif, type = "II")
	}

	ret
}

decompCutDown('Global', 2050, 'c')
decompCutDown('EU27', 2050, 'p')
decompCutDown('Global', 2100, 'f', removeExtremes = TRUE) 


# Reg extract

for (yr in c(2050, 2060, 2100)) {
	formula_all = formula("value ~ pop_2100 + gdp_rate_to_2100 + inequality_2100 + co2_2100 + modelType + numCellsLog + scenDelta + tech_change + trade")
	dt = allNonGriddedData[location == "Global" & land_type == 'c' & year == yr]
	
	if ('modelType' %in% all.vars(formula_all)) {
		model_type = relevel(factor(dt$modelType), ref="PE")
		formula_all = update(formula_all, .~. - modelType + model_type)
	}
	reg_all = lm(formula_all, data=dt)
	reg_signif = step(reg_all, direction="backward", trace=0)  
	print(summary(reg_signif))
		
	
	print (sprintf("%d: Residual standard error: %.4f, Adjusted R-squared:  %.4f", yr, summary(reg_signif)$r.squared, summary(reg_signif)$adj.r.squared))
#	summary(reg_signif)$r.squared
	
	write.table(data.table(summary(reg_signif)$coefficients,keep.rownames=TRUE), paste0("/Users/peteralexander/Documents/LURG/Model Comp/Phase1/LUC4C MIP/reg_", yr, ".csv"), sep=',', row.names=FALSE, quote=FALSE)
	
}

reg_all = lm("value ~ pop_2100 + gdp_rate_to_2100 + inequality_2100 + co2_2100 + modelType + numCellsLog + scenDelta + tech_change + trade", allNonGriddedData[year == 2060 & land_type =='f' & location == "Global"])
reg_sig = step(reg_all, direction="backward", trace=0)

summary(reg_all)
summary(reg_sig)

Anova(reg_all, type = "II")
Anova(reg_sig, type = "II")
