
library(reshape2)

gcam_dir_root = "/Users/peteralexander/Documents/LURG/Model Comp/Phase1/LUC4C MIP/GCAM/"

# -----------------------------------------------------------------------------
# set the years to be written out. The model data is available in 5-year timesteps from 2005 to 2100.
luc4c_years <- seq( 2010, 2100, 10 )
#Column names can't start with numbers, so when years are columns they will be preceded by "X"
X_luc4c_years <- paste( "X", luc4c_years, sep = "" )

#Indicate the order and names of the columns being written out
luc4c_column_names <- c( "model", "scenario", "year", "location", "land_type", "unit", "value" )

# Unit conversions
# The model unit is billion square meters, equal to thousand square kilometers.
# This makes a few options available
land_unit <- "Mha"
if( land_unit == "Mha" ) conv_land_unit <- 0.1
if( land_unit == "kha" ) conv_land_unit <- 100
if( land_unit == "ha" ) conv_land_unit <- 100000
if( land_unit == "km2" ) conv_land_unit <- 1000
if( land_unit == "bm2" ) conv_land_unit <- 1
if( land_unit == "thousand km2" ) conv_land_unit <- 1
if( land_unit == "million km2" ) conv_land_unit <- .001

# -----------------------------------------------------------------------------
# 1. Read files

GCAM_luc4c_reg <- read.csv( paste0(gcam_dir_root, "GCAM_luc4c_reg.csv"), stringsAsFactors = F, na.strings = "" )
GCAM_luc4c_land <- read.csv( paste0(gcam_dir_root, "GCAM_luc4c_land.csv"), stringsAsFactors = F, na.strings = "" )
GCAM_luc4c_scenarios <- read.csv( paste0(gcam_dir_root, "my_GCAM_luc4c_scenarios.csv"), stringsAsFactors = F, na.strings = "" )
land <- read.csv( paste0(gcam_dir_root, "land.csv"), stringsAsFactors = F, na.strings = "" )

# -----------------------------------------------------------------------------
# 2. Build tables
# This is written so that more output variables can be added over time
tables <- list( land )
names( tables ) <- c( "land" )
for( i in 1:length( tables ) ){
	tables[[i]][["model"]] <- "GCAM"
	tables[[i]][["scen_name"]] <- substr( tables[[i]][["scenario"]], 1, regexpr( ",", tables[[i]][["scenario"]], fixed = T ) - 1 )
	tables[[i]][["scenario"]] <- GCAM_luc4c_scenarios[["scenario"]][ match( tables[[i]][["scen_name"]], GCAM_luc4c_scenarios[["scen_name"]] )]
	tables[[i]][["location"]] <- GCAM_luc4c_reg[["location"]][ match( tables[[i]][["region"]], GCAM_luc4c_reg[["GCAM_region"]] ) ]
	tables[[i]][["R1"]] <- "Global"
}

#Land areas
land <- tables[[ "land" ]]

#We'll drop the AEZ information; assuming that this is not wanted in this study
# Would be important to keep if these data were later downscaled to a grid
land$GCAM_LandLeaf <- sub( "AEZ[0-9]{2}", "", land$land.allocation )
land[ c( "LUT", "LCC" ) ] <- GCAM_luc4c_land[
      match( land$GCAM_LandLeaf, GCAM_luc4c_land$GCAM_LandLeaf ),
      c( "LUT", "LCC" ) ]
land.list <- list()
for( reg in c( "location", "R1" ) ){
	for( land_level in c( "LUT", "LCC" ) ){
		objectname <- paste("land", reg, land_level, sep = "_" )
		object <- aggregate( land[ X_luc4c_years ] * conv_land_unit, by=as.list( land[ c( "model", "scenario", reg, land_level ) ] ), sum )
		names( object ) <- c( "model", "scenario", "location", "land_type", X_luc4c_years )
		assign( objectname, object )
		land.list[[objectname]] <- object
	}
}
Area <- do.call( rbind, land.list )
Area <- melt( Area, measure.vars = X_luc4c_years, variable.name = "year", value.name = "value" )
Area$year <- as.numeric( substr( Area$year, 2, 5 ) )
Area$unit <- land_unit
Area <- Area[ luc4c_column_names ]

# -----------------------------------------------------------------------------
#3. OUTPUT
write.csv( Area, paste0(gcam_dir_root, "luc4c_GCAM_output.csv"), row.names = F )
