library(raster)
library(data.table)

data_dir_root = "/Users/peteralexander/Documents/LURG/Model Comp/Phase1/LUC4C MIP"

GBlcMapping <- data.table(GB=c('cropland', 'grassland', 'forest', 'other'), 
                          conv=c('c', 'p', 'f', 'o'), key='GB') # map GLOBIOM categories to convention of analysis 

boundaries <- raster(file.path(data_dir_root, 'country_boundaries.asc'))
crs(boundaries) <- '+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs'
eu27 = boundaries %in% fread(file.path(data_dir_root, 'eu27.txt'))$numCode
eu27 = extend(crop(eu27, extent(-15,35,30,75)), extent(-180,180,-90,90))
names(eu27) = "eu27"

raster_SimU <- raster(file.path(data_dir_root, 'GLOBIOM/raster_simU/hdr.adf')) # Load raster containing IDs of Simulation Units (provided by Tamas)
eu27_5min <- resample(eu27, raster_SimU, method = 'ngb')

raster_SimU_dt = data.table(as.data.frame(raster_SimU, na.rm=TRUE))
raster_SimU_dt[, dummy:=1]
simuDupAdj <- reclassify(raster_SimU, raster_SimU_dt[, 1/length(dummy), by=hdr]) # duplicate simulation unit ID, but area given for all of them

GBdata <- list.files(file.path(data_dir_root, 'GLOBIOM'), pattern='\\.csv.xls$', full.names=TRUE) # list all *.csv files containing GLOBIOM data (ones ending .xls are the new ones, although not excel s/s)

globiomDT <- NULL

for (nfile in  GBdata){
  dt <- fread(nfile) # read csv.file
  scenario <- gsub('.*/res_scenRCPref_SPA0_([[:alnum:]]+)__abs.csv.xls', '\\1', nfile)  # extract scenario 
  for (column in data.table(layer=names(dt))[layer %like% 'forest' | layer %like% 'land']$layer){
    dt.sub <- dt[,.SD, .SDcols=c('SimUID', column)] # subset dt taking only SimUID 
    lctype <- gsub('([A-z]) [0-9]+', '\\1', names(dt.sub)[2]) 
    year <- gsub('[A-z]+ ([0-9]+)', '\\1', names(dt.sub)[2]) 
    print(paste("Processing GLOBIOM:", scenario, lctype, year)) 
    lctype <- GBlcMapping[GB==lctype]$conv # map land type to MIP convention
    r <- reclassify(raster_SimU, dt.sub) # map data to raster (according to simulation unit ID)
    r[r>1 & r%%1 < 0.00001] <- NA # set all SimUs left to 0 
    
    # extract global and EU27 values 
    GBglobal <- cellStats(r * simuDupAdj, sum)
    GBEU27 <- cellStats(r*eu27_5min * simuDupAdj, sum)
    GBgdt <- data.table(unit = 'kha', 
                        year = year, 
                        location = 'Global',
                        lc_type = lctype,
                        value = GBglobal,
                        model = 'GLOBIOM',
                        scenarioId = scenario)
    GBedt <- data.table(unit = 'kha', 
                        year = year, 
                        location = 'EU27', 
                        lc_type = lctype, 
                        value = GBEU27, 
                        model = 'GLOBIOM', 
                        scenarioId = scenario) 
    
    globiomDT <- rbind(globiomDT, GBgdt, GBedt)
	
	write.table(globiomDT,file.path(data_dir_root, paste0('GLOBIOM/temp_', column,'.csv')),row.names=FALSE)
	}
}

globiomDT[, c('unit', 'value') := list('Mha', value/1000)]
setnames(globiomDT, "lc_type", "land_type")
write.table(globiomDT,file.path(data_dir_root, 'GLOBIOM/summary.csv'),row.names=FALSE)

