require(ggplot2)
require(grid)

landTypeToName = data.table(land_type = c('c', 'p', 'f', 'b', 'u'), lt_name = c("a) Cropland", "b) Pasture", "c) Forest", "Urban", "Unmanaged/Other")) 

gg_color_hue <- function(n) {
	hues = seq(40, 360+50, length=n+1)
	hcl(h=hues, l=c(50, 70), c=100)[1:n]
}
# assign styles to models
modelPlotStyle = unique(allNonGriddedData[, list(model)])
numColours = (length(fread(file.path(data_dir_root, "modelData.txt"))$model) + 1)/2
modelPlotStyle[, c('ltype', 'lcolour', 'lsize', 'lalpha', 'pshape') := 
				list( c(rep('solid', numColours), rep('dashed', numColours)), gg_color_hue(numColours), 0.5, 0.8, 3)]
modelPlotStyle = rbind(data.table(model = "Historic (FAO)", ltype = "solid", lcolour = "black", lsize = 0.9, lalpha = 0.9, pshape=NA), modelPlotStyle)
modelPlotStyle = rbind(data.table(model = "Model mean", ltype = "dotdash", lcolour = "black", lsize = 0.9, lalpha = 0.5, pshape=NA), modelPlotStyle)


getGpplotOfLandType = function(dt, ltype, loc, valueToPlot = "value", plotAxisLabels = false) {	
	theData = dt[year%%5 ==0 & location == loc & land_type == ltype & dummy == FALSE]
	theData[, inter := paste(theData$model, theData$scenarioId)]
	if (length(theData$year) == 0) return()
	hist = fread(file.path(data_dir_root, 'histSummary.csv'))[location == loc & land_type == ltype][, list(model="Historic (FAO)", year, v = value, inter="hist")]
	
	dtToAvg = dt[location == loc & land_type == ltype, list(model, scenarioId, year, v=get(valueToPlot), land_type)]
	avgData = dtToAvg[year%%10 == 0 & year >= 2000, list(sdev = sd(v), mn = mean(v), median=median(v)), by=list(year, land_type)]
	
	dtToPlot = rbind(theData[, list(model, year, v=get(valueToPlot), inter)], hist) #, avgData[, list(model="Model mean", year, v=mn, inter="mean")]) #this would add mean line
	styles = merge(unique(dtToPlot[, list(model)]), modelPlotStyle, by="model")
	ordBreaks = c("Historic (FAO)", "Model mean", unique(dtToPlot$model))
	
	theAes = aes_string(x="year", y="v", colour="model", linetype="model", size="model", alpha="model", shape="model", group="inter")
	
	if (valueToPlot == "value") yAxisLabel = "Area (Mha)" else yAxisLabel = "Area rebased (Mha)"
	
	p1 = ggplot() +
			geom_ribbon(data=avgData, aes(x=year, ymin=mn-1.98*sdev,ymax=mn+1.98*sdev), alpha=0.05) +
			geom_line(data = dtToPlot[!model %in% c("Historic (FAO)", "Model mean")], theAes) + 
			geom_point(data = dtToPlot, theAes, na.rm = TRUE) + 
			geom_line(data = dtToPlot[model %in% c("Historic (FAO)", "Model mean")], theAes) + # just doing this separately so drawn on top
			scale_linetype_manual(values = styles$ltype, breaks = ordBreaks, guide = guide_legend(nrow = 2)) + 
			scale_colour_manual(values = styles$lcolour, breaks = ordBreaks) + 
			scale_size_manual(values = styles$lsize, breaks = ordBreaks) + 
			scale_alpha_manual(values = styles$lalpha, breaks = ordBreaks) + 
			scale_shape_manual(values = styles$pshape, breaks = ordBreaks) + 
			scale_x_continuous(breaks = c(2010, 2040, 2070, 2100)) +
			labs(x="Year", y=yAxisLabel) + 
			theme_classic(base_size = 12) + theme(legend.text=element_text(size=14)) +
			theme(legend.position="bottom") + theme(legend.title=element_blank()) + theme(axis.title.y = element_blank())
	p1
}


getGpplotOfLandTypeOld = function(dt, ltype, loc, colourBy = "model", valueToPlot = "value", fileName="ByModel", saveToFile=TRUE) {	
	
	hist = fread(file.path(data_dir_root, 'histSummary.csv'))[location == loc & land_type == ltype][, dataType := "Historic (FAO)"]
	theData = dt[year%%10 ==0 & location == loc & land_type == ltype & dummy == FALSE]
	theData[, inter := paste(theData$model, theData$scenarioId)]
	if (length(theData$year) == 0) return()

	avgData = dt[location == loc & land_type == ltype & year%%10 == 0 & year >= 2000, list(sdev = sd(get(valueToPlot)), mn = mean(get(valueToPlot))), by=list(year, land_type)][, dataType := "Model mean"]
	
	theData[, groupedScenario:=paste0(groupedScenario, "-like")]
	
	colourByMedian = theData[year%%10 ==0][, list(medV=median(get(valueToPlot)), dataType="Model Medians"), by=list(year, colourCat=get(colourBy))]
	
		
		
	theAes = aes_string(x="year", y=valueToPlot, colour=colourBy, group="inter")

	if (valueToPlot == "value") yAxisLabel = "Area (Mha)" else yAxisLabel = "Area rebased (Mha)"
	
	p1 = ggplot() +
			geom_line(data = theData, theAes, alpha=0.8, size = 0.3) + 
			geom_point(data = theData, theAes, alpha=0.5, size=0.4, na.rm = TRUE, shape=3) + 
			geom_line(data = hist, alpha=0.9, aes_string(x="year", y="value", linetype="dataType"), size = 1) + 
			geom_line(data=colourByMedian, aes_string(x="year", y="medV", colour="colourCat", linetype="dataType"), alpha=0.9, size=1) +
			geom_ribbon(data=avgData, aes(x=year, ymin=mn-1.98*sdev,ymax=mn+1.98*sdev), alpha=0.05) +
			labs(x="Year", y=yAxisLabel) +
			theme_classic(base_size = 11) + 
			theme(legend.direction = "horizontal", legend.position = "bottom", legend.box = "horizontal") + 
			theme(legend.title=element_blank())
	
	p1
}

pdf(width=10.5, height=5.2, file = file.path(data_dir_root, "Output", "GlobalByModelScenario.pdf"))
byModelType=getGpplotOfLandTypeOld(dt=allNonGriddedData, ltype='c', loc='Global', colourBy="modelType", valueToPlot='value')
byScenario=getGpplotOfLandTypeOld(dt=allNonGriddedData, ltype='c', loc='Global', colourBy="groupedScenario", valueToPlot='value')
print(byModelType + guides(linetype=FALSE), vp=viewport(just=c("left", "top"), x=0, y=unit(0.98, "npc"), width=0.51, height=0.97))
print(byScenario + guides(linetype=FALSE), vp=viewport(just=c("left", "top"), x=0.5, y=unit(0.98, "npc"), width=0.51, height=0.97))

g <- ggplotGrob(byScenario + guides(colour=FALSE))$grobs
legend <- g[[which(sapply(g, function(x) x$name) == "guide-box")]]
# add legend viewport
pushViewport(viewport(just=c("left", "top"), x=0.03, y=0.09, width=1, height=0.1))
grid.draw(legend)
upViewport()
grid.text(gp=gpar(cex=0.93, font=4), x=unit(.04, "npc"), y=unit(.99, "npc"), just=c("left", "top"), "a) By model type")
grid.text(gp=gpar(cex=0.93, font=4), x=unit(.54, "npc"), y=unit(.99, "npc"), just=c("left", "top"), "b) By scenarios mapped to SSPs")
dev.off()


plotLandType = function(dt, ltype, loc, colourBy = "model", saveToFile = TRUE, shapeBy = "model", valueToPlot = "value") {	
	print(paste("Plotting", loc, ltype, colourBy, shapeBy, valueToPlot))
	p1 = getGpplotOfLandTypeOld(dt, ltype, loc, colourBy, shapeBy, valueToPlot)
	
	if (valueToPlot == "value") 
		outputDir = file.path(data_dir_root, "Output", colourBy)
	else
		outputDir = file.path(data_dir_root, "Output_rebased", colourBy)
	
	if (saveToFile) {
		if (!file.exists(outputDir)) dir.create(outputDir, recursive = TRUE)
		fileName = file.path(outputDir, paste0(loc, '-' , ltype, '.pdf'))
		ggsave(fileName, p1)
	}
	else {
		p1 # plot the graph
	}
}


valuetp = "value_rebased"
for (ltype in c('c', 'p', 'f')) {
#	plotLandType(allNonGriddedData, ltype, "EU27", valueToPlot = valuetp)
#	plotLandType(allNonGriddedData, ltype, "Global", valueToPlot = valuetp)
		
#	plotLandType(allNonGriddedData, ltype, "EU27", colourBy = "modelExtent", valueToPlot = valuetp)
		
#	plotLandType(allNonGriddedData, ltype, "Global", colourBy = 'modelRes', valueToPlot = valuetp)
	
#	plotLandType(allNonGriddedData, ltype, "EU27", colourBy = 'modelType', valueToPlot = valuetp)
#	plotLandType(allNonGriddedData, ltype, "Global", colourBy = 'modelType', valueToPlot = valuetp)
	
#	plotLandType(allNonGriddedData[economicScenario %like% 'SSP*'], ltype, "EU27", "economicScenario", valueToPlot = valuetp)
#	plotLandType(allNonGriddedData[economicScenario %like% 'SSP*'], ltype, "Global", "economicScenario", valueToPlot = valuetp)
	
#	plotLandType(allNonGriddedData[climateScenario %like% 'RCP'], ltype, "EU27", 'climateScenario', valueToPlot = valuetp)
#	plotLandType(allNonGriddedData[climateScenario %like% 'RCP'], ltype, "Global", 'climateScenario', valueToPlot = valuetp)
}


# Plot 6 per page, with common legend
plotSummary = function(loc, saveToFile = TRUE) {	
	if (saveToFile) pdf(width=12.5, height=9.5, file = file.path(data_dir_root, "Output", paste0(loc, "Sum", ".pdf")))

	p_c = getGpplotOfLandType(allNonGriddedData, 'c', loc, valueToPlot = "value")
	g <- ggplotGrob(p_c + theme(text = element_text(size=13)))$grobs
	legend <- g[[which(sapply(g, function(x) x$name) == "guide-box")]]
	lheight <- sum(legend$height)
	
	p_c = p_c + theme(legend.position="none")
	p_p = getGpplotOfLandType(allNonGriddedData, 'p', loc, valueToPlot = "value") + theme(legend.position="none")
	p_f = getGpplotOfLandType(allNonGriddedData, 'f', loc, valueToPlot = "value") + theme(legend.position="none")
	p_cr = getGpplotOfLandType(allNonGriddedData, 'c', loc, valueToPlot = "value_rebased_factor") + theme(legend.position="none")
	p_pr = getGpplotOfLandType(allNonGriddedData, 'p', loc, valueToPlot = "value_rebased_factor") + theme(legend.position="none")
	p_fr = getGpplotOfLandType(allNonGriddedData, 'f', loc, valueToPlot = "value_rebased_factor") + theme(legend.position="none")
	
	chart_h = (unit(1.02, "npc") - lheight)*0.5
	
	vp_c <- viewport(just=c("left", "top"), x=0.03, y=0.98, width=.33, height=chart_h)
	vp_p <- viewport(just=c("left", "top"), x=0.35, y=0.98, width=.33, height=chart_h)
	vp_f <- viewport(just=c("left", "top"), x=0.67, y=0.98, width=.33, height=chart_h)
	vp_cr <- viewport(just=c("left", "top"), x=0.03, y=unit(0.99, "npc")-chart_h, width=.33, height=chart_h)
	vp_pr <- viewport(just=c("left", "top"), x=0.35, y=unit(0.99, "npc")-chart_h, width=.33, height=chart_h)
	vp_fr <- viewport(just=c("left", "top"), x=0.67, y=unit(0.99, "npc")-chart_h, width=.33, height=chart_h)
	vp_l <- viewport(just=c("left", "top"), x=0, y=lheight-unit(0.01, "npc"), width=1, height=lheight)
	
	print(p_c, vp=vp_c)
	print(p_p, vp=vp_p)
	print(p_f, vp=vp_f)
	print(p_cr, vp=vp_cr)
	print(p_pr, vp=vp_pr)
	print(p_fr, vp=vp_fr)
	pushViewport(vp_l)
	grid.draw(legend)
	upViewport()
	grid.text(gp=gpar(cex=1.1, font=4), x=unit(.10, "npc"), y=unit(.99, "npc"), just=c("left", "top"), "a) Cropland")
	grid.text(gp=gpar(cex=1.1, font=4), x=unit(.42, "npc"), y=unit(.99, "npc"), just=c("left", "top"), "b) Pasture")
	grid.text(gp=gpar(cex=1.1, font=4), x=unit(.74, "npc"), y=unit(.99, "npc"), just=c("left", "top"), "c) Forest")
	grid.text(gp=gpar(cex=1.1, font=4), x=unit(.02, "npc"), y=unit(.66, "npc"), rot=90, just=c("left", "top"), "i) Area unadjusted (Mha)")
	grid.text(gp=gpar(cex=1.1, font=4), x=unit(.02, "npc"), y=unit(.13, "npc"), rot=90, just=c("left", "top"), "ii) Area scaled to FAO data at 2010 (Mha)")
	
	if (saveToFile) dev.off()
}
plotSummary("EU27")
plotSummary("Global")


# Extract historic data using FAO data
#histG = country_data[, list(location = "Global", c=sum(arable_and_perm)/1000, f=sum(forest)/1000, p=sum(perm_pasture)/1000), by = Year]
# 1992 didn't separate Baltic states, BELF need for Belgium and Lux in 90s
#histE = country_data[Year >= 1993 & CountryCode %in% c('BELF', fread(file.path(data_dir_root, 'eu27.txt'))$alphaCode), list(location = "EU27", c=sum(arable_and_perm)/1000, f=sum(forest)/1000, p=sum(perm_pasture)/1000), by = Year]
#hist = melt(rbind(histG, histE), variable.name = "land_type", value.name = "value", measure.vars=c('c', 'p','f'))
#setnames(hist, "Year", "year")
#hist = hist[!(land_type == 'f' & year < 1990)]
#h2010 = hist[year == 2010, list(land_type, location, v2010=value)]
#hist = merge(hist, h2010, by=c('land_type', 'location'))
#hist = hist[, c('value_rebased', 'v2010') := list(value/v2010, NULL)]
#write.table(hist,file.path(data_dir_root, 'histSummary.csv'), row.names=FALSE)





#dm = allNonGriddedData[year == 2010 & land_type %in% c('c', 'f', 'p', 'u', 'b'), list(sd = sd(value), mn = mean(value), rsd = sd(value)/mean(value)*100), by=list(location, land_type)]
#initialVar = merge(hist[year == 2010, list(location, land_type, value)], dm, by=c('land_type', 'location'), all.y=TRUE)
#initialVar = merge(initialVar, landTypeToName, by='land_type')
#iv = initialVar[, list("Location" = location, "Land Cover Type" = lt_name, "FAO area (Mha)" = format(value, 1), "Mean (Mha)" = mn, "Standard Dev. (Mha)" = sd, "Relative Std Dev. (%)" = rsd)]
#write.table(iv, file.path(data_dir_root, 'initialVar.csv'), sep=",", row.names=FALSE)


require(car)
require(lme4)
require(RColorBrewer)

getTermMap = function() {
	termMap = data.table(varType = c('Initial', rep('Model', 3), rep('Economic', 6), rep('Climate', 2), 'Residual'), 
			term = c('scenDelta', 'model_type', 'modelExtent', 'numCellsLog', 
					'groupedScenario', 'pop_2100', 'gdp_rate_to_2100', 'inequality_2100', 'tech_change', 'trade',
					'co2_2100', 'rcp', 
					'Residual'),
			termName = c('Initial condition', "Model Type", "Model extent", "Model cell number",
					"Mapped economic scenario", "Population", "GDP growth rate", "Inequality", "Technology change", "Global trade",
					"CO2 concentration", "Mapped climate scneario", 
					"Residual"),
			fcolour = c("#0571b0", brewer.pal(4, "Greens")[seq(2,4)], "red", brewer.pal(6, "Reds")[seq(2,6)], "orange", "orange", "#f7f7f7"), 
			groupedScenario = FALSE)
	termMap[term %in% c('groupedScenario', 'rcp'), groupedScenario := TRUE]
	termMap
}

weighted.sd <- function(x, w, na.rm = FALSE) {
	if (na.rm) {
		w <- w[i <- !is.na(x)]
		x <- x[i]
	}
	sum.w <- sum(w)
	sum.w2 <- sum(w^2)
	mean.w <- sum(x * w) / sum(w)
	var <- (sum.w / (sum.w^2 - sum.w2)) * sum(w * (x - mean.w)^2, na.rm = na.rm)
	sqrt(var)
}

decompVariations = function(loc, yr, ltype, formulaString, yearRestriction, useAllParams, useWeights, removeExtremes, anovaType = "II", initialRestriction) {
	
	print(paste("Processing variation for:", loc, yr, ltype))
	formula_all = formula(formulaString)
	
	locAndTypeDt = allNonGriddedData[location == loc & land_type == ltype & (initialRestriction == 0 | initialRestriction >= abs(scenDelta)/median2010)]
	
	if (removeExtremes) {
		maxRange = locAndTypeDt[, list(minR = mean(value)-sd(value)*1.96, maxR = mean(value)+sd(value)*1.96), by=year]
		maxYears = locAndTypeDt[, list(year=max(year)), by=list(model, scenarioId)]
		nonextremeScenarios = merge(merge(maxRange, maxYears, by='year'), locAndTypeDt, by=c('model', 'scenarioId', 'year'))[value <= maxR & value >= minR, list(model, scenarioId)]
		print ("Removing")
		print (merge(merge(maxRange, maxYears, by='year'), locAndTypeDt, by=c('model', 'scenarioId', 'year'))[value > maxR | value < minR, list(model, scenarioId)])
		locAndTypeDt = merge(locAndTypeDt, nonextremeScenarios, by=c('model', 'scenarioId'))
	}
	
	dt = locAndTypeDt[year == yr & model %in% locAndTypeDt[year == yearRestriction]$model]
	
	
	if (useWeights) {
		dt[, weight := 1/length(scenarioId), by=model]
		wghts = dt$weight
	} else wghts = rep(1, length(dt$scenarioId))
	
	
	ret = list()
	ret$dtSummary = dt[, list(location=loc, year=yr, land_type = ltype, mn=weighted.mean(value, wghts), stddev=weighted.sd(value, wghts), coeff_of_var=weighted.sd(value, wghts)/weighted.mean(value, wghts))]
	
	if (yr == 2010) {
		# by definition all variance is initial conditions, get an error if you run rest as R works out it is a perfect fit and doesn't like it
		ret$anovaSummary = data.table(varType=c('Economic', 'Climate', 'Model', 'Residual', 'Initial'), relSS=c(0, 0, 0, 0, 1.0), location=loc, year=yr, land_type = ltype)
		return (ret)
	}
	
	# add specific default type to modelType
	if ('modelType' %in% all.vars(formula_all)) {
		if ('PE' %in% dt$modelType)
			model_type = relevel(factor(dt$modelType), ref="PE")
		else
			model_type = relevel(factor(dt$modelType), ref="CGE")
		formula_all = update(formula_all, .~. - modelType + model_type)
	}
	
	# some data only has 1 extent, i.e. 'Global', which causes an error
	if ('modelExtent' %in% all.vars(formula_all) & length(unique(dt$modelExtent)) <= 1) {
		formula_all = update(formula_all, .~.-modelExtent)
	}
	
	reg_all = lm(formula_all, data=dt, weights=wghts)
	
	# find variables which minimize AIC
	reg_signif = if (useAllParams) reg_all else step(reg_all, direction="backward", trace=0)  

	if (anovaType == "II") {
		# calc type II ANOVA
		retDt = data.table(Anova(reg_signif, type = "II"))
		retDt [, term := c(labels(terms(reg_signif)), "Residual")]
		sumOfSqColName = "Sum Sq"

	} else if (anovaType == "mixed") {
		mixed_formula = update(formula(reg_signif), .~. + (1|model) + (1|economicScenario) + (1|climateScenario))
		mixed_reg_all = lmer(mixed_formula, dt)
		retDt = data.table(Anova(mixed_reg_all, type = "II"))
		retDt [, term := labels(terms(mixed_reg_all))]
		sumOfSqColName = "Chisq"
		
	} else {
		# calc type I ANOVA
		retDt = data.table(summary(aov(reg_signif))[[1]])
		retDt [, term := c(labels(terms(reg_signif)), "Residual")]
		sumOfSqColName = "Sum Sq"
	}
	
	retDt[, relSS := get(sumOfSqColName)/sum(get(sumOfSqColName))]
	
	ret$reg_signif = reg_signif
	ret$anovaSummary = merge(retDt, getTermMap(), by="term", all.y=TRUE)[, list(relSS=sum(relSS,na.rm=TRUE), location=loc, year=yr, land_type = ltype), by=varType]
	ret$anovaTerms = merge(retDt, getTermMap(), by="term")[, list(location=loc, year=yr, land_type = ltype, sum_sq=get(sumOfSqColName), Df, termName, relSS)]
	
	# check with mixed model
	mixed_formula = update(formula(reg_signif), .~. + (1|model) + (1|economicScenario) + (1|climateScenario))
	mixed_reg = lmer(mixed_formula, dt)
	ret$mixedResidual = data.table(as.data.frame(VarCorr(mixed_reg)))[, list(location=loc, year=yr, land_type = ltype, randomTerm=grp, sdcor)] # must be a better way to get this out, but haven't found it
	
	ret
}

getPlotOfFactVariance = function(dtToPlot, yearRestriction) {
	dtToPlot[, varFactor := factor(varType, levels=c('Initial', 'Model', 'Economic', 'Climate', 'Residual'))]
	
	theAes = aes(x = year, y = relSS, fill = varFactor, order = varFactor)
	g = ggplot() + 
			labs(x="Year", y="") + 
			geom_area(data = dtToPlot, theAes, position = 'stack') + 
			scale_fill_manual("Type of variance", values = c("#0571b0", "#92c5de", "#ca0020", "#f4a582", "#f7f7f7")) +  #rev(brewer.pal(5, "RdBu"))) +
			scale_x_continuous(breaks = c(2010, 2040, 2070, 2100), limits=c(2010, if (yearRestriction == 2010) 2100 else yearRestriction)) +
			scale_y_continuous(breaks = seq(0, 1, 0.2)) +
			theme(text = element_text(size=11)) + theme(axis.title.y = element_blank())
	
	if (yearRestriction == 2010)
		g = g + geom_rect(aes(xmin=2050, xmax=2060, ymin=-Inf, ymax=Inf), alpha=0.7, fill="white")
	
	g
}

getPlotOfAllFactVariance = function(dtToPlot, yearRestriction, showExtent = TRUE, show2010 = TRUE) {
	termMap = getTermMap()
	listOfTerms = termMap[(groupedScenario==(('Mapped economic scenario' %in% dtToPlot$termName)  | ("Mapped climate scneario" %in% dtToPlot$termName)) 
					| varType %in% c('Initial', 'Model', 'Residual')) & 
					(showExtent | term!="modelExtent") , termName]
	
	dtToPlot = merge(dtToPlot, 
			CJ(termName=listOfTerms, year=seq(2010, 2100, 10)), 
			by=c('termName', 'year'), all.y=TRUE)
	
	dtToPlot[is.na(relSS), relSS := 0]
	dtToPlot[year == 2010 & termName == "Initial condition", relSS := 1]	# 2010 is fitted perfectly for initial conditions
	dtToPlot[, termFactor := factor(termName, levels=termMap$termName)]
	if (show2010 == FALSE) dtToPlot = dtToPlot[year != 2010]
	
	theAes = aes(x = year, y = relSS, fill = termFactor, order = termFactor)
	g = ggplot() + 
			labs(x="Year", y="") + 
			geom_area(data = dtToPlot, theAes, position = 'stack') + 
			scale_fill_manual(values = termMap[termName %in% listOfTerms, fcolour], guide = guide_legend(nrow = 2)) +
			scale_x_continuous(breaks = c(2010, 2040, 2070, 2100), limits=c(2010, if (yearRestriction == 2010) 2100 else yearRestriction)) +
			scale_y_continuous(breaks = seq(0, 1, 0.2)) +
			theme(text = element_text(size=11)) +
			theme(axis.title.y = element_blank()) +
			theme(legend.position="none") 
	
	if (yearRestriction == 2010)
		g = g + geom_rect(aes(xmin=2050, xmax=2060, ymin=-Inf, ymax=Inf), alpha=0.7, fill="white")
	g
}

getPlotCoeffVariance = function(dtToPlot, yearRestriction) {
	theAes =  aes(x = year, y = coeff_of_var)
	g = ggplot() + 
			labs(x="Year", y="") + 
			geom_point(data = dtToPlot, theAes) + 
			geom_line(data = dtToPlot, theAes) +
			scale_x_continuous(breaks = c(2010, 2040, 2070, 2100), limits=c(2010, if (yearRestriction == 2010) 2100 else yearRestriction)) +
			scale_y_continuous(limits=c(0, 0.375)) +
			theme(text = element_text(size=11)) + theme(axis.title.y = element_blank())
	
	if (yearRestriction == 2010)
		g = g + geom_rect(aes(xmin=2050, xmax=2060, ymin=-Inf, ymax=Inf), alpha=0.7, fill="white")
	
	g
}

getPlotMixedSd = function(dtToPlot, yearRestriction) {
	dtToPlot[, termFactor := factor(c("Climate scenario", "Economic scenario", "Model", "Residual"), levels=c("Model", "Economic scenario", "Climate scenario", "Residual"))]
	
	theAes =  aes(x = year, y = sdcor, colour = termFactor, shape = termFactor, order = termFactor)
	g = ggplot() + 
			labs(x="Year", y="") + 
			scale_colour_manual(values = c("#238B45", "red", "orange", "black")) +  #rev(brewer.pal(5, "RdBu"))) +
			geom_point(data = dtToPlot, theAes) + 
			geom_line(data = dtToPlot, theAes) + 
			theme(text = element_text(size=11)) + theme(legend.text=element_text(size=10)) +
			theme(axis.title.y = element_blank()) + theme(legend.title=element_blank())  + 
			theme(legend.position="bottom") 
	g
}

getVarInfo = function(loc, formulaString, yearRestriction, useAllParams, useWeights, removeExtremes, anovaType = "II", initialRestriction) {
	ret = list()
	allVarDecomps = NULL
	allVarSummary = NULL
	allVarTerms = NULL
	allMixedResidual = NULL
	
	for (yr in seq (2010, 2100, 10))
		for (ltype in c('c', 'p', 'f')) {
			
			tryCatch( {
						decomp = decompVariations(loc, yr, ltype, formulaString, yearRestriction, useAllParams, useWeights, removeExtremes, anovaType, initialRestriction)
						allVarSummary = rbind(allVarSummary, decomp$dtSummary)
						allVarDecomps = rbind(allVarDecomps, decomp$anovaSummary)
						allVarTerms = rbind(allVarTerms, decomp$anovaTerms)
						allMixedResidual = rbind(allMixedResidual, decomp$mixedResidual)
			}, 
			error = function(e) {print(e)})
		}
		
	ret$decomp = allVarDecomps
	ret$summary = allVarSummary
	ret$terms = allVarTerms
	ret$mixed = allMixedResidual
	ret
}

drawLegendPart = function(termNames) {
	termMap = getTermMap()
	legendDummyData = data.table(year=2010, termName=termNames, relSS=0.5)
	legendDummyData[, termFactor := factor(termName, levels=termMap$termName)]
	
	leg = ggplot() + 
			geom_area(data = legendDummyData, aes(x = year, y = relSS, fill = termFactor, order = termFactor)) + 
			scale_fill_manual(values = termMap[termName %in% termNames, fcolour], guide = guide_legend(nrow = 3)) +
			theme(legend.position="bottom") + theme(text = element_text(size=14)) + theme(legend.title=element_blank()) + 
			theme(legend.key = element_rect(size=1)) + theme(legend.key = element_rect(size=0.2, colour="grey"))
	
	g <- ggplotGrob(leg)$grobs
	legend <- g[[which(sapply(g, function(x) x$name) == "guide-box")]]
	lheight <- sum(legend$height)
	grid.draw(legend)
}

plotVariationSummary = function(loc, saveToFile = TRUE, yearRestriction = 2010, useAllParams = FALSE, useWeights = FALSE, removeExtremes = FALSE,
		formulaString = "value ~ scenDelta + modelType + modelExtent + numCellsLog + gdp_rate_to_2100 + co2_2100 + pop_2100 + tech_change + trade + inequality_2100",
		showCoeffPlots = TRUE, fileName = "VarSummary", anovaType = "II", plotMixedResidual=FALSE, initialRestriction=0) {
	
	if (saveToFile) pdf(width=10.5, height=if (showCoeffPlots) 5.9 else 4, file = file.path(data_dir_root, "Output", paste0(loc, fileName, ".pdf")))
	varData = getVarInfo(loc, formulaString, yearRestriction, useAllParams, useWeights, removeExtremes, anovaType, initialRestriction)
		
	showExtent = (loc == "EU27")
	
	if (plotMixedResidual) {
		p_b_l = getPlotMixedSd(varData$mixed[land_type == 'c'], yearRestriction)
		p_b_m = getPlotMixedSd(varData$mixed[land_type == 'p'], yearRestriction) + theme(legend.position="none")
		p_b_r = getPlotMixedSd(varData$mixed[land_type == 'f'], yearRestriction) + theme(legend.position="none")
		yLabelText = "Random effect standard dev."
	} else {
		p_b_l = getPlotOfAllFactVariance(varData$terms[land_type == 'c'], yearRestriction, showExtent = showExtent, show2010 = (initialRestriction==0))
		p_b_m = getPlotOfAllFactVariance(varData$terms[land_type == 'p'], yearRestriction, showExtent = showExtent, show2010 = (initialRestriction==0))
		p_b_r = getPlotOfAllFactVariance(varData$terms[land_type == 'f'], yearRestriction, showExtent = showExtent, show2010 = (initialRestriction==0))
		yLabelText = "Fraction of variance"
	}
		
	lheight = if (showCoeffPlots) unit(0.17, "npc") else unit(0.27, "npc")
		
	if (showCoeffPlots) {
		chart_h_t = (unit(1.03, "npc") - lheight)*0.33
		chart_h_b = (unit(1.03, "npc") - lheight)*0.67
		
		p_t_l = getPlotCoeffVariance(varData$summary[land_type == 'c'], yearRestriction)
		p_t_m = getPlotCoeffVariance(varData$summary[land_type == 'p'], yearRestriction)
		p_t_r = getPlotCoeffVariance(varData$summary[land_type == 'f'], yearRestriction)
		
		vp_t_l <- viewport(just=c("left", "top"), x=0.03, y=0.98, width=.33, height=chart_h_t)
		vp_t_m <- viewport(just=c("left", "top"), x=0.35, y=0.98, width=.33, height=chart_h_t)
		vp_t_r <- viewport(just=c("left", "top"), x=0.67, y=0.98, width=.33, height=chart_h_t)
		
		print(p_t_l, vp=vp_t_l)
		print(p_t_m, vp=vp_t_m)
		print(p_t_r, vp=vp_t_r)
	} else {
		chart_h_t = unit(0.02, "npc")
		chart_h_b = unit(1.03, "npc") - lheight
	}
	
	vp_b_l <- viewport(just=c("left", "top"), x=0.03, y=unit(1, "npc")-chart_h_t, width=.33, height=chart_h_b)
	vp_b_m <- viewport(just=c("left", "top"), x=0.35, y=unit(1, "npc")-chart_h_t, width=.33, height=chart_h_b)
	vp_b_r <- viewport(just=c("left", "top"), x=0.67, y=unit(1, "npc")-chart_h_t, width=.33, height=chart_h_b)
	
	if (plotMixedResidual) {
		g <- ggplotGrob(p_b_l + theme(legend.position="bottom", text = element_text(size=14)))$grobs
		legend <- g[[which(sapply(g, function(x) x$name) == "guide-box")]]
		# add legend viewport
		pushViewport(viewport(just=c("left", "top"), x=0, y=lheight-unit(0.01, "npc"), width=1, height=lheight))
		grid.draw(legend)
		upViewport()
		p_b_l = p_b_l + theme(legend.position="none")
	} else { # Manually draw legend, so we have complete control
		pushViewport(viewport(just=c("left", "top"), x=0.07, y=lheight-unit(0.01, "npc"), width=0.15, height=lheight))
		drawLegendPart(c("Initial condition"))
		upViewport()
		
		pushViewport(viewport(just=c("left", "top"), x=0.26, y=lheight-unit(0.01, "npc"), width=0.15, height=lheight))
		termMap = getTermMap()
		drawLegendPart(termMap[varType == "Model" & (showExtent | term!="modelExtent"), termName])
		upViewport()
		
		pushViewport(viewport(just=c("left", "top"), x=0.44, y=lheight-unit(0.01, "npc"), width=0.15, height=lheight))
		drawLegendPart(c("Population", "GDP growth rate", "Inequality"))
		upViewport()
		
		pushViewport(viewport(just=c("left", "top"), x=0.64, y=lheight-unit(0.01, "npc"), width=0.15, height=lheight))
		drawLegendPart(c("Technology change", "Global trade", "CO2 concentration"))
		upViewport()
		
		pushViewport(viewport(just=c("left", "top"), x=0.80, y=lheight-unit(0.01, "npc"), width=0.15, height=lheight))
		drawLegendPart(c("Residual"))
		upViewport()
	}

	print(p_b_l, vp=vp_b_l)
	print(p_b_m, vp=vp_b_m)
	print(p_b_r, vp=vp_b_r)
	grid.text(gp=gpar(cex=1, font=4), x=unit(.10, "npc"), y=unit(.99, "npc"), just=c("left", "top"), "a) Cropland")
	grid.text(gp=gpar(cex=1, font=4), x=unit(.42, "npc"), y=unit(.99, "npc"), just=c("left", "top"), "b) Pasture")
	grid.text(gp=gpar(cex=1, font=4), x=unit(.74, "npc"), y=unit(.99, "npc"), just=c("left", "top"), "c) Forest")
	
	if (showCoeffPlots) {
		grid.text(gp=gpar(cex=1, font=4), x=unit(.02, "npc"), y=unit(.66, "npc"), rot=90, just=c("left", "top"), "i) Coefficient of variation")
		grid.text(gp=gpar(cex=1, font=4), x=unit(.02, "npc"), y=unit(.23, "npc"), rot=90, just=c("left", "top"), paste("ii) ", yLabelText))
	} else {
		grid.text(gp=gpar(cex=1, font=4), x=unit(.02, "npc"), y=unit(.55, "npc"), rot=90, just=c("centre", "top"), yLabelText)
	}
	
	if (saveToFile) dev.off()
}

plotInitialRestriction = function(loc, saveToFile = TRUE, yearRestriction=2010,
		formulaString = "value ~ scenDelta + modelType + modelExtent + numCellsLog + gdp_rate_to_2100 + co2_2100 + pop_2100 + tech_change + trade + inequality_2100", fileName) {
	
	if (saveToFile) pdf(width=10.5, height=7.5, file = file.path(data_dir_root, "Output", paste0(loc, fileName, ".pdf")))
	
	varData4pc = getVarInfo(loc, formulaString, yearRestriction=yearRestriction, useAllParams = FALSE, useWeights = FALSE, removeExtremes = FALSE, anovaType = "II", initialRestriction=0.04)
	varData8pc = getVarInfo(loc, formulaString, yearRestriction=yearRestriction, useAllParams = FALSE, useWeights = FALSE, removeExtremes = FALSE, anovaType = "II", initialRestriction=0.08)
	showExtent = (loc == "EU27")
	
	p_4_l = getPlotOfAllFactVariance(varData4pc$terms[land_type == 'c'], yearRestriction, showExtent = showExtent, show2010 = FALSE)
	p_4_m = getPlotOfAllFactVariance(varData4pc$terms[land_type == 'p'], yearRestriction, showExtent = showExtent, show2010 = FALSE)
	p_4_r = getPlotOfAllFactVariance(varData4pc$terms[land_type == 'f'], yearRestriction, showExtent = showExtent, show2010 = FALSE)
	p_8_l = getPlotOfAllFactVariance(varData8pc$terms[land_type == 'c'], yearRestriction, showExtent = showExtent, show2010 = FALSE)
	p_8_m = getPlotOfAllFactVariance(varData8pc$terms[land_type == 'p'], yearRestriction, showExtent = showExtent, show2010 = FALSE)
	p_8_r = getPlotOfAllFactVariance(varData8pc$terms[land_type == 'f'], yearRestriction, showExtent = showExtent, show2010 = FALSE)
	
	lheight = unit(0.17, "npc")
	chart_h_b = unit(0.43, "npc")
	
	# Manually draw legend
	pushViewport(viewport(just=c("left", "top"), x=0.07, y=lheight-unit(0.01, "npc"), width=0.15, height=lheight))
	drawLegendPart(c("Initial condition"))
	upViewport()
		
	pushViewport(viewport(just=c("left", "top"), x=0.26, y=lheight-unit(0.01, "npc"), width=0.15, height=lheight))
	termMap = getTermMap()
	drawLegendPart(termMap[varType == "Model" & (showExtent | term!="modelExtent"), termName])
	upViewport()
		
	pushViewport(viewport(just=c("left", "top"), x=0.44, y=lheight-unit(0.01, "npc"), width=0.15, height=lheight))
	drawLegendPart(c("Population", "GDP growth rate", "Inequality"))
	upViewport()
		
	pushViewport(viewport(just=c("left", "top"), x=0.64, y=lheight-unit(0.01, "npc"), width=0.15, height=lheight))
	drawLegendPart(c("Technology change", "Global trade", "CO2 concentration"))
	upViewport()
		
	pushViewport(viewport(just=c("left", "top"), x=0.80, y=lheight-unit(0.01, "npc"), width=0.15, height=lheight))
	drawLegendPart(c("Residual"))
	upViewport()
	
	print(p_4_l, vp=viewport(just=c("left", "top"), x=0.06, y=unit(0.98, "npc"), width=.33, height=chart_h_b))
	print(p_4_m, vp=viewport(just=c("left", "top"), x=0.37, y=unit(0.98, "npc"), width=.33, height=chart_h_b))
	print(p_4_m, vp=viewport(just=c("left", "top"), x=0.68, y=unit(0.98, "npc"), width=.33, height=chart_h_b))
	print(p_8_l, vp=viewport(just=c("left", "top"), x=0.06, y=unit(0.57, "npc"), width=.33, height=chart_h_b))
	print(p_8_m, vp=viewport(just=c("left", "top"), x=0.37, y=unit(0.57, "npc"), width=.33, height=chart_h_b))
	print(p_8_r, vp=viewport(just=c("left", "top"), x=0.68, y=unit(0.57, "npc"), width=.33, height=chart_h_b))
	grid.text(gp=gpar(cex=1, font=4), x=unit(.10, "npc"), y=unit(.99, "npc"), just=c("left", "top"), "a) Cropland")
	grid.text(gp=gpar(cex=1, font=4), x=unit(.42, "npc"), y=unit(.99, "npc"), just=c("left", "top"), "b) Pasture")
	grid.text(gp=gpar(cex=1, font=4), x=unit(.74, "npc"), y=unit(.99, "npc"), just=c("left", "top"), "c) Forest")
	
	grid.text(gp=gpar(cex=1, font=4), x=unit(.02, "npc"), y=unit(.80, "npc"), rot=90, just=c("centre", "top"), "i) 2010 within 4% of median")
	grid.text(gp=gpar(cex=1, font=4), x=unit(.02, "npc"), y=unit(.36, "npc"), rot=90, just=c("centre", "top"), "ii) 2010 within 8% of median")
	grid.text(gp=gpar(cex=1, font=1), x=unit(.06, "npc"), y=unit(.55, "npc"), rot=90, just=c("centre", "top"), "Fraction of variance")
	
	if (saveToFile) dev.off()
}

for (loc in c('Global', 'EU27')) {
	plotVariationSummary(loc, fileName = "VarSig")
	plotVariationSummary(loc, fileName = "MixedRandomSd", showCoeffPlots = FALSE, plotMixedResidual=TRUE)
	plotVariationSummary(loc, useWeights=TRUE, fileName = "VarWeightedSig")
	plotVariationSummary(loc, removeExtremes=TRUE, fileName = "VarExtremesRemovedSig")
	plotVariationSummary(loc, yearRestriction = 2100, fileName = "Var2100Sig")
	plotVariationSummary(loc, formulaString = "value ~ scenDelta + modelType + modelExtent + numCellsLog + groupedScenario", fileName = "VarGroupScenario", showCoeffPlots = FALSE)
	plotInitialRestriction(loc, fileName = "VarInitialRestrict")
	#	plotVariationSummary(loc, showCoeffPlots = FALSE, formulaString = "value ~ groupedScenario + rcp + modelType + numCellsLog + modelExtent + scenDelta", fileName = "VarGroupedSig")

	for (ltype in c('c', 'p', 'f')) {
		print(paste(loc, ltype))
		for (intRes in c(0.04, 0.08)) {
			print(paste("   ", length(allNonGriddedData[location == loc & land_type == ltype & intRes >= abs(scenDelta)/median2010 & year == 2010]$scenarioId)))
		}
	}
}


#allNonGriddedData[land_type=='c' & year == 2010 & location == "Global", list(mean(value), 1.98 * sd(value))]

#ggplot(allNonGriddedData[year == 2050 & location == "Global" & land_type == 'p'], aes(x= modelType, y=value)) + geom_boxplot()