require(randtoolbox)
require(plyr)
require(ggplot2)
require(reshape2)
require(data.table)

findBetaParams = function(xmode, x95=NA, x05=NA) {
	calibBeta = function(a) {
		if (xmode > 0.5) { x95 - qbeta(p = 0.95, shape1 = a, shape2 = (a-1)/xmode - a + 2)
		} else { x05 - qbeta(p = 0.05, shape1 = a, shape2 = (a-1)/xmode - a + 2) }
	}
	
	if (xmode > 0.5 & is.na(x95)) { print ("Need x95 if mode greater than 0.5") 
	} else if (xmode <= 0.5 & is.na(x05)) { print ("Need x05 if mode less than or equal to 0.5")
	} else  {
		a = uniroot(calibBeta, c(1, 100))$root  # min a for positive b is (2*xmode-1)/(xmode-1))
		data.table(a = a, b = (a-1)/xmode - a + 2)
	}
}
#params=findBetaParams(xmode = 0.4, x05 = 0.2)
#xmin=1
#xmax=5
#xmode=4
#x95=4.5
#params=findBetaParams(xmode = (xmode-xmin)/(xmax-xmin), x95 = (x95-xmin)/(xmax-xmin), x05 = (x05-xmin)/(xmax-xmin))
#d = data.table(x=seq(0, 1, length=100))
#d[, y:=dbeta(x, params$a, params$b)]
#ggplot(d, aes(x=x, y=y)) + geom_line()

rcpProbs=data.table(ssp=paste0("ssp", 1:5), 
		rcp26=c(0.0909,0,0,0,0), 
		rcp45=c(0.4545, 0.0909, 0.1667, 0.3704, 0.0741), 
		rcp60 = c(0.4545, 0.6818, 0.5, 0.5556, 0.3704),
		rcp85=c(0, 0.2273, 0.3333, 0.0741, 0.5556))

generateMCSample <- function(n, vals, ensem) {
	# Generate a Sobol' sequence
	sob <- sobol(n, nrow(vals))
	
	# Fill a matrix with the values
	samp <- matrix(rep(0,n*(nrow(vals)+2)), nrow=n)
	samp[,1] <- rep(ensem, n)
	samp[,2] <- paste0('s', 1:n)
	
	# inverted from uniform values to distributions of choice
	for (i in 1:nrow(vals)) {
		l <- vals[i]
		dist <- l$dist
		print(paste(" .. calculating", l$pname))
		
		if (dist == "unif_int") {
			s = round(qunif(sob[,i],l$xmin,l$xmax))
		} else if (dist == "unif") {
			s = qunif(sob[,i],l$xmin,l$xmax)
		} else if (dist == "beta") {
			# calc beta parameters
			bp = findBetaParams(xmode = (l$xmode-l$xmin)/(l$xmax-l$xmin), x05 = (l$x05-l$xmin)/(l$xmax-l$xmin), x95 = (l$x95-l$xmin)/(l$xmax-l$xmin))
			# use then to get quantiles
			s = qbeta(sob[,i], bp$a, bp$b)
			s <- s * (l$xmax-l$xmin) + l$xmin
		} else if (dist == "value") {
			s = rep(l$value, length(sob[,i]))
		} else if (dist %in% c("rcp")) {
			rcpCs = melt(rcpProbs[ssp==l$value], id='ssp')
			rcpCs[, maxq := cumsum(value)]
			rcpCs[, minq := rcpCs[, c(0, maxq[c(1,2,3)])]]
			s = sapply(sob[,i], function(v) {rcpCs[maxq>v & minq<=v, variable]}) # look up rcp from probablity
			s = as.character(s)
		} else {
			print(paste("Potentially unexpected distrubtion:", dist))
			s = eval(call(paste("q",dist,sep=""),sob[,i],l$mn,l$sd))
		}
		
		samp[,i+2] <- s
	}
	
	samp <- data.table(samp)
	names(samp) <- c("Ensemble", "Scenario",vals$pname)
	return(samp)
}
#paramDt = data.table(scenario="hind", pname="PASTURE_INCREASE_COST", dist="unif", xmin=2, xmax=6)
#paramDt = rbind(paramDt, data.table(scenario="hind", pname="LAND_CHANGE_COST", dist="beta", xmin=2, xmax=7, xmode=5, x95=6, x05=NA), fill=TRUE)
#paramDt = rbind(paramDt, data.table(scenario="hind", pname="NORMAL_WORKS_TOO", dist="norm", mn=5, sd=2), fill=TRUE)
#write.table(paramDt, file.path(baseSimDir, "hindparms.csv"),sep=",",row.names=FALSE,quote=FALSE)

baseSimDir="C:\\Users\\rhenry2\\workspace\\PLUM_src\\plumv2\\plumv2\\data\\sims"

generateScenarios = function(inputFile, outputFile, numScen, drawPlot=FALSE, ensemblePrefix="") {
	paramDt = fread(file.path(baseSimDir, inputFile))
	
	for (ensemble in unique(paramDt$Ensemble)) {
		# Generate the sample
		ensWithPrefix = paste0(ensemblePrefix, ensemble)
		print (paste("Generating ensemble", ensWithPrefix))
		sampEns <- generateMCSample(numScen, paramDt[Ensemble == ensemble], ensWithPrefix)
		if (exists('samp')) {
			samp = rbind (samp, sampEns)
		} else {
			samp = sampEns
		}
	}
	
	# Based on RCP (which needs to be defined), so that they are consistent
	if ("YIELD_DIR_TOP" %in% names(samp) & "RCP" %in% names(samp)) {
		yield_top = samp[ , RCP]
		#yield_top= revalue(yield_top, c("rcp26"="runs_2018032/LPJGPLUM_expt1.1_2006-2100_PLUM6xtra_rcp26_forED_20180406134705"))
		#yield_top= revalue(yield_top, c("rcp45"="runs_2018032/LPJGPLUM_expt1.1_2006-2100_PLUM6xtra_rcp45_forED_20180326154749"))
		#yield_top= revalue(yield_top, c("rcp60"="runs_2018032/LPJGPLUM_expt1.1_2006-2100_PLUM6xtra_rcp60_forED_20180326154807"))
		#yield_top= revalue(yield_top, c("rcp85"="runs_2018032/LPJGPLUM_expt1.1_2006-2100_PLUM6xtra_rcp85_forED_20180326154824"))
		samp = cbind(samp[, YIELD_DIR_TOP := NULL], YIELD_DIR_TOP=yield_top)
	}
	
	if ("BIOENERGY_DEMAND_SCENARIO" %in% names(samp)) {
		ssp_rcp = toupper(samp[, paste0(BIOENERGY_DEMAND_SCENARIO, "_", RCP)]) # for ssp_rcp we do two parameters
		samp = cbind(samp[, BIOENERGY_DEMAND_SCENARIO := NULL], BIOENERGY_DEMAND_SCENARIO=ssp_rcp)
	}
	
	if("SHOCKS_POSSIBLE" %in% names(samp)){
		
		samp[,c('CEREALS_SUB_PROPORTION','PULSES_SUB_PROPORTION','OILCROPS_SUB_PROPORTION','STARCHY_ROOTS_SUB_PROPORTION') := 
						list(as.numeric(CEREALS_SUB_PROPORTION)/(as.numeric(CEREALS_SUB_PROPORTION) + as.numeric(PULSES_SUB_PROPORTION)+ 
						as.numeric(OILCROPS_SUB_PROPORTION) + as.numeric(STARCHY_ROOTS_SUB_PROPORTION)), 
							 as.numeric(PULSES_SUB_PROPORTION)/(as.numeric(CEREALS_SUB_PROPORTION) + as.numeric(PULSES_SUB_PROPORTION)+ 
						as.numeric(OILCROPS_SUB_PROPORTION) + as.numeric(STARCHY_ROOTS_SUB_PROPORTION)),
							 as.numeric(OILCROPS_SUB_PROPORTION)/(as.numeric(CEREALS_SUB_PROPORTION) + as.numeric(PULSES_SUB_PROPORTION)+ 
						as.numeric(OILCROPS_SUB_PROPORTION) + as.numeric(STARCHY_ROOTS_SUB_PROPORTION)),
							as.numeric(STARCHY_ROOTS_SUB_PROPORTION)/(as.numeric(CEREALS_SUB_PROPORTION) + as.numeric(PULSES_SUB_PROPORTION)+ 
						as.numeric(OILCROPS_SUB_PROPORTION) + as.numeric(STARCHY_ROOTS_SUB_PROPORTION)))]
	}
	
	
	write.table(samp, file.path(baseSimDir, outputFile),sep=",",row.names=FALSE,quote=FALSE)
	
	if (drawPlot) {
		samp.mt <- melt(samp[Ensemble=="ssp3/SSP1"],id=c("Scenario", "Ensemble"))[variable %in% c('MIN_NATURAL_RATE', 'AGRI_LAND_EXPANSION_COST_FACTOR', 'TRADE_BARRIER_ADJ', 'BIOENERGY_DEMAND_SHIFT', 'CROP_TO_PASTURE_COST_FACTOR', 'FERTILISER_COST_PER_T', 'INITIAL_PRICE_SHIFT', 'SSP_POPULATION_FACTOR', 'OTHER_INTENSITY_COST', 'MARKET_LAMBA')]
		ggplot(samp.mt[!variable %in% c('YIELD_DIR_TOP', 'SSP_SCENARIO'), list(Scenario, Ensemble, variable, value=as.numeric(value))], aes(x=value)) +
				geom_histogram(binwidth=0.05) + # really need to set based on the range
				facet_wrap(~variable, ncol=3,scale="free")
	}
}

generateScenarios("ssp_params.csv", "ssp_sims11.csv", 50, ensemblePrefix="ssp11/")
generateScenarios("rcp_params_climate.csv", "rcp_sims_climate_ns.csv", 5, ensemblePrefix="climateShocks/")
generateScenarios("hind_params_ha.csv", "hind_sims_ha.csv", 50)

generateScenarios("shocks_params_ssp2.csv", "baseline.csv", 5, ensemblePrefix="shocks/baseline/SSP2")

generateScenarios("shocks_params_ssp2.csv", "demandSystem.csv", 5, ensemblePrefix="demandSystem/baseline/")

generateScenarios("prot_params.csv", "protectionismLevels.csv", 5, ensemblePrefix="protectionismLevels/")

generateScenarios("prot_params.csv", "protectionismLevels.csv", 5, ensemblePrefix="protectionismLevels/")
