require(raster)
require(data.table)
require(gridExtra)
require(ggplot2)
require(reshape2)
require(maptools)
require(grid)
require(rgdal)

data(wrld_simpl)

# Read PLUM results
# resultFiles = list.files("/Users/peteralexander/Documents/R_Workspace/UNPLUM/output", pattern='(pastureArea|croplandArea)(2010|2050|2100)+.asc', full.names=TRUE)
# resultsStack <- stack() 
# for (aFile in resultFiles) {
# 	resultsStack = stack (resultsStack, raster(aFile))
# }
# crs(resultsStack) <- '+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs'
# plot(subset(resultsStack, c('croplandArea2010', 'croplandArea2100', 'pastureArea2010', 'pastureArea2100')))

baseOutputDir="/Users/peteralexander/Documents/R_Workspace/UNPLUM/output"
baseHurttDir="/Users/peteralexander/Documents/R_Workspace/UNPLUM"
baseFigDir="/Users/peteralexander/Documents/LURG/PLUM/offline paper/figures"
#baseOutputDir="/exports/csce/eddie/geos/groups/LURG/models/PLUM/output"
#baseHurttDir="/exports/csce/eddie/geos/groups/LURG/models/PLUM/plumv2"
#baseFigDir="/exports/csce/eddie/geos/groups/LURG/models/PLUM/figures"

newi = raster("~/Documents/R_Workspace/UNPLUM/hind1970/output/irrig_constraint_1970.asc")
oldi = rasterFromFile("Max_irr_water", "~/Documents/R_Workspace/UNPLUM/hind1970/data/halfdeg/blue_water_available_pseudoCRU_rcp8p5_2004_2013_grid_allhdyro_mm.txt")
oldi[oldi> 1000] <-1000


getCropYieldRes = function (luDt, lcType, offset=0.0) {
	cropRateForType = rasterFromXYZ(luDt[, list(Lon-offset, Lat-offset, get(paste0(lcType, '_A'))*cropland/area)],
			crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
	yieldForType = rasterFromXYZ(luDt[, list(Lon-offset, Lat-offset, get(paste0(lcType, '_Y')))],
			crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
	
	yieldForType * (cropRateForType>0.05)
}

plumRes = function(lcType, year, simId='', outBase = baseOutputDir, offset=0.0) {
	if (lcType %in% c("Fert", "Irrig", "Yield")) {
		fileName = file.path(outBase, simId, year, "LandUse.txt")
		luDt = data.table(read.table(fileName, header=TRUE))
		
		if (lcType == "Fert") {
			rasterFromXYZ(luDt[, list(Lon-offset, Lat-offset, 
					(oilcrops_A*oilcrops_FQ + starchyRoots_A*starchyRoots_FQ + pulses_A*pulses_FQ + wheat_A*wheat_FQ + rice_A*rice_FQ + maize_A*maize_FQ + energycrops_A*energycrops_FQ)*cropland/area)], 
				crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
		} else if (lcType == "Irrig") {
			rasterFromXYZ(luDt[, list(Lon-offset, Lat-offset, 
					(oilcrops_A*oilcrops_IQ + starchyRoots_A*starchyRoots_IQ + pulses_A*pulses_IQ + wheat_A*wheat_IQ + rice_A*rice_IQ + maize_A*maize_IQ + energycrops_A*energycrops_IQ)*cropland/area)], 
				crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
		} else {
			rasterFromXYZ(luDt[, list(Lon-offset, Lat-offset, 
					(oilcrops_A*oilcrops_Y + starchyRoots_A*starchyRoots_Y + pulses_A*pulses_Y + wheat_A*wheat_Y + rice_A*rice_Y + maize_A*maize_Y + energycrops_A*energycrops_Y))], 
				crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
		}
	} else if (lcType == "IrrigConstraint") { 
		fileName = file.path(outBase, simId, year, "IrrigConstraint.asc")
		raster(fileName)
	} else { 
		fileName = file.path(outBase, simId, year, "LandCoverFract.txt")
		rasterFromFile(lcType, fileName, offset=offset)
	}
}


hurttRaster = function(lcType, year, offset=0.0) {
	if (year == 1970) {
		fileName = file.path(baseHurttDir, "hind1970/data/halfdeg/hurtt_1970.txt")
	} else if (year == 1990) {
		fileName = file.path(baseHurttDir, "hindcast/data/halfdeg/hurtt_1990.txt")
	} else if (year == 2000) {
		fileName = file.path(baseHurttDir, "/data/halfdeg/hurtt_2000.txt") 
	} else if (year == 2010) {
		fileName = file.path(baseHurttDir, "/data/halfdeg/hurtt_2010.txt")
	}
	rasterFromFile(lcType, fileName, offset)
}

shpFile = crop(readShapePoly("~/Documents/LURG/Data/NaturalEarthShapefile/ne_110m_admin_0_countries_lakes.shp", proj4string=CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")), extent(-180,180, -55, 90))
plotBorder = function() {
	plot(shpFile, add = TRUE, border=rgb(r=0.1, g=0.1, b=0.1, alpha=.6), lwd=0.1)
}

plotDiff = function(r1, r2, legend=FALSE, legend.lab="", fileName=NA) {
	if (!is.na(fileName)) {
		pdf(width=8, height=3, file = file.path(baseFigDir, paste0(fileName, ".pdf")))
		par(mar=c(0.5,0.5,0.5,1))
	}
	e = intersect(extent(r1), extent(r2))
#	plot(crop(r2, e)-crop(r1, e), col = c("#E10000", "#E44B4B", "#E49B9B", "#DFDFDF", "#8E8EDB", "#4D4DDB", "#0000DC"), 
#			breaks=c(-1, -.7, -.4, -.1, 0.1, 0.4, 0.7, 1), legend=legend, axes=FALSE, box=FALSE, legend.lab=legend.lab)
	plot(crop(r2, e)-crop(r1, e), col = c("#E10000", "#E27070", "#DFDFDF", "#6C6CDE", "#0000DC"), 
			breaks=c(-1, -.6, -.2, 0.2, 0.6, 1), legend=legend, axes=FALSE, box=FALSE, legend.lab=legend.lab)
	
	plotBorder()
	if (!is.na(fileName)) dev.off()
}

plotAbsoulte = function (lctype, hindDir='../hind1970/output', startYr=1970, endYr=2010) {
	pdf(width=12, height=5.5, file = file.path(baseFigDir, paste0("hind", lctype, startYr, "-", endYr, ".pdf")))
	par(oma=c(0,0.5,0,2))
	layout(matrix(c(1,2,3,4), 2, 2, byrow = TRUE))
	par(mar=c(0.5,0.5,0.5,1))
	plot(plumRes(lctype, startYr, hindDir), axes=FALSE, box=FALSE)
	plot(plumRes(lctype, endYr, hindDir), axes=FALSE, box=FALSE)
	
	plot(hurttRaster(lctype, startYr), axes=FALSE, box=FALSE)
	plot(hurttRaster(lctype, 2010), axes=FALSE, box=FALSE)
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.03, "npc"), y=unit(.97, "npc"), just=c("left", "top"), paste("a) PLUM", startYr))
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.51, "npc"), y=unit(.97, "npc"), just=c("left", "top"), paste("b) PLUM", endYr))
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.03, "npc"), y=unit(.48, "npc"), just=c("left", "top"), paste("c) LUH2", startYr))
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.51, "npc"), y=unit(.48, "npc"), just=c("left", "top"), paste("c) LUH2", endYr))
	dev.off()
}

plotAbsoulteChanges = function (lctype, hindDir='../hindcast/output', startYr=1990, endYr=2010) {
	pdf(width=8, height=8, file = file.path(baseFigDir, paste0("hindabs", lctype, startYr, "-", endYr, ".pdf")))
	par(oma=c(0,0.5,0,2))
	layout(matrix(c(1,2), 2, 1, byrow = TRUE))
	par(mar=c(0.5,0.5,0.5,1))
	plotDiff(plumRes(lctype, startYr, hindDir), plumRes(lctype, endYr, hindDir), legend.lab="Change fraction")
	plotDiff(hurttRaster(lctype, startYr), hurttRaster(lctype, endYr), legend.lab="Change fraction", legend=TRUE)
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.03, "npc"), y=unit(.97, "npc"), just=c("left", "top"), paste("i) PLUM", startYr, "-", endYr, "change"))
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.03, "npc"), y=unit(.48, "npc"), just=c("left", "top"), paste("ii) LUH2", startYr, "-", endYr, "change"))
	dev.off()
}
#plotAbsoulteChanges("CROPLAND", hindDir='../hind1970/output', startYr=1970, endYr=2010)
plotAbsoulteChanges("CROPLAND", hindDir='hind1970/ha7', startYr=1970, endYr=2010)
plotAbsoulteChanges("PASTURE", hindDir='hind1970/ha7', startYr=1970, endYr=2010)
plotAbsoulte("CROPLAND", hindDir='hind1970/ha7', startYr=1970, endYr=2010)
plotAbsoulte("PASTURE", hindDir='hind1970/ha7', startYr=1970, endYr=2010)
plot(plumRes("PASTURE", 1976, 'hind1970/ha11/calib' ) - hurttRaster("PASTURE", 1970))


plotPastureCropComp = function (hindDir='../hind1970/output', aYear=2010) {
	pdf(width=12, height=5.5, file = file.path(baseFigDir, paste0("crop_past_", aYear, ".pdf")))
	par(oma=c(0,0.5,0,2))
	layout(matrix(c(1,2,3,4), 2, 2, byrow = TRUE))
	par(mar=c(0.5,0.5,0.5,1))
	plot(plumRes("CROPLAND", aYear, hindDir), axes=FALSE, box=FALSE, legend=FALSE)
	plot(plumRes("PASTURE", aYear, hindDir), axes=FALSE, box=FALSE, legend=FALSE)
	
	plot(hurttRaster("CROPLAND", aYear), axes=FALSE, box=FALSE, legend=FALSE)
	plot(hurttRaster("PASTURE", aYear), axes=FALSE, box=FALSE, legend=TRUE)
	grid.text(gp=gpar(cex=1, font=4), x=unit(.03, "npc"), y=unit(.97, "npc"), just=c("left", "top"), paste("a) PLUMv2 cropland", aYear))
	grid.text(gp=gpar(cex=1, font=4), x=unit(.51, "npc"), y=unit(.97, "npc"), just=c("left", "top"), paste("b) PLUMv2 pasture", aYear))
	grid.text(gp=gpar(cex=1, font=4), x=unit(.03, "npc"), y=unit(.48, "npc"), just=c("left", "top"), paste("c) LUH2 cropland", aYear))
	grid.text(gp=gpar(cex=1, font=4), x=unit(.51, "npc"), y=unit(.48, "npc"), just=c("left", "top"), paste("d) LUH2 pasture", aYear))
	dev.off()
}

plotPastureCropComp()

plotHindComp = function (lctype, hindDir='../hind1970/output', startYr=1970, endYr=2010) {
	pdf(width=12, height=5.5, file = file.path(baseFigDir, paste0("hindcomp", lctype, startYr, "-", endYr, ".pdf")))
	par(oma=c(0,0.5,0,2))
	layout(matrix(c(1,2,3,4), 2, 2, byrow = TRUE))
	par(mar=c(0.5,0.5,0.5,1))
	
	plot(plumRes(lctype, endYr, hindDir), legend=FALSE, axes=FALSE, box=FALSE)
	plotBorder()
	plot(hurttRaster(lctype, endYr), legend=TRUE, axes=FALSE, box=FALSE, legend.lab="Cover fraction")
	plotBorder()
	plotDiff(plumRes(lctype, endYr, hindDir)-plumRes(lctype, startYr, hindDir), hurttRaster(lctype, endYr)-hurttRaster(lctype, startYr), legend=(lctype=="PASTURE"), legend.lab="Change fraction")
	
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.03, "npc"), y=unit(.97, "npc"), just=c("left", "top"), paste("a)", endYr, "PLUM hindcast with", startYr, "baseline"))
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.51, "npc"), y=unit(.97, "npc"), just=c("left", "top"), paste("b) LUH2", endYr))
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.03, "npc"), y=unit(.48, "npc"), just=c("left", "top"), paste("c) PLUM to LUH2", startYr, "-", endYr, "change difference"))

	if (lctype=="CROPLAND") {
		plotDiff(rasterFromFile('farea', "~/Documents/LURG/Data/SAGE/sage.txt"), hurttRaster(lctype, 2000), legend=TRUE, legend.lab="Change fraction")
		grid.text(gp=gpar(cex=0.7, font=4), x=unit(.51, "npc"), y=unit(.48, "npc"), just=c("left", "top"), "d) SAGE to LUH2 difference at 2000")
	}
	dev.off()
}
plotHindComp('CROPLAND')
plotHindComp('PASTURE')
plotHindComp('CROPLAND', hindDir='../hind1970/output', startYr=1970, endYr=2010)



plotScenarioAll = function(ensemble, scenarioId, startYr=2010, endYr=2100) {
	pdf(width=12, height=5.5, file = file.path(baseFigDir, paste0("scn_", startYr, "-", endYr, "-", ensemble, "_", scenarioId, ".pdf")))
	scenDir=file.path(ensemble, scenarioId)
	par(oma=c(0,0.5,0,2))
	layout(matrix(c(1,2,3,4), 2, 2, byrow = TRUE))
	par(mar=c(0.5,0.5,0.5,1))
	plot(plumRes("CROPLAND", startYr, scenDir), axes=FALSE, box=FALSE)
	plot(plumRes("CROPLAND", endYr, scenDir), axes=FALSE, box=FALSE)
	plot(plumRes("PASTURE", startYr, scenDir), axes=FALSE, box=FALSE)
	plot(plumRes("PASTURE", endYr, scenDir), axes=FALSE, box=FALSE)
	
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.03, "npc"), y=unit(.97, "npc"), just=c("left", "top"), paste("a) Cropland", startYr))
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.51, "npc"), y=unit(.97, "npc"), just=c("left", "top"), paste("b) Cropland", endYr))
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.03, "npc"), y=unit(.48, "npc"), just=c("left", "top"), paste("c) Pasture", startYr))
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.51, "npc"), y=unit(.48, "npc"), just=c("left", "top"), paste("d) Pasture", endYr))
	dev.off()
}
plotScenarioAll('SSP1', 's1')




randomBits_DontRun = function() {
	r = plumRes("CROPLAND", 2010, '../hindcast/output')
	png(file = file.path(baseFigDir, paste0("hindcomp", "Test", ".png")), width=1200, res=120, pointsize=16)
	r2 = disaggregate(r,fact=3)
	plot(r2, legend=TRUE, axes=FALSE, box=FALSE)
	grid.text(gp=gpar(cex=0.7, font=4), x=unit(.03, "npc"), y=unit(.97, "npc"), just=c("left", "top"), "a) 2010 PLUM hindcast")
	plotBorder()
	dev.off()
	
# Comparison between hurtt and results
#colorRampPalette(c("red", "white", "blue"))(7)
	 v - (crop (initialCrop, extent(plumRes('CROPLAND', 2010)))), col = c("#FF0000", "#FF5555", "#FFAAAA", "#FFFFFF", "#FFFFFF", "#AAAAFF", "#5555FF", "#0000FF"), breaks=c(-1, -.5, -.2, -.1, 0, 0.1, 0.2, 0.5, 1))
	plot(plumRes('PASTURE', 2010) - (crop (initialPasture, extent(plumRes('PASTURE', 2010)))), col = c("#FF0000", "#FF5555", "#FFAAAA", "#FFFFFF", "#FFFFFF", "#AAAAFF", "#5555FF", "#0000FF"), breaks=c(-1, -.5, -.2, -.1, 0, 0.1, 0.2, 0.5, 1))
	plot(plumRes('PASTURE', 2100) - plumRes('PASTURE', 2010), col = c("#FF0000", "#FF5555", "#FFAAAA", "#FFFFFF", "#FFFFFF", "#AAAAFF", "#5555FF", "#0000FF"), breaks=c(-1, -.5, -.2, -.1, 0, 0.1, 0.2, 0.5, 1))
	
	
	c2010 = plumRes('CROPLAND', 2010, outputDir = "/Users/peteralexander/Documents/R_Workspace/UNPLUM/output_rcp8.5/")
	c2100 = plumRes('CROPLAND', 2100, outputDir = "/Users/peteralexander/Documents/R_Workspace/UNPLUM/output_rcp8.5/")
	p2010 = plumRes('PASTURE', 2010, outputDir = "/Users/peteralexander/Documents/R_Workspace/UNPLUM/output_rcp8.5/")
	p2100 = plumRes('PASTURE', 2100, outputDir = "/Users/peteralexander/Documents/R_Workspace/UNPLUM/output_rcp8.5/")
	
	c2100_26 = plumRes('CROPLAND', 2100, outputDir = "/Users/peteralexander/Documents/R_Workspace/UNPLUM/output_rcp2.6/")
	p2100_26 = plumRes('PASTURE', 2100, outputDir = "/Users/peteralexander/Documents/R_Workspace/UNPLUM/output_rcp2.6/")
	
	par(mar=c(2,2,1,0.5))
	plot(c2010, main="Cropland 2010")
	plot(c2100, main="Cropland 2100 SSP2/RCP8.5")
	plot(p2010, main="Pasture 2010")
	plot(p2100, main="Pasture 2100 SSP2/RCP8.5")
	
	plot(c2100 - c2010, main="Cropland change 2010-2100 SSP2/RCP8.5", col = c("#FF0000", "#FF5555", "#FFAAAA", "#FFFFFF", "#FFFFFF", "#AAAAFF", "#5555FF", "#0000FF"), breaks=c(-1, -.5, -.2, -.1, 0, 0.1, 0.2, 0.5, 1))
	plot(wrld_simpl, add = TRUE, lwd=0.1)
	
	plot(p2010 -p2100, main="Pasture change 2010-2100 SSP2/RCP8.5", col = c("#FF0000", "#FF5555", "#FFAAAA", "#FFFFFF", "#FFFFFF", "#AAAAFF", "#5555FF", "#0000FF"), breaks=c(-1, -.5, -.2, -.1, 0, 0.1, 0.2, 0.5, 1))
	plot(wrld_simpl, add = TRUE, lwd=0.1)
	
	plot(p2100 -p2100_26, main="Pasture diff between RCP 8.5 to 2.6 in 2100", col = c("#FF0000", "#FF5555", "#FFAAAA", "#FFFFFF", "#FFFFFF", "#AAAAFF", "#5555FF", "#0000FF"), breaks=c(-1, -.5, -.2, -.1, 0, 0.1, 0.2, 0.5, 1))
	plot(wrld_simpl, add = TRUE, lwd=0.1)
	
	plot(c2100 -c2100_26, main="Cropland diff between RCP 8.5 to 2.6 in 2100", col = c("#FF0000", "#FF5555", "#FFAAAA", "#FFFFFF", "#FFFFFF", "#AAAAFF", "#5555FF", "#0000FF"), breaks=c(-1, -.5, -.2, -.1, 0, 0.1, 0.2, 0.5, 1))
	plot(wrld_simpl, add = TRUE, lwd=0.1)
}

# Boundary input data
boundary = raster("/Users/peteralexander/Documents/R_Workspace/UNPLUM/data/halfdeg/country_boundaries.asc")
crs(boundary) <- '+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs'
plot(boundary, main="Boundary")
plot(wrld_simpl, add = TRUE, lwd=0.2)


plot(is.na(initialCrop) & !is.na(crop (boundary, extent(initialCrop))), main="Missing in hurtt")
plot(wrld_simpl, add = TRUE, lwd=0.2)
#plot(is.na(lpjExample) & !is.na(crop (boundary, extent(lpjExample))), main="Missing in LPJG data")
#plot(wrld_simpl, add = TRUE, lwd=0.2)


# Read missing from log extract (grep "No YieldResponsesItem for" log.txt > missing.txt)
missingDt=fread("~/Documents/R_Workspace/UNPLUM/output/missing.txt", header=FALSE)[, list(x=as.numeric(gsub('x:(.*)', '\\1', V3)), y=as.numeric(gsub('y:(.*)', '\\1', V4)), z=1)]
missing = rasterFromXYZ(missingDt, crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")



# Plot prices and import/exports
prices = fread("~/Downloads/prices.txt")
setnames(prices, c('year', 'crop', 'import', 'export', 'price', 'stock'))

prices = merge(prices, prices[year == 2010, list(crop, base_import=import, base_export=export, base_price=price)], by=c('crop'))	
price_melt = melt(prices[, list(year, crop, price_index=price/base_price, import_index=import/base_import, export_index=export/base_import)], 
		measure.vars=c('price_index', 'import_index', 'export_index'), variable.name='type', value.name="index_value")
price_melt[type %in% c('import_index', 'export_index'), c('import_export_type', 'price_type') := list(type, 'import_export')]
price_melt[type %in% c('price_index'), c('import_export_type', 'price_type') := list('price_index', 'price_index')]

ggplot(price_melt[crop %in% c('ruminants', 'monogastrics', 'maize', 'wheat', 'rice')], aes(x=year, y=index_value, colour=import_export_type)) + 
		geom_line() + facet_grid(price_type ~ crop, scales="free_y") + scale_y_continuous(limits=c(0, NA)) +
		theme(legend.position="bottom") + theme(legend.title=element_blank())


prices = fread("~/Downloads/price_concat_26.txt")
price_melt = melt(prices[, list(Imports =median(Imports), Exports =median(Exports)), by=list(Year, Crop)], id.vars=c("Year", "Crop"))
ggplot(price_melt[Crop %in% c('ruminants', 'monogastrics', 'maize', 'wheat', 'rice')], aes(x=Year, y=value, colour=variable)) + 
		geom_line() + facet_grid(Crop ~ .)

plotAggComparison = function() {
	f_melt = melt(worldLUHist, id.vars='Year', variable.name='variable', value.name="Value")
	f_melt[, dataType:="Historic (FAO/IFA)"]
	
	hindDt = fread("/Users/peteralexander/Downloads/lc.txt")[,c(1:3,7,9)]
	names(hindDt) = c('Year', 'cropland', 'pasture', 'fert', 'irrig')
	h_melt = melt(hindDt, id.vars='Year', variable.name='variable', value.name="Value")
	h_melt[, rebased:="i) Unadjusted"]
	
#	rebase_factor = merge(h_melt[Year == 1970, list(hind=Value, variable)], f_melt[Year == 1970, list(fao=Value, variable)], by='variable')[, list(variable, fac=fao/hind)]
#	h_r_melt = merge(h_melt, rebase_factor, by='variable')[, list(Year, variable, Value=Value*fac, rebased="Rebased values")]
	rebase_diff = merge(h_melt[Year == 1970, list(hind=Value, variable)], f_melt[Year == 1970, list(fao=Value, variable)], by='variable')[, list(variable, diff=fao-hind)]
	h_r_melt = merge(h_melt, rebase_diff, by='variable')[, list(Year, variable, Value=Value+diff, rebased="ii) Rebased at 1970")]
	
	res2 = rbind(rbind(h_melt, h_r_melt)[, dataType:="Validation simulations"], data.table(rebased=c("i) Unadjusted", "ii) Rebased at 1970"))[,as.list(f_melt),by=rebased])

	res2[variable=="cropland", variable:="a) Cropland area\n (Mha)"]
	res2[variable=="pasture", variable:="b) Pasture area\n (Mha)"]
	res2[variable=="fert", variable:="c) Nitrogen applied\n (Mt)"]
	res2[variable=="irrig", variable:="d) Irrigation water\n withdrawn (km\u00b3)"]
	res2[, variable:=factor(variable, levels=c("a) Cropland area\n (Mha)", "b) Pasture area\n (Mha)", "c) Nitrogen applied\n (Mt)", "d) Irrigation water\n withdrawn (km\u00b3)"))]
	res2[, rebased:=factor(rebased, levels=c("i) Unadjusted", "ii) Rebased at 1970"))]
	
	ggplot(res2, aes(x=Year, y=Value, colour=dataType, linetype=dataType)) + geom_line() + facet_grid(variable ~ rebased, scales="free", switch = 'y') +
			scale_colour_manual(values = c("black", "red")) +
			theme(legend.title=element_blank(), 
				#legend.position="bottom",
				strip.text.y = element_text(angle = 180),
				axis.title.y = element_blank(), # remove the default y-axis title, "wt"
				strip.background = element_rect(fill = 'transparent'), # replace the strip backgrounds with transparent
				strip.placement = 'outside', # put the facet strips on the outside
				axis.title.x = element_text(angle=0, size=9)) +
			ggsave(file=file.path(baseFigDir, "hind_change_over_time.pdf"),width=8,height=5.5)
}
plotAggComparison()


getHindResultTable = function (lctype, fileName = "/Users/peteralexander/Documents/LURG/PLUM/offline paper/figures/Hind-h5/2010/LandCoverFract.txt") {
	prj = rasterFromFile(lctype, fileName)
	hur=hurttRaster(lctype, 2010)
	s = stack(prj, crop(hur, extent(prj))) # * shift(boundary==356, x=-0.25, y=0.25)  # 156 is china, masking out a c
	names(s) = c('proj', 'hurtt')
	cbind(lctype = lctype, data.table(as.data.frame(s, na.rm=TRUE, xy=TRUE)))
}
dt = rbind(getHindResultTable("PASTURE"), getHindResultTable ("CROPLAND"))

ggplot(dt, aes(x=hurtt, y=proj)) +
		geom_point(size=0.5, alpha=0.02) + 
		geom_smooth(method='lm', size=0.4) +
		theme(strip.background = element_rect(fill = 'transparent')) + 
		facet_grid(. ~ lctype) +
		labs(x="LUH2 land fraction", y="PLUMv2 land fraction")

grid.text(gp=gpar(cex=0.9, font=1), x=unit(.10, "npc"), y=unit(.92, "npc"), just=c("left", "top"), paste0("R\u00b2=", format(summary(lm(hurtt ~ proj, dt[lctype=="CROPLAND"]))$r.squared, digits = 3)))
grid.text(gp=gpar(cex=0.9, font=1), x=unit(.60, "npc"), y=unit(.92, "npc"), just=c("left", "top"), paste0("R\u00b2=", format(summary(lm(hurtt ~ proj, dt[lctype=="PASTURE"]))$r.squared, digits = 3)))
