require(raster)
#write files for java model
#output_dir_root = "C:\\Users\\rhenry2\\workspace\\PLUM_src\\plumv2\\plumv2"
output_dir_root = "/Users/peteralexander/Documents/R_Workspace/UNPLUM"

# Stock levels
calculateStockLevels <- function(stockvar){
	stockLevels = cumsum(stockvar)
	Mp <- min(stockLevels)
	Mp[Mp > 0] <- 0
	stockLevels <- stockLevels-Mp	
}

writePlumFiles = function(dt, year, output_dir) {
	
	if (exists("dt$isHindcast") && dt$isHindcast){
		missingCountries = data.table(Country=c("Malawi", "Algeria", "Kuwait", "Fiji"), 
				toCountry=c("Democratic Republic of the Congo", "Libya", "Oman", "Papua New Guinea"), 
				popRatio=c(65.93871/14.76982, 6.278438/36.03616, 2.943747/3.059473, 6.847517/0.859952),
				gdpRatio=c(15.665/3.874, NA, 58.641352/115.419051, 9.716103/3.140509))
	} else{
		# From country_data in 2010, supplemented by http://data.worldbank.org/indicator/SP.POP.TOTL?locations=SD
		missingCountries = data.table(Country=c("Chad", "Chad", "Chad", "Malawi", "Algeria"), 
				toCountry=c('Sudan', 'South Sudan', 'Somalia', "Democratic Republic of the Congo", "Libya"), 
				popRatio=c(36.115/12.29851, 10.056/12.29851, 9.581/12.29851, 65.93871/14.76982, 6.278438/36.03616), 
				gdpRatio=c(65.634/10.658, 15.727/10.658, 5.352/10.658, 15.665/3.874, NA)) # 2013 for Somalia GDP
	}
	
	#SSP
	newSsp = rbind(dt$ssp[!Country %in% missingCountries[!is.na(gdpRatio)]$toCountry], 
			merge(missingCountries, dt$ssp, by="Country")[, list(Model, Scenario, Year, population=population*popRatio, Country=toCountry, gdp=gdp*gdpRatio)])
	write.table(newSsp[!is.na(population) & !is.na(gdp) & Year >= year, list(Model,Scenario,Year,population,Country,gdp)], file.path(output_dir,"ssp.csv"), sep=",", row.names=FALSE, quote=FALSE)

	# Base Consumption (of commoditites)
	newBaseConsumption = dt$baseConsumption[!is.na(baseCpc), list(Country, basePop, Item, baseCpc)]
	newBaseConsumption = rbind(newBaseConsumption, merge(missingCountries, newBaseConsumption, by="Country")[, list(Country=toCountry, basePop=basePop*popRatio, Item, baseCpc=baseCpc)])
	popForG = dt$histDt[Year == 2010 & Item == "Cereals" & !is.na(population), list(Country, popForGrouping=population)]
	newBaseConsumption = merge(newBaseConsumption, popForG, by='Country', all.x=TRUE)
	newBaseConsumption[is.na(popForGrouping), popForGrouping:=basePop]
	write.table(newBaseConsumption[!Country %in% c("World", "Sudan (former)")], file.path(output_dir,"base_consump.csv"), sep=",", row.names=FALSE, quote=FALSE)

	# Net imports and production (of crops)
	consumpDt = dt$cb_fs[Year == year]
	consumpDt[!is.na(fcr), c('net_import', 'prod') := list(net_import * fcr, prod *fcr)]
	consumpAggreated = consumpDt[, list(net_import=sum(net_import, na.rm=TRUE), prod=sum(prod, na.rm=TRUE)), by=list(plumCropItem, Country, Year)]
	consumpAggreated = rbind(consumpAggreated, merge(missingCountries[!toCountry %in% consumpDt$Country], consumpAggreated, by="Country")[, list(Country=toCountry, Year, plumCropItem, net_import=net_import*popRatio, prod=prod*popRatio)])
	write.table(consumpAggreated, file.path(output_dir, "net_imports.csv"),sep=",",row.names=FALSE,quote=FALSE)

	# Animal number mapping
	animalNum = merge(consumpAggreated, dt$livestockNumbers[Year == year, list(Country, plumCropItem=plumDemandItem, LivestockItem, animalM)], by=c("Country", "plumCropItem"))
	write.table(animalNum[, list(Country, plumCropItem, LivestockItem, animalRate=animalM/prod, prod)], file.path(output_dir, "animal_numbers.csv"),sep=",",row.names=FALSE,quote=FALSE)

	#stock levels
	cb = copy(dt$cb_fs)
	cb[, StockLevel := calculateStockLevels(stockvar), by=c("Country","Item")]
	globalstock = cb[Year == year, list(StockLevel=sum(StockLevel)), by=c("plumCropItem", "Item", "fcr")]
	st = rbind(globalstock[is.na(fcr), list(sum(StockLevel)), by=plumCropItem], globalstock[!is.na(fcr), list(sum(StockLevel*fcr)), by=plumCropItem])
	write.table(st, file.path(output_dir, "global_stocks.csv"), sep=",", row.names=FALSE, quote=FALSE)

	# Bioenergy demand
	bio = dt$cb_fs[Year == year & !Item %in% itemDetails[animal==TRUE], list(Country, Year, Item, other=other, Item, plumDemandItem)]
	
	if (exists("dt$isHindcast") && dt$isHindcast){
		bio = bio[, list(other=0), by=list(Country, Year, Item=plumDemandItem)] ##set to zero for hindcast
	} else {
		bio = bio[, list(other=sum(other, na.rm=TRUE)), by=list(Country, Year, Item=plumDemandItem)]
	}
	write.table(bio, file.path(output_dir, "bio_demand.csv"), sep=",", row.names=FALSE, quote=FALSE)

	#energy per mass values 
	cals = merge(dt$cb_fs[Year == year],dt$country_data[Year == year, list(Country,population, gdp_pc)], by=c('Country'))
	cals[!is.na(fcr), c('food') := list(food * fcr)]
	calsB = cals[,list(gdp_pc=mean(gdp_pc),kcalPerT=sum(energy_kcal_pc*population*365,na.rm=TRUE)/sum(food)),by=c('Country','plumDemandItem')]
	calsB = rbind(calsB[,list(Country,plumDemandItem,kcalPerT)], merge(missingCountries, calsB, by="Country")[, list(Country=toCountry, plumDemandItem, kcalPerT)])
	calsC = calsB[!Country %in% c("World", "Sudan (former)") & kcalPerT != 0]
	write.table(calsC, file.path(output_dir,"calories_per_t.csv"), sep=",", row.names=FALSE, quote=FALSE)
	
	# base_demand_fracts
	newComBal = rbind(dt$cb_fs[,list(Country,Year,Item,net_import,food,feed,other)], 
			merge(missingCountries, dt$cb_fs, by="Country")[, list(Country=toCountry, Item, Year,
							net_import=net_import*popRatio, food=food*popRatio,feed=feed*popRatio, other=other*popRatio)])
	
	cereals = merge ( itemDetails[plumDemandItem %in% c("Cereals", "OilcropsPulses"), list(Item, plumDemandItem, plumCropItem)],
			newComBal[Year == 2010,	list(Country, Year, Item,net_import,food,feed,other)],by = "Item")
	
	cereals2 = cereals[, list(food=sum(food, na.rm=TRUE)), by=list(Country, plumDemandItem, Item=plumCropItem)]
	write.table(cereals2, file.path(output_dir,"base_demand_fracts.csv"), sep=",", row.names=FALSE, quote=FALSE)



}

writePlumFiles(dt=processedFull, year=2010, output_dir=file.path(output_dir_root, "data"))
#writePlumFiles(processedHind1970, year=1970, file.path(output_dir_root, "hind1970/data")) 

# comcurves
write.table(processedFull$com_curves, file.path(output_dir_root,"data/com_curves.csv"), sep=",", row.names=FALSE, quote=FALSE)
#write.table(processedHind1970$com_curves, file.path(output_dir_root,"hind1970/data/com_curves.csv"), sep=",", row.names=FALSE, quote=FALSE)

# hind consumption
missingCountries = data.table(Country=c("Malawi", "Algeria", "Kuwait", "Fiji"), 
		toCountry=c("Democratic Republic of the Congo", "Libya", "Oman", "Papua New Guinea"), 
		popRatio=c(65.93871/14.76982, 6.278438/36.03616, 2.943747/3.059473, 6.847517/0.859952),
		gdpRatio=c(15.665/3.874, NA, 58.641352/115.419051, 9.716103/3.140509))

histComp = processedFull$histDt[, list(Year, Country, Item, population, cpc)]
histComp = rbind(histComp, merge(missingCountries, histComp, by="Country")[, list(Year, Country=toCountry, Item, population=population*popRatio, cpc=cpc)])
write.table(histComp, file.path(output_dir_root,"hind1970/data/hist_comsump.csv"), sep=",", row.names=FALSE, quote=FALSE)

bio = processedFull$cb_fs[Year == 2010]
bio_reduced = bio[, list(Year=1970, other=sum(other)/10), by=list(Country, Item=plumDemandItem)] # we will then increase bioenergy by 20 times between 1970 and 2010
write.table(bio_reduced[, list(Country, Year, Item, other)], file.path(output_dir_root, "hind1970/data", "bio_demand.csv"), sep=",", row.names=FALSE, quote=FALSE)


# IRRIGATION COST
# read original file and project to 0.5 deg grid
#arid1 = raster("/Users/peteralexander/Documents/LURG/Data/CGIAR/AI_annual/ai_yr/")
#arid2 = projectRaster(arid1, crs="+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs", res=c(0.5))
#writeRaster(aridityCost, "/Users/peteralexander/Documents/LURG/Data/CGIAR/AI_half_deg.asc", format='ascii') # had to edit the 0.0001 shift in this file manually

arid2=raster("/Users/peteralexander/Documents/LURG/Data/CGIAR/AI_half_deg.asc") # read in 0.5 deg grid
arid2[arid2>20000] <- 20000 # set max value of 20000
irrigationCost = 1-(arid2)/20000 # rebase to 0-1 range
writeRaster(irrigationCost, "/Users/peteralexander/Documents/LURG/Data/CGIAR/irrigation_cost.asc", format='ascii')

cols <- colorRampPalette(c('dark green', 'yellow', 'red'))
par(mar=c(0.5,0.5,0.5,1))
plot(arid2, col=cols(60), axes=FALSE, box=FALSE)

# old way 
# irrigationCost = 1 - (log10(arid2+1)-1.5)/3.5 
# or 1.3 - (log(raster("/Users/peteralexander/Documents/LURG/Data/CGIAR/AI_half_deg.asc")+1))/10 does more or less the same thing
# irrigationCost = calc(irrigationCost, fun=function(x){ x[x<0] = 0; x[x>1] = 1; return(x) })


# Add earlier other water uses based on rate of change for each FPU
owu = fread("~/Documents/R_Workspace/UNPLUM/hind1970/data/other_water_uses.csv")
owu_change = merge(owu[Year == 2001, list(FPU, value2001=Value)], owu[Year == 2041, list(FPU, value2041=Value)], by='FPU')
owu_change[, rate:=(value2041/value2001) ^ (1/40) - 1]
missing_owu = merge(CJ(FPU=unique(owu_change$FPU), Year = seq(1970,2000,1)), owu_change, by="FPU")
missing_owu = missing_owu[, list(FPU, Year, Value=value2001*(1+rate)^(Year-2001))]
write.table(rbind(missing_owu, owu[Year>2000]), "~/Documents/R_Workspace/UNPLUM/hind1970/data/other_water_uses.csv", sep=",", row.names=FALSE, quote=FALSE)
write.table(rbind(missing_owu, owu[Year>2000]), "~/Documents/R_Workspace/UNPLUM/data/other_water_uses.csv", sep=",", row.names=FALSE, quote=FALSE)

# FEED CHECKS/CALCS TODO feeds are in raw equiv terms for processed goods so DM values need altered to match 
fbs = fread("/Users/peteralexander/Documents/R_Workspace/UNPLUM/output/fbs.txt")
fao = processedFull$cb_fs[Country=="World" & Year == 2010, list(faoFeed=sum(feed), faoFeedDM=sum(feed*dryMatter)), by=list(Crop=plumCropItem)]
#plum=merge(fbs, itemGroupMapping[, list(drymatter=mean(drymatter)), by=list(Crop=gamsCrop)], by="Crop")[Year == 2010, list(mono=sum(MonogastricsFeed), rum=sum(RuminantsFeed), monoDM=sum(MonogastricsFeed * drymatter), rumDM=sum(RuminantsFeed * drymatter)), by=Crop]
#feedComparison=merge(fao, plum, by="Crop")
#feedComparison[, diff:=mono+rum-faoFeed]
#feedComparison[, diffDM:=monoDM+rumDM-faoFeedDM]
#feedComparison[, list(faoFeed=sum(faoFeed), faoFeedDM =sum(faoFeedDM))]
#feedComparison
#feedComparison[, list(sum(diff), sum(diffDM))]

# This give 937 Mt of feed dry from these sources. 
# All commodities have 1009 Mt (so 72 Mt from these missing commodities). cb_fs[is.na(fcr) & Country == "World" & Year ==2010 & Item != "Forage crops", sum(feed*dryMatter)]
# Global forage crops according to FAO data is 1412.1 Mt, assuming 30% dry matter, 423.63 Mt 
# processedFull$baseConsumption[Country == "World"] suggests 1162 Mt of feed for monogastrics (dry) and 2754 for ruminants
# These two sources of feed give 1360 Mt of total feed, implying 198 Mt for ruminants which seems plausible.
# It also implies we are missing 495 Mt of feed, primarily from forage crops
# This is 12.7% of total feed requirements, 495 / (1162 + 2754)




