require(zoo)

readCropProd = function() {
	crop_prod_data = fread(file.path(fao_data_dir,"Production_Crops_E_All_Data_Norm.csv"))
	result = data.table(dcast(crop_prod_data, Country + Year + Item ~ Element, value.var = 'Value'))
	result[is.na(result)] = 0
	rbind( result[, list(Country, Year, Item, area=get("Area harvested")/1000000, prod=get("Production")/1000000)],
			readForageCropProd())
}

readForageCropProd = function() {
	if (exists('forage_prod_data')) rm(forage_prod_data)
	
	for (forageFile in list.files(file.path(fao_data_dir), pattern='forage_.*\\.csv$', full.names=TRUE)) {
		if (exists('forage_prod_data'))
			forage_prod_data = rbind (forage_prod_data, fread(forageFile))
		else
			forage_prod_data = fread(forageFile)
	}
	
	forage_prod_data[, Value := as.numeric(Value)]	
	result = data.table(dcast(forage_prod_data, Country + Year + Item ~ Element, value.var = 'Value'))
	result[is.na(result)] = 0
	result[, list(Item = "Forage crops", area=sum(get("Area harvested"))/1000000,prod=sum(get("Production"))/1000000), by=list(Country, Year)]
}

readPrices = function() {
	prc = fread(file.path(fao_data_dir,"Prices_E_All_Data_Norm.csv"))[Element=="Producer Price (USD/tonne)"][, list(Country, Item, Year, price=Value, Element)]
	setkey(prc, Country, Year, Item)
	
	lwCattleMissing = prc[Item == "Meat live weight cattle"][!unique(prc[Item == "Meat cattle", list(Country, Year)])]	
	lwAdj = prc[Country == "China" & Year == 2010 & Item =="Meat cattle"]$price / prc[Country == "China" & Year == 2010 & Item =="Meat live weight cattle"]$price
	lwCattleMissing[, c('Item', 'price') := list('Meat cattle', lwAdj*price)]

	prc = rbind(prc, lwCattleMissing)
	setkey(prc, Country, Year, Item)
	prc
}

# Read SSP data
getSsp  = function(country_data) {
	ssp_data = fread(file.path(data_dir_root,"SSP","SspDb_country_data_2013-06-12.csv"), header=TRUE)
	
	ssp_pop = reshape(ssp_data[VARIABLE=="Population"], varying = as.character(seq(2010,2100,5)), 
			v.names = "population", timevar = "Year", 
			times = seq(2010,2100,5), direction = "long")
	
	ssp_gdp = reshape(ssp_data[VARIABLE=="GDP|PPP"], varying = as.character(seq(2010,2100,5)), 
			v.names = "gdp_ppp", timevar = "Year", 
			times = seq(2010,2100,5), direction = "long")
	
	ssp_dt=merge(ssp_pop, ssp_gdp, by=c("MODEL", "SCENARIO", "REGION", "Year"))[,list(Model=MODEL, Scenario=SCENARIO, CountryCode=REGION, Year, gdp_ppp=gdp_ppp*1000, population=population)]
	
	baseline_gdp = country_data[Year == 2010]
	baseline_gdp_adj = merge(baseline_gdp, ssp_dt[Year == 2010], by=c("CountryCode"))[,list(CountryCode, Country, Model, Scenario, IncomeGroup, gdp_adj=gdp/gdp_ppp, pop_adj=population.x/population.y)]
	ssp_dt = merge(ssp_dt, baseline_gdp_adj, by=c("CountryCode", "Model", "Scenario"))
	ssp_dt[, c('gdp', 'population') := list(gdp_ppp * gdp_adj, population * pop_adj)]
	
	ssp_dt[Country == "Sudan", Country:="Sudan (former)"]
	ssp_dt[Model != "PIK GDP-32", list(Model, Scenario, Country, Year, gdp, population)] # PIK GDP-32 seems to be US only
}

disaggregateCountries = function(Dt,wbCountryDt, colsToChange){
			
	splitting_states = data.table (oldC="USSR", newC = c("Armenia", "Azerbaijan", "Belarus", "Estonia", "Georgia", "Kazakhstan", "Kyrgyzstan", "Latvia", 
						"Lithuania", "Republic of Moldova", "Russian Federation", "Tajikistan", "Turkmenistan", "Ukraine", "Uzbekistan"), convYear = 1992)
	splitting_states = rbind(splitting_states, data.table(oldC="Ethiopia PDR", newC = c("Ethiopia", "Eritrea"), convYear = 1993))
	splitting_states = rbind(splitting_states, data.table(oldC="Belgium-Luxembourg", newC = c("Belgium", "Luxembourg"), convYear = 2000))
	splitting_states = rbind(splitting_states, data.table(oldC="Yugoslav SFR", newC = c("Bosnia and Herzegovina", "Slovenia", "Croatia", "Serbia","Montenegro","The former Yugoslav Republic of Macedonia"), convYear = 1992))
	splitting_states = rbind(splitting_states, data.table(oldC="Czechoslovakia", newC = c("Czech Republic", "Slovakia"), convYear = 1994))
	splitting_states = rbind(splitting_states, data.table(oldC="Sudan (former)", newC = c('Sudan', 'South Sudan', 'Somalia'), convYear = 2011))
			
	setkey(splitting_states, newC, convYear)
	setkey(wbCountryDt, Country, Year)
	splitting_states = wbCountryDt[splitting_states][, list(newC=Country, convYear=Year, pop_ratio=population/sum(population)), by=oldC]
			
	Dt = Dt[!((Country %in% splitting_states[oldC=="USSR"]$newC & Year < 1992) | (Country %in% splitting_states[oldC=="Ethiopia PDR"]$newC & Year < 1993)|
				(Country %in% splitting_states[oldC=="Belgium-Luxembourg"]$newC & Year < 2000)	|(Country %in% splitting_states[oldC=="Yugoslav SFR"]$newC & Year < 1992)|
				(Country %in% splitting_states[oldC=="Czechoslovakia"]$newC & Year < 1994)|(Country %in% splitting_states[oldC=="Sudan (former)"]$newC & Year < 2011))] 
			
	adjustValue = function (x, y) { x * y}
	convert_com_bal = function (newC, factor, dt, colNames) {
		dt$Country = newC
		adjusted = dt[, lapply(.SD, adjustValue, y=factor), .SDcols = colNames]
		for (i in length(colNames):1) {
			dt[,colNames[i] := NULL]
		}
		cbind(dt, adjusted)
	}
			
	for (i in 1:length(splitting_states$newC)) {
		ss = splitting_states[i]
		print(ss$newC)
		Dt = rbind(convert_com_bal(ss$newC, ss$pop_ratio, Dt[Country == ss$oldC & Year <= ss$convYear], colsToChange), Dt, use.names=TRUE)
	}
	
	Dt = Dt[!((Country == "USSR" & Year < 1992) | (Country == "Ethiopia PDR" & Year < 1993) |(Country =="Belgium-Luxembourg"& Year < 2000)|
						(Country =="Yugoslav SFR" & Year < 1992)|(Country =="Serbia and Montenegro"& Year < 2006)|	(Country =="Czechoslovakia" & Year < 1994)|
						(Country =="Sudan (former)"& Year < 2011))] 
	Dt
}

getHistoricDataset  = function(commodityDt, countryDt) {
	
	h_dt = commodityDt[Item %in% itemGroupMapping$combalItem, 
			list(Country, Year, Item,
					supply=supply, 
					net_import=(import-export), 
					waste_rate=waste/(waste+processing+food+feed+other),
					food_rate=(food+processing)/(waste+processing+food+feed+other),
					feed_rate=feed/(waste+processing+food+feed+other),
					other_rate=other/(waste+processing+food+feed+other))]

	h_dt = merge(h_dt, itemGroupMapping[, list(plumDemandItem, Item=combalItem, fcr)], by=c('Item'))
	
	itemDetails = fread(paste0(data_dir_root, "/HALF/itemsInputs-PLUM.csv"))
	h_dt = merge(h_dt, itemDetails, by='Item', all.x=TRUE)
	h_dt[, dm_food := supply*food_rate*dryMatter]
	
	# animal product feed conversion adjustment
	h_dt[!is.na(fcr), c('supply', 'net_import') := list(supply * fcr, net_import * fcr)]
	
	h_dt2 = h_dt[, list(supply=sum(supply), net_import=sum(net_import), 
					waste_rate=sum(supply*waste_rate, na.rm=TRUE)/sum(supply, na.rm=TRUE), food_rate=sum(supply*food_rate, na.rm=TRUE)/sum(supply, na.rm=TRUE),
					feed_rate=sum(supply*feed_rate, na.rm=TRUE)/sum(supply, na.rm=TRUE), other_rate=sum(supply*other_rate, na.rm=TRUE)/sum(supply, na.rm=TRUE),
					avg_fcr_dm_adj=sum(dm_food, na.rm=TRUE)/sum(supply*food_rate, na.rm=TRUE) # factor to convert from wet to dry, and also from feed equivalent quantities back to real quantities
				), by=list(Item=plumDemandItem, Country, Year)]
		
	h_dt2 = merge(h_dt2, countryDt[, list(Country, Year, gdp,population)], by=c('Country', 'Year'))
	h_dt2[, c('gdpPc', 'cpc') := list(gdp/population, food_rate*supply/population)]
}

getBaseConsumption  = function(year,consumpDt, gdpDt) {
	dt = consumpDt[Year == year, list(Item, Country, baseYear=Year, 
					baseSupply=supply,
					avg_fcr_dm_adj,
					baseFoodRate=food_rate,
					basePop=population, 
					baseGdpPc=gdp/population)]
	
	dt[, baseCpc := baseSupply/basePop*baseFoodRate]
	dt
}

getCommodityCurves = function(Dt) {
	dt = Dt[cpc > 0 & !is.na(cpc) & Country != "World"]
	
	curves=data.table(Item="test", a=NA, b=NA, c=NA, r2=NA, p=NA, fitType=NA)
	
	for (itemName in unique(dt$Item)) {
		dt1 = dt[Item==itemName]
		if (length(dt1$gdpPc) > 10) {
			print (itemName)
		#	fit1 = lm(cpc ~ log(gdpPc) - 1, data=dt1, weights=dt1$population)
		#	curves = rbind(curves, data.table(Item=itemName, a=0, b=fit1$coefficients[1], c=0,
			fit1 = lm(cpc ~ log(gdpPc), data=dt1, weights=dt1$population)
			curves = rbind(curves, data.table(Item=itemName, a=fit1$coefficients[1], b=fit1$coefficients[2], c=0,
							r2=summary(fit1)$adj.r.squared, p=anova(fit1)$'Pr(>F)'[1], fitType="loglinear"))
							
		#	fit2 = lm(cpc ~ log(gdpPc) + I(log(gdpPc)^2) - 1, dt1, weights=dt1$population)
		#	curves = rbind(curves, data.table(Item=itemName, a=0, b=fit2$coefficients[1], c=fit2$coefficients[2],
			fit2 = lm(cpc ~ log(gdpPc) + I(log(gdpPc)^2), dt1, weights=dt1$population)
			curves = rbind(curves, data.table(Item=itemName, a=fit2$coefficients[1], b=fit2$coefficients[2], c=fit2$coefficients[3],
							r2=summary(fit2)$adj.r.squared, p=anova(fit2)$'Pr(>F)'[1], fitType="kuznets"))
			
			y = dt1[,cpc]
			x = dt1[,gdpPc]
			
			try (fit3 <- nls(y ~ SSlogis(x, a, b, c), weights=dt1$population))	# nls(y ~ a / (1 + exp((b-x)/c)), start = list(a=1, b= 100, c = 100))
			curves = rbind(curves, data.table(Item=itemName, a=summary(fit3)$coef[1], b=summary(fit3)$coef[2], c=summary(fit3)$coef[3], r2=NA, p=NA, fitType="logistic"))
		}
	}
	curves[!is.na(b)]
}

getProjectedConsumption = function(fitType, gdpPc, a, b, c) {
	if (fitType == "logistic") {
		v = SSlogis(gdpPc, a, b, c)
	}
	else {
		v = a + b*log(gdpPc) + c*log(gdpPc)^2
	}
	as.numeric(v)
}

# Join ssp and baseConsumption
getProjectAllConsumption  = function(consumptionDt,sspDt, comCurvesDt) {
	setkey(consumptionDt, Country)
	setkey(sspDt, Country, Model, Scenario)
	dt=consumptionDt[sspDt, allow.cartesian=TRUE]	
	dt=dt[!is.na(Item) & baseCpc > 0 & Country != "World"]    # baseConsumption[Country %in% unique(dt[is.na(Item),Country])] # some countries are not in com_bal
	
	dt[, gdpPc:=gdp/population]
	setkey(dt, Item)
	setkey(comCurvesDt, Item, fitType)
	dt = dt[comCurvesDt, allow.cartesian=TRUE]
	dt=dt[!is.na(a) & !is.na(population) & !is.na(baseGdpPc)]     # unique(dt[is.na(i),Item]) # some Items not in com_bal + Grenada GRN does not have a projection in some SSP models
	
	z = 0 # z=0 is no dietary convergence    log(0.9)/2 # choose closing speed so that 10% reduction (still 90% gap) after increase to 2 times size, i.e. 100% increase 
	
	dt[,c('baseExpCpc', 'newExpCpc', 'gapRatio') := list(
					#if (fitType == "logistic") SSlogis(baseGdpPc, a, b, c) else a + b*log(baseGdpPc) + c*log(baseGdpPc)^2,					
					getProjectedConsumption(fitType, baseGdpPc, a, b, c),  # (a+b*log(baseGdpPc)+c*log(baseGdpPc)^2),
					getProjectedConsumption(fitType, gdpPc, a, b, c),  # (a+b*log(gdpPc)+c*log(gdpPc)^2),
					exp((gdpPc-baseGdpPc)/baseGdpPc*z) ), by=list(Model, Scenario, Year, Country, Item, fitType)]
	
	dt[gapRatio>1, gapRatio:=1] # if gdp drops
	
	dt[,projectedCpc:= newExpCpc/baseExpCpc*(baseCpc*gapRatio+baseExpCpc*(1-gapRatio))]   #(newExpCpc+(baseCpc-baseExpCpc)*gapRatio)]
	dt[projectedCpc<0, projectedCpc:=0]
	dt
}

processData = function(isHindcast=FALSE, hindYear=1990, minYear=1960){
	year = ifelse(isHindcast, hindYear, 2010)
	print(paste("Base year is ", year))
	
	com_bal = readCommoditiyBalance()
	com_bal = handleProcessedOilcrops(com_bal,"Oilcrops", c("Rape and Mustard Oil", "Rape and Mustard Cake", "Soyabean Oil", 
					"Soyabean Cake", "Sunflowerseed Oil", "Sunflowerseed Cake", "Palmkernel Oil"))
	
	# Why not handle more?  
	#com_bal_adj2 = handleProcessedOilcrops(com_bal,"Oilcrops", c("Rape and Mustard Oil", "Rape and Mustard Cake", "Soyabean Oil", 
	#				"Soyabean Cake", "Sunflowerseed Oil", "Sunflowerseed Cake", "Palmkernel Oil", "Palm Oil", "Palmkernel Cake", "Sesameseed Oil", "Sesameseed Cake",
	#				"Oilcrops Oil Other", "Oilseed Cakes Other"))
	
	country_data = readCountryData()
	
	if (isHindcast) {
		com_bal = disaggregateCountries(com_bal,country_data, c("supply","export","feed","food","import","other","processing","prod","seed","stockvar","waste"))
		histDt = getHistoricDataset(com_bal, country_data)[Year <= year]
		
		country_data_Extrap = copy(country_data)
		country_data_Extrap[,gdp:=as.numeric(na.approx(gdp,rule=2)), by=Country] # this interpolates and extrapolation (keeping last value for future missing values).
		histDtExtrap = getHistoricDataset(com_bal, country_data_Extrap)[Year <= year] # should we restirct to 2010 when not hindcasting?
		ssp = country_data_Extrap[Year < 2011, list(Model="HINDCAST", Scenario="HINDCAST", Year, population, Country, gdp)] 
	} else {
		histDt = getHistoricDataset(com_bal, country_data)[Year>=minYear]
		histDtExtrap=histDt
		ssp=getSsp(country_data)
	}
	com_curves = getCommodityCurves(histDt)
	
	# Calculate unmodelled area fraction
	if (!isHindcast) {
		crop_prod = readCropProd()
		modelledCropArea = crop_prod[Item %in% itemGroupMapping$cropProdItem & Country == "World" & Year == year, sum(area)]	
		faoCropArea = country_data[Year == year & Country == "World", sum(arable, perm_crops)]
		fractionMissingDueToUnmodelledCropsAndSetasside =  1 - modelledCropArea/faoCropArea
		print(paste0("Unmodelled crop fraction = ", fractionMissingDueToUnmodelledCropsAndSetasside))
	}

	baseConsumption = getBaseConsumption(year,histDtExtrap,ssp)
	projectedConsumption = getProjectAllConsumption(baseConsumption,ssp[Year >= year],com_curves)
	
	return(list(isHindcast=isHindcast,ssp=ssp,histDt=histDt,baseConsumption=baseConsumption,com_curves=com_curves,projectedConsumption=projectedConsumption,com_bal=com_bal))
}

processedFull = processData(isHindcast=FALSE)
processedFullFrom1990 = processData(isHindcast=FALSE, minYear=1990)
processedHind = processData(isHindcast=TRUE)
processedHind1970 = processData(isHindcast=TRUE, hindYear=1970)


# prices - calculate prices in feed equiv terms, to help set initial prices in PLUM
#prices = readPrices()
#dt = merge(prices, itemGroupMapping[, list(Item=priceItem, combalItem, plumDemandItem, fcr)], by=c('Item'))
#setnames(dt, 'Item', 'priceItem')
#setnames(dt, 'combalItem', 'Item')
#dt2 = merge(dt, processedFull$com_bal, by=c('Country', 'Item', 'Year'))
#dt2[!is.na(fcr), list(sum(price * fcr * supply)/sum(fcr * supply)), by=list(Country, Year, plumDemandItem)] # calculate weighted average price per feed equivalent

#checks
#dt1= processedFull$projectedConsumption[Item == "Cereals" & Year==2010 & Model == "OECD Env-Growth" & Scenario == "SSP2_v9_130325"]
#dt2 = processedFull$com_bal[Item == "Cereals - Excluding Beer" & Year==2010]
#merge(dt1, dt2, by='Country')[, list(Country, base=baseCpc*population, proj=projectedCpc*population, actual=(food+processing))]
#dt2[!Country %in% dt1$Country]
processedFull$histDt[Year == 2010 & Item == "Ruminants" & !is.na(gdp) & !Country %in% processedHind$projectedConsumption[Year == 2010 & Item == "Ruminants"]$Country, list(Country)]

# Charts
bigCountries = processedFull$ssp[Year == 2050 & Scenario == "SSP2_v9_130325" & population>120]$Country # 14 of 178 which includes 64% in 2010 of world population and 62% in 2050
smallToLargeCountries = processedFull$ssp[Year == 2050 & Scenario == "SSP2_v9_130325" & population>20]$Country  # 68 of 178 countries 

countriesToDisplay = processedFull$ssp[Year == 2010 & Scenario == "SSP2_v9_130325" & population>60]$Country
chinaIndiaUS = c("China", "India", "United States of America")
allCountries = unique(processedFull$ssp$Country)

shortenCountryNames = function (dt) {
	dt[Country=="United States of America", Country := "USA"]
	dt[Country=="United Kingdom", Country := "UK"]
	dt[Country=="Iran (Islamic Republic of)", Country := "Iran"]
	dt[Country=="Russian Federation", Country := "Russia"]
	dt[Country=="Sudan (former)", Country := "Sudan"]
	dt[Country=="Venezuela (Bolivarian Republic of)", Country := "Venezuela"]
	dt[Country=="United Republic of Tanzania", Country := "Tanzania"]
	dt[Country=="Viet Nam", Country := "Vietnam"]
	dt[Country=="United Arab Emirates", Country := "UAE"]
	dt[Country=="Democratic Republic of the Congo", Country := "DR Congo"]
	dt
}

require(ggplot2)
baseFigDir="~/Documents/LURG/PLUM/offline_paper/figures"

plotConsumptionScatter = function(processedData, scenario, year, countries, aFitType, fileName=file.path(baseFigDir, "demand-scatter.pdf"), showFit = TRUE, fixColours = FALSE, max_gdp=0, max_gdp_year=2030) {
	hist = processedData$histDt[Country %in% countries, list(Year, Country, Item, gdpPc, cpc, population)]
	min_gdp = 0 #min(processedData$histDt$gdpPc, na.rm=TRUE)
	
	proj = processedData$projectedConsumption[Scenario == scenario & Year <= year & fitType == aFitType & Country %in% countries]
	if (max_gdp == 0) max_gdp = max(processedData$projectedConsumption[Scenario == scenario & fitType == aFitType & Country %in% countries & Year==max_gdp_year]$gdpPc)
	
	dt = rbind(hist[Year %in% seq(1962, 2010, 2), list(Year, Country, Item, gdpPc, cpc, population, dataType="Historic")],
			proj[,list(Year, Country, Item, gdpPc, cpc=projectedCpc, population, dataType="Projected")])
	dt = shortenCountryNames(dt)
	
	fcr_dm_adj = processedData$histDt[Country =="World" & Year ==2010, list(Item, fcr_dm_adj=avg_fcr_dm_adj * 1000)]
	dt=merge(dt, fcr_dm_adj, by='Item')
	dt[, cpc:=cpc * fcr_dm_adj]
	dt[, fcr_dm_adj:=NULL]
	
	for (aItem in fcr_dm_adj$Item) {
		fit = processedData$projectedConsumption[Item == aItem & Scenario == scenario & fitType == aFitType][1]
		curve = data.table(gdpPc = seq(min_gdp, max_gdp, length=500))
		curve = curve[, list(gdpPc, Item=aItem,cpc=getProjectedConsumption(aFitType, gdpPc, fit$a, fit$b, fit$c)*fcr_dm_adj[Item==aItem]$fcr_dm_adj)]
		if (exists('allCurves')) allCurves = rbind(allCurves, curve) else allCurves = curve	
	}
	r2Dt = processedData$com_curves[fitType == aFitType, list(x=58000, y=Inf, Item, lab=paste0("R\u00b2=", format(r2, digits = 3)))]
	
	gp = ggplot() +
			#scale_x_log10() + coord_cartesian(xlim = c(80, max_gdp)) + 
			geom_point(data = dt[dataType== "Historic"], aes(x=gdpPc, y=cpc, size=population, colour=Country), alpha=0.3) + 
			geom_path(data = dt, aes(x=gdpPc, y=cpc, size=population, colour=Country), alpha=0.7, size=0.5) + 
	#		geom_text(data=r2Dt, aes(x, y, label=lab), vjust=1.5) + # add R2 value labels
			labs(x="GDP per capita (2010 US$/person)", y="Consumption per capita (kg dry matter/person/year)") + 
			#	scale_colour_discrete(guide = FALSE) +
			scale_size_area(breaks=c(100, 200, 500, 1000, 50000), max_size=10, name = "Population (millions)") + 
			facet_wrap( ~ Item, scales="free_y")
	
	if (fixColours)
		gp = gp + scale_colour_manual(values=scales::hue_pal()(23)[c(3,9,22)])  #colours for China, India and US if 23 countries in total
	
	if (showFit)
		gp = gp + geom_line(data = allCurves, aes(x=gdpPc, y=cpc), colour="black", size=0.5)
	
	gp + ggsave(file=fileName,width=12,height=8)
}

plotConsumptionScatter(processedFull, "SSP2_v9_130325", 2030, countriesToDisplay, "loglinear")

#for (year in seq(2020, 2100, 10)) {
#	plotConsumptionScatter("Ruminants", "SSP2_v9_130325", year, countriesToDisplay, "logistic", paste0("~/Downloads/ruminant_proj_", year, ".pdf"), paste0("Logistic: Projected to ", year))
#}



# Prepare data for demand projection charts
proj_type = data.table(Item = c("Monogastrics", "Ruminants","Cereals", "Oilcrops", "Pulses", "Starchy Roots"), fitType = c(rep("loglinear", 2), rep("loglinear", 4)))
fao=processedFull$histDt[Year <= 2010 & !is.na(cpc) & !is.na(population) & Country %in% getCountryCodes()$Country, list(Country, Year, Item, FAO=cpc*population*avg_fcr_dm_adj)]
hind=merge(processedHind$projectedConsumption, proj_type, by=c('Item', 'fitType'))
hind=hind[!is.na(projectedCpc) & !is.na(population) & Country %in% getCountryCodes()$Country, list(Country, Year, Item, Hindcast=projectedCpc*population*avg_fcr_dm_adj)]
compDt=merge(fao, hind, by=c('Country', 'Year', 'Item'), all=TRUE)[!is.na(Hindcast) | Year < 1990]
compDt[is.na(FAO) & !is.na(Hindcast), FAO:=Hindcast] # fill in things like USSR countries prior to split

proj=merge(processedFull$projectedConsumption, proj_type, by=c('Item', 'fitType'))
proj=proj[!is.na(projectedCpc) & !is.na(population) & Country %in% getCountryCodes()$Country, list(Country, Year, Item, Projected=projectedCpc*population*avg_fcr_dm_adj, Model, Scenario)]
projDt=merge(compDt[Year>=2010], proj, by=c('Country', 'Year', 'Item'), all.y=TRUE)
projDt[!is.na(FAO) & is.na(Projected), Projected:=FAO]

compDt=rbind(compDt, compDt[, list(Country="World", FAO=sum(FAO), Hindcast=sum(Hindcast)), by=c('Year', 'Item')])
projDt=rbind(projDt[, list(Country, Year, Item, Model, Scenario, Projected)], 
		projDt[, list(Country="World", Projected=sum(Projected)), by=c('Year', 'Item', 'Model', 'Scenario')])
compMelt=melt(compDt, id.vars=c('Country', 'Year', 'Item'), variable.name='Type')
allDtToPlot = rbind(compMelt, projDt[, list(Country, Year, Item, 
						Type=paste(gsub('(SSP[0-9])_.*', '\\1', Scenario), gsub('([A-Z]+) .*', '\\1', Model)), value=Projected)])

check=compDt[Country == "World" & Year == 2010]
check[, diff:=(Hindcast-FAO)/Hindcast]
check

plotDemandProjections = function(dt, fileName, countries=c("World", "United States of America", "India", "Brazil", "China")) {
	dt2 = dt[Country %in% countries]
	faoLabel = "Historic (FAO)"
	hindLabel = "Validation, 1990-2010   "
	dt2[Type %like% 'OECD', Type:=gsub('(.*) OECD',  '\\1   ', Type)]
	dt2[Type=="FAO", Type:=faoLabel]
	dt2[Type=="Hindcast", Type:=hindLabel]
	dt2[, Type:=factor(Type, levels=c(faoLabel, hindLabel, sort(unique(as.character(dt2[!Type %in% c(faoLabel, hindLabel)]$Type)))))]
	ggplot(dt2, aes(x=Year, y=value, colour=Type, size=Type, linetype=Type, order = Type)) + 
			geom_line() + facet_grid(Country ~ Item, scale="free") + scale_y_log10() +
	#		scale_colour_manual(values = c("black", "red", "#FFB72BCC","#FFB72BCC", "#96DA00CC","#96DA00CC", "#00EABECC", "#00EABECC", "#00D9FFCC", "#00D9FFCC",  "#F9A3FFCC", "#F9A3FFCC"), guide = guide_legend(nrow = 2)) + # hcl(h=seq(50,290,60), l=c(80), c=100, alpha=0.8)
			scale_colour_manual(values = c("black", "red", "#FFB72BCC","#96DA00CC","#00EABECC", "#00D9FFCC", "#F9A3FFCC")) + # hcl(h=seq(50,290,60), l=c(80), c=100, alpha=0.8)
			scale_size_manual(values = c(0.55, 0.55, rep(.45,10))) + 
	#		scale_linetype_manual(values = c(rep("solid", 2), rep(c("solid", "dashed"),5))) + with both OECD and IIASA projections
			scale_linetype_manual(values = rep("solid", 7)) + 
			theme_minimal() + 
			theme(panel.border = element_rect(colour = "grey10", fill=NA, size=0.3), #axis.line = element_line(size = 0.3, colour ="grey10"),
					legend.position="bottom", legend.title=element_blank()) + 
			labs(x="Year", y="Total consumption (Mt dry matter/year)") +
			ggsave(file=fileName,width=9,height=9)
}

plotDemandProjections(allDtToPlot[!Type %like% 'IIASA'], file.path(baseFigDir,"demand_countries_1961_2100.pdf"))
plotDemandProjections(compMelt[Year >= 1990], file.path(baseFigDir, "demand_countries_1990_2010.pdf"))



#some checks
a = ssp[Year == 2100 & Country == "India", list(Scenario, gdp, population, gdp_pc=gdp/population)]
b = merge(processedFull$projectedConsumption, proj_type, by=c('Item', 'fitType'))[Year == 2100 & Country == "India" & Item == "Ruminants", list(Scenario, projectedCpc, demand=projectedCpc*population)][demand>10]
merge(a, b, by='Scenario')


processedHind1970$com_curves[Item == "Monogastrics" & fitType=="loglinear"]
processedFullFrom1990$com_curves[Item == "Monogastrics" & fitType=="loglinear"]
processedFull$com_curves[Item == "Monogastrics" & fitType=="loglinear"]