fao_data_dir = file.path(data_dir_root, "FAOStat-Sep2018")

# must remember to reset afterwards
itemGroupMapping[plumCropItem=="Oilcrops", plumDemandItem:='Oilcrops']
itemGroupMapping[plumCropItem=="Pulses", plumDemandItem:='Pulses']

processedFull = processData(year=2013)
itemDetails = getItemDetails()

consumpChange = merge(processedFull$projectedConsumption[, list(Country, Year, plumCropItem=Item, Model, Scenario, population, cpcAdj=projectedCpc/baseCpc)], 
				itemDetails, 
				by=c("plumCropItem"), allow.cartesian=TRUE)
		
baseConsump = merge(processedFull$com_bal[Item %in% itemDetails$Item & Year == 2013], 
		processedFull$country_data[, list(Country, Year, population)], 
		by=c('Country', 'Year'))
baseConsump = baseConsump[, list(Country, Item, baseCpc=food/population, baseFood=food)]

dt = merge(consumpChange, baseConsump, by=c("Country", "Item"))[, list(Country, Year, Item, SspModel=Model, Scenario, population, cpcAdj, baseCpc, baseFood, cpc=baseCpc*cpcAdj, food=baseCpc*cpcAdj*population)]

write.table(dt[, list(Country, Year, Item, SspModel, Scenario, foodPerCapita=cpc, food)], "~/Downloads/foodItemProjections.csv", row.names=FALSE, sep=",")


# FIGURE PLOT
baseFigDir="~/Downloads"

compDt=processedFull$histDt[Year <= 2013 & !is.na(cpc) & !is.na(population) & Country %in% getCountryCodes()$Country, list(Country, Year, Item, FAO=cpc*population*avg_fcr_dm_adj)]

proj=processedFull$projectedConsumption
proj=proj[!is.na(projectedCpc) & !is.na(population) & Country %in% getCountryCodes()$Country, list(Country, Year, Item, Projected=projectedCpc*population*avg_fcr_dm_adj, Model, Scenario)]
projDt=merge(compDt[Year>=2010], proj, by=c('Country', 'Year', 'Item'), all.y=TRUE)
projDt[!is.na(FAO) & is.na(Projected), Projected:=FAO]

projDt=rbind(projDt[, list(Country, Year, Item, Model, Scenario, Projected)], 
		projDt[, list(Country="World", Projected=sum(Projected)), by=c('Year', 'Item', 'Model', 'Scenario')])
compMelt=melt(compDt, id.vars=c('Country', 'Year', 'Item'), variable.name='Type')
allDtToPlot = rbind(compMelt, projDt[, list(Country, Year, Item, 
						Type=paste(gsub('(SSP[0-9])_.*', '\\1', Scenario), gsub('([A-Z]+) .*', '\\1', Model)), value=Projected)])

check=compDt[Country == "World" & Year == 2010]
check

plotDemandProjections = function(dt, fileName, countries=c("World", "United States of America", "India", "Brazil", "China")) {
	dt2 = dt[Country %in% countries]
	faoLabel = "Historic (FAO)"
	dt2[Type %like% 'OECD', Type:=gsub('(.*) OECD',  '\\1   ', Type)]
	dt2[Type=="FAO", Type:=faoLabel]
	dt2[, Type:=factor(Type, levels=c(faoLabel, sort(unique(as.character(dt2[!Type %in% c(faoLabel)]$Type)))))]
	ggplot(dt2, aes(x=Year, y=value, colour=Type, size=Type, linetype=Type, order = Type)) + 
			geom_line() + facet_grid(Country ~ Item, scale="free") + scale_y_log10() +
			#		scale_colour_manual(values = c("black", "red", "#FFB72BCC","#FFB72BCC", "#96DA00CC","#96DA00CC", "#00EABECC", "#00EABECC", "#00D9FFCC", "#00D9FFCC",  "#F9A3FFCC", "#F9A3FFCC"), guide = guide_legend(nrow = 2)) + # hcl(h=seq(50,290,60), l=c(80), c=100, alpha=0.8)
			scale_colour_manual(values = c("black", "red", "#FFB72BCC","#96DA00CC","#00EABECC", "#00D9FFCC", "#F9A3FFCC")) + # hcl(h=seq(50,290,60), l=c(80), c=100, alpha=0.8)
			scale_size_manual(values = c(0.55, 0.55, rep(.45,10))) + 
			#		scale_linetype_manual(values = c(rep("solid", 2), rep(c("solid", "dashed"),5))) + with both OECD and IIASA projections
			scale_linetype_manual(values = rep("solid", 7)) + 
			theme_minimal() + 
			theme(panel.border = element_rect(colour = "grey10", fill=NA, size=0.3), #axis.line = element_line(size = 0.3, colour ="grey10"),
					legend.position="bottom", legend.title=element_blank()) + 
			labs(x="Year", y="Total consumption (Mt dry matter/year)") +
			ggsave(file=fileName,width=9,height=9)
}

plotDemandProjections(allDtToPlot[!Type %like% 'IIASA'], file.path(baseFigDir,"demand_countries_1961_2100.pdf"))

#Random stuff from Mark IPCC
fs = food_supply[Country == "World" & Item %in% c('Grand Total', 'Vegetal Products')]
fs2 = data.table(dcast(fs, Year + Country ~ Item, value.var='energy_kcal_pc'))
names(fs2) = c("Year", "Country", "Total", "Vegetal")
fs2 [, NonVegetal:=Total-Vegetal]
ggplot(melt(fs2, id.vars=c("Year", "Country")), aes(x=Year, y=value, colour=variable)) + geom_line()
write.table(fs2, "~/Downloads/foodSupplyKcalPerCap.csv", row.names=FALSE, sep=",")


fs = food_supply[Country %in% c("India", "China", "United States of America", "World", "Brazil", "Nigeria", "Indonesia", "Pakistan", "United Kingdom", "Germany", "Ethiopia", "Russian Federation") & Item %in% c('Grand Total', 'Vegetal Products')]
fs2 = data.table(dcast(fs, Year + Country ~ Item, value.var='energy_kcal_pc'))
names(fs2) = c("Year", "Country", "Total", "Vegetal")
fs2 [, NonVegetal:=Total-Vegetal]
fs2[, meatpercent:= NonVegetal/Total*100]
ggplot(fs2, aes(x=Total, y= meatpercent, colour=Country)) + geom_line() + labs(x="kcal per person per day", y="% from animal products")
