
processIMAGE_be = function(dt, year, output_dir) {
	imageBE = fread("/Users/peteralexander/Documents/R_Workspace/UNPLUM/data/bioenergy_data_from_IMAGE.csv", header=TRUE)
	dt = imageBE[REGION=="World"]
	dt_m = melt(dt, id.vars=c('MODEL', 'SCENARIO', 'REGION', 'Variable', 'Unit'),  variable.name='Year', value.name="value", variable.factor=FALSE)
	dt_m[, Year:=as.numeric(Year)]
	dt_m[, value:=as.numeric(value)]
	dt_m[, SCENARIO:=gsub("(.*)(_SPA[1-5])(.*)", "\\1\\3", SCENARIO)]
	
	# SSP4/5 only have baseline scenarios, so duplicate them for each RCP
	for (rcp in c("RCP45", "RCP60", "RCP85")) {
		dt_ssp_4_5 = dt_m[SCENARIO %in% c("SSP4", "SSP5")]
		dt_ssp_4_5[, SCENARIO:=paste0(SCENARIO, "_", rcp)]
		dt_m = rbind(dt_m, dt_ssp_4_5)
	}
	
	write.table(dt_m, "~/Documents/R_Workspace/UNPLUM/data/bioenergy_data_from_IMAGE_melt.csv", sep=",", row.names=FALSE, quote=FALSE)
}

#dt_m = fread("~/Documents/R_Workspace/UNPLUM/data/bioenergy_data_from_IMAGE_melt.csv")
#ggplot(dt_m[Variable %like% '1st'], aes(x=Year, y=value, colour= SCENARIO)) + geom_line()


gen1 = data.table(year = seq(2000, 2100, 5), 
		beDemand = c(20, 23, 27, 30, 34, 38, 41, 43, 43, 41, 38, 32, 29, 26, 25, 24, 24, 23, 23, 22, 22))


gen2 = data.table(year = seq(2000, 2100, 5), 
		bau=c(0, 0, 0, 80, 180, 300, 450, 800, 1200, 1800, 2100, 2500, 2700, 2900, 3100, 3200, 3300, 3400, 3450, 3500, 3500),
		cc_mit = c(0, 0, 0, 0, 0, 0, 0, 0, 50, 150, 600, 1400, 2500, 3200, 3750, 4200, 4500, 4700, 4850, 4950, 5000))

dt = data.table(CJ(ssp=paste0("SSP", seq(1,5)), rcp=c("RCP26", "RCP45", "RCP60", "RCP85")),
		final2100 = c(	7000, 	5000, 	4000, 	3500,   #SSP1
						9000, 	5500, 	4000, 	2500,	#SSP2
						NaN, 	6000, 	5000, 	3500,	#SSP3
						9000, 	6000, 	5000, 	3500,	#SSP4
						16000,	11000, 	6000, 	2500)) 	#SSP5

dt[, ccMitFact := (final2100-gen2[year==2100, bau])/gen2[year==2100, cc_mit]]

#cartesian join
gen1_dt = dt[, as.list(gen1), by=list(ssp, rcp)]
gen2_dt = dt[, as.list(gen2), by=list(ssp, rcp, final2100, ccMitFact)]

# calc 2 gen trajectories
gen2_dt[, beDemand := ccMitFact * cc_mit + bau]

be_both = rbind(  gen1_dt[, list(Variable="Agricultural Demand|Bioenergy|1st generation", Unit="million t DM/yr", year, ssp, rcp, beDemand)],
		gen2_dt[, list(Variable="Agricultural Demand|Bioenergy|2nd generation", Unit="million t DM/yr", year, ssp, rcp, beDemand)])

write.table(be_both[, list(SCENARIO=paste0(ssp, '_', rcp), REGION="World", Variable, Year=year, value=beDemand)],
		"~/Documents/R_Workspace/UNPLUM/data/bioenergy_scenario_data.csv", sep=",", row.names=FALSE, quote=FALSE)
