require(data.table)

cropIntensitySummary = function (luDt, cropType) {
	
	yDt = luDt[cropland > 0,
			list(   irrig = get(paste0(cropType, '_IQ')),
					fert = get(paste0(cropType, '_FQ')),
					otherint = get(paste0(cropType, '_OI')),
					thisCropFact = get(paste0(cropType, '_A')),
					allCropFact = cropland/area,
					area = get(paste0(cropType, '_A'))*cropland,
					yield = get(paste0(cropType, '_Y'))) ]
	
#       yDt[thisCropFact>0.05 & allCropFact > 0.03, list(cropType = cropType, yield=sum(area * yield)/sum(area), 
	yDt[thisCropFact>0, list(cropType = cropType, yield=sum(area * yield)/sum(area),
					irrig=sum(area * irrig)/sum(area),
					fert=sum(area * fert)/sum(area),
					otherint=sum(area * otherint)/sum(area),
					area = sum(area)) ]
}


summariseLandUseOutput = function(simId='', outBase = baseOutputDir, writeFile=TRUE) {
	
	luFiles <- list.files(file.path(outBase, simId), pattern = 'LandUse.txt', full.names=TRUE, recursive=TRUE)
	cropSumDt = NULL
	
	for (fileName in luFiles) {
		year = basename(dirname(fileName))
		print (paste("Processing", year, "from", fileName))
		luDt = data.table(read.table(fileName, header=TRUE))
		
		
		for (cropType in c('maize', 'rice', 'wheat', 'energycrops', 'oilcrops', 'pulses', 'starchyRoots')) {
			cropSummary = cropIntensitySummary(luDt, cropType)
			if (nrow(cropSummary) >0)
				cropSumDt = rbind (cropSumDt, cbind(cropSummary, year=year))
		}
	}
	
	dryMatterDt = data.table(cropType = c("wheat", "maize", "rice", "oilcrops", "pulses", "starchyRoots", "energycrops"), dryMatter= c(0.87, 0.86, 0.89, 0.88, 0.31, 0.21, 1.0))   
	
	cropSumDt = merge(cropSumDt, dryMatterDt, by = "cropType")
	resDt = rbind(cropSumDt, cropSumDt[cropType != 'energycrops', list(cropType='avgExcEC',
							yield=sum(yield*dryMatter*area)/sum(area),
							irrig=sum(irrig*area)/sum(area),
							fert=sum(fert*area)/sum(area),
							otherint=sum(otherint*area)/sum(area),
							area=sum(area), dryMatter=1),
					by=year])
	
	resDt = rbind(resDt, cropSumDt[, list(cropType='avgIncEC',
							yield=sum(yield*dryMatter*area)/sum(area),
							irrig=sum(irrig*area)/sum(area),
							fert=sum(fert*area)/sum(area),
							otherint=sum(otherint*area)/sum(area),
							area=sum(area), dryMatter=1),
					by=year])
	
	if (writeFile) write.table(resDt, file.path(outBase, simId, "LandUseSummary.csv"), sep=",", row.names=FALSE, quote=FALSE)
	resDt
}

summariseAllLandUse = function (ensDir) {
	print (paste("ensDir", ensDir))
	simDirs <- list.dirs(ensDir, full.names=TRUE, recursive=FALSE)
	for (simDir in simDirs) {
		print (paste("simDir", simDir))
		summariseLandUseOutput(simDir = simDir)
	}
}

baseOutputDir="/exports/csce/eddie/geos/groups/LURG/models/PLUM/output/rcp" # "~/Downloads"

ensemble = commandArgs(trailingOnly = TRUE)[1]
ensDir=file.path(baseOutputDir, ensemble)
if (dir.exists(ensDir)) {
	print(paste(ensDir, "exists.  Processing"))
	summariseAllLandUse(ensDir)
} else {
	print(paste(ensDir, "does not exist.  Stopping"))
}
	

summariseLandUseOutput('rcp/26/s1')





