require(zoo)
require(data.table)
require(reshape2)

data_dir_root = "C:/Users/rhenry2/Desktop/PLUM_orig_data"
fao_data_dir = paste0(data_dir_root, "/FAOStat-Dec2015")

readCommoditiyBalance = function() {
	processCommoditiyBalance = function(fao_file) {
		fao_data =fread(fao_file)
		setnames(fao_data, gsub(' ', '', (names(fao_data))))  
		fao_data = fao_data[!ItemCode == 2948 & !ItemCode == 2949] # remove duplicate eggs and milk totals, as they have the same Item text name as the individual items
		fao_data[, Value := Value / 1000000]
		result = data.table(dcast(fao_data, Country + Year + Item ~ Element, value.var = 'Value'))
		result[is.na(result)] = 0
		setnames(result, c("Domestic supply quantity", "Seed","Waste","Processing","Food supply quantity (tonnes)","Feed","Production","Stock Variation","Import Quantity","Export Quantity","Other uses"),
				c("supply", "seed", "waste", "processing", "food", "feed", "prod", "stockvar", "import", "export", "other"))
		result[, Item := gsub(' and products', '', (Item))]
		result
	}
	
	rbind(processCommoditiyBalance(file.path(fao_data_dir, "CommodityBalances_Crops_E_All_Data_Norm.csv")),
			processCommoditiyBalance(file.path(fao_data_dir, "CommodityBalances_LivestockFish_E_All_Data_Norm.csv")))
}

########## Food supply
readFoodSupply = function() {
	processFoodSupply = function(fao_file) {
		fao_data =fread(fao_file)
		setnames(fao_data, gsub(' ', '', (names(fao_data))))  
		fao_data = fao_data[!ItemCode == 2948 & !ItemCode == 2949] # remove duplicate eggs and milk totals, as they have the same Item text name as the individual items
		
		result = data.table(dcast(fao_data[Item != "Miscellaneous"], Country + Year + Item ~ Element, value.var = 'Value'))
		
		result = result[, list(Country, Year, Item, energy_kcal_pc= get("Food supply (kcal/capita/day)"),
						protein_g_pc = get("Protein supply quantity (g/capita/day)"))]
		result[, Item := gsub(' and products', '', (Item))]
	}
	
	animal_food = processFoodSupply(paste0(fao_data_dir, "/FoodSupply_LivestockFish_E_All_Data_Norm.csv"))
	
	rbind(processFoodSupply(paste0(fao_data_dir, "/FoodSupply_Crops_E_All_Data_Norm.csv")),
			animal_food[Item %in% c(getFeedConvRatio()$Item, "Fish Seafood")])
}

getFeedConvRatio  = function(generateRandom=FALSE, lowerB=-0.2, upperB=0.2) {
	fcrDt = data.table(
			productionItem=c("Milk Total + (Total)", "Eggs Primary + (Total)", "Meat Poultry + (Total)", "Beef and Buffalo Meat + (Total)", "Sheep and Goat Meat + (Total)", "Meat pig", "Meat Other", "Animal fats"),
			Item=c("Milk - Excluding Butter", "Eggs", "Poultry Meat", "Bovine Meat", "Mutton & Goat Meat", "Pigmeat", "Meat Other", "Animal fats"),
			fcr=c(0.7, 2.3, 3.3, 25, 15, 6.4, 15, 9.5),
			justFeed = c(FALSE, TRUE, TRUE, FALSE, FALSE, TRUE, FALSE, FALSE)) # animal fats from weighted average world consumption in 2010 of meats not including poultry meat
	
	if (generateRandom) {
		fcrDt[, fcr := fcr * (1 + runif(8, min=lowerB, max=upperB))]
	}
	fcrDt
}


 handleProcessedOilcrops = function(consump_dt,processedComm, resultantComms) {
 
	 processedCropAggRows = consump_dt[Item %in% resultantComms, list(Item=processedComm, 
                     supply=sum(-export+import+stockvar), prod=0, # no change to prod or supply due to tracing processed commodities, adjust supply to match import/exports
                     processing=-sum(prod), # so that processed amounts will be removed from oilcrop row when summed
                     export=sum(export), import=sum(import), feed=sum(feed), food=sum(food), other=sum(other),
                     seed=sum(seed), stockvar=sum(stockvar), waste=sum(waste), energy_kcal_pc=sum(energy_kcal_pc, na.rm=TRUE),protein_g_pc=sum(protein_g_pc,na.rm=TRUE)),
             by=list(Country, Year)]
 
     rbind(consump_dt, processedCropAggRows)[, list(supply=sum(supply), export=sum(export), feed=sum(feed), food=sum(food), 
                    import=sum(import), other=sum(other), processing=sum(processing), prod=sum(prod),
                     seed=sum(seed), stockvar=sum(stockvar), waste=sum(waste),energy_kcal_pc=sum(energy_kcal_pc,na.rm=TRUE),protein_g_pc=sum(protein_g_pc,na.rm=TRUE)),
             by=list(Country, Year, Item)]
 }


 itemGroupMapping = data.table(
		 plumDemandItem = c(rep("Monogastrics",3), rep("Ruminants",5),
				 rep("Cereals",7), 
				 "Oilcrops", "Pulses", "Starchy Roots"),
		 
		 plumCropItem = c(rep("Monogastrics",3), rep("Ruminants",5),
				 rep("WheatBarleyOats",3), rep("MaizeMilletSorghum", 3), "Rice (Paddy Equivalent)",
				 "Oilcrops", "Pulses", "Starchy Roots"),
		 
		 combalItem=c("Eggs", "Poultry Meat", "Pigmeat", "Milk - Excluding Butter", "Bovine Meat", "Mutton & Goat Meat", "Meat Other", "Animal fats",
				 "Wheat", "Barley", "Oats", "Maize", "Millet", "Sorghum", "Rice (Paddy Equivalent)",
				 "Oilcrops", "Pulses", "Starchy Roots"),
		 
		 priceItem=c("Eggs hen in shell", "Meat chicken", "Meat pig", "Milk whole fresh cow", "Meat cattle", "Meat sheep", NA, NA,
				 "Wheat", "Barley", "Oats", "Maize", "Millet", "Sorghum", "Rice paddy",
				 "Soybeans", "Beans dry", "Potatoes" ),
		 
		 cropProdItem=c(rep(NA, 8),
				 "Wheat", "Barley", "Oats", "Maize", "Millet", "Sorghum", "Rice paddy",
				 "Oilcrops Primary", "Pulses Total", "Roots and Tubers Total" ),
		 
		 fcr=c(2.3, 3.3, 6.4, 0.7, 25, 15, 15, 9.5, rep(NA, 10)),
		 
		 bioenergyUse = c(rep(FALSE, 8), rep(TRUE, 10))
 )

getItemDetails = function() {
	fread(paste0(data_dir_root, "/HALF/itemsInputs-PLUM.csv"))
}

food_supply = readFoodSupply()
com_bal = readCommoditiyBalance()
consump = merge(com_bal, food_supply, by=c('Country', 'Year', 'Item'), all.x=TRUE)

consump= handleProcessedOilcrops(consump,"Oilcrops", c("Rape and Mustard Oil", "Rape and Mustard Cake", "Soyabean Oil", 
				"Soyabean Cake", "Sunflowerseed Oil", "Sunflowerseed Cake"))

country_data = readCountryData() #common R script
country_data[Country =='World' & Year == 2011]$population = sum(country_data[Country != 'World' & Year == 2011][,population], na.rm=TRUE)
consump_dt = merge(consump, country_data[, list(Country, Year, population)], by=c('Country', 'Year'))

itemDetails = getItemDetails()
consump_dt[Item %in% itemDetails[produced==FALSE & animal==FALSE]$Item & ! Item %in% c("Cottonseed", "Molasses"), c('food', 'processing') := list(food + processing, 0)] # small amounts of processed comm. are themselves processed, assumed to be food, Cottonseed and Molasses handled separately
consump_dt[Item %in% itemDetails[animal==TRUE]$Item, c('food', 'processing', 'feed', 'seed') := list(food + processing, 0, feed + seed, 0)] # for animal prod, feed include eggs used as 'seed', processing is assumed as food

# Calc nutritional values (only use the World/2011 ones, but all calculated)
consump_dt[, mj_per_kg:=energy_kcal_pc*population*365/food/1000/239.006] 
consump_dt[, protein_g_per_kg:=protein_g_pc*population*365/food/1000]

consump_dt[Item == "Sugar (Raw Equivalent)", protein_g_per_kg:=0]
consump_dt[Item == "Sugar beet", c('mj_per_kg', 'protein_g_per_kg'):= list(0.188 * 14.8, 0.188 * 7.8 * 10)] # feedpedia assuming 19% moisture and 16 MJ/kg DM, and 7.8% protein by DM
consump_dt[Item == 'Soyabean Cake', c('mj_per_kg', 'protein_g_per_kg'):= list( 0.879 * 9.3, 0.879 * 43.8 * 10)]
consump_dt[Item == 'Rape and Mustard Cake', c('mj_per_kg', 'protein_g_per_kg'):= list( 0.901 * 11.7, 0.901 * 39 * 10)]
consump_dt[Item %like% ' Cake' & is.na(mj_per_kg), c('mj_per_kg', 'protein_g_per_kg') := list( 0.922 * 12.3, 0.922 * 45 * 10)] # based on cottonseed cake, the next highest
consump_dt[Item == 'Cotton lint', c('mj_per_kg', 'protein_g_per_kg'):= list( 20, 900)]
consump_dt[Item == 'Cottonseed', c('mj_per_kg', 'protein_g_per_kg'):= list( 18, 310)] # based on Cottonseed Oil and Cake output, and mass lost
consump_dt[Item == 'Seed cotton', c('mj_per_kg', 'protein_g_per_kg'):= list( 19, 510)] # based on Cotton lint and Cottonseed output, and mass lost
consump_dt[Item == 'Molasses', c('mj_per_kg', 'protein_g_per_kg'):= list( .73 * 13, 0.73 * 5.5 * 10)] # feedpedia
consump_dt[Item == 'Rape and Mustardseed', c('mj_per_kg', 'protein_g_per_kg'):= list( 22, 205)] # based on cake and oil, and mass lost
consump_dt[Item == 'Oil palm fruit', c('mj_per_kg', 'protein_g_per_kg'):= list(11, (9.26 + 11.9) /2 * 10)] # based on http://www.fao.org/docrep/003/w3647e/W3647E04.htm

# The amount of sugar cane eaten is tiny (<1%), but the energy from it appears incorrect, updating the food amount so as not to push out the human consumption figures
sugarcane_mj_per_kg = 0.234 * 11.3
consump_dt[Item == "Sugar cane" & food > 0, c('mj_per_kg', 'protein_g_per_kg', 'food', 'prod') 
				:= list(sugarcane_mj_per_kg, 0.234 * 9.3 * 10, food*mj_per_kg/sugarcane_mj_per_kg, prod - food*(1-mj_per_kg/sugarcane_mj_per_kg))]

getEnergyRates = function(consump_Dt){

energy_dt = consump_Dt[Item %in% itemGroupMapping$combalItem, 
		list(Country, Year, Item,
				supply=supply, 
				net_import=(import-export), 
				waste_rate=waste/(waste+processing+food+feed+other),
				food_rate=(food+processing)/(waste+processing+food+feed+other),
				feed_rate=feed/(waste+processing+food+feed+other),
				other_rate=other/(waste+processing+food+feed+other),
				energy_kcal_pc=energy_kcal_pc,
				protein_g_pc=protein_g_pc,
				population=population,
				mj_per_kg=mj_per_kg,
				protein_g_per_kg=protein_g_per_kg)]

energy_dt = merge(energy_dt, itemGroupMapping[, list(plumDemandItem, Item=combalItem, fcr)], by=c('Item'))

energy_dt = merge(energy_dt, itemDetails, by='Item', all.x=TRUE)
energy_dt[, dm_food := supply*food_rate*dryMatter]

#this needs to be done without fcr adjustment because fcr changes proportions
energy_dt[,'propOfCommodity' := food_rate*supply/sum(food_rate*supply, na.rm=TRUE), by=list(plumDemandItem, Country, Year)]


#energy_dt[Item == 'Rice (Paddy Equivalent)' & Country!='World'][,mean(energy_kcal_per_kg,na.rm=TRUE),by=list(Year)]
energy_dt[Item=="Rice (Paddy Equivalent)" & Country=='World' &Year==2011]$mj_per_kg = mean(energy_dt[Item == 'Rice (Paddy Equivalent)' & Country!='World' & Year==2011]$mj_per_kg, na.rm=TRUE)
energy_dt[Item=="Rice (Paddy Equivalent)" & Country=='World' &Year==2011]$protein_g_per_kg = mean(energy_dt[Item == 'Rice (Paddy Equivalent)' & Country!='World' & Year==2011]$protein_g_per_kg, na.rm=TRUE)


#if not using world and year = 2011 all come out different because different countries eat different proportions of commodities AND those commodities all differ in terms of mj_per_kg for commodities  
energy_dt1=energy_dt[Country =="World" & Year == 2011]

energy_tab_fcr = rbind(energy_dt1[is.na(fcr),list(mj_per_kg=sum(mj_per_kg*propOfCommodity, na.rm=TRUE),
					avg_fcr_dm_adj=1),
					by =list(Item=plumDemandItem, Country, Year)],
					energy_dt1[!is.na(fcr),list(mj_per_kg=sum(mj_per_kg/dryMatter*propOfCommodity, na.rm=TRUE),
					avg_fcr_dm_adj=sum(dm_food, na.rm=TRUE)/sum(supply*food_rate*fcr, na.rm=TRUE)),
					by =list(Item=plumDemandItem, Country, Year)])

##weight of feed*adj*mj_per_kg_DM = shortfall mj

energy_tab_fcr[,mj_adj_per_kg := mj_per_kg*avg_fcr_dm_adj]
energy_tab_fcr[,MJ_per_mt := mj_adj_per_kg*1e+9]
energy_tab_fcr[,EJ_per_mt := MJ_per_mt/1e+12]

}

energy_tab = getEnergyRates(consump_dt) ##values from here go into commodityType in PLUM , starchy roots are very low...

############################## toy model check against logWriter output in abstract demand manager 
conv = data.table(rbind(c("cereals",0.010851271,0.3),
c("oilcrops", 0.024473389,0.05),
c("pulses", 0.014761665,0.35),
c("starchyRoots", 0.003473635,0.3),
c("monogastrics", 0.001919722, 1.0),
c("ruminants", 0.001000159, 1.0)))

colnames(conv)=c('crop','energy_t','subProp')

calculateNewDemand = function(originalDemandVeg, originalDemandMono, originalDemandRum, vegCrop, rateRumChange, rateMonChange){
	originalDemandVeg+
	(originalDemandRum*rateRumChange*as.numeric(conv[crop == 'ruminants']$energy_t)*
		as.numeric(conv[crop == vegCrop]$subProp)/as.numeric(conv[crop == vegCrop]$energy_t))+
	(originalDemandMono*rateMonChange*as.numeric(conv[crop == 'monogastrics']$energy_t)*
		as.numeric(conv[crop == vegCrop]$subProp)/as.numeric(conv[crop == vegCrop]$energy_t))
}

calculateNewDemand(39.77888775480942,4.507219550337405,21.802695912673418,'starchyRoots',0.075,0)


g