# TODO: Add comment
# 
# Author: rhenry2
###############################################################################

library(raster)
library(ncdf4) # 'ncdf4' package must be downloaded and installed manually
library(data.table)
library(reshape2)
library(plyr)
require(maptools)
data(wrld_simpl)


convertToDt = function(file, whatYear,variables, calculateArea=FALSE){ 
	
	if (calculateArea){
		ncFile = file
		year = 1
	}
	else{
		ncFile = file
		year = which(ncvar_get(ncFile,"time")%in% whatYear) 	
	}
	
	rasterStack = stack()
	
	for(var in variables){
		
		landType = ncFile$var[[var]]
		landTypeSize = landType$varsize
		landTypeName = var
		landTypeDims = landType$ndims
		start = rep(1,landTypeDims)
		start[landTypeDims] = year 
		count = landTypeSize
		
		if (!calculateArea){
			count[landTypeDims] = 1 ##for taking only 1 year, don't need for area file as it doesn't have time dimension 
		}
		
		landTypeData = ncvar_get(ncFile, landType, start=start, count=count)
		
		colnames(landTypeData) = lat
		rownames(landTypeData) = lon
		dtTemp = data.table(melt(landTypeData, varnames=c('Lon', 'Lat')))
		
		
		if (!calculateArea){
			landTypeR = aggregate(rasterFromXYZ(dtTemp[, list(Lon, Lat, value)], crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs"), fact=2, fun=mean)
		}
		else{
			landTypeR = aggregate(rasterFromXYZ(dtTemp[, list(Lon, Lat, value)], crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs"), fact=2, fun=sum) 
		}
		
		names(landTypeR) = landTypeName
		rasterStack = stack(rasterStack, landTypeR)	
	}
	
	landDT = data.table(as.data.frame(rasterStack, xy=TRUE))
	
	colnames(landDT)[colnames(landDT)=="x"] <- "Lon"
	colnames(landDT)[colnames(landDT)=="y"] <- "Lat"
	landDT[, c('Lon', 'Lat') := list(Lon-0.25, Lat-0.25)] ##move to bottom left hand corner 
	
	landDT <- landDT[complete.cases(landDT),] ##remove NA data
	
	landDT
	
}


writeLandCoverMap= function(year){
	lcCover = convertToDt(ncLandCovers,year,landCoversVariables,FALSE)
	lcTran = convertToDt(ncLandTran,year-849,c("primf_bioh","secmf_bioh","secyf_bioh","primf_harv","secmf_harv","secyf_harv"),FALSE) #-849 because time dimension is in numbers not years
	lcMan = convertToDt(ncLandMan,year-849,c("rndwd","fulwd","combf"),FALSE) #-849 because time dimension is in numbers not years
	

	landCovers= merge(lcCover[,list(Lon,Lat,URBAN=urban,CROPLAND = c3ann+c4ann+c3per+c4per+c3nfx,PASTURE = pastr+range,
				TOT_FOREST = primf+secdf,NATURAL =primn+secdn)],lcTran[,list(Lon,Lat,MANAGED_FOREST=primf_harv+secmf_harv+secyf_harv)] , by=c("Lon","Lat"))		

	landCovers=merge(lcMan[,list(Lon,Lat,INDUSTRIAL = rndwd, TRADITIONAL = fulwd, BIOFUEL=combf)], landCovers, by=c("Lat","Lon"))

	landCovers[MANAGED_FOREST>0]$MANAGED_FOREST = landCovers[MANAGED_FOREST>0][,list(MANAGED_FOREST=TOT_FOREST)]
	landCovers[MANAGED_FOREST>0 & (INDUSTRIAL+BIOFUEL < 0.25)]$MANAGED_FOREST = 0
	landCovers = cbind(landCovers[,!c('TOT_FOREST','INDUSTRIAL','BIOFUEL','TRADITIONAL')], 
			landCovers[,list(UNMANAGED_FOREST = TOT_FOREST-MANAGED_FOREST,BARREN=1-rowSums(landCovers[,c('URBAN', 'CROPLAND', 'PASTURE', 'TOT_FOREST','NATURAL')]))]) 
	landCovers[BARREN <0]$BARREN = 0
	landCovers = landCovers[order(landCovers$Lon, landCovers$Lat),] 

	write.table(landCovers,paste0("C:\\Users\\rhenry2\\Desktop\\hurtt_",year,".txt"), row.names=F)
}

data_dir_root = "U:\\Datastore\\CSCE\\geos\\users\\rhenry2\\landcover\\luh2\\"
ncStatic =  nc_open(paste0(data_dir_root,"staticData_quarterdeg.nc"))
ncLandCovers = nc_open(paste0(data_dir_root,"states.nc"))
ncLandTran = nc_open(paste0(data_dir_root,"transitions.nc"))
ncLandMan = nc_open(paste0(data_dir_root,"management.nc"))

landCoversVariables = names(ncLandCovers[['var']])
lon <- ncvar_get(ncStatic, "lon") #rows 
lat <- ncvar_get(ncStatic, "lat")	#cols

area=convertToDt(ncStatic,1,"carea",TRUE)

writeLandCoverMap(2010)

##checks 

plum_cover = data.table(read.table("C:\\Eclipse_workspace\\plumV2\\hurtt_forest_files\\hurtt_forest_.txt", header =TRUE))
plum_cover = data.table(read.table("C:\\Eclipse_workspace\\plumV2\\data\\halfdeg\\netfract_hurtt_2010.txt", header =TRUE))
plum_cover = data.table(read.table("C:\\Users\\rhenry2\\Desktop\\hurtt_2010.txt", header =TRUE))


plum_cover_area = merge(area,plum_cover, by=c('Lat','Lon')) 
sum(plum_cover_area$MANAGED_FOREST*plum_cover_area$carea, na.rm=TRUE)*100/1000000

rowSums(plum_cover[,c('URBAN', 'CROPLAND', 'PASTURE', 'MANAGED_FOREST', 'UNMANAGED_FOREST','NATURAL','BARREN')])

manForest = rasterFromXYZ(plum_cover[, list(Lon, Lat, MANAGED_FOREST)], crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
unmanForest = rasterFromXYZ(plum_cover[, list(Lon, Lat, UNMANAGED_FOREST)], crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")

##colours = topo.colors(300)
##colour = c("#FFFFFF",colours)

par(mfrow=c(1,2))
plot(manForest, main="managed forest 2010")
plot(wrld_simpl, add = TRUE, lwd=0.2)
plot(unmanForest, main="unmanaged forest 2010")
plot(wrld_simpl, add = TRUE, lwd=0.2)


###area through time

areaThroughTime = function(file,years,variables){
	j = 1
	resultsList=list()
	for (year in years) {
		
		land = convertToDt(file, year,variables,FALSE)
		land = setnames(land[,list(Lon,Lat,value = rowSums((land[,!c('Lon', 'Lat')])))],c('Lon','Lat',year))	
		land = merge(land, area, by=c('Lon','Lat'))
		
		resultsList[[j]] = land
		j=j+1
	}
	
	unlist(lapply(resultsList, function(x){sum(x[,3]*x[,4])*100/1000000}))	
	
}

years=1961:2010
croplandVar = c("c3ann","c4ann","c3per","c4per","c3nfx")
pastureVar = c("pastr","range")
cropland = areaThroughTime(ncLandCovers,years,croplandVar)
pasture = areaThroughTime(ncLandCovers,years,pastureVar)
perennials = areaThroughTime(ncLandCovers,2000,c("c3per","c4per"))

plot(cropland~years, type='l', ylim=c(1000,3500), ylab="Area (Mha)", xlab="Year")
lines(pasture~years, col="red")

###################################################################
###### SAGE, is a bit more tricky because the file doesn't have equal intervals between co-ordinates and raster
## package doesn't like it so need to do some manual editing by hand 

sage = nc_open("C:\\Users\\rhenry2\\Desktop\\landcover\\sage\\Cropland2000_5min.nc") ##0.8333 resolution (5 min)

variables = names(sage[['var']])
dimensions = names(sage[['dim']])

lon <- ncvar_get(sage, "longitude") #rows
lat <- ncvar_get(sage, "latitude") #cols

sageArea <- sage$var[[1]]
sageSize <- sageArea$varsize
sageName <- ncatt_get(sage,sageArea$name, "long_name")$value
sageDims <- sageArea$ndims
start <- rep(1,sageDims)
count <- varsize
sageData <- ncvar_get(sage, sageArea, start=start, count=count)

colnames(sageData) <- rev(seq(min(lat-1/12*0.5),max(lat-1/12*0.5), by=1/12)) #5 min resolution and moving to bottom left corner
rownames(sageData) <- seq(min(lon-1/12*0.5),max(lon-1/12*0.5), by=1/12)
sageDtTemp = data.table(melt(sageData, varnames=c('Lon', 'Lat')))

landTypeR = aggregate(rasterFromXYZ(sageDtTemp[, list(Lon, Lat, value)], crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs", res=1/12), fact=6, fun=mean)

#unique(diff(sort(unique(sageDtTemp$Lon)))) ## cant rasterise sage as intervals are all different

landDT = data.table(as.data.frame(landTypeR, xy=TRUE))
colnames(landDT) <- c("Lon","Lat", "farea")
landDT = landDT[order(landDT$Lon, landDT$Lat),] 

##raster changes co-ordinates very slightly so re-bin with lookup table 
lookUp= setnames(data.table(cbind(unique(landDT$Lon),seq(-180,179.5, by=0.5),unique(landDT$Lat),seq(-90,89.5, by=0.5) )),
		c("oldLon", "newLon","oldLat", "newLat"))

landDT$Lon = lookUp$newLon[match(unlist(landDT$Lon), lookUp$oldLon)]
landDT$Lat = lookUp$newLat[match(unlist(landDT$Lat), lookUp$oldLat)]
landDT = landDT[complete.cases(landDT),] ##remove NA data

setwd("C:\\Users\\rhenry2\\Desktop\\data_1990\\")
write.table(landDT, "sage.txt", row.names=F)


## maps

# Read initial land cover file
getRaster = function(lcType, fileName) {
	plumDt=data.table(read.table(fileName, header=TRUE))
	plumDt[, c('Lon', 'Lat') := list(Lon, Lat)]
	rasterFromXYZ(plumDt[, list(Lon, Lat, get(lcType))], crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
}

dir = "/Users/peteralexander/Documents/R_Workspace/UNPLUM"
plumHindCrop2010 = getRaster("CROPLAND", file.path(dir, "hindcast", "output", 2010, "LandCoverFract.txt"))
plumHindPasture2010 = getRaster("PASTURE", file.path(dir, "hindcast", "output", 2010, "LandCoverFract.txt"))
luh2Crop2010 = getRaster("CROPLAND", file.path(dir, "data", "halfdeg", "netfract_hurtt_2010.txt"))
luh2Pasture2010 = getRaster("PASTURE", file.path(dir, "data", "halfdeg", "netfract_hurtt_2010.txt"))

plotDiffs = function(plumRaster, observedRaster, type) {
	par(mfrow=c(1,3), mar=c(2,2,1,5))
	plot(observedRaster, main=paste("LUH2 2010", type))
	plot(wrld_simpl, add = TRUE, lwd=0.2)
	plot(plumRaster, main=paste("PLUM 2010", type))
	plot(wrld_simpl, add = TRUE, lwd=0.2)
	plot(observedRaster - plumRaster, col = c("#FF0000", "#FF5555", "#FFAAAA", "#FFFFFF", "#FFFFFF", "#AAAAFF", "#5555FF", "#0000FF"), breaks=c(-1, -.5, -.2, -.1, 0, 0.1, 0.2, 0.5,1), main=paste("LUH2 - PLUM 2010", type))
	plot(wrld_simpl, add = TRUE, lwd=0.2)
}
plotDiffs(plumHindCrop2010, luh2Crop2010, "Cropland")
plotDiffs(plumHindPasture2010, luh2Pasture2010, "Pasture")

raster(nrows=180, ncols=360, xmn=-180, xmx=180, ymn=-90, ymx=90,
		crs, ext, resolution, vals=NULL)



