require(raster)
require(data.table)
require(gridExtra)
require(ggplot2)
require(reshape2)
require(maptools)
require(grid)
require(rgdal)
data(wrld_simpl)

baseOutputDir="/exports/csce/eddie/geos/groups/LURG/models/PLUM/output"
baseHurttDir="/exports/csce/eddie/geos/groups/LURG/models/PLUM/plumv2"
baseFigDir="/exports/csce/eddie/geos/groups/LURG/models/PLUM/figures"

rasterFromFile = function(lcType, fileName, offset=0.0) {
	plumDt=data.table(read.table(fileName, header=TRUE))
	plumDt[, c('Lon', 'Lat') := list(Lon-offset, Lat-offset)]
	rasterFromXYZ(plumDt[, list(Lon, Lat, get(lcType))], crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
}

shpFile = crop(readShapePoly("~/Documents/LURG/Data/NaturalEarthShapefile/ne_110m_admin_0_countries_lakes.shp", proj4string=CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")), extent(-180,180, -55, 90))

plotWithBorder = function(r, axes=FALSE, box=FALSE, col=rev(terrain.colors(255)), legend.lab="", 
		breaks=c(), legend=TRUE, axisArgs=list(lwd=0.6, tck =-0.3, mgp=c(0, 0.5, 0))) {
	par(mar=c(0.1,0.5,1.5,1))
	plot(r, axes=axes, box=box, col=col, 
			legend.lab=legend.lab, legend=legend, axis.args=axisArgs,
			legend.width=1.1, legend.shrink=0.8, cex.lab=0.6,
			breaks=breaks)
	plot(shpFile, add = TRUE, border=rgb(r=0.1, g=0.1, b=0.1, alpha=.5), lwd=0.05)
}

plumRes = function(lcType, year, simId='', outBase = baseOutputDir, offset=0.0) {
	if (lcType %in% c("Fert", "Irrig", "Yield")) {
		fileName = file.path(outBase, simId, year, "LandUse.txt")
		luDt = data.table(read.table(fileName, header=TRUE))
		
		if (lcType == "Fert") {
			rasterFromXYZ(luDt[, list(Lon-offset, Lat-offset, 
									(oilcrops_A*oilcrops_FQ + starchyRoots_A*starchyRoots_FQ + pulses_A*pulses_FQ + wheat_A*wheat_FQ + rice_A*rice_FQ + maize_A*maize_FQ + energycrops_A*energycrops_FQ)*cropland/area)], 
					crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
		} else if (lcType == "Irrig") {
			rasterFromXYZ(luDt[, list(Lon-offset, Lat-offset, 
									(oilcrops_A*oilcrops_IQ + starchyRoots_A*starchyRoots_IQ + pulses_A*pulses_IQ + wheat_A*wheat_IQ + rice_A*rice_IQ + maize_A*maize_IQ + energycrops_A*energycrops_IQ)*cropland/area)], 
					crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
		} else {
			dt = luDt[, list(Lon, Lat, cropland, yieldAvg=(oilcrops_A*oilcrops_Y*0.88 + starchyRoots_A*starchyRoots_Y*0.21 + pulses_A*pulses_Y*0.31 + wheat_A*wheat_Y*0.87 + rice_A*rice_Y*0.89 + maize_A*maize_Y*0.86))] # + energycrops_A*energycrops_Y
			dt[cropland < 0.05, yieldAvg:=0]
			rasterFromXYZ(dt[, list(Lon-offset, Lat-offset, yieldAvg)], crs = "+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs")
		}
	} else if (lcType == "IrrigConstraint") { 
		fileName = file.path(outBase, simId, year, "IrrigConstraint.asc")
		raster(fileName)
	} else { 
		fileName = file.path(outBase, simId, year, "LandCoverFract.txt")
		rasterFromFile(lcType, fileName, offset=offset)
	}
}

 hurttRaster = function(lcType, year) {
	if (year == 1970) {
		fileName = file.path(baseHurttDir, "hind1970/data/halfdeg/hurtt_1970.txt")
	} else if (year == 1990) {
		fileName = file.path(baseHurttDir, "hindcast/data/halfdeg/hurtt_1990.txt")
	} else if (year == 2000) {
		fileName = file.path(baseHurttDir, "/data/halfdeg/hurtt_2000.txt") 
	} else if (year == 2010) {
		fileName = file.path(baseHurttDir, "/data/halfdeg/hurtt_2010.txt")
	}
	rasterFromFile(lcType, fileName)
 }
 
plotDiff = function(r1, r2, legend=TRUE, legend.lab="", fileName=NA, 
		breaks=c(-1, -.7, -.5, -0.3, -.1, 0.1, 0.3, 0.5, 0.7, 1),
		col = c("#a50f15", "#de2d26", "#fb6a4a", "#fcae91", "#eeeeee", "#bdd7e7", "#6baed6", "#3182bd", "#08519c"),
		axisArgs=list(lwd=0.6, tck =-0.3, mgp=c(0, 0.5, 0))) {
	
	e = intersect(extent(r1), extent(r2))
	rDiff = crop(r2, e)-crop(r1, e)
	plotDiff2(rDiff, legend=legend, legend.lab=legend.lab, fileName=fileName, breaks=breaks, col = col, axisArgs=axisArgs)
}

plotDiff2 = function(rDiff, legend=TRUE, legend.lab="", fileName=NA, 
		breaks=c(-1, -.7, -.5, -0.3, -.1, 0.1, 0.3, 0.5, 0.7, 1),
		col = c("#a50f15", "#de2d26", "#fb6a4a", "#fcae91", "#eeeeee", "#bdd7e7", "#6baed6", "#3182bd", "#08519c"),
		axisArgs=list(lwd=0.6, tck =-0.3, mgp=c(0, 0.5, 0))) {
	
	lowest = breaks[1]
	highest = breaks[length(breaks)]
	legendLabs = copy(breaks)
	if (length(rDiff[rDiff<lowest])) {
		rDiff[rDiff<lowest] <- lowest
		legendLabs[1] = paste("<", lowest)
	}
	if (length(rDiff[rDiff>highest])) {
		rDiff[rDiff>highest] <- highest
		legendLabs[length(breaks)] = paste(">", highest)
	}
	axisArgs$labels=legendLabs
		
	if (!is.na(fileName)) {
		pdf(width=8, height=3, file = file.path(baseFigDir, paste0(fileName, ".pdf")))
		par(mar=c(0.5,0.5,0.5,1))
	}
	par(cex=0.7)
	
	plotWithBorder(rDiff, col = col, breaks=breaks, legend=legend, legend.lab=legend.lab, axisArgs=axisArgs)
			 	
	if (!is.na(fileName)) dev.off()
}
 
plotAbsoulteCandP = function (hindDir='../hindcast/output', ensemble, endYr=2010, fileId="") {
	pdf(width=12, height=4.8, file = file.path(baseFigDir, paste0("hindCandP_", gsub('\\/', '_', ensemble), "_", endYr, "-", fileId, ".pdf")))
	par(oma=c(0,0.5,0,2))
	layout(matrix(c(1,2,3,4), 2, 2, byrow = TRUE))
	cf = plumRes("CROPLAND", endYr, hindDir)
	pf = plumRes("PASTURE", endYr, hindDir)
	plotWithBorder(cf, legend=FALSE)
	plotWithBorder(crop(hurttRaster("CROPLAND", endYr), extent(cf)), legend=FALSE)
	plotWithBorder(pf, legend=FALSE)
	plotWithBorder(crop(hurttRaster("PASTURE", endYr), extent(pf)), legend.lab="Cover fraction")
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a1)", endYr, "PLUM2v cropland projected from 1970"))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a2)", endYr, "LUH2 cropland"))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.49, "npc"), just=c("left", "top"), paste("b1)", endYr, "PLUM2v pasture projected from 1970"))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.49, "npc"), just=c("left", "top"), paste("b2)", endYr, "LUH2 pasture"))
	 dev.off()
}
 
plotAbsoulte = function (lctype, hindDir='../hindcast/output', startYr=1990, endYr=2010, fileId="") {
	pdf(width=12, height=4.1, file = file.path(baseFigDir, paste0("hind", lctype, "_", startYr, "-", endYr, "-", fileId, ".pdf")))
	par(oma=c(0,0.5,0,2))
	layout(matrix(c(1,2,3,4), 2, 2, byrow = TRUE))
	plotWithBorder(plumRes(lctype, startYr, hindDir), legend.lab="Cover fraction")
	plotWithBorder(plumRes(lctype, endYr, hindDir), legend.lab="Cover fraction")
	plotWithBorder(hurttRaster(lctype, startYr), legend.lab="Cover fraction")
	plotWithBorder(hurttRaster(lctype, endYr), legend.lab="Cover fraction")
	
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a) PLUM", startYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("b) PLUM", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.49, "npc"), just=c("left", "top"), paste("c) LUH2", startYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.49, "npc"), just=c("left", "top"), paste("d) LUH2", endYr))
	dev.off()
}
 
plotCandPChanges = function (hindDir='../hindcast/output', ensemble, startYr=1990, endYr=2010, fileId="") {
	pdf(width=12, height=4.1, file = file.path(baseFigDir, paste0("hindCandPchange_", gsub('\\/', '_', ensemble), "_", startYr, "-", endYr, "-", fileId, ".pdf")))
	par(oma=c(0,0.5,0,2))
	layout(matrix(c(1,2,3,4), 2, 2, byrow = TRUE))
	cs = plumRes("CROPLAND", startYr, hindDir)
	cf = plumRes("CROPLAND", endYr, hindDir)
	ps = plumRes("PASTURE", startYr, hindDir)
	pf = plumRes("PASTURE", endYr, hindDir)
	
	plotDiff(cs, cf, legend.lab="Change fraction")
	plotDiff(crop(hurttRaster("CROPLAND", startYr), cs), crop(hurttRaster("CROPLAND", endYr), cs), legend.lab="Change fraction")
	plotDiff(ps, pf, legend.lab="Change fraction")
	plotDiff(crop(hurttRaster("PASTURE", startYr), ps), crop(hurttRaster("PASTURE", endYr), ps), legend.lab="Change fraction")
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a1) PLUMv2 cropland ", startYr, "-", endYr, "change"))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a2) LUH2 cropland", startYr, "-", endYr, "change"))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.49, "npc"), just=c("left", "top"), paste("b1) PLUMv2 pasture ", startYr, "-", endYr, "change"))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.49, "npc"), just=c("left", "top"), paste("b2) LUH2 pasture", startYr, "-", endYr, "change"))
	dev.off()
}
 
plotHindAll = function(ensemble, scenarioId, startYr=1970, endYr=2010) {
	plotCandPChanges(hindDir=file.path(ensemble, scenarioId), ensemble, startYr=startYr, endYr=endYr, fileId=scenarioId)
	plotAbsoulteCandP(hindDir=file.path(ensemble, scenarioId), ensemble, endYr=endYr, fileId=scenarioId)
	plotAbsoulte("CROPLAND", hindDir=file.path(ensemble, scenarioId), startYr=startYr, endYr=endYr, fileId=scenarioId)
	plotAbsoulte("PASTURE", hindDir=file.path(ensemble, scenarioId), startYr=startYr, endYr=endYr, fileId=scenarioId)
}

plotIntensityAll = function(ensemble, scenarioId, startYr=2010, endYr=2100) {
	pdf(width=12, height=6.1, file = file.path(baseFigDir, paste0("intensity_", startYr, "-", endYr, "-", gsub('\\/', '_', ensemble), "_", scenarioId, ".pdf")))
	scenDir=file.path(ensemble, scenarioId)
	par(oma=c(0,0.5,0,2))
	layout(matrix(c(1,2,3,4,5,6), 3, 2, byrow = TRUE))
 
	fs = plumRes("Fert", startYr, scenDir)
	fe = plumRes("Fert", endYr, scenDir)
	is = plumRes("Irrig", startYr, scenDir)
	ie = plumRes("Irrig", endYr, scenDir)
	plotWithBorder(fs, legend.lab="Fertiliser (kg/ha)")
	plotWithBorder(is, legend.lab="Irrig. water (mm)")
	plotWithBorder(fe, legend.lab="Fertiliser (kg/ha)")
	plotWithBorder(ie, legend.lab="Irrig. water (mm)")
	plotDiff(fs, fe, breaks=c(-500, -400, -200, -100, -30, 30, 100, 200, 300, 500), legend.lab="Fertiliser (kg/ha)")
	plotDiff(is, ie, breaks=c(-800, -600, -400, -200, -50, 50, 200, 400, 600, 800), legend.lab="Irrig. water (mm)")
 
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a) Fertiliser", startYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("b) Irrigation", startYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.66, "npc"), just=c("left", "top"), paste("c) Fertiliser", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.66, "npc"), just=c("left", "top"), paste("d) Irrigation", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.33, "npc"), just=c("left", "top"), paste("e) Fertiliser", startYr, "-", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.33, "npc"), just=c("left", "top"), paste("f) Irrigation", startYr, "-", endYr))

	dev.off()
}

 plotScenarioAll = function(ensemble, scenarioId, startYr=2010, endYr=2100) {
	pdf(width=12, height=6.1, file = file.path(baseFigDir, paste0("areas_", startYr, "-", endYr, "-", gsub('\\/', '_', ensemble), "_", scenarioId, ".pdf")))
	scenDir=file.path(ensemble, scenarioId)
	par(oma=c(0,0.5,0,2))
	layout(matrix(c(1,2,3,4,5,6), 3, 2, byrow = TRUE))
  
	cs = plumRes("CROPLAND", startYr, scenDir)
	cf = plumRes("CROPLAND", endYr, scenDir)
	ps = plumRes("PASTURE", startYr, scenDir)
	pf = plumRes("PASTURE", endYr, scenDir)
	plotWithBorder(cs, legend.lab="Cover fraction")
	plotWithBorder(ps, legend.lab="Cover fraction")
	plotWithBorder(cf, legend.lab="Cover fraction")
	plotWithBorder(pf, legend.lab="Cover fraction")
	plotDiff(cs, cf, legend.lab="Change fraction")
	plotDiff(ps, pf, legend.lab="Change fraction")
  
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a) Cropland", startYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("b) Pasture", startYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.66, "npc"), just=c("left", "top"), paste("c) Cropland", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.66, "npc"), just=c("left", "top"), paste("d) Pasture", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.33, "npc"), just=c("left", "top"), paste("e) Cropland", startYr, "-", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.33, "npc"), just=c("left", "top"), paste("f) Pasture", startYr, "-", endYr))
	 
	dev.off()
}

plotWaterAvail = function (ensemble, scenarioId, startYr=2010, endYr=2100) {
	pdf(width=12, height=6.1, file = file.path(baseFigDir, paste0("waterAvail", startYr, "-", endYr, "-", gsub('\\/', '_', ensemble), "_", scenarioId, ".pdf")))
	scenDir=file.path(ensemble, scenarioId)
	par(oma=c(0,0.5,0,2))
	layout(matrix(c(1,2,3,4,5,6), 3, 2, byrow = TRUE))
	
	cs = plumRes("CROPLAND", startYr, scenDir, offset=-0.25)
	cf = plumRes("CROPLAND", endYr, scenDir, offset=-0.25)

	waterConstraintStart = plumRes("IrrigConstraint", startYr, scenDir)
	waterConstraintEnd = plumRes("IrrigConstraint", endYr, scenDir)
	waterConstraintStart = crop(waterConstraintStart, extent(cs))
	waterConstraintEnd = crop(waterConstraintEnd, extent(cs))
	
	waterUsedStart = plumRes("Irrig", startYr, scenDir, offset=-0.25)
	waterUsedEnd = plumRes("Irrig", endYr, scenDir, offset=-0.25)
	
#	waterUnusedFractStart = ((waterConstraintStart-waterUsedStart)/waterConstraintStart) * (cs>0.05)
#	waterUnusedFractEnd = ((waterConstraintEnd-waterUsedEnd)/waterConstraintEnd) * (cf>0.05)
#	waterUnusedFractStart[waterUnusedFractStart<0] <-0
#	waterUnusedFractEnd[waterUnusedFractEnd<0] <-0
	
	waterUsedFractStart = (waterUsedStart/waterConstraintStart) * (cs>0.05)
	waterUsedFractEnd = (waterUsedEnd/waterConstraintEnd) * (cf>0.05)
	waterUsedFractStart[waterUsedFractStart>1.0] <- 1.0
	waterUsedFractEnd[waterUsedFractEnd>1.0] <- 1.0
	
	
	plotWithBorder(waterConstraintStart, legend.lab="Water (mm)")
	plotWithBorder(waterUsedFractStart, legend.lab="Water fraction", col=rev(heat.colors(255)))
	plotWithBorder(waterConstraintEnd, legend.lab="Water (mm)")
	plotWithBorder(waterUsedFractEnd, legend.lab="Water fraction", col=rev(heat.colors(255)))
	plotDiff(waterConstraintStart, waterConstraintEnd, breaks=c(-800, -400, -200, -100, -50, 50, 100, 200, 400, 800), legend.lab="Water change (mm)")
	plotDiff(waterUsedFractStart, waterUsedFractEnd, legend.lab="Water used fraction change", col=rev(c("#E10000", "#E44B4B", "#E49B9B", "#DFDFDF", "#8E8EDB", "#4D4DDB", "#0000DC")))
	
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a) Water available for irrigation", startYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("b) Fraction of irrigation water used in cropland areas", startYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.66, "npc"), just=c("left", "top"), paste("c) Water available for irrigation", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.66, "npc"), just=c("left", "top"), paste("d) Fraction of irrigation water used in cropland areas", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.03, "npc"), y=unit(.33, "npc"), just=c("left", "top"), paste("e) Change in water available for irrigation", startYr, "-", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.33, "npc"), just=c("left", "top"), paste("f) Change in Fraction of irrigation water used in cropland", startYr, "-", endYr))
	dev.off()
}

plotSummary = function(ensemble, scenarioId, startYr=2010, endYr=2100) {
	pdf(width=12, height=11.0, file = file.path(baseFigDir, paste0("summary_", gsub('\\/', '_', ensemble), "_", scenarioId, "_", startYr, "-", endYr, ".pdf")))
	scenDir=file.path(ensemble, scenarioId)
	par(oma=c(0,0.5,0,2))
	layout(matrix(seq(1,10,1), 5, 2, byrow = TRUE))
	
	plotWithBorder(plumRes("CROPLAND", endYr, scenDir), legend.lab="Land fraction")
	plotDiff(plumRes("CROPLAND", startYr, scenDir), plumRes("CROPLAND", endYr, scenDir), legend.lab="Land fraction")

	plotWithBorder(plumRes("PASTURE", endYr, scenDir), legend.lab="Land fraction")
	plotDiff(plumRes("PASTURE", startYr, scenDir), plumRes("PASTURE", endYr, scenDir), legend.lab="Land fraction")

	plotWithBorder(plumRes("Fert", endYr, scenDir), legend.lab="Fertiliser (kg/ha)")
	plotDiff(plumRes("Fert", startYr, scenDir), plumRes("Fert", endYr, scenDir), breaks=c(-200, -150, -100, -60, -20, 20, 60, 100, 150, 200), legend.lab="Fertiliser (kg/ha)")

	plotWithBorder(plumRes("Irrig", endYr, scenDir), legend.lab="Irrig. water (mm)")
	plotDiff(plumRes("Irrig", startYr, scenDir), plumRes("Irrig", endYr, scenDir), breaks=c(-600, -400, -200, -100, -30, 30, 100, 200, 400, 600), legend.lab="Irrig. water (mm)")
	
	yEnd = plumRes("Yield", endYr, scenDir)
	plotWithBorder(yEnd, legend.lab="Yield (t/ha)")
	plotDiff(plumRes("Yield", startYr, scenDir), yEnd, breaks=c(-40, -20, -10, -5, -2, 2, 5, 10, 20, 40), legend.lab="Yield (t/ha)")
	
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.01, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a) Cropland", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("b) Cropland change", startYr, "-", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.01, "npc"), y=unit(.79, "npc"), just=c("left", "top"), paste("c) Pasture", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.79, "npc"), just=c("left", "top"), paste("d) Pasture change", startYr, "-", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.01, "npc"), y=unit(.59, "npc"), just=c("left", "top"), paste("e) Fertiliser", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.59, "npc"), just=c("left", "top"), paste("f) Fertiliser change", startYr, "-", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.01, "npc"), y=unit(.39, "npc"), just=c("left", "top"), paste("g) Irrigation", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.39, "npc"), just=c("left", "top"), paste("h) Irrigation change", startYr, "-", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.01, "npc"), y=unit(.19, "npc"), just=c("left", "top"), paste("i) Yield", endYr))
	grid.text(gp=gpar(cex=0.8, font=4), x=unit(.51, "npc"), y=unit(.19, "npc"), just=c("left", "top"), paste("j) Yield change", startYr, "-", endYr))
	dev.off()
}

plotRcpComp = function(rootEnsemble, startYr=2010, endYr=2100, ens1='26', ens2='85') {
	pdf(width=15, height=7.5, file = file.path(baseFigDir, paste0("rcpComp_", startYr, "-", endYr, "-", rootEnsemble, ens1, "_", ens2, ".pdf")))
	dir26=file.path(rootEnsemble, ens1, 's1')
	dir85=file.path(rootEnsemble, ens2, 's1')
	ens1Text = gsub("([0-9])([0-9])$", "RCP\\1.\\2",  ens1)
	ens2Text = gsub("([0-9])([0-9])$", "RCP\\1.\\2",  ens2)
	
	par(oma=c(0,0.5,0,2))
	layout(matrix(seq(1,12,1), 4, 3, byrow = TRUE))
		
	plotWithBorder(plumRes("CROPLAND", endYr, dir26), legend.lab="")
	plotDiff(plumRes("CROPLAND", startYr, dir26), plumRes("CROPLAND", endYr, dir26), legend.lab="")
	plotDiff(plumRes("CROPLAND", endYr, dir26), plumRes("CROPLAND", endYr, dir85), legend.lab="")
	
	plotWithBorder(plumRes("PASTURE", endYr, dir26), legend.lab="")
	plotDiff(plumRes("PASTURE", startYr, dir26), plumRes("PASTURE", endYr, dir26), legend.lab="")
	plotDiff(plumRes("PASTURE", endYr, dir26), plumRes("PASTURE", endYr, dir85), legend.lab="")
	
	plotWithBorder(plumRes("Fert", endYr, dir26), legend.lab="")
	plotDiff(plumRes("Fert", startYr, dir26), plumRes("Fert", endYr, dir26), breaks=c(-200, -150, -100, -60, -20, 20, 60, 100, 150, 200), legend.lab="")
	plotDiff(plumRes("Fert", endYr, dir26), plumRes("Fert", endYr, dir85), breaks=c(-200, -150, -100, -60, -20, 20, 60, 100, 150, 200), legend.lab="")
	
	i26Start = plumRes("Irrig", startYr, dir26)
	i26End = plumRes("Irrig", endYr, dir26)
	i85End = plumRes("Irrig", endYr, dir85)
	plotWithBorder(i26End, legend.lab="")
	plotDiff(i26Start, i26End, breaks=c(-400, -300, -200, -100, -30, 30, 100, 200, 300, 400), legend.lab="")
	plotDiff(i26End, i85End, breaks=c(-400, -300, -200, -100, -30, 30, 100, 200, 300, 400), legend.lab="")
	
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.01, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a1) Cropland land fraction", ens1Text, endYr))
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.34, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a2) Cropland land fraction change", ens1Text, "from", startYr, "to", endYr))
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.67, "npc"), y=unit(.99, "npc"), just=c("left", "top"), paste("a3) Cropland change from", ens1Text, "to", ens2Text, "in", endYr))
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.01, "npc"), y=unit(.74, "npc"), just=c("left", "top"), paste("b1) Pasture land fraction", ens1Text, endYr))
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.34, "npc"), y=unit(.74, "npc"), just=c("left", "top"), paste("b2) Pasture land fraction change", ens1Text, "from", startYr, "to", endYr))
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.67, "npc"), y=unit(.74, "npc"), just=c("left", "top"), paste("b3) Pasture change from", ens1Text, "to", ens2Text, "in", endYr))
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.01, "npc"), y=unit(.49, "npc"), just=c("left", "top"), paste("c1) Fertiliser rate", ens1Text, endYr, "(kg/ha)"))
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.34, "npc"), y=unit(.49, "npc"), just=c("left", "top"), paste("c2) Fertiliser rate change", ens1Text, "from", startYr, "to", endYr, "(kg/ha)"))
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.67, "npc"), y=unit(.49, "npc"), just=c("left", "top"), paste("c3) Fertiliser rate change", ens1Text, "to", ens2Text, "in", endYr, "(kg/ha)"))
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.01, "npc"), y=unit(.24, "npc"), just=c("left", "top"), paste("d1) Irrigation water", ens1Text, endYr, "(mm)"))
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.34, "npc"), y=unit(.24, "npc"), just=c("left", "top"), paste("d2) Irrigation water change", ens1Text, "from", startYr, "to", endYr, "(mm)"))
	grid.text(gp=gpar(cex=0.75, font=4), x=unit(.67, "npc"), y=unit(.24, "npc"), just=c("left", "top"), paste("d3) Irrigation water change from", ens1Text, "to", ens2Text, "in", endYr, "(mm)"))
	dev.off()
}


#plotHindAll('hind1970/hc', 's1')
#plotIntensityAll('hind1970/hc', 's1', startYr=1970, endYr=2010)
#plotIntensityAll('rcp/26', 's1')
#plotScenarioAll('rcp/26', 's1')
#plotWaterAvail('rcp/26', 's1')
plotRcpComp('rcp')
#plotRcpComp('rcp', ens1='85', ens2='85_constCO2')
#plotRcpComp('rcp', ens1='85', ens2='85_constClim')
#plotRcpComp('rcp', ens1='85', ens2='constCO2_constClim')

#plotSummary('rcp/26', 's1')