require(ggplot2)
require(grid)

gg_color_hue <- function(n) {
	hues = seq(45, 405, length=n+1)
	hcl(h=hues, l=65, c=100)[1:n]
}

shortenCountryNames = function (dt) {
	dt[Country=="United States of America", Country := "USA"]
	dt[Country %like% "United Kingdom", Country := "UK"] # should not need a %like% here, but == does match for some unknown reason
	dt
}

countryPlotStyle= data.table(Country=c("Brazil","China","India","Nigeria,","UK","USA","World"), 
				lcolour=c("#00B4F0", "#C77CFF" , "#DE8C00", "#00C08B", "#7CAE00", "#FF64B0", "black"),
				lsize=c(rep(0.65, 6), 0.7),
				ltype =c("dashed", "longdash", "dashed", "twodash", "twodash", "longdash", "solid") )
		
# HALF over time
plotHalfByTime = function () {
	dt_baseline = shortenCountryNames(halfIndexesByTime[type == "Overall" & prodYear == 2011 & popYear == 2011])
	dt_concurrent = shortenCountryNames(halfIndexesByTime[type == "Overall" & prodYear == Year & popYear == Year])
	gg1 = ggplot() + 
			geom_line(data=dt_concurrent, aes(x = Year, y = agri_index, size=Country, colour = Country, linetype="Diet, population & production variable ")) +
			geom_line(data=dt_baseline, aes(x = Year, y = agri_index, size=Country, colour = Country, linetype="Diet only variable (2011 population and production) ")) +
			labs(x="Year", y="Human appropriation of land for food (HALF) index") +
			theme_minimal() + 
			theme(panel.grid.minor.y = element_blank(), 
					panel.grid.minor.x = element_blank(), 
					legend.title=element_blank(),
					panel.background = element_rect(colour = "black", size =.4),
					legend.key.width=unit(2,"line"),
					legend.key.height=unit(0,"line"),
					legend.position="bottom",
					legend.direction = "horizontal") +
			scale_linetype_manual(values = c("solid", "dashed")) + 
			scale_size_manual(values = countryPlotStyle$lsize) +
			scale_colour_manual(values =countryPlotStyle$lcolour) +
			scale_x_continuous(breaks = seq(1960, 2010, 10)) +
			scale_y_continuous(breaks = seq(0, 140, 20), limits=c(0, max(dt_baseline$agri_index))) 
	pdf(width=8, height=5.5, file = "/Users/peteralexander/Documents/LURG/Alt\ Scenarios/figures/half_by_time.pdf")
	vp1 = viewport()
	print(gg1, vp=vp1)
	dev.off()
}

# HALF over time, constant 2011 base year
plotHalfByTime()


plotWorldHalfByTime = function () {
	dtToPlot = rbind(halfIndexesByTime[type == "Overall" & Country == "World" & prodYear == 2011 & popYear == 2011, list(Year, val=agri_index, type = "HALF: Diet only variable\n(2011 population and production)")], 
					 halfIndexesByTime[type == "Overall" & Country == "World" & prodYear == Year & popYear == Year, list(Year, val=agri_index, type = "HALF: Diet, population and\nproduction variable")])
	dtToPlot = rbind(dtToPlot, halfIndexesByTime[type == "Overall" & Country == "World" & popYear == 2011 & Year == 2011, list(Year = prodYear, val=agri_index, type = "HALF: Population only variable\n(2011 diet and population)")])
	dtToPlot = rbind(dtToPlot, halfIndexesByTime[type == "Overall" & Country == "World" & prodYear == 2011 & Year == 2011, list(Year = popYear, val=agri_index, type = "HALF: Production only variable\n(2011 diet and production)")])
	dtToPlot = rbind(dtToPlot, data=country_data[Country=="World" & Year < 2012, list(Year, val=agri/land*100, type = "Global agricultural land")])
	
	dtToPlot[, type := factor(type, levels=c('HALF: Diet only variable\n(2011 population and production)', 'HALF: Production only variable\n(2011 diet and production)', 'HALF: Population only variable\n(2011 diet and population)', 'HALF: Diet, population and\nproduction variable', 'Global agricultural land'))]
	
	gg1 = ggplot(data=dtToPlot, aes(x = Year, y = val, colour=type, linetype=type)) + 
			geom_line() + 
			labs(x="Year", y="Percentage of global land") +
			theme_minimal() + 
			theme(panel.grid.minor.y = element_blank(), 
					panel.grid.minor.x = element_blank(), 
					legend.title=element_blank(),
					panel.background = element_rect(colour = "black", size =.4),
					legend.key.height=unit(2.5,"line")) +
			scale_linetype_manual(values = c("solid", "dotdash", "dotted", "dashed", "solid")) + 
			scale_colour_manual(values = c("grey30", "grey30", "grey30", "grey30", "blue")) + 
			scale_x_continuous(breaks = seq(1960, 2010, 10)) +
			scale_y_continuous(breaks = seq(0, 140, 20)) 
	
	pdf(width=8, height=3.5, file = "/Users/peteralexander/Documents/LURG/Alt\ Scenarios/figures/half_by_time_world.pdf")
	vp1 = viewport()
	print(gg1, vp=vp1)
	dev.off()
}
plotWorldHalfByTime()


getNutrientPanel = function(yAxisLabel, dt) {
	nutrient_hist = dt[, list(Value=sum(Value)), by=list(Country, Year)]
	ggplot(data=nutrient_hist, aes(x=Year, y=Value, size=Country, colour=Country, linetype=Country)) +
			geom_line() +
			labs(x="Year", y=yAxisLabel) +
			theme_minimal() + 
			theme(panel.grid.minor.y = element_blank(), 
					panel.grid.minor.x = element_blank(), 
					panel.background = element_rect(colour = "black", size =.4),
					legend.key.width=unit(2,"line"),
					legend.title=element_blank(),
					legend.position="bottom",
					legend.direction = "horizontal") +
			scale_y_continuous(limits=c(0, max(nutrient_hist$Value))) + 
			scale_linetype_manual(values = countryPlotStyle$ltype) +
			scale_size_manual(values = countryPlotStyle$lsize) +
			scale_colour_manual(values = countryPlotStyle$lcolour)
}


getAnimalPanel = function(yAxisLabel, dt) {
	ap_ratios = merge(dt[isAnimal==FALSE], dt[isAnimal==TRUE], by=c('Country', 'Year'))[, list(Country, Year, Value_percent=Value.y/(Value.y+Value.x)*100)]
	ggplot(ap_ratios, aes(x = Year, y = Value_percent, size=Country, colour = Country, linetype=Country)) +
			geom_line() +
			labs(x="Year", y="% from animal products") +
			theme_minimal() + 
			theme(panel.grid.minor.y = element_blank(), 
					panel.grid.minor.x = element_blank(), 
					panel.background = element_rect(colour = "black", size =.4),
					legend.key.width=unit(2,"line"),
					legend.title=element_blank(),
					legend.position="bottom",
					legend.direction = "horizontal") +
			scale_y_continuous(limits=c(0, max(ap_ratios$Value_percent))) +
			scale_linetype_manual(values = countryPlotStyle$ltype) +
			scale_size_manual(values = countryPlotStyle$lsize) +
			scale_colour_manual(values = countryPlotStyle$lcolour)	
}

# Nutrient consumption over time
plotNutrientsByTime = function (yAxisLabel, fileName, dt) {

	dt = shortenCountryNames(dt)
	dt[, Country := paste0(Country, "  ")]
	
	gg_energy = getNutrientPanel(yAxisLabel, dt)	
	gg_energy_ratio = getAnimalPanel(yAxisLabel, dt)
	
	pdf(width=9, height=4.5, file = paste0("/Users/peteralexander/Documents/LURG/Alt\ Scenarios/figures/", fileName))
	
	print(gg_energy + theme(legend.position="none"), vp=viewport(just=c("left", "top"), x=0.01, y=0.98, width=0.48, height=0.9))
	print(gg_energy_ratio + theme(legend.position="none"), vp=viewport(just=c("left", "top"), x=0.51, y=0.98, width=0.48, height=0.9))
	
	grid.text(gp=gpar(cex=0.9, font=4), x=0.25, y=.99, just=c("left", "top"), "a)")
	grid.text(gp=gpar(cex=0.9, font=4), x=0.75, y=.99, just=c("left", "top"), "b)")
	
	g <- ggplotGrob(gg_energy_ratio)$grobs
	legend <- g[[which(sapply(g, function(x) x$name) == "guide-box")]]
	lheight <- sum(legend$height)
	
	pushViewport(viewport(just=c("left", "top"), x=0.01, y=0.16, width=0.98, height=0.2))
	grid.draw(legend)
	upViewport()
	dev.off()
}

animal_prods_inc_fish=c("Fish Seafood", "Milk - Excluding Butter", "Eggs", "Poultry Meat", "Bovine Meat", "Mutton & Goat Meat", "Pigmeat", "Meat Other", "Animal fats")

plot_data = merge(con_prod[Country == "World" & Year == 2011, list (Item, mj_per_kg, protein_g_per_kg)], 
		con_prod[Country %in% c("United States of America", "United Kingdom", "India", "China", "Brazil", "Nigeria", "World"), list(Country, Year, Item, food_pc_pd = food/population/365*1000)], by='Item')

plot_data[, isAnimal := Item %in% animal_prods_inc_fish]

plotNutrientsByTime("Energy (MJ/person/day)", "energy_intake_by_time2.pdf",
		plot_data[, list(Value=sum(mj_per_kg*food_pc_pd, na.rm=TRUE)), by=list(Country, Year, isAnimal)])
plotNutrientsByTime("Protein (MJ/person/day)", "protein_intake_by_time.pdf",
		plot_data[, list(Value=sum(protein_g_per_kg*food_pc_pd, na.rm=TRUE)), by=list(Country, Year, isAnimal)])


# Nutrient consumption over time
plotNutrientsByTime_4panel = function (fileName, dt) {
	dt = shortenCountryNames(dt)
	dt[, Country := paste0(Country, "  ")]
	
	energy_dt = plot_data[, list(Value=sum(mj_per_kg*food_pc_pd, na.rm=TRUE)), by=list(Country, Year, isAnimal)]
	protein_dt = plot_data[, list(Value=sum(protein_g_per_kg*food_pc_pd, na.rm=TRUE)), by=list(Country, Year, isAnimal)]
	
	gg_energy = getNutrientPanel("Energy (MJ/person/day)", energy_dt)	
	gg_energy_ratio = getAnimalPanel("Energy (MJ/person/day)", energy_dt)
	
	gg_protien = getNutrientPanel("Protein (g/person/day)", protein_dt)	
	gg_protein_ratio = getAnimalPanel("Protein (g/person/day)", protein_dt)
	
	pdf(width=9, height=9, file = paste0("/Users/peteralexander/Documents/LURG/Alt\ Scenarios/figures/", fileName))
	
	print(gg_energy + theme(legend.position="none"), vp=viewport(just=c("left", "top"), x=0.01, y=0.96, width=0.48, height=0.44))
	print(gg_energy_ratio + theme(legend.position="none"), vp=viewport(just=c("left", "top"), x=0.51, y=0.96, width=0.48, height=0.44))
	
	print(gg_protien + theme(legend.position="none"), vp=viewport(just=c("left", "top"), x=0.01, y=0.50, width=0.48, height=0.44))
	print(gg_protein_ratio + theme(legend.position="none"), vp=viewport(just=c("left", "top"), x=0.51, y=0.50, width=0.48, height=0.44))
	
	grid.text(gp=gpar(cex=0.9, font=4), x=0.25, y=.98, just=c("left", "top"), "a)")
	grid.text(gp=gpar(cex=0.9, font=4), x=0.75, y=.98, just=c("left", "top"), "b)")
	grid.text(gp=gpar(cex=1, font=4), x=0.02, y=.99, just=c("left", "top"), "i) Energy")
	grid.text(gp=gpar(cex=1, font=4), x=0.02, y=.52, just=c("left", "top"), "ii) Protein")
	
	g <- ggplotGrob(gg_energy_ratio)$grobs
	legend <- g[[which(sapply(g, function(x) x$name) == "guide-box")]]
	lheight <- sum(legend$height)
	
	pushViewport(viewport(just=c("left", "top"), x=0.01, y=0.08, width=0.98, height=0.1))
	grid.draw(legend)
	upViewport()
	dev.off()
}
plotNutrientsByTime_4panel('nutrient_4panel.pdf', plot_data)

plotMeatConsump = function (dt) {

	ggp1 = ggplot(dt, aes(x = Year, y = food_pc_pd*1000, size=Country, colour = Country, linetype=Country)) +
			geom_line() +
			labs(x="Year", y="Consumption per capita (g/person/day)") +
			theme_minimal() + 
			theme(panel.grid.minor.y = element_blank(), 
					panel.grid.minor.x = element_blank(), 
					panel.background = element_rect(colour = "black", size =.4),
					legend.key.width=unit(2,"line"),
					legend.title=element_blank(),
					legend.position="bottom",
					legend.direction = "horizontal") +
			scale_linetype_manual(values = countryPlotStyle$ltype) +
			scale_size_manual(values = countryPlotStyle$lsize) +
			scale_colour_manual(values = countryPlotStyle$lcolour) +
			facet_grid(. ~ Item)
	
	pdf(width=10, height=4.5, file = paste0("/Users/peteralexander/Documents/LURG/Alt\ Scenarios/figures/", "meat_consup_by_time.pdf"))
	print(ggp1)
	dev.off()
}

plotMeatConsump (plot_data[Item %in%  c("Poultry Meat", "Bovine Meat", "Pigmeat")])


# Maps of HALF
if (!require(rworldmap)) {
	install.packages("rworldmap",dependencies=TRUE)
}


drawMap = function (dt, fileName, legendDivisions) {	
	dt = merge(dt[type == "Overall" & agri_index > 0], getCountryCodes(), by='Country')
	sPDF = joinCountryData2Map(dt, joinCode="ISO3", nameJoinColumn="CountryCode")
	
	pdf(paste0("/Users/peteralexander/Documents/LURG/Alt\ Scenarios/figures/", fileName), width = 10, height = 5.3)
	par(mar=c(3,0,0,0))
	mapParams = mapCountryData(sPDF, nameColumnToPlot='agri_index', addLegend=FALSE, catMethod=legendDivisions, mapTitle='', missingCountryCol = 'gray95')
	do.call( addMapLegend, c(mapParams, legendWidth=0.5,legendLabels="all", legendMar = 3))
	
	dev.off()
}

drawMap(halfIndexes2011ByCountry, "half_map_2011.pdf", legendDivisions=seq(0, 140, 20)) # c(0, 0.2, 0.5, 1, 2, 5, 10, 20, 40)
drawMap(landUseFootprint2011ByCountry, "lu_footprint_map_2011.pdf", legendDivisions=c(0, 0.2, 0.5, 1, 2, 5, 10, 20, 40))
#drawMap(halfIndexes1961ByCountry, "half_map_1961.pdf") # missing countries (e.g. USSR states) makes this not so useful

# Histograms
#dt = merge(halfIndexes2011ByCountry[Country!="World" & type == "Overall" & agri_index > 0], country_data[Year == 2011, list(Country, population)], by='Country')
#ggplot(dt, aes(x = agri_index)) + geom_histogram(binwidth=1) + labs(x="HALF index", y="Country count") 
		
#ggplot(dt, aes(x = agri_index, weight=population)) + geom_histogram(binwidth=1) + labs(x="HALF index", y="Population count (millions)") 





#dt = merge(country_data[Year >= 1990 & Country %in% c("World", "Australia")], country_data[Year == 1998 & Country %in% c("World", "Australia")], by='Country')[, list(Country, Year=Year.x, diff=perm_pasture.x - perm_pasture.y)]
#ggplot(data = dt, aes(x=Year, y=diff, colour = Country)) + geom_line() + labs(x="Year", y="Pasture area change from 1998 (Mha)")
		
# extract nutrient range
dt = merge(con_prod[Country == "World" & Year == 2011, list (Item, mj_per_kg, protein_g_per_kg)], con_prod[Year == 2011, list(Country, Year, Item, food_pc_pd = food/population/365*1000)], by='Item')
dt[food_pc_pd > 0, list(energy=sum(mj_per_kg*food_pc_pd, na.rm=TRUE), protein=sum(protein_g_per_kg*food_pc_pd, na.rm=TRUE)), by=list(Country, Year)]