require(data.table)
require(reshape2)

data_dir_root = "~/Documents/LURG/Data"
fao_data_dir = paste0(data_dir_root, "/FAOStat-Sep2018")

country_data = readCountryData()
com_bal = readCommoditiyBalance()
crop_prod = readCropProd()
food_supply = readFoodSupply()

		
prod_c = copy(crop_prod) 

prod_c=rbind(prod_c, prod_c[Item=="Rice paddy", list(Country, Year, Item="Rice (Paddy Equivalent)", area, prod)])
prod_c[Item=="Rice paddy"]$Item = "Rice (Milled Equivalent)"
prod_c[Item=="Soybeans"]$Item = "Soyabeans"
prod_c[Item=="Coconuts"]$Item = "Coconuts - Incl Copra"
prod_c[Item=="Groundnuts with shell"]$Item = "Groundnuts (Shelled Eq)" 
prod_c[Item=="Rapeseed"]$Item = "Rape and Mustardseed" 
prod_c[Item=="Onions dry"]$Item = "Onions" 
prod_c[Item=="Peas dry"]$Item = "Peas" 
prod_c[Item=="Beans dry"]$Item = "Beans" 
prod_c[Item=="Lemons and limes"]$Item = "Lemons Limes" 
prod_c[Item=="Coffee green"]$Item = "Coffee" 
prod_c[Item=="Grapefruit (inc. pomelos)"]$Item = "Grapefruit" 
prod_c[Item=="Grapes"]$Item = "Grapes (excl wine)"
prod_c[Item=="Olives"]$Item = "Olives (including preserved)"
prod_c[Item=="Cocoa beans"]$Item = "Cocoa Beans" 
prod_c[Item=="Chillies and peppers green"]$Item = "Pimento"

combineProduction = function(consumed, prodList) {
	dt = rbind(prod_c, prod_c[Item %in% prodList, list(Item=consumed, area=sum(area), prod=sum(prod)), by=list(Country, Year)], use.names=TRUE)
	dt[!Item %in% prodList]
}

prod_c = combineProduction("Tea (including mate)",c("Tea", "Mat"))
prod_c = combineProduction("Oranges Mandarines",c("Oranges", "Tangerines mandarins clementines satsumas"))
prod_c = combineProduction("Fruits Other",c("Apricots", "Cherries", "Watermelons", "Mangoes mangosteens guavas", "Melons other (inc.cantaloupes)", "Fruit tropical fresh nes", 
				"Fruit fresh nes", "Pears", "Peaches and nectarines", "Persimmons", "Plums and sloes", "Strawberries", "Kiwi fruit", "Cherries sour", "Figs"))
prod_c = combineProduction("Citrus Other",c("Fruit citrus nes"))
prod_c = combineProduction("Roots Other",c("Roots and tubers nes", "Taro (cocoyam)"))
prod_c = combineProduction("Vegetables Other", c("Artichokes", "Asparagus", "Avocados", "Beans green", "Broad beans horse beans dry", "Cabbages and other brassicas", 
				"Cauliflowers and broccoli", "Chillies and peppers dry", "Cow peas dry", "Cucumbers and gherkins", "Eggplants (aubergines)", "Garlic", 
				"Vegetables leguminous nes", "Leeks other alliaceous vegetables", "Lettuce and chicory", "String beans", "Cashewapple", "Mushrooms and truffles", "Vetches", 
				"Okra", "Onions shallots green", "Peas green", "Papayas", "Pigeon peas", "Pumpkins squash and gourds", "Spinach", "Vegetables fresh nes",
				"Yautia (cocoyam)", "Pepper (piper spp.)", "Chicory roots", "Carrots and turnips"))
prod_c = combineProduction("Cereals Other",c("Cereals nes", "Grain mixed", "Maize green", "Triticale"))
prod_c = combineProduction("Pulses Other",c("Buckwheat", "Chick peas", "Lentils", "Pulses nes", "Carobs", "Lupins", "Fonio"))
prod_c = combineProduction("Spices Other",c("Spices nes","Ginger", "Anise badian fennel coriander"))
prod_c = combineProduction("Oilcrops Other",c("Linseed", "Castor oil seed", "Oilseeds nes", "Mustard seed", "Safflower seed", "Tallowtree seed"))
prod_c = combineProduction("Nuts",c("Nuts nes", "Almonds with shell", "Walnuts with shell", "Chestnut", "Cashew nuts with shell", "Hazelnuts with shell", "Areca nuts", "Pistachios", 
				"Karite nuts (sheanuts)", "Kola nuts", "Brazil nuts with shell", "Tung nuts"))
prod_c = combineProduction("Rape and Mustardseed",c("Rapeseed","Mustard seed"))


consump = merge(com_bal, food_supply, by=c('Country', 'Year', 'Item'), all.x=TRUE)
con_prod = merge(consump[, list(Country, Year, Item, com_bal_prod=prod, food, processing, feed, seed, other, waste, stockvar, net_import=import-export, energy_kcal_pc, protein_g_pc)],
				prod_c[, list(Country, Year, Item, prod, prod_area=area)], by=c('Country', 'Year', 'Item'), all=TRUE)
con_prod[is.na(prod) & !is.na(com_bal_prod), prod:=com_bal_prod]
con_prod[, com_bal_prod:=NULL]
con_prod = merge(con_prod, country_data[, list(Country, Year, population)], by=c('Country', 'Year'))

itemDetails = getItemDetails()

# Processes commodities not handled if re-processed, and feed use of animal products also different
con_prod[Country == "World", c('net_import', 'waste') := list(0, waste-net_import)]
con_prod[, used := food+processing+feed+other-stockvar]

con_prod[Item %in% itemDetails[produced==FALSE & animal==FALSE]$Item & ! Item %in% c("Cottonseed", "Molasses"), c('food', 'processing') := list(food + processing, 0)] # small amounts of processed comm. are themselves processed, assumed to be food, Cottonseed and Molasses handled separately
con_prod[Item %in% itemDetails[animal==TRUE]$Item, c('food', 'processing', 'feed', 'seed') := list(food + processing, 0, feed + seed, 0)] # for animal prod, feed include eggs used as 'seed', processing is assumed as food


# not including animal product feed as 'used' or HALF calc, might need to remove for Sankey
# THIS IS A PROBLEM - feed does need to be included for Sankey
con_prod[Item %in% itemDetails[animal==TRUE]$Item, used := food+feed+other-stockvar] 


# no com bal for oil palm fruit, assume all processed
con_prod[Item == "Oil palm fruit", c('used', 'processing'):=list(prod, prod)]


# Function to split primary crop areas by processed commodities
splitCropArea = function(processedComm, dtResultantComms) {
	if (dtResultantComms[, sum(fraction) != 1])
		print ("ERROR: total fraction is not 1")
	
	processing_area = con_prod[Item == processedComm, list(Country, Year, total_processing_area=processing/used*prod_area, dummy=1)]
	fractional_area = merge(processing_area, cbind(dtResultantComms, dummy=1), by='dummy', allow.cartesian=TRUE)[, list(Country, Year, Item, fract_area = total_processing_area*fraction)]
	
	dt = merge(con_prod, fractional_area, by=c('Country', 'Year', 'Item'), all.x=TRUE)
	dt[!is.na(fract_area), prod_area:=sum(prod_area, fract_area, na.rm=TRUE), by=list(Country, Year, Item)] # adds to any existing areas
	dt[, fract_area:=NULL]
	
	# if it's not a primary commodity need to decrement the prod area (or will get double counting)
	if (processedComm %in% itemDetails[produced == FALSE]$Item) {
		dt[Item == processedComm, c('prod_area', 'processing', 'used', 'prod') := list(prod_area - processing/used*prod_area, 0, used-processing, prod-processing)]
	}
	
	dt
}

# Cotton is a tricky one
con_prod[Item=="Seed cotton", c('food', 'processing', 'feed', 'seed', 'other', 'waste', 'used', 'stockvar', 'net_import') := list(0, prod, 0, 0, 0, 0, prod, 0, 0)]
con_prod = splitCropArea("Seed cotton", data.table(Item=c("Cotton lint", "Cottonseed"), fraction=c(0.85, 0.15)))
con_prod = splitCropArea("Cottonseed", data.table(Item=c("Cottonseed Cake", "Cottonseed Oil"), fraction=c(0.5, 0.5))) 

#Also sugar is, particularly Molasses are complicated
con_prod = splitCropArea("Sugar cane", data.table(Item=c("Sugar (Raw Equivalent)", 'Molasses', "Sugar non-centrifugal"), fraction=c(0.7, 0.26, 0.04)))
con_prod = splitCropArea("Sugar beet", data.table(Item=c("Sugar (Raw Equivalent)"), fraction=c(1.0))) # adds to area from sugar cane
con_prod = splitCropArea("Molasses", data.table(Item=c("Sugar (Raw Equivalent)"), fraction=c(1.0))) 

# 1-1 primary crop to processed commodity
con_prod = splitCropArea("Wheat", data.table(Item=c("Beverages Fermented"), fraction=c(1)))
con_prod = splitCropArea("Barley", data.table(Item=c("Beer"), fraction=c(1)))
con_prod = splitCropArea("Olives (including preserved)", data.table(Item=c("Olive Oil"), fraction=c(1)))
con_prod = splitCropArea("Grapes (excl wine)", data.table(Item=c("Wine"), fraction=c(1)))
con_prod = splitCropArea("Potatoes", data.table(Item=c("Beverages Fermented"), fraction=c(1)))

# 50/50 split primary crop to processed commodity
con_prod = splitCropArea("Soyabeans", data.table(Item=c("Soyabean Oil", "Soyabean Cake"), fraction=c(0.5, 0.5)))
con_prod = splitCropArea("Coconuts - Incl Copra", data.table(Item=c("Coconut Oil", "Copra Cake"), fraction=c(0.5, 0.5)))
con_prod = splitCropArea("Sunflower seed", data.table(Item=c("Sunflowerseed Oil", "Sunflowerseed Cake"), fraction=c(0.5, 0.5)))
con_prod = splitCropArea("Groundnuts (Shelled Eq)", data.table(Item=c("Groundnut Oil", "Groundnut Cake"), fraction=c(0.5, 0.5)))
con_prod = splitCropArea("Sesame seed", data.table(Item=c("Sesameseed Oil", "Sesameseed Cake"), fraction=c(0.5, 0.5)))
con_prod = splitCropArea("Oilcrops Other", data.table(Item=c("Oilcrops Oil Other", "Oilseed Cakes Other"), fraction=c(0.5, 0.5)))
con_prod = splitCropArea("Rape and Mustardseed", data.table(Item=c("Rape and Mustard Oil", "Rape and Mustard Cake"), fraction=c(0.5, 0.5)))

# other splits 
con_prod = splitCropArea("Maize", data.table(Item=c("Sweeteners Other", "Maize Germ Oil"), fraction=c(0.9, 0.1))) # Corn syrup and similar
con_prod = splitCropArea("Oil palm fruit", data.table(Item=c("Palm Oil", "Palmkernel Cake", "Palmkernel Oil"), fraction=c(0.78, 0.11, 0.11)))
con_prod = splitCropArea("Rice (Milled Equivalent)", data.table(Item=c("Beverages Alcoholic", "Ricebran Oil"), fraction=c(0.8, 0.2)))

# one or two crops with a little processing where we are not tracking, assume its all food
con_prod[ Item %in% c('Sorghum', 'Plantains', 'Millet', 'Fruits Other', 'Rye', 'Apples', 'Roots Other', "Grapefruit", "Oats", "Pineapples", "Sweet potatoes", "Cocoa Beans", "Oranges Mandarines",
				"Citrus Other", "Lemons Limes", "Cereals Other", "Vegetables Other", "Bananas"), c('food', 'processing') := list(food + processing, 0)]

# Calc nutritional values (only use the World/2011 ones, but all calculated)
con_prod[, mj_per_kg:=energy_kcal_pc*population*365/food/1000/239.006] 
con_prod[, protein_g_per_kg:=protein_g_pc*population*365/food/1000]

con_prod[Item == "Sugar (Raw Equivalent)", protein_g_per_kg:=0]
con_prod[Item == "Sugar beet", c('mj_per_kg', 'protein_g_per_kg'):= list(0.188 * 14.8, 0.188 * 7.8 * 10)] # feedpedia assuming 19% moisture and 16 MJ/kg DM, and 7.8% protein by DM
con_prod[Item == 'Soyabean Cake', c('mj_per_kg', 'protein_g_per_kg'):= list( 0.879 * 9.3, 0.879 * 43.8 * 10)]
con_prod[Item == 'Rape and Mustard Cake', c('mj_per_kg', 'protein_g_per_kg'):= list( 0.901 * 11.7, 0.901 * 39 * 10)]
con_prod[Item %like% ' Cake' & is.na(mj_per_kg), c('mj_per_kg', 'protein_g_per_kg') := list( 0.922 * 12.3, 0.922 * 45 * 10)] # based on cottonseed cake, the next highest
con_prod[Item == 'Cotton lint', c('mj_per_kg', 'protein_g_per_kg'):= list( 20, 900)]
con_prod[Item == 'Cottonseed', c('mj_per_kg', 'protein_g_per_kg'):= list( 18, 310)] # based on Cottonseed Oil and Cake output, and mass lost
con_prod[Item == 'Seed cotton', c('mj_per_kg', 'protein_g_per_kg'):= list( 19, 510)] # based on Cotton lint and Cottonseed output, and mass lost
con_prod[Item == 'Molasses', c('mj_per_kg', 'protein_g_per_kg'):= list( .73 * 13, 0.73 * 5.5 * 10)] # feedpedia
con_prod[Item == 'Rape and Mustardseed', c('mj_per_kg', 'protein_g_per_kg'):= list( 22, 205)] # based on cake and oil, and mass lost
con_prod[Item == 'Oil palm fruit', c('mj_per_kg', 'protein_g_per_kg'):= list(11, (9.26 + 11.9) /2 * 10)] # based on http://www.fao.org/docrep/003/w3647e/W3647E04.htm

# The amount of sugar cane eaten is tiny (<1%), but the energy from it appears incorrect, updating the food amount so as not to push out the human consumption figures
sugarcane_mj_per_kg = 0.234 * 11.3
con_prod[Item == "Sugar cane" & food > 0, c('mj_per_kg', 'protein_g_per_kg', 'food', 'used', 'prod') 
			:= list(sugarcane_mj_per_kg, 0.234 * 9.3 * 10, food*mj_per_kg/sugarcane_mj_per_kg, used - food*(1-mj_per_kg/sugarcane_mj_per_kg), prod - food*(1-mj_per_kg/sugarcane_mj_per_kg))]

# Add use of forage crops, as feed
con_prod[Item == "Forage crops", c('feed', 'used', 'mj_per_kg', 'protein_g_per_kg') := list (prod*.98, prod*.98, 12 * 0.30, 60 * 0.30)] # 30% DM, 2% losses based on years prior to 2010 (after which feed amount is not provided).

# Just select the rows we want
con_prod = con_prod[Item %in% itemDetails$Item & Year < 2014 & Country %in% getCountryCodes()$Country] # 2012 and 2013 incomplete in current dataset (dec 2015), this is all you should need to change to all these years to be calculated

# Data for setaside / fallow rates
con_prod_unadj = copy(con_prod)

# get actual cropland area, and adjust to match it
crop_adj = merge(con_prod[Item %in% itemDetails[produced == TRUE]$Item, list(crop_land_alloc = sum(prod_area, na.rm=TRUE)), by=list(Country, Year)], country_data[, list(Country, Year, cropland_real=perm_crops+arable)], by=c('Country', 'Year'))
crop_adj[Country == "World" & Year ==2011]
crop_adj = crop_adj[, list(Country, Year, crop_adj = cropland_real/crop_land_alloc)]
con_prod = merge(con_prod, crop_adj, by=c('Country', 'Year'))
con_prod[, prod_area := crop_adj*prod_area]


# handle international trade of vegetal commodities
allocateExports = function(dt) {
	areas_exported=dt[net_import < 0 & prod > 0, list(world_export_area=-sum(prod_area*net_import/(prod-waste), na.rm=TRUE), world_export=-sum(net_import)), by=list(Item, Year)]
	dt = merge(dt, areas_exported, by=c('Item', 'Year'), all.x=TRUE)
	dt[net_import > 0, imported_area := net_import*world_export_area/world_export] #imports based on global average yield
	dt[net_import <= 0 & prod > 0, imported_area := (prod_area*net_import/(prod-waste))] #exports based on that countries yield
	dt[is.na(dt)] = 0
	dt[, net_area := prod_area+imported_area]
	dt
}

con_prod = allocateExports(con_prod)

# allocate to use, with waste divided across other uses
con_prod[, c('feed_area', 'food_area', 'other_area', 'waste_area', 'processing_area', 'stockvar_area', 'seed_area') := 
				list(net_area*feed/used, net_area*food/used, net_area*other/used, net_area*waste/(used+waste), net_area*processing/used, net_area*stockvar/used, net_area*seed/used)]

con_prod_checkpoint = copy(con_prod)

calcAnimalStuff = function(cp, fcrDt) {
	# work out animal feed
	cp = merge(cp, fcrDt[, list(Item, fcr)], by=c('Item'), all.x=TRUE)
	cp = merge(cp, itemDetails[, list(Item, dryMatter, commType)], by=c('Item'))
	cp = merge(cp, cp[is.na(fcr) & !is.infinite(feed_area), list(feed_area_t=sum(feed_area, na.rm=TRUE), feed_t=sum(dryMatter*feed, na.rm=TRUE)), by=list(Country, Year)], by=c('Country', 'Year'))
	cp = merge(cp, country_data[, list(Country, Year, pasture_t=perm_pasture+temp_pasture)], by=c('Country', 'Year'))
	
	# chicken/eggs/pork use just feed
	cp[Item %in% fcrDt[justFeed==TRUE]$Item, fcr:= fcr*(1 + (2011 - Year)/50)] # historical fcr twice as high, after Havenstein (2006).  Although only relevant when HALF calculated with changing prod system

	# needed when dealing with some countries, not binding at global scale, i.e. in the main analysis
	monoToRuminantRatio = cp[Item %in% fcrDt[justFeed==TRUE]$Item,  list(monoRatio = sum(fcr*prod/feed_t)), by=list(Country, Year)]
	monoToRuminantRatio[monoRatio <=1, monoAdj:=1]
	monoToRuminantRatio[monoRatio >1, monoAdj:=1/(monoRatio*1.1)]
	cp = merge(cp, monoToRuminantRatio, by=c('Country', 'Year'))
	
	cp[Item %in% fcrDt[justFeed==TRUE]$Item, c('animal_a_feed', 'animal_a_pasture') := list(monoAdj*fcr*prod/feed_t*feed_area_t, 0)]
	cp[, feed_area_t := feed_area_t - sum(animal_a_feed, na.rm=TRUE), by=list(Country, Year)] # work out how much feed is left
	
	# allocate this and pasture over other animal products
	cp[Item %in% fcrDt[justFeed==FALSE]$Item, ruminant_ratio := fcr*prod/sum(fcr*prod, na.rm=TRUE), by=list(Country, Year)]
	cp[Item %in% fcrDt[justFeed==FALSE]$Item, c('animal_a_feed', 'animal_a_pasture') := list(ruminant_ratio*feed_area_t, ruminant_ratio*pasture_t)]
	
	cp[, feed_area_t:=NULL]
	cp[, pasture_t:=NULL]
	cp[, ruminant_ratio:=NULL]
	cp[, monoRatio:=NULL]
	
	cp
}

con_prod = calcAnimalStuff(con_prod, getFeedConvRatio())

allocateMeatExports = function(dt) {
	areas_exported=dt[!is.na(fcr) & net_import < 0, list(world_export_area_feed=-sum(animal_a_feed*net_import/(prod-waste), na.rm=TRUE), 
					world_export_area_pasute=-sum(animal_a_pasture*net_import/(prod-waste), na.rm=TRUE),
					world_export_animal=-sum(net_import)), by=list(Item, Year)]
	dt = merge(dt, areas_exported, by=c('Item', 'Year'), all.x=TRUE)
	dt[!is.na(fcr) & net_import > 0, imported_feed_area := net_import*world_export_area_feed/world_export_animal] #imports based on global average yield
	dt[!is.na(fcr) & net_import > 0, imported_pasture_area := net_import*world_export_area_pasute/world_export_animal] #imports based on global average yield
	dt[!is.na(fcr) & net_import <= 0, imported_feed_area := (animal_a_feed*net_import/(prod-waste))] #exports based on that countries yield
	dt[!is.na(fcr) & net_import <= 0, imported_pasture_area := (animal_a_pasture*net_import/(prod-waste))] #exports based on that countries yield
	dt[, animal_a_feed := animal_a_feed+imported_feed_area]
	dt[, animal_a_pasture := animal_a_pasture+imported_pasture_area]
	dt
}

con_prod = allocateMeatExports(con_prod)


write.table(merge(itemDetails, con_prod[Country == "World" & Year == 2011, list(Item, mj_per_kg, protein_g_per_kg)], by='Item'), 
		"/Users/peteralexander/Documents/LURG/Alt\ Scenarios/figures/items.csv", row.names=FALSE, sep=",")
