con_prod_to_use = con_prod[Year == 2013]
regional = merge(con_prod_to_use, fread(paste0(data_dir_root, "/HALF/gustavsson_country_regions.csv")), by=c('Country'))

country_prod = regional[, list(Country, GustRegion, Item, commType, food, feed, used)]

waste_rates = fread(paste0(data_dir_root, "/HALF/wasteRatesAll.csv"))
waste_rates = melt(waste_rates, id.vars=c("GustRegion", "commType"), value.name="lossrate", variable.name="stage")

agProd = merge(country_prod, waste_rates[stage=="Agricultural Production"], by=c('GustRegion', 'commType'))
agProd = melt(agProd, measure.vars=c("food", "feed"), variable.name="use", value.name="outAmount")
agProd[, loss:= outAmount * lossrate / (1-lossrate)]
agProd[, inAmount:= outAmount + loss]
agProd[, used:=NULL]

postHarvest = merge(agProd[, list(Country, GustRegion, commType, Item, use, inAmount=outAmount)], waste_rates[stage=="Handling and storage"], by=c('GustRegion', 'commType'))
postHarvest[, loss:= inAmount * lossrate]
postHarvest[, outAmount:= inAmount - loss]

processing = merge(postHarvest[use == "food", list(Country, GustRegion, commType, Item, use, inAmount=outAmount)], waste_rates[stage=="Processing"], by=c('GustRegion', 'commType'))
processing[, loss:= inAmount * lossrate]
processing[, outAmount:= inAmount - loss]

distrubution = merge(processing[, list(Country, GustRegion, commType, Item, use, inAmount=outAmount)], waste_rates[stage=="Distrubution"], by=c('GustRegion', 'commType'))
distrubution[, loss:= inAmount * lossrate]
distrubution[, outAmount:= inAmount - loss]

consumerWaste = merge(distrubution[, list(Country, GustRegion, commType, Item, use, inAmount=outAmount)], waste_rates[stage=="Consumer waste"], by=c('GustRegion', 'commType'))
consumerWaste[, loss:= inAmount * lossrate]
consumerWaste[, outAmount:= inAmount - loss]

lossDt = rbind(agProd, postHarvest, processing, distrubution, consumerWaste)
lossDt = merge(lossDt, con_prod_to_use[Country=="World", list(Item, dryMatter, mj_per_kg, protein_g_per_kg)], by=c('Item'))

lossSummary = rbind(
		lossDt[use=="food", list(type="wetGt", inAmount=sum(inAmount)/1000, loss=sum(loss)/1000, outAmount=sum(outAmount)/1000), by=list(stage, Country)],
		lossDt[use=="food", list(type="dryGt", inAmount=sum(inAmount*dryMatter)/1000, loss=sum(loss*dryMatter)/1000, outAmount=sum(outAmount*dryMatter)/1000), by=list(stage, Country)],
		lossDt[use=="food", list(type="energyEJ", inAmount=sum(inAmount*mj_per_kg)/1000, loss=sum(loss*mj_per_kg)/1000, outAmount=sum(outAmount*mj_per_kg)/1000), by=list(stage, Country)],
		lossDt[use=="food", list(type="proteinMt", inAmount=sum(inAmount*protein_g_per_kg)/1000, loss=sum(loss*protein_g_per_kg)/1000, outAmount=sum(outAmount*protein_g_per_kg)/1000), by=list(stage, Country)]
)

# Overconsumption losses
nutritentRequired = rbind(
		country_data[Year==2013, list(Country, type="energyEJ", requiredAmount=9.8 * population*365/1000000)], # 9.8 MJ/person/day
		country_data[Year==2013, list(Country, type="proteinMt", requiredAmount=52 * population*365/1000000 )] # 52g/person/day
)

nutritentSupplied = lossSummary[stage=="Consumer waste", list(stage="Over-consumption", Country, type, inAmount=outAmount)]

overeating = merge(nutritentRequired, nutritentSupplied, by=c("Country", "type"))
overeating[, loss:=inAmount-requiredAmount]
overeating[loss<0, loss:=0]
overeating[, outAmount:=inAmount-loss] # need this to avoid out being outAmount being greater than inAmount
overeating[, requiredAmount:=NULL]

# assuming energy is more constraining (which it is in 2013 globally)
wetDryOverConsup=merge(lossSummary[stage=="Consumer waste" & type %in% c("wetGt", "dryGt"), list(Country, type, inAmount=outAmount)], overeating[type=="energyEJ", list(stage, Country, lossRate=loss/inAmount)], by="Country")
wetDryOverConsup[, loss:=inAmount*lossRate]
wetDryOverConsup[, outAmount:=inAmount-loss]
wetDryOverConsup[, lossRate:=NULL]
overeating = rbind(overeating, wetDryOverConsup)

lossSummary = rbind(lossSummary, overeating)


# Livestock production losses
livestockInputs = rbind(
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item & stage == "Handling and storage", list(type="wetGt", inAmount=sum(outAmount)/1000), by=list(Country)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item & stage == "Handling and storage", list(type="dryGt", inAmount=sum(outAmount*dryMatter)/1000), by=list(Country)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item & stage == "Handling and storage", list(type="energyEJ", inAmount=sum(outAmount*mj_per_kg)/1000), by=list(Country)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item & stage == "Handling and storage", list(type="proteinMt", inAmount=sum(outAmount*protein_g_per_kg)/1000), by=list(Country)]
)

rp_dt = merge(country_prod, con_prod_to_use[Country=="World", list(Item, dryMatter, mj_per_kg, protein_g_per_kg)], by=c('Item'))

livestockOutputs = rbind(
		rp_dt[Item %in% itemDetails[animal==TRUE]$Item, list(type="wetGt", food=sum(food)/1000, used=sum(used)/1000), by=Country],
		rp_dt[Item %in% itemDetails[animal==TRUE]$Item, list(type="dryGt", food=sum(food*dryMatter)/1000, used=sum(used*dryMatter)/1000), by=Country],
		rp_dt[Item %in% itemDetails[animal==TRUE]$Item, list(type="energyEJ", food=sum(food*mj_per_kg)/1000, used=sum(used*mj_per_kg)/1000), by=Country],
		rp_dt[Item %in% itemDetails[animal==TRUE]$Item, list(type="proteinMt", food=sum(food*protein_g_per_kg)/1000, used=sum(used*protein_g_per_kg)/1000), by=Country]
)
livestock = merge(livestockInputs, livestockOutputs, by=c("Country","type"))
livestock[, loss:=(inAmount-used)]
livestock[loss<0, loss:=0]
livestock_foodloss=livestock[, list(Country, type, inAmount=inAmount*food/used, loss=loss*food/used, food_rate=food/used)]

livestockFeed = rbind(
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item , list(type="wetGt", inAmount=sum(inAmount)/1000, loss=sum(loss)/1000, outAmount=sum(outAmount)/1000), by=list(stage, Country)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item , list(type="dryGt", inAmount=sum(inAmount*dryMatter)/1000, loss=sum(loss*dryMatter)/1000, outAmount=sum(outAmount*dryMatter)/1000), by=list(stage, Country)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item , list(type="energyEJ", inAmount=sum(inAmount*mj_per_kg)/1000, loss=sum(loss*mj_per_kg)/1000, outAmount=sum(outAmount*mj_per_kg)/1000), by=list(stage, Country)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item , list(type="proteinMt", inAmount=sum(inAmount*protein_g_per_kg)/1000, loss=sum(loss*protein_g_per_kg)/1000, outAmount=sum(outAmount*protein_g_per_kg)/1000), by=list(stage, Country)]
)

adj_livestockFeed = merge(livestockFeed, livestock_foodloss[, list(Country, type, food_rate)], by=c("Country","type"))
adj_livestockFeed=adj_livestockFeed[, list(Country, type, stage, inAmount=inAmount*food_rate, loss=loss*food_rate, outAmount=outAmount*food_rate)]

lossWithoutLivestockProd=lossDt[use=="food" & !(commType %in% c("Meat", "Milk") & stage %in% c("Agricultural Production", "Handling and storage"))]

lossSummaryWithoutLivestockProd = rbind(
		lossWithoutLivestockProd[, list(type="wetGt", inAmount=sum(inAmount)/1000, loss=sum(loss)/1000, outAmount=sum(outAmount)/1000), by=list(stage, Country)],
		lossWithoutLivestockProd[, list(type="dryGt", inAmount=sum(inAmount*dryMatter)/1000, loss=sum(loss*dryMatter)/1000, outAmount=sum(outAmount*dryMatter)/1000), by=list(stage, Country)],
		lossWithoutLivestockProd[, list(type="energyEJ", inAmount=sum(inAmount*mj_per_kg)/1000, loss=sum(loss*mj_per_kg)/1000, outAmount=sum(outAmount*mj_per_kg)/1000), by=list(stage, Country)],
		lossWithoutLivestockProd[, list(type="proteinMt", inAmount=sum(inAmount*protein_g_per_kg)/1000, loss=sum(loss*protein_g_per_kg)/1000, outAmount=sum(outAmount*protein_g_per_kg)/1000), by=list(stage, Country)]
)

lossSummaryWithlivestock=rbind(lossSummaryWithoutLivestockProd, adj_livestockFeed)[, list(inAmount=sum(inAmount), loss=sum(loss), outAmount=sum(outAmount)), by=list(stage, Country, type)]
lossSummaryWithlivestock=rbind(lossSummaryWithlivestock, livestock_foodloss[, list(Country, type, stage="Livestock production", inAmount, loss, outAmount=inAmount-loss)], fill=TRUE)
lossSummaryWithlivestock = rbind(lossSummaryWithlivestock, overeating)


#Some summary stats
summariseLosses = function(dt) {
	dt=rbind(dt, dt[, list(Country="World", inAmount=sum(inAmount, na.rm=TRUE), loss=sum(loss, na.rm=TRUE), outAmount=sum(outAmount, na.rm=TRUE)), by=list(type, stage)])
	
	dt = merge(dt, dt[stage=="Agricultural Production", list(Country, type, initialAmount=inAmount)], by=c("Country","type"))
	dt = merge(dt, dt[stage=="Over-consumption", list(Country, type, finalAmount=outAmount)], by=c("Country","type"))
	dt[, lossOfInitialRate:=loss/initialAmount]
	dt[, lossAtStageRate:=loss/inAmount]
	dt[, totalLossRate:=(initialAmount-finalAmount)/initialAmount]
	dt[, adjustedLossRate:=lossAtStageRate*totalLossRate/sum(lossAtStageRate), by=c("Country","type")]
	
	dt[, stage := factor(stage, levels=rev(c('Agricultural Production', 'Livestock production', 'Handling and storage', 'Processing','Distrubution','Consumer waste','Over-consumption')))]
	dt
}

lossSummary2 = summariseLosses(lossSummary)
lossSummaryWithlivestock2 = summariseLosses(lossSummaryWithlivestock)

lossSummary2$type = factor(lossSummary2$type, levels=c("dryGt", "energyEJ", "proteinMt", "wetGt"))
levels(lossSummary2$type) = c("Dry", "Energy", "Protein", "Wet")


require(ggplot2)
ggplot(lossSummary2[Country %in% c('China', 'India', 'Brazil', 'Nigeria', 'United States of America', 'World')], aes(x= type, y=adjustedLossRate*100, fill=stage) ) + 
		geom_bar(stat="identity") + facet_grid(. ~ Country) +
		theme_minimal() + 
		theme(text = element_text(size=11),
				legend.title=element_blank(),
				axis.text.x = element_text(size=10),
				panel.grid.minor.y = element_blank(), 
				panel.grid.major.x = element_blank(),
				legend.position="bottom",
				legend.direction = "horizontal",
				panel.grid.minor.x = element_blank(), 
				panel.background = element_rect(colour = "black", size =.4)) +
		scale_fill_manual(values =  c("#A6CEE3", "#1F78B4", "#B2DF8A", "#33A02C", "#FB9A99", "#E31A1C")) + 
		labs(x="", y="Loss rate (%)") +
		ggsave(file=paste0("~/Documents/LURG/Papers/Marginal gains/data/countrylosses.pdf"),width=14,height=6)



write.table(lossSummary2[, list(Country, type, stage, inAmount, outAmount, loss, lossOfInitialRate, lossAtStageRate)], 
		"~/Documents/LURG/Papers/Marginal gains/data/countrylosses.csv", row.names=FALSE, sep=",")
