outputLossData = function(aCountry, aYear=2013, aCommodity=NA, outputDir="/Users/peteralexander/Documents/LURG/Alt\ Scenarios/figures2/") {
	con_prod_to_use = con_prod[Year == aYear]
	cp_country = con_prod_to_use[Country == aCountry]
	if (!is.na('aCommodity')) cp_country = cp_country[Item == aCommodity]
	
	fibreDt = cp_country[Item == "Cotton lint", list("Crops to fibre",
					fibre_Gt=(prod+net_import)/1000, fibre_DryGt=(prod+net_import)*dryMatter/1000, fibre_EJ=(prod+net_import)*20/1000, fibre_protein_Mt=(prod+net_import)*.90, fibre_Mha = prod_area)]
	
	harvest_wet = cp_country[Item %in% itemDetails[produced==TRUE]$Item & Item != "Forage crops", 
			list(des ="Crops harvested", type="wetGt", 
					total=sum(prod+net_import, na.rm=TRUE)/1000, 
					food=sum(food, na.rm=TRUE)/1000, 
					feed=sum(feed, na.rm=TRUE)/1000, 
					seed=sum(seed, na.rm=TRUE)/1000,
					processing=sum(processing, na.rm=TRUE)/1000, 
					bioenergy=sum(other, na.rm=TRUE)/1000 - fibreDt$fibre_Gt, 
					fibre = fibreDt$fibre_Gt,
					stockvar= -sum(stockvar, na.rm=TRUE)/1000,
					losses=sum(prod+net_import-used, na.rm=TRUE)/1000
					)]
	
	harvest_dry = cp_country[Item %in% itemDetails[produced==TRUE]$Item & Item != "Forage crops", 
					list(des ="Crops harvested", type="dryGt", 
							total=sum((prod+net_import)*dryMatter, na.rm=TRUE)/1000, 
							food=sum(food*dryMatter, na.rm=TRUE)/1000, 
							feed=sum(feed*dryMatter, na.rm=TRUE)/1000, 
							seed=sum(seed*dryMatter, na.rm=TRUE)/1000, 
							processing=sum(processing*dryMatter, na.rm=TRUE)/1000, 
							bioenergy=sum(other*dryMatter, na.rm=TRUE)/1000 - fibreDt$fibre_DryGt, 
							fibre = fibreDt$fibre_DryGt,
							stockvar= -sum(stockvar*dryMatter, na.rm=TRUE)/1000,
							losses=sum((prod+net_import-used)*dryMatter, na.rm=TRUE)/1000
					)]
			
	harvest_energy = cp_country[Item %in% itemDetails[produced==TRUE]$Item & Item != "Forage crops", 
			list(des ="Crops harvested", type="energyEJ", 
					total=sum((prod+net_import)*mj_per_kg, na.rm=TRUE)/1000, 
					food=sum(food*mj_per_kg, na.rm=TRUE)/1000, 
					feed=sum(feed*mj_per_kg, na.rm=TRUE)/1000, 
					seed=sum(seed*mj_per_kg, na.rm=TRUE)/1000, 
					processing=sum(processing*mj_per_kg, na.rm=TRUE)/1000, 
					bioenergy=sum(other*mj_per_kg, na.rm=TRUE)/1000 - fibreDt$fibre_EJ, 
					fibre = fibreDt$fibre_EJ,
					stockvar= -sum(stockvar*mj_per_kg, na.rm=TRUE)/1000,
					losses=sum((prod+net_import-used)*mj_per_kg, na.rm=TRUE)/1000
			)]
	
	harvest_protein = cp_country[Item %in% itemDetails[produced==TRUE]$Item & Item != "Forage crops", 
			list(des ="Crops harvested", type="proteinMt", 
					total=sum((prod+net_import)*protein_g_per_kg, na.rm=TRUE)/1000, 
					food=sum(food*protein_g_per_kg, na.rm=TRUE)/1000, 
					feed=sum(feed*protein_g_per_kg, na.rm=TRUE)/1000, 
					seed=sum(seed*protein_g_per_kg, na.rm=TRUE)/1000, 
					processing=sum(processing*protein_g_per_kg, na.rm=TRUE)/1000, 
					bioenergy=sum(other*protein_g_per_kg, na.rm=TRUE)/1000 - fibreDt$fibre_protein_Mt, 
					fibre = fibreDt$fibre_protein_Mt,
					stockvar= -sum(stockvar*protein_g_per_kg, na.rm=TRUE)/1000,
					losses=sum((prod+net_import-used)*protein_g_per_kg, na.rm=TRUE)/1000
			)]
	
	
	harvest_area = cp_country[Item %in% itemDetails[produced==TRUE]$Item & Item != "Forage crops", 
			list(des ="Crops harvested", type="areaMha", 
					total=sum(prod_area, na.rm=TRUE), 
					food=sum(food_area, na.rm=TRUE), 
					feed=sum(feed_area, na.rm=TRUE), 
					seed=sum(seed_area, na.rm=TRUE), 
					processing=sum(processing_area, na.rm=TRUE), 
					bioenergy=sum(other_area, na.rm=TRUE) - fibreDt$fibre_Mha, 
					fibre = fibreDt$fibre_Mha,
					stockvar= -sum(stockvar_area, na.rm=TRUE),
					losses = NA
			)]
	
	crops_harvested = rbind(harvest_wet, harvest_dry, harvest_energy, harvest_protein, harvest_area)
	#crops_harvested[, list(type, total, feed + seed + food + processing + bioenergy + fibre + stockvar, losses)]
			
	# forage crops
	forage_crops = rbind(
		cp_country[Item == "Forage crops", list(des ="Forage crops", type="wetGt", total=prod/1000, feed=feed/1000, losses=(prod-feed)/1000)],
		cp_country[Item == "Forage crops", list(des ="Forage crops", type="dryGt", total=prod*dryMatter/1000, feed=feed*dryMatter/1000, losses=(prod-feed)*dryMatter/1000)],
		cp_country[Item == "Forage crops", list(des ="Forage crops", type="energyEJ", total=prod*mj_per_kg/1000, feed=feed*mj_per_kg/1000, losses=(prod-feed)*mj_per_kg/1000)],
		cp_country[Item == "Forage crops", list(des ="Forage crops", type="proteinMt", total=prod*protein_g_per_kg/1000, feed=feed*protein_g_per_kg/1000, losses=(prod-feed)*protein_g_per_kg/1000)],
		cp_country[Item == "Forage crops", list(des ="Forage crops", type="areaMha", total=prod_area, feed=food_area, losses=NA)]
	)
	
	# processing
	processed_wet = cp_country[Item %in% itemDetails[produced==FALSE & animal==FALSE]$Item, 
			list(des = 'Processed commodities',  type="wetGt",
					total=crops_harvested[type=="wetGt", processing] + sum(net_import, na.rm=TRUE)/1000, 
					food=sum(food, na.rm=TRUE)/1000, 
					feed=sum(feed, na.rm=TRUE)/1000, 
					processing=sum(processing, na.rm=TRUE)/1000, 
					bioenergy=sum(other, na.rm=TRUE)/1000, 
					stockvar= -sum(stockvar, na.rm=TRUE)/1000,
					losses = crops_harvested[type=="wetGt", processing] + sum(net_import - used, na.rm=TRUE)/1000
			)]
	
	processed_dry = cp_country[Item %in% itemDetails[produced==FALSE & animal==FALSE]$Item, 
			list(des = 'Processed commodities',  type="dryGt",
					total=crops_harvested[type=="dryGt", processing] + sum(net_import*dryMatter, na.rm=TRUE)/1000, 
					food=sum(food*dryMatter, na.rm=TRUE)/1000, 
					feed=sum(feed*dryMatter, na.rm=TRUE)/1000, 
					processing=sum(processing*dryMatter, na.rm=TRUE)/1000, 
					bioenergy=sum(other*dryMatter, na.rm=TRUE)/1000, 
					stockvar= -sum(stockvar*dryMatter, na.rm=TRUE)/1000,
					losses = crops_harvested[type=="dryGt", processing] + sum((net_import - used)*dryMatter, na.rm=TRUE)/1000
			)]
					
	processed_energy = cp_country[Item %in% itemDetails[produced==FALSE & animal==FALSE]$Item, 
			list(des = 'Processed commodities',  type="energyEJ",
					total = crops_harvested[type=="energyEJ", processing] + sum(net_import*mj_per_kg, na.rm=TRUE)/1000, 
					food=sum(food*mj_per_kg, na.rm=TRUE)/1000, 
					feed=sum(feed*mj_per_kg, na.rm=TRUE)/1000, 
					processing=sum(processing*mj_per_kg, na.rm=TRUE)/1000, 
					bioenergy=sum(other*mj_per_kg, na.rm=TRUE)/1000, 
					stockvar= -sum(stockvar*mj_per_kg, na.rm=TRUE)/1000,
					losses = crops_harvested[type=="energyEJ", processing] + sum((net_import - used)*mj_per_kg, na.rm=TRUE)/1000
			)]
	
	processed_protein = cp_country[Item %in% itemDetails[produced==FALSE & animal==FALSE]$Item, 
			list(des = 'Processed commodities',  type="proteinMt",
					total = crops_harvested[type=="proteinMt", processing] + sum(net_import*protein_g_per_kg, na.rm=TRUE)/1000, 
					food=sum(food*protein_g_per_kg, na.rm=TRUE)/1000, 
					feed=sum(feed*protein_g_per_kg, na.rm=TRUE)/1000, 
					processing=sum(processing*protein_g_per_kg, na.rm=TRUE)/1000, 
					bioenergy=sum(other*protein_g_per_kg, na.rm=TRUE)/1000, 
					stockvar= -sum(stockvar*protein_g_per_kg, na.rm=TRUE)/1000,
					losses = crops_harvested[type=="proteinMt", processing] + sum((net_import - used)*protein_g_per_kg, na.rm=TRUE)/1000
			)]
	
	processed_area = cp_country[Item %in% itemDetails[produced==FALSE & animal==FALSE]$Item, 
			list(des ="Processed commodities", type="areaMha", 
					total= crops_harvested[type=="areaMha", processing], 
					food=sum(food_area, na.rm=TRUE), 
					feed=sum(feed_area, na.rm=TRUE), 
					processing=sum(processing_area, na.rm=TRUE), 
					bioenergy=sum(other_area, na.rm=TRUE), 
					stockvar= -sum(stockvar_area, na.rm=TRUE),
					losses=NA
					# area losses should be zero, as already accounted for (small amount ~0.6 Mha due to some processing not taken into account).
	)]
	
	processed_commodities = rbind(processed_wet, processed_dry, processed_energy, processed_protein, processed_area)
	processed_commodities[losses<0, losses := 0]
	#processed_commodities[, list(type, total, feed + food + processing + bioenergy + stockvar )]
	
	animal_wet = cp_country[Item %in% itemDetails[animal==TRUE]$Item,
			list(des ="Animal product", type = "wetGt",
					total=sum((prod+net_import))/1000, 
					food=sum(food)/1000, 
					feed=sum(feed)/1000, 
					bioenergy=sum(other)/1000, 
					stockvar=-sum(stockvar)/1000,
					losses= sum(prod+net_import-used)/1000
			)]
	
	animal_dry = cp_country[Item %in% itemDetails[animal==TRUE]$Item,
			list(des ="Animal product", type = "dryGt",
					total=sum((prod+net_import)*dryMatter)/1000, 
					food=sum(food*dryMatter)/1000, 
					feed=sum(feed*dryMatter)/1000, 
					bioenergy=sum(other*dryMatter)/1000, 
					stockvar=-sum(stockvar*dryMatter)/1000,
					losses= sum((prod+net_import-used)*dryMatter)/1000
			)]
	
	
	animal_energy = cp_country[Item %in% itemDetails[animal==TRUE]$Item,
			list(des ="Animal product", type = "energyEJ",
					total=sum((prod+net_import)*mj_per_kg)/1000, 
					food=sum(food*mj_per_kg)/1000, 
					feed=sum(feed*mj_per_kg)/1000, 
					bioenergy=sum(other*mj_per_kg)/1000, 
					stockvar=-sum(stockvar*mj_per_kg)/1000,
					losses= sum((prod+net_import-used)*mj_per_kg)/1000
			)]
	
	animal_protein = cp_country[Item %in% itemDetails[animal==TRUE]$Item,
			list(des ="Animal product", type = "proteinMt",
					total=sum((prod+net_import)*protein_g_per_kg)/1000, 
					food=sum(food*protein_g_per_kg)/1000, 
					feed=sum(feed*protein_g_per_kg)/1000, 
					bioenergy=sum(other*protein_g_per_kg)/1000, 
					stockvar=-sum(stockvar*protein_g_per_kg)/1000,
					losses= sum((prod+net_import-used)*protein_g_per_kg)/1000
			)]
	
	animal_area = cp_country[Item %in% itemDetails[animal==TRUE]$Item,
			list(des ="Animal product", type = "areaMha",
					total=sum(animal_a_feed+animal_a_pasture), 
					food=sum((animal_a_feed+animal_a_pasture) * food/used), 
					feed=sum((animal_a_feed+animal_a_pasture) * feed/used), 
					bioenergy=sum((animal_a_feed+animal_a_pasture) * other/used),
					stockvar=-sum((animal_a_feed+animal_a_pasture) * stockvar/used),
					losses= NA
			)]
	
	animal_products = rbind(animal_wet, animal_dry, animal_energy, animal_protein, animal_area)
	#animal_products[, list(type, total, food + feed+  bioenergy + stockvar + losses)]
			
	sankey_dt = rbind(crops_harvested, forage_crops, processed_commodities, animal_products, fill=TRUE)
	#sankey_dt[, list(sum(food, na.rm=TRUE)), by=type]
	
	
	regional_food = merge(con_prod_to_use, fread(paste0(data_dir_root, "/HALF/gustavsson_country_regions.csv")), by=c('Country'))
	
	if (aCountry == "World") {
		regional_food = regional_food[, list(food = sum(food, na.rm=TRUE)), by=list(GustRegion, Item, commType)]
		# I think this is wrong, Country=="World" should be excluded from the sum, this seems to cause a problem that I dont have time to track down now
		missing = merge(regional_food[, list(reg_sum=sum(food)), by=list(Item, commType)], cp_country[, list(world=sum(food)), by=Item], by=c('Item'))[, list(GustRegion = "Missing", Item, commType, food = world-reg_sum)]
		regional_food = rbind(regional_food, missing)
	} else {
		regional_food = regional_food[Country == aCountry, list(food = sum(food, na.rm=TRUE)), by=list(GustRegion, Item, commType)]
	}
	waste_rates = fread(paste0(data_dir_root, "/HALF/wasteRates.csv"))
	waste_rates = rbind(waste_rates, waste_rates[GustRegion == 'SSEAsia', list(GustRegion = "Missing",commType, consumerWaste)])
	regional_food = merge(regional_food, waste_rates, by=c('GustRegion', 'commType'))
	regional_food = merge(regional_food, cp_country[, list(Item, dryMatter, mj_per_kg, protein_g_per_kg)], by=c('Item'))
	
	
	consumer_waste = rbind(
			regional_food[, list(type = "wetGt", total = sum(food, na.rm=TRUE)/1000, losses=sum(food*consumerWaste, na.rm=TRUE)/1000)],
			regional_food[, list(type = "dryGt", total = sum(food*dryMatter, na.rm=TRUE)/1000, losses=sum(food*dryMatter*consumerWaste, na.rm=TRUE)/1000)],
			regional_food[, list(type = "energyEJ", total = sum(food*mj_per_kg, na.rm=TRUE)/1000, losses=sum(food*mj_per_kg*consumerWaste, na.rm=TRUE)/1000)],
			regional_food[, list(type = "proteinMt", total = sum(food*protein_g_per_kg, na.rm=TRUE)/1000, losses=sum(food*protein_g_per_kg*consumerWaste, na.rm=TRUE)/1000)]
			)[, list(des="Food consumption", type, total, food=total-losses, losses)]
			
			
	sankey_dt = rbind(sankey_dt, consumer_waste, fill=TRUE)
		
	overeating = rbind(
			sankey_dt[des=="Food consumption" & type=="energyEJ", list(type, total=food, food=9.8 * country_data[Country==aCountry & Year==aYear]$population*365/1000000)], # 9.8 MJ/person/day
			sankey_dt[des=="Food consumption" & type=="proteinMt", list(type, total=food, food=52 * country_data[Country==aCountry & Year==aYear]$population*365/1000000 )] # 52g/person/day
			)
			
	# assuming energy is more constraining (which it is in 2011 globally)
	overeating = rbind(overeating, 
			sankey_dt[des=="Food consumption" & type %in% c("wetGt", "dryGt"), list(type, total=food, food=food*overeating[type=="energyEJ", food/total])]
			)[, list(des="Food requirements", type, total, food, losses=total-food)]
	
	sankey_dt = rbind(sankey_dt, overeating, fill=TRUE)
			
	
	# Grassland NPP (assuming grassland is Ito & Oikawa (2004) Heath and moorland + Warm or hot shrub and grassland + Tibetan meadow, Siberian highland)
	grass_assumptions = data.table(npp_Gt = 5.9 * 2, dryMatter = 0.20, mj_per_kg = 10, protein_g_per_kg = 70) # 20% DM, 10MJ/kg, 70g/kg assumed for grass
	
	feed_used = sankey_dt[,list(feed=sum(feed, na.rm=TRUE)), by=type]
	animal_nutritional_req_Gt = cp_country[! is.na(fcr), list(Item, feed_req=prod * fcr)][, sum(feed_req)/1000]
	grass_harvested_dry_Gt = animal_nutritional_req_Gt-feed_used[type=="dryGt", feed] # Work out inputs to animal products working backwards
	
	grass = rbind(
			grass_assumptions[, list(type = "dryGt", total=npp_Gt, harvested=grass_harvested_dry_Gt)],
			grass_assumptions[, list(type = "wetGt", total=npp_Gt/dryMatter, harvested=grass_harvested_dry_Gt/dryMatter)],
			grass_assumptions[, list(type = "energyEJ", total=npp_Gt*mj_per_kg, harvested=grass_harvested_dry_Gt*mj_per_kg)],
			grass_assumptions[, list(type = "proteinMt", total=npp_Gt*protein_g_per_kg, harvested=grass_harvested_dry_Gt*protein_g_per_kg)]
	)[, list(des="GrassNPP", type, total, harvested, losses=total-harvested)]
	sankey_dt = rbind(sankey_dt, grass, fill=TRUE)
	
	#Livestock production
	livestock_production = merge(feed_used, sankey_dt[des=="GrassNPP", list(type, grass=harvested)], by='type')[, list(type, total=grass+feed)]
	livestock_production = merge(livestock_production, sankey_dt[des == "Animal product", list(type, animal_prods=total)], by='type')[, list(des="Livestock production", type, total, animal_prods, losses=total-animal_prods)]
	
	sankey_dt = rbind(sankey_dt, livestock_production, fill=TRUE)
	
	# Cropland NPP
	crop_assumptions = data.table(npp_Gt = 8.0 * 2, dryMatter = 0.35, mj_per_kg = 12, protein_g_per_kg = 100) # 35% DM, 10MJ/kg, 100g/kg assumed for grass
	crop = rbind(
			crop_assumptions[, list(type = "dryGt", total=npp_Gt)],
			crop_assumptions[, list(type = "wetGt", total=npp_Gt/dryMatter)],
			crop_assumptions[, list(type = "energyEJ", total=npp_Gt*mj_per_kg)],
			crop_assumptions[, list(type = "proteinMt", total=npp_Gt*protein_g_per_kg)]
	)
	
	crop = merge(crop, sankey_dt[des %in% c("Crops harvested", "Forage crops"), list(harvested=sum(total)), by=type], by="type")[, list(des="CropNPP", type, total, harvested, losses=total-harvested)]
	sankey_dt = rbind(sankey_dt, crop, fill=TRUE)
	
	
	sankey_dt[, des:=factor(des, c("CropNPP", "GrassNPP", "Crops harvested", "Forage crops", "Processed commodities", "Livestock production", "Animal product", "Food consumption", "Food requirements"))]
	setkey(sankey_dt, des, type)
	
	sankey_dt[, loss_rate:=losses/total]
	
	sankey_dt = sankey_dt[type != "areaMha", list(total, harvested, food, processing, feed, seed, animal_prods, stockvar, non_food=sum(bioenergy,fibre, na.rm=TRUE), losses, loss_rate), by=list(des, type)]
	
	write.table(sankey_dt, "/Users/peteralexander/Documents/LURG/Alt\ Scenarios/figures2/sankey_data.csv", row.names=FALSE, sep=",")
	
	
	# Summaries - uses
	overall_loss = sankey_dt[des %in% c('CropNPP', 'GrassNPP'), list(npp=sum(total), harvested=sum(harvested)), by=type]
	overall_loss = merge(overall_loss, sankey_dt[des == "CropNPP", list(type, crop=harvested)], by='type')
	overall_loss = merge(overall_loss, sankey_dt[des == "Food requirements", list(type, needed=food, eaten=total)], by='type')
	overall_loss = merge(overall_loss, sankey_dt[des == "Food consumption", list(type, delivered=total)], by='type')
	overall_loss = merge(overall_loss, sankey_dt[, list(non_food=sum(non_food)), by=type], by='type')
	overall_loss = merge(overall_loss, sankey_dt[, list(stock_seed=sum(stockvar, seed, na.rm=TRUE)), by=type], by='type')
	overall_loss = merge(overall_loss, sankey_dt[des == "Forage crops", list(type, forage=total)], by='type', all.x=TRUE)
	overall_loss[is.na(forage), forage:=0]
	
	dt = overall_loss[, list(type, needed_npp_rate=needed/npp*100, eaten_npp_rate=eaten/npp*100, delivered_npp_rate=delivered/npp*100, 
					non_food_npp_rate=non_food/npp*100, loss_eaten_npp_rate=(npp-non_food-eaten)/npp*100, loss_needed_npp_rate=(npp-non_food-needed)/npp*100)]
	dcast.data.table(melt(dt, id.vars = "type")[, value:=round(value, 1)], variable ~ type)
	
	dt = overall_loss[, list(type, needed_harv_rate=needed/(harvested-stock_seed)*100, eaten_harv_rate=eaten/(harvested-stock_seed)*100, delivered_harv_rate=delivered/(harvested-stock_seed)*100, 
					non_food_harv_rate=non_food/(harvested-stock_seed)*100, loss_eaten_harv_rate=(harvested-stock_seed-non_food-eaten)/(harvested-stock_seed)*100, loss_need_harv_rate=(harvested-stock_seed-non_food-needed)/(harvested-stock_seed)*100)]
	dcast.data.table(melt(dt, id.vars = "type")[, value:=round(value, 1)], variable ~ type)
	
	crop_losses = overall_loss[, list(type, needed_crop_rate=needed/(crop-stock_seed-forage)*100, eaten_crop_rate=eaten/(crop-stock_seed-forage)*100, delivered_crop_rate=delivered/(crop-stock_seed-forage)*100, 
					non_food_crop_rate=non_food/(crop-stock_seed-forage)*100, loss_eaten_crop_rate=(crop-stock_seed-non_food-eaten-forage)/(crop-stock_seed-forage)*100, loss_needed_crop_rate=(crop-stock_seed-non_food-needed-forage)/(crop-stock_seed-forage)*100)]
	dcast.data.table(melt(crop_losses, id.vars = "type")[, value:=round(value, 1)], variable ~ type)
	
	
	# Absoulte loss breakdown
	dt = sankey_dt[, list(des, type, losses)]
	dcast.data.table(dt[, list(des, loss_breakdown=round(losses/sum(losses)*100,1)), by=type], des ~ type, value.var='loss_breakdown')
	
	dt = sankey_dt[des %in% c('Crops harvested', 'Forage crops', 'Processed commodities', 'Livestock production', 'Animal product', 'Food consumption', 'Food requirements'), list(des, type, losses)]
	dcast.data.table(dt[, list(des, loss_breakdown=round(losses/sum(losses)*100,1)), by=type], des ~ type, value.var='loss_breakdown')
	
	grass_and_forage = sankey_dt[des %in% c("GrassNPP", "Forage crops"), list(des=factor('Livestock production'), grass_plus_forage=sum(harvested, feed, na.rm=TRUE)), by=type]
	less_grass_and_forage = merge(dt[des != "Forage crops"], grass_and_forage, by=c('des', 'type'), all.x=TRUE)
	less_grass_and_forage[!is.na(grass_plus_forage), losses := losses - grass_plus_forage]
	dcast.data.table(less_grass_and_forage[, list(des, loss_breakdown=round(losses/sum(losses)*100,1)), by=type], des ~ type, value.var='loss_breakdown')
	
	
	# embodied - how much is lost forwards
	e_s_dt = copy(sankey_dt)
	e_s_dt[des == "Crops harvested", embodied_total := (total - seed - stockvar)]
	e_s_dt[des == "Crops harvested", embodied_food := embodied_total * food/ (feed + food + processing + non_food)]
	e_s_dt[des == "Crops harvested", embodied_feed := embodied_total *feed/ (feed + food + processing + non_food)]
	e_s_dt[des == "Crops harvested", embodied_processing := embodied_total *processing/ (feed + food + processing + non_food)]
	e_s_dt[des == "Crops harvested", embodied_non_food := embodied_total *non_food/ (feed + food + processing + non_food)]
	e_s_dt[des == "Crops harvested", embodied_losses := embodied_total * losses / total]
	
	
	e_s_dt = merge(e_s_dt, e_s_dt[des == "Crops harvested", list(des = factor("Processed commodities"), type, embodied_processing2=embodied_processing)], all.x=TRUE)
	e_s_dt[des=="Processed commodities", embodied_total := embodied_processing2 ]
	e_s_dt[, embodied_processing2 := NULL ]
	e_s_dt[des == "Processed commodities", embodied_food := embodied_total * food / (feed + food + non_food) ]
	e_s_dt[des == "Processed commodities", embodied_feed := embodied_total * feed / (feed + food + non_food)]
	e_s_dt[des == "Processed commodities", embodied_non_food := embodied_total * non_food / (feed + food + non_food) ]
	e_s_dt[des == "Processed commodities", embodied_losses := embodied_total * losses / total ]
	
	e_s_dt = merge(e_s_dt, grass_and_forage, by=c('des', 'type'), all.x=TRUE)
	e_s_dt[!is.na(grass_plus_forage), losses := losses - grass_plus_forage]
	e_s_dt[!is.na(grass_plus_forage), total := total - grass_plus_forage]
	e_s_dt[, grass_plus_forage := NULL ]
	
	
	e_s_dt = merge(e_s_dt, e_s_dt[des %in% c("Crops harvested", "Processed commodities"), list(des=factor("Livestock production"), embodied_feed2=sum(embodied_feed)), by=type], by=c('des', 'type'), all.x=TRUE)
	e_s_dt[des=="Livestock production", embodied_total := embodied_feed2 ]
	e_s_dt[des=="Livestock production", embodied_losses := embodied_total * losses / total]
	e_s_dt[, embodied_feed2 := NULL ]
	
	e_s_dt = merge(e_s_dt, e_s_dt[des == "Livestock production", list(des = factor("Animal product"), type, embodied_animal_prods=embodied_total)], all.x=TRUE)
	e_s_dt[des=="Animal product", embodied_total := embodied_animal_prods]
	e_s_dt[, embodied_animal_prods := NULL ]
	e_s_dt[des=="Animal product", embodied_food := embodied_total * food / (food + non_food) ]
	e_s_dt[des=="Animal product", embodied_non_food := embodied_total * non_food / (food + non_food) ]
	e_s_dt[des=="Animal product", embodied_losses := embodied_total * losses / total ]
	
	e_s_dt = merge(e_s_dt, e_s_dt[, list(des = factor("Food consumption"), all_e_f = sum(embodied_food, na.rm=TRUE)), by=type], by=c('des', 'type'), all.x=TRUE)
	e_s_dt[des=="Food consumption", embodied_total := all_e_f ]
	e_s_dt[, all_e_f := NULL ]
	e_s_dt[des=="Food consumption", embodied_food := embodied_total ]
	e_s_dt[des=="Food consumption", embodied_losses := embodied_total * losses / total ]
	
	e_s_dt = merge(e_s_dt, e_s_dt[des == "Food consumption", list(des=factor("Food requirements"), type, all_e_f = embodied_total)], by=c('des', 'type'), all.x=TRUE)
	e_s_dt[des=="Food requirements", embodied_total := all_e_f ]
	e_s_dt[, all_e_f := NULL ]
	e_s_dt[des=="Food requirements", embodied_food := embodied_total ]
	e_s_dt[des=="Food requirements", embodied_losses := embodied_total * losses / total ]
	
	write.table(e_s_dt, paste0(outputDir, "sankey_data_embodied_", aCountry,".csv"), row.names=FALSE, sep=",")
	
	# Output breakdown percentages
	require("RColorBrewer")
	require("ggplot2")
	
	plotLossBarChart = function(toPlot, fileName, yLabel, saveToFile=TRUE) {
		toPlot[type == "dryGt", type:="Dry matter"]
		toPlot[type == "energyEJ", type:="Energy"]
		toPlot[type == "proteinMt", type:="Protein"]
		toPlot[type == "wetGt", type:="Wet mass"]
		
		toPlot[des == "Crops harvested", des:="Transport & storage"]
		toPlot[des == "Processed commodities", des:="Processing"]
		toPlot[des == "Livestock production", des:="Livestock production "]
		toPlot[des == "Animal product", des:="Animal product distrubution"]
		toPlot[des == "Food consumption", des:="Consumer waste"]
		toPlot[des == "Food requirements", des:="Over-consumption"]
			
		if (saveToFile) pdf(width=10, height=6.5, file = fileName)
		ggp = ggplot(toPlot, aes(x=type, y=loss_rate, fill=(des))) + 
				geom_bar(stat="identity")  +
				labs(x="", y=yLabel) + 
				scale_fill_manual(values = c("#FEC44F" ,"#FFF7BC",  "#E31A1C", "#FB9A99", "#AF8DC3", "#762A83")) + 
				theme(legend.title=element_blank()) + theme(axis.title.x = element_blank()) + guides(fill = guide_legend(reverse=FALSE))
		print (ggp)
		if (saveToFile) dev.off()
	}
	
	embodied_summary = e_s_dt[!is.na(embodied_losses), list(des, lr=round(100*embodied_losses/sum(embodied_losses, na.rm=TRUE),1)), by=type]
	dcast.data.table(embodied_summary, des ~ type, value.var='lr')
	dt = merge(embodied_summary, crop_losses, by='type')[, list(des, type, loss_rate=lr* loss_needed_crop_rate/100)]
	plotLossBarChart(dt, paste0(outputDir, "loss_bar_", aCountry, ".pdf"), "Embodied loss rate (%)")
	
	dt = merge(less_grass_and_forage[, list(des, lr=100*losses/sum(losses)), by=type], crop_losses, by='type')[, list(des, type, loss_rate=lr* loss_needed_crop_rate/100)]
	plotLossBarChart(dt, paste0(outputDir, "loss_bar_abs_", aCountry, ".pdf"), "Absolute loss rate (%)")
	sankey_dt
}

sankey_dt = outputLossData(aCountry="World", aYear=2013, aCommodity="Milk - Excluding Butter")