con_prod_to_use = con_prod[Year == 2013 & Item == "Milk - Excluding Butter"]
regional_prod = merge(con_prod_to_use, fread(paste0(data_dir_root, "/HALF/gustavsson_country_regions.csv")), by=c('Country'))

regional_prod = regional_prod[, list(inAmount = sum(food+processing, na.rm=TRUE)), by=list(GustRegion, Item, commType)]
missing = merge(regional_prod[, list(reg_sum=sum(inAmount)), by=list(Item, commType)], con_prod_to_use[Country == "World", list(world=sum(food+processing)), by=Item], by=c('Item'))[, list(GustRegion = "Missing", Item, commType, inAmount = world-reg_sum)]
regional_prod = rbind(regional_prod, missing)

waste_rates = fread(paste0(data_dir_root, "/HALF/wasteRatesMilk.csv"))
waste_rates = melt(waste_rates, id.vars=c("GustRegion", "commType"), value.name="lossrate", variable.name="stage")


regional_prod = merge(regional_prod, waste_rates[stage=="AgProd"], by=c('GustRegion', 'commType'))
regional_prod[, loss:= inAmount * lossrate]
regional_prod[, outAmount:= inAmount - loss]

postHarvest = merge(regional_prod[, list(GustRegion, commType, Item, inAmount=outAmount)], waste_rates[stage=="PostHarvest"], by=c('GustRegion', 'commType'))
postHarvest[, loss:= inAmount * lossrate]
postHarvest[, outAmount:= inAmount - loss]

processing = merge(postHarvest[, list(GustRegion, commType, Item, inAmount=outAmount)], waste_rates[stage=="Processing"], by=c('GustRegion', 'commType'))
processing[, loss:= inAmount * lossrate]
processing[, outAmount:= inAmount - loss]

distrubution = merge(processing[, list(GustRegion, commType, Item, inAmount=outAmount)], waste_rates[stage=="Distrubution"], by=c('GustRegion', 'commType'))
distrubution[, loss:= inAmount * lossrate]
distrubution[, outAmount:= inAmount - loss]

consumerWaste = merge(distrubution[, list(GustRegion, commType, Item, inAmount=outAmount)], waste_rates[stage=="consumerWaste"], by=c('GustRegion', 'commType'))
consumerWaste[, loss:= inAmount * lossrate]
consumerWaste[, outAmount:= inAmount - loss]

milkDt = rbind(regional_prod, postHarvest, processing, distrubution, consumerWaste)
milkDt = merge(milkDt, con_prod_to_use[Country=="World", list(Item, dryMatter, mj_per_kg, protein_g_per_kg)], by=c('Item'))

milkSummary = milkDt[, list(inAmount=sum(inAmount),loss= sum(loss), outAmount=sum(outAmount)), by=stage]
milkSummary[, lossRate:=list(loss/inAmount*100)]
milkSummary[, percentOfAllLosses:=list(loss/sum(loss)*100)]
milkSummary

require(ggplot2)

ggplot(milkDt[GustRegion != 'Missing'], aes(x= GustRegion, y= loss, fill = stage) ) + 
		geom_bar(stat="identity") + 
		scale_fill_manual(values = c("#e41a1c", "#377eb8", "#4daf4a", "#984ea3", "#ff7f00")) + 
		labs(x="Region", y="Loss of milk (Mt)")
		
		
