require(ggplot2)

##MARGINAL GAINS##
regional = merge(con_prod, fread(paste0(data_dir_root, "/HALF/gustavsson_country_regions.csv")), by=c('Country'))
colsToSum=c('feed', 'food', 'used', 'feed_area', 'food_area', 'animal_a_feed', 'animal_a_pasture') 
regional_prod = regional[, lapply(.SD, sum, na.rm=TRUE), by=list(GustRegion, Item, commType, Year), .SDcols=colsToSum]
popDt = merge(country_data[Year == 2013, list(Country, population)], fread(paste0(data_dir_root, "/HALF/gustavsson_country_regions.csv")), by=c('Country'))[, list(population=sum(population, na.rm=TRUE)), by=GustRegion]
regional_prod=merge(regional_prod, popDt, by='GustRegion')
#add regional avg 'mj_per_kg', protein_g_per_kg', 'dryMatter'
regional_prod=merge(regional_prod, con_prod[Country=="World", list(Item, Year, mj_per_kg, protein_g_per_kg, dryMatter)], by=c('Item', 'Year'))
regional_prod=merge(regional_prod, getFeedConvRatio()[, list(Item, fcr)], by='Item', all.x=TRUE)
setnames(regional_prod, 'GustRegion', 'Region')




#Function for substituting meat with alternative products...
getMeatSubs = function(cp, act, aYear) {
	avg_feed_dm_yield = cp[Country == "World" & Year == aYear & is.na(fcr), sum(feed*dryMatter, na.rm=TRUE)/sum(feed_area, na.rm=TRUE)]
	soy_dm_yield = cp[Country == "World" & Year == aYear & Item == 'Soyabeans', food/food_area* dryMatter]
	
	alt_ap_data = data.table(Item = c("Mealworm", "Crickets", "Cultured meat", "Tilapia", "Carp", "Tofu"),
			# note the rate/2 indicates split across 2 products? reduction is by 1%        
			replacement_rate = c(act['Insects']$rate/2, act['Insects']$rate/2, act['Cultured meat']$rate, 
					act['Aquaculture']$rate/2, act['Aquaculture']$rate/2, (act['Tofu']$rate + act['Imitation meat']$rate)),
			
			fcr = c(1.8, 2.1, 4.0, 4.59, 4.86, 0.29), 
			mj_per_kg = c(8.9, 5.9, 8.3, 960/239.006, 1270/239.006, 3.18), 
			protein_g_per_kg = c(179, 205, 190, 200.8, 178.3, 80.8),
			feed_yield_tdm_per_ha=c(rep(avg_feed_dm_yield, 5), soy_dm_yield),
			pasture_req=0)
	
	alt_ap_data[, feed_req := fcr / feed_yield_tdm_per_ha]
	alt_ap_data[, feed_yield_tdm_per_ha := NULL]
	
	# Add conventional livestock
	alt_ap_data = rbind (alt_ap_data, cp[Country == "World" & Year == aYear & Item %in% c("Eggs", "Poultry Meat", "Pigmeat"),
					list(Item,
							replacement_rate = c(act['Monogastrics']$rate/3), # split across 3 products.
							feed_req=animal_a_feed/used, 
							pasture_req=animal_a_pasture/used,  
							mj_per_kg=mj_per_kg, 
							protein_g_per_kg, fcr)], fill=TRUE)
	
	alt_ap_data[, c('animal','allowedForVeggie', 'crop_food_req') := list(TRUE, FALSE, 0)]
	alt_ap_data[Item=="Tofu", c('animal','allowedForVeggie', 'crop_food_req', 'feed_req') := list(FALSE, TRUE, feed_req, 0)]
	
	alt_ap_data[, fcr:=NULL]
	alt_ap_data
}

#MArgiNal GaiNs
cjdt <- function(a,b){
	cj = CJ(1:nrow(a),1:nrow(b))
	cbind(a[cj[[1]],],b[cj[[2]],])
}

calcMarginGains = function(cp, rp, act, aYear=2013) {
	### key, from con prod. global avg diet, feed area required, pasture area required, nutrients in products to make substitutions
	world_land = cp[Country == "World" & Year == aYear, list(Item, crop_food_req=food_area/food, feed_req=animal_a_feed/used, pasture_req=animal_a_pasture/used)]
	orig_diet = rp[Year == aYear, list (Region, Item, quantity_person_year = food/population, base_food=food, mj_per_kg, protein_g_per_kg)]
	
	orig_diet = merge(orig_diet, itemDetails[, list(Item, animal, allowedForVeggie)])
	adjusted_diet = copy(orig_diet)
	adjusted_land = rp[Year == aYear, list(Region, Item, food, used, crop_food_req=food_area/food, feed_req=animal_a_feed/used, pasture_req=animal_a_pasture/used, 
					base_food_area=food_area, base_animal_a_feed=animal_a_feed, base_animal_a_pasture=animal_a_pasture)]
	
	##### vegan/veggie (combines effects of going vegan/veggie and reducing meat intake?)??? 
	vegan_change = 1 - (1-act['Vegan diets']$rate) * (1-act['Low-meat diets']$rate/2) # 1% for vegan and 0.5% for other meat reduction
	proteinTotal = orig_diet[, list(protein=sum(quantity_person_year*protein_g_per_kg)), by=list(animal, Region)]
	vegan_fraction = merge(proteinTotal[animal==TRUE, list(Region, nonveganProtein=protein)], proteinTotal[animal==FALSE, list(Region, veganProtein=protein)], by="Region")[, list(Region, veganFact=nonveganProtein/veganProtein)]
	adjusted_diet = merge(adjusted_diet, vegan_fraction, by="Region")
	adjusted_diet[animal == TRUE, quantity_person_year :=quantity_person_year*(1-vegan_change)]
	adjusted_diet[animal == FALSE, quantity_person_year := quantity_person_year*(1+vegan_change*veganFact)]
	adjusted_diet[, veganFact := NULL]
	
	veggie_change = 1 - (1-act['Vegetarian diets']$rate) * (1-act['Low-meat diets']$rate/2) # 1% for vegan and 0.5% for other meat reduction
	proteinTotal = adjusted_diet[, list(protein=sum(quantity_person_year*protein_g_per_kg)), by=list(allowedForVeggie, Region)]
	veggie_fraction = proteinTotal[allowedForVeggie==FALSE, protein]/proteinTotal[allowedForVeggie==TRUE, protein]
	veggie_fraction = merge(proteinTotal[allowedForVeggie==TRUE, list(Region, veggieProtein=protein)], proteinTotal[allowedForVeggie==FALSE, list(Region, nonveggieProtein=protein)], by="Region")[, list(Region, veggieFact=nonveggieProtein/veggieProtein)]
	adjusted_diet = merge(adjusted_diet, veggie_fraction, by="Region")
	adjusted_diet[allowedForVeggie==FALSE, quantity_person_year :=quantity_person_year*(1-veggie_change)]
	adjusted_diet[allowedForVeggie==TRUE, quantity_person_year := quantity_person_year*(1+veggie_change*veggieFact)]
	adjusted_diet[, veggieFact := NULL]
	
	##### Substitution of animal product demand
	meatSubs = getMeatSubs(cp, act, aYear)
		
	proteinTotal = adjusted_diet[animal == TRUE, list(animalProtein=sum(quantity_person_year * protein_g_per_kg)), by=Region]
	meatSubToAdd = cjdt(meatSubs, proteinTotal)
		
	meatSubToAdd[, quantity_person_year := replacement_rate*animalProtein/protein_g_per_kg]
	decreaseInOrigAP = meatSubToAdd[, list(origLivestockFactor=prod(1-replacement_rate)), by=Region]
		
	# decrement existing AP
	adjusted_diet = merge(adjusted_diet, decreaseInOrigAP, by=c("Region"))
	adjusted_diet[animal == TRUE, quantity_person_year := quantity_person_year*origLivestockFactor]
	adjusted_diet[, origLivestockFactor:=NULL]
		
	# already in adjusted_diet, so adjust
	adjusted_diet = merge(adjusted_diet, 
			meatSubToAdd[Item %in% adjusted_diet$Item, list(Region, Item, addQuantity=quantity_person_year)], 
			by=c("Region", "Item"), all.x=TRUE)
	adjusted_diet[!is.na(addQuantity), quantity_person_year:= quantity_person_year + addQuantity]
	adjusted_diet[, addQuantity := NULL]
	# need to add new products
	adjusted_diet = rbind(adjusted_diet, meatSubToAdd[!Item %in% adjusted_diet$Item, list(Region, Item, quantity_person_year, base_food=0, mj_per_kg, protein_g_per_kg, animal, allowedForVeggie)])	
	adjusted_land = rbind(adjusted_land, 
			meatSubToAdd[!Item %in% adjusted_land$Item, list(Region, Item, food=1, used=1, crop_food_req, feed_req, pasture_req, base_food_area=0, base_animal_a_feed=0, base_animal_a_pasture=0)])	
	
	# Losses and waste
	wasteRates = fread("~/Documents/LURG/Papers/Marginal gains/data/lossRates.csv")[type == "wetGt"]
	setnames(wasteRates, "GustRegion", "Region")
	
	# Demand reduction losses
	reduceDemandLoss = function(reductionType, wasteStage) {
		adjusted_diet = merge(adjusted_diet, wasteRates[stage==wasteStage, list(Region, lossAtStageRate)], by="Region")
		adjusted_diet[, quantity_person_year := quantity_person_year*(1-act[reductionType]$rate*lossAtStageRate)]
		adjusted_diet[, lossAtStageRate:=NULL]
		adjusted_diet
	}
	
	adjusted_diet = reduceDemandLoss('Over-consumption', 'Over-consumption')
	adjusted_diet = reduceDemandLoss('Consumer losses', 'Consumer waste')
	adjusted_diet = reduceDemandLoss('Retailer losses', 'Distrubution')
	adjusted_diet = reduceDemandLoss('Transport & storage losses', 'Handling and storage')
	adjusted_diet = reduceDemandLoss('Processing losses', 'Processing')
	
	##### production loss reduction (includes storage and transport)
	reduceProductionLoss = function(reductionType, wasteStage) {
		adjusted_land = merge(adjusted_land, wasteRates[stage==wasteStage, list(Region, lossAdj=(1-act[reductionType]$rate*lossAtStageRate))], by="Region")
		adjusted_land[, c('crop_food_req', 'feed_req', 'pasture_req') := list(crop_food_req*lossAdj, feed_req*lossAdj, pasture_req*lossAdj)]
		adjusted_land[, lossAdj:=NULL]
		adjusted_land
	}
	
	adjusted_land = reduceProductionLoss('Harvest losses', 'Agricultural Production')
	
	##### crop production yield gains
	cropEfficiency = (1-act['Crop management']$rate) * (1-act['Crop breeding']$rate) * (1-act['Crop GMO']$rate) *
			(1-act['Multi-cropping and less fallow']$rate) * (1-act['Vertical and urban farms']$rate) * 
			(1-act['Trade and infrastructure']$rate) 
	pastureEfficiency = 1-act['Pasture management']$rate
	adjusted_land[, c('crop_food_req', 'feed_req', 'pasture_req') := list(crop_food_req*cropEfficiency, feed_req*cropEfficiency, pasture_req*pastureEfficiency)]
	
	##### livestock production efficiency gains
	overallLivestockEfficieny = (1-act['Livestock management']$rate) * (1-act['Livestock breeding']$rate) * (1-act['Livestock GMO']$rate) *
			(1-act['Household pets']$rate * 0.05) * (1-act['Consumption of offals']$rate)
	adjusted_land[, c('feed_req', 'pasture_req') := list(feed_req*overallLivestockEfficieny, pasture_req*overallLivestockEfficieny)]
	feedEfficieny = (1 - act['Food waste as feed']$rate) * (1-act['Alternative feeds']$rate) #food waste as feed based on 30% waste being avaliable, alternative feed (1%)
	adjusted_land[, feed_req := feed_req*feedEfficieny]
	
	adjusted_diet2 = merge(adjusted_diet, rp[Item=="Wheat" & Year==aYear, list(Region, population)], by="Region")
	# need to add new commodites not in world_land
	adjusted_diet2 = merge(adjusted_diet2, rbind(world_land, adjusted_land[!Item %in% world_land$Item, list(crop_food_req=mean(crop_food_req), feed_req=mean(feed_req), pasture_req=mean(pasture_req)), by=Item]), by="Item")
	adjusted_diet2[, food_chg:=base_food-population*quantity_person_year]
	
	regionalLandSaved = rbind(
			adjusted_land[, list(variable="Cropland for food", changeCat="Supply change", saved_area=sum(base_food_area-food*crop_food_req, na.rm=TRUE)), by=Region],
			adjusted_land[, list(variable="Cropland for feed", changeCat="Supply change", saved_area=sum(base_animal_a_feed-feed_req*used, na.rm=TRUE)), by=Region],
			adjusted_land[, list(variable="Pasture", changeCat="Supply change", saved_area=sum(base_animal_a_pasture-pasture_req*used, na.rm=TRUE)), by=Region],
			adjusted_diet2[, list(variable="Cropland for food", changeCat="Consumer change", saved_area=sum(crop_food_req*food_chg, na.rm=TRUE)), by=Region],
			adjusted_diet2[, list(variable="Cropland for feed", changeCat="Consumer change", saved_area=sum(feed_req*food_chg, na.rm=TRUE)), by=Region],
			adjusted_diet2[, list(variable="Pasture", changeCat="Consumer change", saved_area=sum(pasture_req*food_chg, na.rm=TRUE)), by=Region]
	)
		
	baseAreas = rbind(	adjusted_land[, list(variable="Cropland for food", base_area=sum(base_food_area, na.rm=TRUE)), by=Region],
		adjusted_land[, list(variable="Cropland for feed", base_area=sum(base_animal_a_feed, na.rm=TRUE)), by=Region],
		adjusted_land[, list(variable="Pasture", base_area=sum(base_animal_a_pasture, na.rm=TRUE)), by=Region]
	)
	
	regionalRes=merge(regionalLandSaved, baseAreas, by=c("Region", "variable"))
	
	
	worldAdjustDiet = adjusted_diet2[, list(quantity_person_year=sum(population*quantity_person_year)/sum(population)), by=Item]
	worldAdjustLand = adjusted_land[, list(crop_food_req=sum(crop_food_req*food)/sum(food), 
					feed_req=sum(feed_req*food)/sum(food), 
					pasture_req=sum(pasture_req*food)/sum(food)), by=Item]
	
	pop_req = country_data[Country == "World" & Year == aYear, population]
	land_area = country_data[Country == "World" & Year == aYear, land]/100 # includes 100 for % calc
	
	# world areas in FAO data is greater than that covered by the regional data
	missingAreaAdj=cbind(con_prod[Year == 2013 & Country == "World", list(foodW=sum(food_area, na.rm=TRUE)/land_area, feedW=sum(animal_a_feed, na.rm=TRUE)/land_area, pastureW=sum(animal_a_pasture, na.rm=TRUE)/land_area)],
			regional_prod[Year == aYear, list(foodR=sum(food_area, na.rm=TRUE)/land_area, feedR=sum(animal_a_feed, na.rm=TRUE)/land_area, pastureR=sum(animal_a_pasture, na.rm=TRUE)/land_area)])
	
	worldRes=merge(worldAdjustLand, worldAdjustDiet, by="Item")[, list(
					food_crop_t = sum(quantity_person_year*crop_food_req, na.rm=TRUE)*pop_req/land_area*missingAreaAdj[, foodW/foodR],
					feed_t = sum(quantity_person_year*feed_req, na.rm=TRUE)*pop_req/land_area*missingAreaAdj[, feedW/feedR],
					pasture_t = sum(quantity_person_year*pasture_req, na.rm=TRUE)*pop_req/land_area*missingAreaAdj[, pastureW/pastureR],
					food_crop_ha_per_person = sum(quantity_person_year*crop_food_req*missingAreaAdj[, foodW/foodR], na.rm=TRUE),
					feed_ha_per_person = sum(quantity_person_year*feed_req*missingAreaAdj[, feedW/feedR], na.rm=TRUE),
					pasture_ha_per_person = sum(quantity_person_year*pasture_req*missingAreaAdj[, pastureW/pastureR], na.rm=TRUE))]
	
	
	if (FALSE) {
		dt = merge(regionalRes[, list(chg=sum(saved_area)), by=c("Region", "variable")], adjusted_diet2[Item == "Wheat", list(Region, population)], by="Region")
		org_area= adjusted_diet2[, list(food=sum(crop_food_req* population* quantity_person_year, na.rm=TRUE),
						feed=sum(feed_req* population* quantity_person_year, na.rm=TRUE),
						pasture=sum(pasture_req* population* quantity_person_year, na.rm=TRUE)), by=Region]
		org_area_melt = melt(org_area, id.vars="Region", value.name="base")
		
		org_area_melt$variable = factor(org_area_melt$variable, levels=c("pasture", "feed", "food"))
		levels(org_area_melt$variable) = c("Pasture", "Cropland for feed", "Cropland for food")
		
		dt=merge(dt, org_area_melt, by=c("Region", "variable"))
		dt2 = melt(dt[, list(Region, variable, base_perperson=base/population, updated_perperson=(base-chg)/population)], 
				id.vars=c("Region", "variable"), variable.name="dataType")
		levels(dt2$dataType) = c("Before", "After")
		dt2$variable = factor(dt2$variable, levels=c("Pasture", "Cropland for feed", "Cropland for food"))
		
		ggplot(updateRegionNames(dt2), aes(x=dataType, y=value, fill=variable, alpha=dataType)) + geom_bar(stat="identity") + 
				facet_grid(. ~ Region) +
				theme_minimal() + 
				labs(x="", y="Food area (ha/person)") +
				scale_fill_manual(values=c("#238b45","#cc4c02", "#fec44f")) + 
				scale_alpha_manual(values=c(0.5, 0.9), guide = FALSE) +
				theme(text = element_text(size=12),
						legend.position="bottom",
						axis.text.x = element_text(size=10),
						legend.title=element_blank(),,
						panel.grid.minor.y = element_blank(), 
						panel.grid.major.x = element_blank(), 
						panel.grid.minor.x = element_blank(), 
						panel.background = element_rect(colour = "black", size =.4)) +
				ggsave(file=file.path("/Users/peteralexander/Documents/LURG/Papers/Marginal gains/Figures", "area_per_person.pdf"),width=9,height=5.5)
		
		dt3 = merge(dt2[dataType == "Before", list(before=sum(value)), by=list(Region)],  dt2[dataType == "After", list(after=sum(value)), by=list(Region)], by="Region")
		dt3[, diff:=before-after]
		dt3[, pc:=diff/before]
	}
	
	list(regionalRes=regionalRes, worldRes=worldRes)
}


#### VARIOUS RATES FOR EACH OF THE DIFFERENT CHANGES, THESE ARE ADJUSTED BY THE RATES SPECIFIED IN THE ABOVE FUNCTION
productionDt = data.table(changeType=c('Crop management', 'Crop breeding', 'Crop GMO', 'Pasture management',
				'Livestock management', 'Livestock breeding', 'Livestock GMO',
				'Trade and infrastructure', 'Vertical and urban farms', 'Multi-cropping and less fallow'), 
		rate=c(2,1,2,2, 2,1,2,  1,1,2)/100)


wasteActionsDt = data.table(changeType=c('Harvest losses', 'Transport & storage losses', 'Processing losses', 'Retailer losses', 'Consumer losses',
				'Household pets', 'Food waste as feed', 'Alternative feeds', 'Consumption of offals'), 
		rate=c(5,5,5,5,5, 5,1,0.5,2)/100)

demandActionsDt = data.table(changeType=c('Vegetarian diets', 'Vegan diets', 'Low-meat diets', 
				'Over-consumption', 'Insects', 'Cultured meat', 'Tofu', 'Imitation meat', 
				'Aquaculture', 'Monogastrics'), 
		rate=c(2,1,3, 5,1,0.5,1,2, 2,3)/100)


actionsDt = rbind(cbind(productionDt, actionGroup="Production efficiency"),
	cbind(wasteActionsDt, actionGroup="Reducing losses"),
	cbind(demandActionsDt, actionGroup="Shifting diets"))
actionsDt = cbind(actionsDt, ID=seq(1,29))
setkey(actionsDt, changeType)

mg = calcMarginGains(con_prod, regional_prod, actionsDt)
mg



dt = merge(mg$regionalRes[, list(cat_tot=sum(saved_area)), by=list(Region, changeCat)], mg$regionalRes[, list(reg_tot=sum(saved_area)), by=list(Region)], by="Region")
dt[, percent:= cat_tot / reg_tot]
dt[order(changeCat)]

#############################
calcRangesOfMarginalByGroup = function (cp, rp, acts) {
	
	res = data.table()
	for (rateAdj in c(0, 0.5, 1, 2)) {
		print(rateAdj)
		actions1 = copy(acts)
		actions1[, rate := rateAdj*rate]
		res = rbind(res, cbind(calcMarginGains(cp, rp, actions1)$worldRes, rateAdj=rateAdj, actionGroup="All"))
		
		for (actionGrp in unique(actions1$actionGroup)) {
			print(actionGrp)
			actions2 = copy(actions1)
			actions2[actionGroup!=actionGrp, rate:=0]
			res = rbind(res, cbind(calcMarginGains(cp, rp, actions2)$worldRes, rateAdj=rateAdj, actionGroup=actionGrp))
		}
	}
	cbind(Region="World", res)
}


marginalGainByGroup = calcRangesOfMarginalByGroup(con_prod, regional_prod, actionsDt)
#############################

calcMarginalGainBySingleChanges = function (cp, rp, acts) {
	
	res = data.table()
	for (rateAdj in c(0, 0.5, 1, 2)) {
		actions1 = copy(acts)
		actions1[, rate := rateAdj*rate]
		res = rbind(res, cbind(calcMarginGains(cp, rp, actions1)$worldRes, rateAdj=rateAdj, changeType="All"))
		
		for (changeTyp in unique(actions1$changeType)) {
			print(changeTyp)
			actions2 = copy(actions1)
			actions2[changeType !=changeTyp, rate:=0]
			res = rbind(res, cbind(calcMarginGains(cp, rp, actions2)$worldRes, rateAdj=rateAdj, changeType=changeTyp))
		}
	}
	res
}

actionsDtA = rbind(demandActionsDt, wasteActionsDt, productionDt)
setkey(actionsDtA, changeType)
marginalGainsSingleChange = calcMarginalGainBySingleChanges(con_prod, regional_prod, actionsDtA)

#############################

marginalGainsByRate = data.table()
actionsDtB = copy(actionsDt)

for (r in seq(0, 0.1, 0.005)) {
	print (r)
	actionsDtB[, rate:=r]
	marginalGainsByRate = rbind(marginalGainsByRate, calcMarginGains(con_prod, regional_prod, actionsDtB)$worldRes[, list(rate=r, food_crop_t, feed_t, pasture_t, agri_t=food_crop_t+feed_t+pasture_t)])
}
ggplot(marginalGainsByRate, aes(x=rate*100, y=agri_t)) + geom_line() +
		labs(x="Rate of marginal actions (%)", y="Global land used for food (%)") +
		theme_minimal() + 
		theme(	panel.grid.minor.y = element_blank(), 
				panel.grid.minor.x = element_blank(), 
				panel.background = element_rect(colour = "black", size =.4)) + 
		ggsave(file=file.path("/Users/peteralexander/Documents/LURG/Papers/Marginal gains/Figures", "mg_by_rate.pdf"),width=4,height=2.5)


#############################
marginalGainsUniformAdjust = function(act, lower=0, upper=2, fileName) {
	marginalGainsSamples= data.table()
	
	for (i in seq(1, 1000)) {
		actionsDtC = copy(act)
		print (i)
		for (chgType in actionsDtB$changeType) {
			actionsDtC[changeType==chgType, rate:=rate* runif(1, lower, upper)]
			#actionsDtC[changeType==chgType, rate:=rnorm(1, rate, rate*(upper-lower)/2)]
		}
		marginalGainsSamples = rbind(marginalGainsSamples, calcMarginGains(con_prod, regional_prod, actionsDtC)$worldRes[, list(id=i, food_crop_t, feed_t, pasture_t, agri_t=food_crop_t+feed_t+pasture_t)])
	}
	ggplot(marginalGainsSamples, aes(agri_t)) + geom_freqpoly(binwidth = 0.5)
	
	marginalGainsSamples = cbind(marginalGainsSamples, calcMarginGains(con_prod, regional_prod, actionsDtC[,rate:=0])$worldRes[, list(base_food_crop=food_crop_t, base_feed=feed_t, base_pasture=pasture_t, base_agri=food_crop_t+feed_t+pasture_t)])
	marginalGainsSamples[, food_crop_change_area := food_crop_t-base_food_crop]
	marginalGainsSamples[, feed_change_area := feed_t-base_feed]
	marginalGainsSamples[, pasture_change_area := pasture_t-base_pasture]
	marginalGainsSamples[, agri_change_area := agri_t-base_agri]
	marginalGainsSamples[, food_crop_change_pc := food_crop_change_area/base_food_crop]
	marginalGainsSamples[, feed_change_pc := feed_change_area/base_feed]
	marginalGainsSamples[, pasture_change_pc := pasture_change_area/base_pasture]
	marginalGainsSamples[, agri_change_pc := agri_change_area/base_agri]
	
	dtToPlot= melt(marginalGainsSamples[, list(id, food_crop_change_pc, feed_change_pc, pasture_change_pc, agri_change_pc)], id.vars="id")
	dtToPlot$variable = factor(dtToPlot$variable, levels=c("pasture_change_pc", "feed_change_pc", "food_crop_change_pc", "agri_change_pc"))
	levels(dtToPlot$variable) = c("Pasture", "Cropland for feed", "Cropland for food", "All agricultural land")
	
	ggplot(dtToPlot, aes(-100*value, colour=variable, fill=variable)) + geom_density(alpha=0.2) + labs(x="Reduction in global land used for food (%)") +
			theme_minimal() + 
			scale_fill_manual(values =c("mediumseagreen","#fd8d3c","#fecc5c","royalblue1")) +
			scale_colour_manual(values =c("mediumseagreen","#fd8d3c","#fecc5c","royalblue1")) +
			theme(	legend.title=element_blank(),
					panel.grid.minor.y = element_blank(), 
					panel.grid.minor.x = element_blank(), 
					panel.background = element_rect(colour = "black", size =.4)) + 
			ggsave(file=file.path("/Users/peteralexander/Documents/LURG/Papers/Marginal gains/Figures", fileName), width=8,height=4)
	
	marginalGainsSamples
}

mgUniformAdjust = marginalGainsUniformAdjust(actionsDt, 0, 2, "mg_sample.pdf")

#############################

meltMeanLU = function(dt) {
	melt(dt[, list(food_crop_t, feed_t, pasture_t, agri_t)], measure.vars=c('food_crop_t', 'feed_t', 'pasture_t', 'agri_t'))[, list(meanV=mean(value), sdV=sd(value)), by=variable]
}

projectedSummary = meltMeanLU(mgUniformAdjust)
baselineDt = meltMeanLU(mgUniformAdjust[1, list(food_crop_t=base_food_crop, feed_t=base_feed, pasture_t=base_pasture, agri_t=base_agri)])


dtToPlot = rbind(cbind(simType="Baseline", baselineDt), cbind(simType="Projected", projectedSummary))
dtToPlot[, variable:=factor(variable, levels=c('feed_t', 'food_crop_t', 'pasture_t', 'agri_t'))]
dtToPlot[, simVar:=factor(paste(simType, variable), levels=(dtToPlot[order(variable, simType), paste(simType, variable)]))]

ggplot(dtToPlot) + 
		geom_bar(aes(x=simVar, y=meanV, fill=variable), stat="identity") +
		geom_errorbar( aes(x=simVar, ymin=meanV-sdV*1.98, ymax=meanV+sdV*1.98), width=0.4, colour="orange", alpha=0.9, size=1.3) +
#		labs(x="", y="HALF index") +
		theme_minimal() + 
#		scale_linetype_manual(values = c("dashed", "dotted")) + 
		scale_fill_manual(values=c("mediumseagreen","chocolate1", "khaki1", "red"), labels = c("Pasture", "Cropland for feed", "Cropland for food", "Food total")) + 
		scale_colour_manual(values = c("grey", "black"), guide = FALSE) + 
		theme(text = element_text(size=12),
				legend.title=element_blank(),
				axis.text.x = element_text(size=12),
				panel.grid.minor.y = element_blank(), 
				panel.grid.major.x = element_blank(), 
				panel.grid.minor.x = element_blank(), 
				panel.background = element_rect(colour = "black", size =.4))