con_prod_to_use = con_prod[Year == 2013]
regional = merge(con_prod_to_use, fread(paste0(data_dir_root, "/HALF/gustavsson_country_regions.csv")), by=c('Country'))

missing = merge(regional[, list(reg_food=sum(food), reg_feed=sum(feed), reg_used=sum(feed+processing+food+other)), by=list(Item, commType)], 
		con_prod_to_use[Country == "World"][, list(world_food=sum(food), world_feed=sum(feed), world_used=sum(feed+processing+food+other)), by=Item], 
		by=c('Item'))[, list(GustRegion = "Missing", Item, commType, food=world_food-reg_food, feed=world_feed-reg_feed, used=world_used-reg_used)]
regional_prod = regional[, list(food = sum(food, na.rm=TRUE), feed=sum(feed, na.rm=TRUE), used=sum(feed+processing+food+other)), by=list(GustRegion, Item, commType)]
regional_prod = rbind(regional_prod, missing)
regional_prod[feed<0, feed:=0] # a few rounding values -2.220446e-16 to remove from "Missing"

waste_rates = fread(paste0(data_dir_root, "/HALF/wasteRatesAll.csv"))
waste_rates = melt(waste_rates, id.vars=c("GustRegion", "commType"), value.name="lossrate", variable.name="stage")

agProd = merge(regional_prod, waste_rates[stage=="Agricultural Production"], by=c('GustRegion', 'commType'))
agProd = melt(agProd, measure.vars=c("food", "feed"), variable.name="use", value.name="outAmount")
agProd[, loss:= outAmount * lossrate / (1-lossrate)]
agProd[, inAmount:= outAmount + loss]
agProd[, used:=NULL]

postHarvest = merge(agProd[, list(GustRegion, commType, Item, use, inAmount=outAmount)], waste_rates[stage=="Handling and storage"], by=c('GustRegion', 'commType'))
postHarvest[, loss:= inAmount * lossrate]
postHarvest[, outAmount:= inAmount - loss]

processing = merge(postHarvest[use == "food", list(GustRegion, commType, Item, use, inAmount=outAmount)], waste_rates[stage=="Processing"], by=c('GustRegion', 'commType'))
processing[, loss:= inAmount * lossrate]
processing[, outAmount:= inAmount - loss]

distrubution = merge(processing[, list(GustRegion, commType, Item, use, inAmount=outAmount)], waste_rates[stage=="Distrubution"], by=c('GustRegion', 'commType'))
distrubution[, loss:= inAmount * lossrate]
distrubution[, outAmount:= inAmount - loss]

consumerWaste = merge(distrubution[, list(GustRegion, commType, Item, use, inAmount=outAmount)], waste_rates[stage=="Consumer waste"], by=c('GustRegion', 'commType'))
consumerWaste[, loss:= inAmount * lossrate]
consumerWaste[, outAmount:= inAmount - loss]

lossDt = rbind(agProd, postHarvest, processing, distrubution, consumerWaste)
lossDt = merge(lossDt, con_prod_to_use[Country=="World", list(Item, dryMatter, mj_per_kg, protein_g_per_kg)], by=c('Item'))

regional_pop=merge(country_data[Year==2013, list(Country, population)], fread(paste0(data_dir_root, "/HALF/gustavsson_country_regions.csv")), by=c('Country'))[, list(population=sum(population, na.rm=TRUE)), by=GustRegion]
regional_pop = rbind(regional_pop, regional_pop[, list(GustRegion="Missing", population=country_data[Country == "World" & Year == 2013]$population-sum(population))])


lossSummary = rbind(
		lossDt[use=="food", list(type="wetGt", inAmount=sum(inAmount)/1000, loss=sum(loss)/1000, outAmount=sum(outAmount)/1000), by=list(stage, GustRegion)],
		lossDt[use=="food", list(type="dryGt", inAmount=sum(inAmount*dryMatter)/1000, loss=sum(loss*dryMatter)/1000, outAmount=sum(outAmount*dryMatter)/1000), by=list(stage, GustRegion)],
		lossDt[use=="food", list(type="energyEJ", inAmount=sum(inAmount*mj_per_kg)/1000, loss=sum(loss*mj_per_kg)/1000, outAmount=sum(outAmount*mj_per_kg)/1000), by=list(stage, GustRegion)],
		lossDt[use=="food", list(type="proteinMt", inAmount=sum(inAmount*protein_g_per_kg)/1000, loss=sum(loss*protein_g_per_kg)/1000, outAmount=sum(outAmount*protein_g_per_kg)/1000), by=list(stage, GustRegion)]
)

# Overconsumption losses
nutritentRequired = rbind(
		regional_pop[, list(GustRegion, type="energyEJ", requiredAmount=9.8 * population*365/1000000)], # 9.8 MJ/person/day
		regional_pop[, list(GustRegion, type="proteinMt", requiredAmount=52 * population*365/1000000 )] # 52g/person/day
)

nutritentSupplied = lossSummary[stage=="Consumer waste", list(stage="Over-consumption", GustRegion, type, inAmount=outAmount)]

overeating = merge(nutritentRequired, nutritentSupplied, by=c("GustRegion", "type"))
overeating[, loss:=inAmount-requiredAmount]
overeating[loss<0, loss:=0]
overeating[, outAmount:=inAmount-loss] # need this to avoid out being outAmount being greater than inAmount
overeating[, requiredAmount:=NULL]

# assuming energy is more constraining (which it is in 2013 globally)
wetDryOverConsup=merge(lossSummary[stage=="Consumer waste" & type %in% c("wetGt", "dryGt"), list(GustRegion, type, inAmount=outAmount)], overeating[type=="energyEJ", list(stage, GustRegion, lossRate=loss/inAmount)], by="GustRegion")
wetDryOverConsup[, loss:=inAmount*lossRate]
wetDryOverConsup[, outAmount:=inAmount-loss]
wetDryOverConsup[, lossRate:=NULL]
overeating = rbind(overeating, wetDryOverConsup)

lossSummary = rbind(lossSummary, overeating)


# Livestock production losses
livestockInputs = rbind(
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item & stage == "Handling and storage", list(type="wetGt", inAmount=sum(outAmount)/1000), by=list(GustRegion)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item & stage == "Handling and storage", list(type="dryGt", inAmount=sum(outAmount*dryMatter)/1000), by=list(GustRegion)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item & stage == "Handling and storage", list(type="energyEJ", inAmount=sum(outAmount*mj_per_kg)/1000), by=list(GustRegion)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item & stage == "Handling and storage", list(type="proteinMt", inAmount=sum(outAmount*protein_g_per_kg)/1000), by=list(GustRegion)]
)

rp_dt = merge(regional_prod, con_prod_to_use[Country=="World", list(Item, dryMatter, mj_per_kg, protein_g_per_kg)], by=c('Item'))

livestockOutputs = rbind(
		rp_dt[Item %in% itemDetails[animal==TRUE]$Item, list(type="wetGt", food=sum(food)/1000, used=sum(used)/1000), by=GustRegion],
		rp_dt[Item %in% itemDetails[animal==TRUE]$Item, list(type="dryGt", food=sum(food*dryMatter)/1000, used=sum(used*dryMatter)/1000), by=GustRegion],
		rp_dt[Item %in% itemDetails[animal==TRUE]$Item, list(type="energyEJ", food=sum(food*mj_per_kg)/1000, used=sum(used*mj_per_kg)/1000), by=GustRegion],
		rp_dt[Item %in% itemDetails[animal==TRUE]$Item, list(type="proteinMt", food=sum(food*protein_g_per_kg)/1000, used=sum(used*protein_g_per_kg)/1000), by=GustRegion]
)
livestock = merge(livestockInputs, livestockOutputs, by=c("GustRegion","type"))
livestock[, loss:=(inAmount-used)]
livestock[loss<0, loss:=0]
livestock_foodloss=livestock[, list(GustRegion, type, inAmount=inAmount*food/used, loss=loss*food/used, food_rate=food/used)]

livestockFeed = rbind(
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item , list(type="wetGt", inAmount=sum(inAmount)/1000, loss=sum(loss)/1000, outAmount=sum(outAmount)/1000), by=list(stage, GustRegion)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item , list(type="dryGt", inAmount=sum(inAmount*dryMatter)/1000, loss=sum(loss*dryMatter)/1000, outAmount=sum(outAmount*dryMatter)/1000), by=list(stage, GustRegion)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item , list(type="energyEJ", inAmount=sum(inAmount*mj_per_kg)/1000, loss=sum(loss*mj_per_kg)/1000, outAmount=sum(outAmount*mj_per_kg)/1000), by=list(stage, GustRegion)],
		lossDt[use=="feed" & Item %in% itemDetails[animal==FALSE]$Item , list(type="proteinMt", inAmount=sum(inAmount*protein_g_per_kg)/1000, loss=sum(loss*protein_g_per_kg)/1000, outAmount=sum(outAmount*protein_g_per_kg)/1000), by=list(stage, GustRegion)]
)

adj_livestockFeed = merge(livestockFeed, livestock_foodloss[, list(GustRegion, type, food_rate)], by=c("GustRegion","type"))
adj_livestockFeed=adj_livestockFeed[, list(GustRegion, type, stage, inAmount=inAmount*food_rate, loss=loss*food_rate, outAmount=outAmount*food_rate)]

lossWithoutLivestockProd=lossDt[use=="food" & !(commType %in% c("Meat", "Milk") & stage %in% c("Agricultural Production", "Handling and storage"))]

lossSummaryWithoutLivestockProd = rbind(
		lossWithoutLivestockProd[, list(type="wetGt", inAmount=sum(inAmount)/1000, loss=sum(loss)/1000, outAmount=sum(outAmount)/1000), by=list(stage, GustRegion)],
		lossWithoutLivestockProd[, list(type="dryGt", inAmount=sum(inAmount*dryMatter)/1000, loss=sum(loss*dryMatter)/1000, outAmount=sum(outAmount*dryMatter)/1000), by=list(stage, GustRegion)],
		lossWithoutLivestockProd[, list(type="energyEJ", inAmount=sum(inAmount*mj_per_kg)/1000, loss=sum(loss*mj_per_kg)/1000, outAmount=sum(outAmount*mj_per_kg)/1000), by=list(stage, GustRegion)],
		lossWithoutLivestockProd[, list(type="proteinMt", inAmount=sum(inAmount*protein_g_per_kg)/1000, loss=sum(loss*protein_g_per_kg)/1000, outAmount=sum(outAmount*protein_g_per_kg)/1000), by=list(stage, GustRegion)]
)

lossSummaryWithlivestock=rbind(lossSummaryWithoutLivestockProd, adj_livestockFeed)[, list(inAmount=sum(inAmount), loss=sum(loss), outAmount=sum(outAmount)), by=list(stage, GustRegion, type)]
lossSummaryWithlivestock=rbind(lossSummaryWithlivestock, livestock_foodloss[, list(GustRegion, type, stage="Livestock production", inAmount, loss, outAmount=inAmount-loss)], fill=TRUE)
lossSummaryWithlivestock = rbind(lossSummaryWithlivestock, overeating)


#Some summary stats
summariseLosses = function(dt) {
	dt=rbind(dt, dt[, list(GustRegion="World", inAmount=sum(inAmount), loss=sum(loss), outAmount=sum(outAmount)), by=list(type, stage)])
	
	dt = merge(dt, dt[stage=="Agricultural Production", list(GustRegion, type, initialAmount=inAmount)], by=c("GustRegion","type"))
	dt = merge(dt, dt[stage=="Over-consumption", list(GustRegion, type, finalAmount=outAmount)], by=c("GustRegion","type"))
	dt[, lossOfInitialRate:=loss/initialAmount]
	dt[, lossAtStageRate:=loss/inAmount]
	dt[, totalLossRate:=(initialAmount-finalAmount)/initialAmount]
	dt[, adjustedLossRate:=lossAtStageRate*totalLossRate/sum(lossAtStageRate), by=c("GustRegion","type")]
	
	dt[, stage := factor(stage, levels=rev(c('Agricultural Production', 'Livestock production', 'Handling and storage', 'Processing','Distrubution','Consumer waste','Over-consumption')))]
	dt
}

lossSummary2 = summariseLosses(lossSummary)
lossSummaryWithlivestock2 = summariseLosses(lossSummaryWithlivestock)

updateRegionNames = function(dt) {
	dt[GustRegion =="NAmericaOc",    GustRegion:="North America &\nOceania"]
	dt[GustRegion =="IndAsia",       GustRegion:="Industrialized\nAsia"]
	dt[GustRegion =="SubSAfrica",    GustRegion:="Sub-Saharan\nAfrica"]
	dt[GustRegion =="NAfricaWCAsia", GustRegion:="North Africa, West\nand Central Asia"]
	dt[GustRegion =="SSEAsia",       GustRegion:="South and\nSoutheast Asia"]
	dt[GustRegion =="LatinAm",       GustRegion:="Latin\nAmerica"]
}
lossSummary2 = updateRegionNames(lossSummary2)
require(ggplot2)
require(RColorBrewer)

plotLosses = function(dtToPlot, aType, yTitle, filePrefix="") {
	if ("Livestock production" %in% unique(dtToPlot$stage)) {
		coloursToPlot = c("#A6CEE3", "#1F78B4", "#B2DF8A", "#33A02C", "#FB9A99", "#FDBF6F", "#E31A1C")
	} else {
		coloursToPlot = c("#A6CEE3", "#1F78B4", "#B2DF8A", "#33A02C", "#FB9A99", "#E31A1C")
	}
	ggplot(dtToPlot[GustRegion != 'Missing' & type==aType], aes(x=GustRegion, y=valueToPlot, fill = stage) ) + 
			geom_bar(stat="identity") + 
			theme_minimal() + 
			theme(text = element_text(size=11),
					legend.title=element_blank(),
					axis.text.x = element_text(size=10),
					panel.grid.minor.y = element_blank(), 
					panel.grid.major.x = element_blank(), 
					panel.grid.minor.x = element_blank(), 
					panel.background = element_rect(colour = "black", size =.4)) +
			scale_fill_manual(values = coloursToPlot) + 
			labs(x="", y=yTitle) +
			ggsave(file=paste0("~/Documents/LURG/Papers/IPCC Special Report 2018/losses_", filePrefix, aType, ".pdf"),width=11,height=5)
	
}

plotLosses(lossSummary2[, list(GustRegion, type, stage, valueToPlot=adjustedLossRate*100)], "dryGt", "Loss rate of dry matter (%)", filePrefix="pc_")
plotLosses(lossSummary2[, list(GustRegion, type, stage, valueToPlot=adjustedLossRate*100)], "wetGt", "Loss rate of wet mass (%)", filePrefix="pc_")
plotLosses(lossSummary2[, list(GustRegion, type, stage, valueToPlot=adjustedLossRate*100)], "proteinMt", "Loss rate of protein (%)", filePrefix="pc_")
plotLosses(lossSummary2[, list(GustRegion, type, stage, valueToPlot=adjustedLossRate*100)], "energyEJ", "Loss rate of energy (%)", filePrefix="pc_")

plotLosses(lossSummaryWithlivestock2[, list(GustRegion, type, stage, valueToPlot=adjustedLossRate*100)], "energyEJ", "Loss rate of energy (%)", filePrefix="livestock_pc")
plotLosses(lossSummary2[GustRegion!="World", list(GustRegion, type, stage, valueToPlot=loss)], "energyEJ", "Loss (EJ)", filePrefix="")

ggplot(lossSummary2[GustRegion == 'World'], aes(x= type, y=adjustedLossRate*100, fill=stage) ) + 
		geom_bar(stat="identity") + 
		theme_minimal() + 
		theme(text = element_text(size=11),
				legend.title=element_blank(),
				axis.text.x = element_text(size=10),
				panel.grid.minor.y = element_blank(), 
				panel.grid.major.x = element_blank(), 
				panel.grid.minor.x = element_blank(), 
				panel.background = element_rect(colour = "black", size =.4)) +
		scale_fill_manual(values =  c("#A6CEE3", "#1F78B4", "#B2DF8A", "#33A02C", "#FB9A99", "#E31A1C")) + 
		labs(x="", y="Loss rate (%)") +
		ggsave(file=paste0("~/Documents/LURG/Papers/IPCC Special Report 2018/losses_global.pdf"),width=10,height=5)

write.table(lossSummary2[GustRegion == "World", list(GustRegion, type, stage, inAmount, outAmount, loss, lossOfInitialRate, lossAtStageRate)], 
		"~/Documents/LURG/Papers/IPCC Special Report 2018/globalFoodSystemLosses.csv", row.names=FALSE, sep=",")

write.table(lossSummary2[, list(GustRegion, type, stage, inAmount, outAmount, loss, lossOfInitialRate, lossAtStageRate)], 
		"~/Documents/LURG/Papers/Marginal gains/data/lossRates.csv", row.names=FALSE, sep=",")
