require(ggplot2)
require(reshape2)
require("RColorBrewer")

updateRegionNames = function(dt) {
	dt[Region =="NAmericaOc",    Region:="North America &\nOceania"]
	dt[Region =="IndAsia",       Region:="Industrialized\nAsia"]
	dt[Region =="SubSAfrica",    Region:="Sub-Saharan\nAfrica"]
	dt[Region =="NAfricaWCAsia", Region:="North Africa, West\nand Central Asia"]
	dt[Region =="SSEAsia",       Region:="South and\nSoutheast Asia"]
	dt[Region =="LatinAm",       Region:="Latin\nAmerica"]
}
#dtToPlot = rbind(mg$regional[variable == "Pasture", list(Region, variable, changeCat, saved_area, base_area)],
#		dtToPlot[variable != "Pasture", list(variable="Cropland", saved_area=sum(saved_area), base_area=sum(base_area)), by=list(Region, changeCat)])
dtToPlot=copy(mg$regional)
dtToPlot[, typesToPlot:=paste0(changeCat, ': ', variable)]
dtToPlot = updateRegionNames(dtToPlot)
dtToPlot$typesToPlot = factor(dtToPlot$typesToPlot, levels=rev(c("Consumer change: Cropland for food", "Consumer change: Cropland for feed", "Consumer change: Pasture", 
				"Supply change: Cropland for food", "Supply change: Cropland for feed", "Supply change: Pasture")))

ggplot(dtToPlot, aes(x=Region, y= saved_area, fill= typesToPlot)) + geom_bar(stat="identity", alpha=0.9) + 
		labs(x="", y="Reduction in land for food (Mha)") +
		scale_fill_manual(values =c("#43a2ca", "#7bccc4", "#bae4bc", "#e34a33","#fc8d59",  "#fdcc8a"), guide = guide_legend(ncol = 2)) +
		theme_minimal() + 
		theme(text = element_text(size=12),
				legend.position="bottom",
				legend.title=element_blank(),,
				axis.text.x = element_text(size=10),
				panel.grid.minor.y = element_blank(), 
				panel.grid.major.x = element_blank(), 
				panel.grid.minor.x = element_blank(), 
				panel.background = element_rect(colour = "black", size =.4)) +
		ggsave(file=file.path("/Users/peteralexander/Documents/LURG/Papers/Marginal gains/Figures", "regional_area_chg.pdf"),width=9,height=5.8)


marginalGainByGroup[rateAdj==0, rateType:=factor("2013 baseline")]
marginalGainByGroup[rateAdj==0.5, rateType:=factor("Low")]
marginalGainByGroup[rateAdj==1, rateType:=factor("Moderate")]
marginalGainByGroup[rateAdj==2, rateType:=factor("High")]


##
plotDecomposition = function(mgByGroup) {
	mg_chg = merge(
			melt(mgByGroup[rateAdj==0 & actionGroup=="All"], measure.vars=c( 'pasture_t', 'feed_t','food_crop_t'))[, list(Region, variable, baseVal=value)],
			melt(mgByGroup[rateAdj!=0 & actionGroup!="All"], measure.vars=c('pasture_t', 'feed_t','food_crop_t')),
			by=c("Region", "variable")
	)
	mg_chg = merge(mg_chg, 
			melt(mgByGroup[rateAdj!=0 & actionGroup=="All"], measure.vars=c('pasture_t', 'feed_t','food_crop_t'))[, list(Region, rateAdj, variable, fullSetVal = value)],
			by=c("Region", "variable", "rateAdj")
	)
	
	# Log Mean Divisia Index (LMDI) approach
	mg_chg[, tempCalc := (fullSetVal-baseVal)/(log(fullSetVal)-log(baseVal))]
	mg_chg[, decompVal := -tempCalc*log(value/baseVal)]
	mg_chg[, actionGroup:=factor(actionGroup, levels=rev(c("Shifting diets", "Reducing losses", "Production efficiency")))]
	mg_chg = mg_chg[order(actionGroup)]
	
	
	# crop / pasture percentage change in area ### CHANGE COLOURS, pink, purple, blue??
	mg_chg2<-mg_chg[, list(Region, variable, baseVal, actionGroup, rateAdj, decompVal)]
	levels(mg_chg2$variable)<- c("Pasture", "Cropland\nfor feed", "Cropland\nfor food")
	mg_chg2$variable <- factor(mg_chg2$variable, levels=rev(levels(mg_chg2$variable)))
	
	mg_chg3 = rbind(mg_chg2, mg_chg2[, list(variable="Agricultural\nland", decompVal=sum(decompVal), baseVal=sum(baseVal)), by=list(Region, rateAdj, actionGroup)])
	mg_chg3[, decompPercent := decompVal/baseVal * 100]
	
	ggplot(mg_chg3[rateAdj==1], aes(x= variable, y= decompPercent, fill= actionGroup)) + geom_bar(stat="identity", alpha=0.9) + 
			labs(x="", y="Percentage reduction in land for food") +
			scale_fill_manual(values =c("#377eb8","#4daf4a",  "#e41a1c"), guide = guide_legend(ncol = 2)) +
			theme_minimal() + 
			theme(legend.position="bottom",
					legend.title=element_blank(),
					axis.text.x = element_text(size=10),
					panel.grid.minor.y = element_blank(), 
					panel.grid.major.x = element_blank(), 
					panel.grid.minor.x = element_blank(), 
					panel.background = element_rect(colour = "black", size =.4)) +
			ggsave(file=file.path("/Users/peteralexander/Documents/LURG/Papers/Marginal gains/Figures", "mg_area_chg_pc.pdf"),width=5,height=5)	
}
plotDecomposition(marginalGainByGroup)

### ABSOLUTE HALF (Low, Med, High)"#009E73","#E69F00", "#F0E442"
dtToPlot = melt(marginalGainByGroup[actionGroup == "All", list(rateType, pasture_t, feed_t, food_crop_t)], id.vars = 'rateType')
dtToPlot[, variable:=factor(variable, levels=c('pasture_t', 'feed_t', 'food_crop_t'))]
dtToPlot = dtToPlot[order(variable)]
historicalCrop = marginalGainByGroup[actionGroup=="All" & rateAdj==0, feed_t+ food_crop_t]
historicalAgri = marginalGainByGroup[actionGroup=="All" & rateAdj==0,  pasture_t + feed_t + food_crop_t]
level(dtToPlot$rateType) = c("2013\nBaseline", "Low", "Moderate", "High")

ggplot() + 
		geom_bar(data = dtToPlot, aes(x=rateType, y=value, fill=variable), alpha=0.9, stat="identity") +
		geom_line(data = data.table(y=c(historicalCrop, historicalCrop), x=c(0.5, length(unique(dtToPlot$rateType))+0.5)), 
				aes(x=x, y=y, linetype="Cropland area in 2013 ")) +
		geom_line(data = data.table(y=c(historicalAgri, historicalAgri), x=c(0.5, length(unique(dtToPlot$rateType))+0.5)), 
				aes(x=x, y=y, linetype="Agricultural area in 2013 ")) +
		labs(x="", y="Percentage global land for food production (%)") +
		scale_y_continuous(sec.axis = sec_axis(~.*13000/100, name = "Land area for food production (Mha)")) + 
		theme_minimal() + 
		scale_linetype_manual(values = c("dashed", "dotted"), guide = guide_legend(nrow = 2)) + 
		scale_fill_manual(values=c("#238b45","#cc4c02", "#fec44f"), labels = c("Pasture", "Cropland for feed", "Cropland for food"), guide = guide_legend(ncol = 2)) + 
		scale_colour_manual(values = c("grey", "black"), guide = FALSE) + 
		theme(legend.position="bottom",
				legend.title=element_blank(),
				axis.text.x = element_text(size=10),
				panel.grid.minor.y = element_blank(), 
				panel.grid.major.x = element_blank(), 
				panel.grid.minor.x = element_blank(), 
				panel.background = element_rect(colour = "black", size =.4)) + 
		ggsave(file=file.path("/Users/peteralexander/Documents/LURG/Papers/Marginal gains/Figures", "mg_area.pdf"),width=5,height=5)

########

marginalGainsSingleChange[rateAdj==0, rateType:=factor("Baseline")]
marginalGainsSingleChange[rateAdj==0.5, rateType:=factor("Low")]
marginalGainsSingleChange[rateAdj==1, rateType:=factor("Moderate")]
marginalGainsSingleChange[rateAdj==2, rateType:=factor("High")]


amg_chg = merge(
		melt(marginalGainsSingleChange[rateAdj==0 & changeType=="All"], measure.vars=c( 'pasture_t', 'feed_t','food_crop_t'))[, list(variable, baseVal=value)],
		melt(marginalGainsSingleChange[rateAdj!=0 & changeType!="All"], measure.vars=c('pasture_t', 'feed_t','food_crop_t')),
		by="variable"
)
amg_chg = merge(amg_chg, 
		melt(marginalGainsSingleChange[rateAdj!=0 & changeType=="All"], measure.vars=c('pasture_t', 'feed_t','food_crop_t'))[, list(rateAdj, variable, fullSetVal = value)],
		by=c("variable", "rateAdj")
)

#######
amg_chg2 = amg_chg[rateType=='Moderate', list(variable, changeType, baseVal, value)]
levels(amg_chg2$variable)<- c("Pasture", "Cropland for feed", "Cropland for food")
amg_chg2 = rbind(amg_chg2, amg_chg2[, list(variable="All agricultural land", baseVal=sum(baseVal), value=sum(value)), by=list(changeType)])
amg_chg2[, percred:=(baseVal-value)/ baseVal*100]


amg_chg2$variable <- factor(amg_chg2$variable, levels = c("Cropland for food", "Cropland for feed", "Pasture", 'All agricultural land'))
amg_chg2$colr<-ifelse(amg_chg2$percred <0, "negative", "positive")

amg_chg4 = merge(amg_chg2, actionsDt[, list(ID, changeType, actionGroup)], by='changeType')
#change to match first plot cols 
amg_chg4[, displayName:=paste0(ID, '. ', changeType)]
amg_chg4$displayName <- factor(amg_chg4$displayName, levels = unique(amg_chg4[order(ID, decreasing=TRUE)]$displayName))

ggplot(amg_chg4, aes(x=displayName, y=percred, fill=colr)) + geom_bar(stat="identity", width=0.5, alpha=0.9) + 
		facet_grid(actionGroup~variable, space="free_y", scale="free_y") +
		coord_flip()+
		scale_fill_manual(values=c("firebrick1","royalblue1"))+
		labs(x="", y="Reduction in land area (%)") +
		theme_minimal() + 
		theme(strip.text.x = element_text(size = 9))+
		theme(strip.text.y = element_text(size = 10))+
		theme(legend.position = "none",
				panel.grid.minor.y = element_blank(), 
				panel.grid.major.y = element_blank(), 
				panel.grid.minor.x = element_blank(), 
				panel.background = element_rect(colour = "black", size =.4)) + 
		ggsave(file=file.path("/Users/peteralexander/Documents/LURG/Papers/Marginal gains/Figures", "mg_single_chg.pdf"),width=9,height=8)


