if (!require(rworldmap)) {
	install.packages("rworldmap",dependencies=TRUE)
}

if(!require(RColorBrewer)){install.packages("RColorBrewer")}
if(!require(classInt)){	install.packages("~/Downloads/classInt_0.1-21.tgz", repos = NULL)}


# Feed ratio
cereals = com_bal[Item=="Cereals - Excluding Beer + (Total)"]
setkey(cereals, Country, Year)
cereals = cereals[animal_prod[, list(feedReq=sum(feedReq), meat_prod=sum(prod)), by=list(Country, Year)]]
setkey(cereals, Country, Year)
cereals[,feedRatio:=feed/feedReq]
dt = cereals[country_data, CountryCode:=CountryCode]
dt = dt[, feedRatio:=feed/feedReq]
dt[feedRatio > 1]$feedRatio = 1
sPDF = joinCountryData2Map(dt[Year==2009], joinCode="ISO3", nameJoinColumn="CountryCode")

pdf(file="/Users/peteralexander/Documents/Future Earth/Maps/feed_ratio.pdf", width = 10, height = 6.6)
							
par(mar=c(2,0,2,0))
mapParams = mapCountryData(sPDF, numCats = 10, nameColumnToPlot='feedRatio', addLegend=FALSE, catMethod='fixedWidth', 
		mapTitle="Proporotion of energy from feed in production of meat, milk and eggs in 2009")
do.call( addMapLegend, c(mapParams, legendWidth=0.5,legendLabels="all", legendMar = 2))
dev.off()





# Meat allocation from 1961
drawSingleAlloc = function(dt) {
	scale = c(-5, -2, -1, -0.5, -0.1, 0, 0.1, 0.5, 1, 2, 5)
	sPDF = joinCountryData2Map(dt, joinCode="ISO3", nameJoinColumn="CountryCode", mapResolution="coarse")
	mapParams = mapCountryData(sPDF, nameColumnToPlot='area_change', addLegend=FALSE, 
			colourPalette=rev(brewer.pal(10,"RdYlGn")), catMethod=scale, mapTitle="")
	mapParams
}

drawAllocMaps = function(writeToFile=TRUE) {
	setkey(country_con_prod, Country)
	
	if (writeToFile) pdf(width = 13, height = 9*3.2/3.1, file=paste0("~/Documents/Future Earth/Maps/alloc2", ".pdf"))
	
	layout(matrix(c(1,1,1,9, 2,3,6,9, 2,4,7,9, 2,5,8,9), ncol=4,byrow=TRUE), widths=c(0.2, 5, 5,.85), heights=c(0.1,1,1,1,1))
	par(mar=c(0,0,0,0))
	plot.new()
	text(0.25,0.5, "a) 1961-1994", cex=1.8, font=4)
	text(0.75,0.5, "b) 1994-2011", cex=1.8, font=4)
	
	plot.new()
	text(0.6,0.87, "Animal Products", cex=1.8, srt=90, font=2)
	text(0.6,0.5, "Vegetal Crops", cex=1.8, srt=90, font=2)
	text(0.6,0.14, "Bioenergy", cex=1.8, srt=90, font=2)
	
	par(mar=c(0,0,0,0))
	
	dt= country_con_prod[country_con_prod[Year==1961], list(CountryCode, Year, area_change=(meat_a-i.meat_a)/33)][Year==1994]
	drawSingleAlloc(dt)
	
	dt = country_con_prod[country_con_prod[Year==1961], list(CountryCode, Year, area_change=(food_nm_a-i.food_nm_a)/33)][Year==1994]
	drawSingleAlloc(dt)	
	
#	dt = country_con_prod[country_con_prod[Year==1961], list(CountryCode, Year, area_change=(food_nm_a-i.food_nm_a+meat_a-i.meat_a)/33)][Year==1994]
#	drawSingleAlloc(dt)	
	
	dt = country_con_prod[country_con_prod[Year==1961], list(CountryCode, Year, area_change=(other_area-i.other_area)/33)][Year==1994]
	mapParams = drawSingleAlloc(dt)
	
	
	dt= country_con_prod[country_con_prod[Year==1994], list(CountryCode, Year, area_change=(meat_a-i.meat_a)/17)][Year==2011]
	drawSingleAlloc(dt)	
	
	dt = country_con_prod[country_con_prod[Year==1994], list(CountryCode, Year, area_change=(food_nm_a-i.food_nm_a)/17)][Year==2011]
	drawSingleAlloc(dt)
	
#	dt = country_con_prod[country_con_prod[Year==1994], list(CountryCode, Year, area_change=(food_nm_a-i.food_nm_a+meat_a-i.meat_a)/17)][Year==2011]
#	mapParams = drawSingleAlloc(dt)
	
	dt = country_con_prod[country_con_prod[Year==1994], list(CountryCode, Year, area_change=(other_area-i.other_area)/17)][Year==2011]
	mapParams = drawSingleAlloc(dt)
	
	plot.new()
	par(mar=c(0,0,5,0))
	do.call( addMapLegend, c(mapParams, legendWidth=6, legendLabels="all", legendMar = 60, horizontal=FALSE, labelFontSize=1.6))
	par(mar=c(0,0,3,0))
	text(0.85,0.756, "Area Change\n(Mha/yr)", cex=1.6)

	if(writeToFile) dev.off()
}
drawAllocMaps()

# Biofuel from 1961
dt = country_con_prod[country_con_prod[Year==1961], list(CountryCode, Year, area_change=other_area-i.other_area)]
sPDF = joinCountryData2Map(dt[Year==2011], joinCode="ISO3", nameJoinColumn="CountryCode", mapResolution="coarse")
par(mar=c(1.5,0,2,0))
mapParams = mapCountryData(sPDF, nameColumnToPlot='area_change', addLegend=FALSE, 
		colourPalette=rev(brewer.pal(10,"RdBu")[1:6]),
		catMethod=c(-1, 0, 1, 2, 5, 10, 20),
		#catMethod=classIntervals( na.omit(sPDF[["diet_area_change"]]), n=10, style="pretty")[["brks"]], 
		mapTitle="Land area change (Mha) for biofuel: 1961-2011")	

do.call( addMapLegend, c(mapParams, legendWidth=0.4, legendLabels="all", legendIntervals="page", legendMar = 2))
dev.copy2pdf(file="/Users/peteralexander/Documents/Future Earth/Maps/biomass_change.pdf", width = 10, height = 6.6)

# Biofuel from 1994
dt = country_con_prod[country_con_prod[Year==1994], list(CountryCode, Year, area_change=other_area-i.other_area)]
sPDF = joinCountryData2Map(dt[Year==2011], joinCode="ISO3", nameJoinColumn="CountryCode", mapResolution="coarse")
par(mar=c(1.5,0,2,0))
mapParams = mapCountryData(sPDF, nameColumnToPlot='area_change', addLegend=FALSE, 
		colourPalette=rev(brewer.pal(10,"RdBu")[1:6]),
		catMethod=c(-1, 0, 1, 2, 5, 10, 20),
		mapTitle="Land area change (Mha) for biofuel: 1994-2011")	

do.call( addMapLegend, c(mapParams, legendWidth=0.4, legendLabels="all", legendIntervals="page", legendMar = 2))
dev.copy2pdf(file="/Users/peteralexander/Documents/Future Earth/Maps/biomass_change_1994.pdf", width = 10, height = 6.6)


# waste from 1994
dt= country_con_prod[country_con_prod[Year==1994], list(CountryCode, Year, area_change=waste_area-i.waste_area + m_waste_area - i.m_waste_area)]

sPDF = joinCountryData2Map(dt[Year==2011], joinCode="ISO3", nameJoinColumn="CountryCode")
par(mar=c(2,0,2,0))
mapParams = mapCountryData(sPDF, nameColumnToPlot='area_change', addLegend=FALSE, 
		colourPalette=rev(brewer.pal(8,"RdBu")[1:8]),
		catMethod=c(-40, -30, -20, -10, 0, 10, 20, 30, 40), mapTitle="Area change to by production wasted (Mha): 1994-2011")

do.call( addMapLegend, c(mapParams, legendWidth=0.5,legendLabels="all", legendMar = 2))



# Decomposition
drawSingleDecomp = function(dt) {
	scale = c(-5, -3, -2, -1, -0.5, 0, 0.5, 1, 2, 3, 5)
	sPDF = joinCountryData2Map(dt, joinCode="ISO3", nameJoinColumn="CountryCode", mapResolution="coarse")
	mapParams = mapCountryData(sPDF, nameColumnToPlot='area_change', addLegend=FALSE, 
			colourPalette=rev(brewer.pal(10,"RdYlGn")),
			catMethod=scale,
			mapTitle="")
	mapParams
}

drawDecompMaps = function(writeToFile=TRUE) {
	if (writeToFile) pdf(width = 13, height = 9, file=paste0("~/Documents/Future Earth/Maps/decomposition", ".pdf"))
		
	layout(matrix(c(1,1,1,9, 2,3,6,9, 2,4,7,9, 2,5,8,9), ncol=4,byrow=TRUE), widths=c(0.2, 5, 5,.85), heights=c(0.1,1,1,1))
	par(mar=c(0,0,0,0))
	plot.new()
	text(0.25,0.5, "a) 1961-1994", cex=1.8, font=4)
	text(0.75,0.5, "b) 1994-2011", cex=1.8, font=4)
	
	plot.new()
	text(0.6,0.86, "Diet", cex=1.8, srt=90, font=2)
	text(0.6,0.5, "Yield", cex=1.8, srt=90, font=2)
	text(0.6,0.15, "Population", cex=1.8, srt=90, font=2)
	
	par(mar=c(0,0,0,0))
		
	dt = country_con_prod1961[Year==1994,list(Year, CountryCode, area_change=(con_change_area_m + con_change_area_c)/land*100*1000/33)]
	drawSingleDecomp(dt)	
	
	dt = country_con_prod1961[Year==1994,list(Year, CountryCode, area_change=(y_change_area_m + y_change_area_c)/land*100*1000/33)]
	drawSingleDecomp(dt)	
	
	dt = country_con_prod1961[Year==1994,list(Year, CountryCode, area_change=(pop_change_area_m + pop_change_area_c)/land*100*1000/33)]
	drawSingleDecomp(dt)
		
	dt = country_con_prod1994[Year==2011,list(Year, CountryCode, area_change=(con_change_area_m + con_change_area_c)/land*100*1000/17)]
	drawSingleDecomp(dt)	
	
	dt = country_con_prod1994[Year==2011,list(Year, CountryCode, area_change=(y_change_area_m + y_change_area_c)/land*100*1000/17)]
	drawSingleDecomp(dt)
	
	dt = country_con_prod1994[Year==2011,list(Year, CountryCode, area_change=(pop_change_area_m + pop_change_area_c)/land*100*1000/17)]
	mapParams = drawSingleDecomp(dt)
		
	plot.new()
	par(mar=c(0,0,5,0))
	do.call( addMapLegend, c(mapParams, legendWidth=6, legendLabels="all", legendMar = 60, horizontal=FALSE, labelFontSize=1.6))
	par(mar=c(0,0,3,0))
	text(0.85,0.756, "Area Change\n(% land/yr)", cex=1.6)
	
	if(writeToFile) dev.off()
}

drawDecompMaps()


# Per capita land allocations
dt = country_con_prod[,list(Year, CountryCode, per_capita_area=1000*(meat_a)/population)]

sPDF = joinCountryData2Map(dt[Year==2011], joinCode="ISO3", nameJoinColumn="CountryCode", mapResolution="coarse")
par(mar=c(1.5,0,2,0))
mapParams = mapCountryData(sPDF, nameColumnToPlot='per_capita_area', addLegend=FALSE, 
		colourPalette=(brewer.pal(7,"Blues")),
		catMethod=c(0, 0.2, 0.5, 1, 2,5,10, 40),
		#catMethod=classIntervals( na.omit(sPDF[["diet_area_change"]]), n=10, style="pretty")[["brks"]], 
		mapTitle="Per capita land area  (ha/person): 2011")	

#do.call( addMapLegend, c(mapParams, legendWidth=0.4, legendLabels="all", legendIntervals="page", legendMar = 2))

#pasture change since 1961
setkey(country_data, Country)
dt = country_data[country_data[Year==1961], list(CountryCode, Year, pasture_change=(perm_pasture+temp_pasture-i.perm_pasture-i.temp_pasture)/1000)]
sPDF = joinCountryData2Map(dt[Year==2009], joinCode="ISO3", nameJoinColumn="CountryCode")
par(mar=c(2,0,2,0))
mapParams = mapCountryData(sPDF, nameColumnToPlot='pasture_change', addLegend=FALSE, 
		colourPalette=c("#2166ac", "#4393c3", "#92c5de", "#d1e5f0", "#fddbc7", "#f4a582", "#d6604d", "#b2182b", "#67001f"),
		catMethod=c(-160, -120, -80,-40, 0, 40, 80, 120, 160, 200), mapTitle="Pasture area change (Mha): 1961-2009")

#do.call( addMapLegend, c(mapParams, legendWidth=0.5,legendLabels="all", legendMar = 2))


#pasture change since 1961
setkey(country_data, Country)
dt = country_data[country_data[Year==1999], list(CountryCode, Year, pasture_change=(perm_pasture+temp_pasture-i.perm_pasture-i.temp_pasture)/1000)]
sPDF = joinCountryData2Map(dt[Year==2009], joinCode="ISO3", nameJoinColumn="CountryCode")
par(mar=c(2,0,2,0))
mapParams = mapCountryData(sPDF, nameColumnToPlot='pasture_change', addLegend=FALSE, 
		colourPalette=c("#053061", "#2166ac", "#4393c3", "#92c5de", "#d1e5f0", "#fddbc7", "#f4a582", "#d6604d"),
		catMethod=c(-50, -30, -20, -10, -5, 0, 5, 10, 20), mapTitle="Pasture area change (Mha): 1999-2009")

#do.call( addMapLegend, c(mapParams, legendWidth=0.5,legendLabels="all", legendMar = 2))


#arable
setkey(country_data, Country)
dt = country_data[country_data[Year==1961], list(CountryCode, Year, arable_change=(arable-i.arable)/1000)]
sPDF = joinCountryData2Map(dt[Year==2009], joinCode="ISO3", nameJoinColumn="CountryCode")
par(mar=c(2,0,2,0))
mapParams = mapCountryData(sPDF, nameColumnToPlot='arable_change', addLegend=FALSE, 
		colourPalette=c("#4393c3", "#92c5de", "#d1e5f0", "#fddbc7", "#f4a582", "#d6604d", "#67001f"),
		catMethod=c(-25, -10,-5, 0, 5, 10, 25, 50), mapTitle="Arable area change (Mha): 1961-2009")

#do.call( addMapLegend, c(mapParams, legendWidth=0.5,legendLabels="all", legendMar = 2))


#forest
setkey(country_data, Country)
dt = country_data[country_data[Year==1990], list(CountryCode, Year, forest_change=(forest-i.forest)/1000)]
sPDF = joinCountryData2Map(dt[Year==2009], joinCode="ISO3", nameJoinColumn="CountryCode")
par(mar=c(2,0,2,0))
mapParams = mapCountryData(sPDF, nameColumnToPlot='forest_change', addLegend=FALSE, 
		colourPalette=c("#2166ac", "#4393c3", "#92c5de", "#d1e5f0", "#fddbc7", "#f4a582", "#d6604d", "#b2182b"),
		catMethod=c(-60, -30, -15, -5, 0, 5, 15, 30, 60), mapTitle="Forest area change (Mha): 1990-2009")

#do.call( addMapLegend, c(mapParams, legendWidth=0.5,legendLabels="all", legendMar = 2))
