# Author: peteralexander
###############################################################################
require(grid)
if (!require(treemap)) {install.packages("treemap")}
if(!require(RColorBrewer)){install.packages("RColorBrewer")}

output_dir = "~/Documents/Future Earth/Treemaps"

assignPosNeg = function(dt) {
	dt[Value > 0, Pos_neg := "Positive"]
	dt[Value < 0, c('Pos_neg', 'Value') := list("Negative", abs(Value))]
	dt = dt[!is.na(Pos_neg)]
	dt
}

shortenCountryNames = function (dt) {
	dt[Country=="United States of America", Country := "USA"]
	dt[Country=="United Kingdom", Country := "UK"]
	dt[Country=="Iran (Islamic Republic of)", Country := "Iran"]
	dt[Country=="Russian Federation", Country := "Russia"]
	dt[Country=="Sudan (former)", Country := "Sudan"]
	dt[Country=="Venezuela (Bolivarian Republic of)", Country := "Venezuela"]
	dt[Country=="United Republic of Tanzania", Country := "Tanzania"]
	dt[Country=="Viet Nam", Country := "Vietnam"]
	dt[Country=="United Arab Emirates", Country := "UAE"]
	dt[Country=="Democratic Republic of the Congo", Country := "DR Congo"]
	dt
}

getDriverDataAsRows = function(countryDt, yearTo = 2011) {
	#setkey(country_con_prod, Country)
	dt = countryDt[Year == yearTo]
	dt = rbind(
			dt[, list(Country, Driver="Diet", Type="Animal products", Value=con_change_area_m)],
			dt[, list(Country, Driver="Diet", Type="Vegetal crops", Value=con_change_area_c)],
			dt[, list(Country, Driver="Yield", Type="Animal products", Value=y_change_area_m)],
			dt[, list(Country, Driver="Yield", Type="Vegetal crops", Value=y_change_area_c)],
			dt[, list(Country, Driver="Population", Type="Animal products", Value=pop_change_area_m)],
			dt[, list(Country, Driver="Population", Type="Vegetal crops", Value=pop_change_area_c)]
			#,dt[countryDt[Year==1994]][,list(Country, Driver="Bioenergy", Type="Bioenergy", Value=other_area-other_area.1)]
	)
	shortenCountryNames(dt)
}

getAllocationAsRows = function(countryDt, startYear, endYear) {
	setkey(countryDt, Country)
	dt = countryDt[Year ==endYear][countryDt[Year==startYear]][,list(
					Country, food_nm_a=food_nm_a-base_food_nm_a, waste_area=waste_area-i.waste_area, other_area=other_area-i.other_area, 
					meat_a=meat_a-base_meat_a, feed_area=feed_area-i.feed_area)]	
	dt = rbind(
			dt[, list(Country, Type="Vegetal crops", SubType = "", Value=food_nm_a)],
			dt[, list(Country, Type="Waste", SubType = "", Value=waste_area)],
			dt[, list(Country, Type="Bioenergy", SubType = "", Value=other_area)],
			dt[, list(Country, Type="Animal products", SubType = "Pasture", Value=meat_a-feed_area)],
			dt[, list(Country, Type="Animal products", SubType ="Feed", Value=feed_area)]
	)
	dt = shortenCountryNames(dt)
}

# Treemap for allocation
drawAllocByTypeCountryTreemaps = function(dt, vp_p, vp_n) {
	dt = copy(dt)
	dt[Type=="Vegetal crops", ColourV:=1]
	dt[Type=="Waste", ColourV:=2]
	dt[Type=="Animal products", ColourV:=3]
	dt[Type=="Bioenergy", ColourV:=4]
	dt[,Type:=sprintf("%s (%0.1f Mha/yr)", Type,sum(Value)), by=list(Type,Pos_neg)]
	
	dt_p = dt[Pos_neg == "Positive"]
	dt_n = dt[Pos_neg == "Negative"]
	
	treemap(dt_p, index=c("Type", "Country"), vSize ="Value", vColor="ColourV", title="",
			lowerbound.cex.labels=0.55, type="manual", palette=c("#800026", "#fc4e2a", "#feb24c", "#54278f"), range=c(1,4), position.legend="none",
			bg.labels=0, align.labels=list(c("left", "top"), c("center", "center")), fontsize.labels=c(13,10), algorithm="pivotSize", vp=vp_p)
	
	treemap(dt_n, index=c("Type", "Country"), vSize ="Value", vColor="ColourV", title="",
			lowerbound.cex.labels=0.55, type="manual", palette=c("#005a32", "#fc4e2a", "#78c679", "#54278f"), range=c(1,4), position.legend="none",
			bg.labels=0, align.labels=list(c("left", "top"), c("center", "center")), fontsize.labels=c(13,10), algorithm="pivotSize", vp=vp_n)
}

drawTypeCountryTreemaps = function() {	
	dt_1961=getAllocationAsRows(country_con_prod1961, 1961, 1994)
	dt_1994=getAllocationAsRows(country_con_prod1994, 1994, 2011)
	
	# Country and Type
	dt_1961_ct = dt_1961[!is.na(Value),list(Value=sum(Value)/33), by=list(Country, Type)]
	dt_1961_ct = assignPosNeg(dt_1961_ct)
	dt_1994_ct = dt_1994[!is.na(Value),list(Value=sum(Value)/17), by=list(Country, Type)]
	dt_1994_ct = assignPosNeg(dt_1994_ct)
	
	total_treemap_height=0.85
	p_1961 = dt_1961_ct[Pos_neg == "Positive",sum(Value)]
	n_1961 = dt_1961_ct[Pos_neg == "Negative",sum(Value)]
	p_1994 = dt_1994_ct[Pos_neg == "Positive",sum(Value)]
	n_1994 = dt_1994_ct[Pos_neg == "Negative",sum(Value)]
	h_adj= total_treemap_height/(max(p_1961,n_1961)+max(p_1994, n_1994))
	y_1961_row = 0.99
	y_1994_row = 0.91-max(p_1961,n_1961)*h_adj
	
	pdf(width=9, height=8, file = paste0(output_dir, "/alloc_t_c.pdf"))
	
	grid.text(gp=gpar(cex=1.25, font=4), x=unit(.01, "npc"), y=unit(.99, "npc"), just=c("left", "top"), sprintf("a) 1961-1994 (Net %0.1f Mha/yr)", p_1961-n_1961))
	grid.text(gp=gpar(cex=1.15), x=unit(.03, "npc"), y=unit(.96, "npc"), just=c("left", "top"), sprintf("Increasing land allocation (%0.1f Mha/yr)", p_1961))
	grid.text(gp=gpar(cex=1.15), x=unit(.53, "npc"), y=unit(.96-(p_1961-n_1961)*h_adj, "npc"), just=c("left", "top"), sprintf("Reducing land allocation (%0.1f Mha/yr)", n_1961))
	vp_p_1961 <- viewport(just=c("left", "top"), x=0.01, y=0.945, width=0.5, height=p_1961*h_adj)
	vp_n_1961 <- viewport(just=c("left", "top"), x=0.51, y=0.945-(p_1961-n_1961)*h_adj, width=0.5, height=n_1961*h_adj)
	
	grid.text(gp=gpar(cex=1.25, font=4), x=unit(.01, "npc"), y=unit(y_1994_row, "npc"), just=c("left", "top"), sprintf("b) 1994-2011 (Net %0.1f Mha/yr)", p_1994-n_1994))
	grid.text(gp=gpar(cex=1.15), x=unit(.03, "npc"), y=unit(y_1994_row-0.03, "npc"), just=c("left", "top"), sprintf("Increasing land allocation (%0.1f Mha/yr)", p_1994))
	grid.text(gp=gpar(cex=1.15), x=unit(.53, "npc"), y=unit(y_1994_row-0.03-(p_1994-n_1994)*h_adj, "npc"), just=c("left", "top"), sprintf("Reducing land allocation (%0.1f Mha/yr)", n_1994))
	vp_p_1994 <- viewport(just=c("left", "top"), x=0.01, y=y_1994_row-0.045, width=0.5, height=p_1994*h_adj)
	vp_n_1994 <- viewport(just=c("left", "top"), x=0.51, y=y_1994_row-0.045-(p_1994-n_1994)*h_adj, width=0.5, height=n_1994*h_adj)
	
	drawAllocByTypeCountryTreemaps(dt_1961_ct, vp_p_1961, vp_n_1961)
	drawAllocByTypeCountryTreemaps(dt_1994_ct, vp_p_1994, vp_n_1994)
	dev.off()
}
drawTypeCountryTreemaps()

# by type and driver
drawByTypeDriverTreemaps = function(dt, vp_p, vp_n) {
	dt = dt[order(Type)]
	
	dt[,Type:=sprintf("%s (%0.1f Mha/yr)", Type,sum(Value)), by=list(Type, Pos_neg)]
	dt[, Driver:=sprintf("%s (%0.1f Mha/yr)", Driver,Value)]
	dt[Type %like% "Bioenergy"]$Driver = ""
	
	dt_p = dt[Pos_neg == "Positive"][, ColourV := 1:.N]
	dt_n = dt[Pos_neg == "Negative"][, ColourV := 1:.N]
	
	treemap(dt_p, index=c("Type", "Driver"), vSize ="Value", vColor="ColourV", title="", fontcolor.labels = c("white", "black"),
			lowerbound.cex.labels=0.6, type="manual", palette=c("#ef6548", "#d7301f", "#dfc27d", "#bf812d"), range=c(1,4), position.legend="none",
			bg.labels=0, align.labels=list(c("left", "top"), c("center", "center")), ymod.labels = c(0,0), fontsize.labels=c(15,11), algorithm="pivotSize", vp=vp_p)

	treemap(dt_n, index=c("Type", "Driver"), vSize ="Value", vColor="ColourV", title="", fontcolor.labels = c("white", "black"),
			lowerbound.cex.labels=0.6, type="manual", palette=c("#31a354", "#7bccc4"), range=c(1,2), position.legend="none",
			bg.labels=0, align.labels=list(c("left", "top"), c("center", "center")), ymod.labels = c(0,0), fontsize.labels=c(15,11), algorithm="pivotSize", vp=vp_n)
}

drawTypeDriverTreemaps = function() {	
	dt_1961_td= getDriverDataAsRows(country_con_prod1961, 1994)[!is.na(Value),list(Value=sum(Value)/33), by=list(Type, Driver)]
	dt_1961_td = assignPosNeg(dt_1961_td)
	dt_1994_td= getDriverDataAsRows(country_con_prod1994, 2011)[!is.na(Value),list(Value=sum(Value)/17), by=list(Type, Driver)]
	dt_1994_td = assignPosNeg(dt_1994_td)
	
	total_treemap_height=0.85
	p_1961 = dt_1961_td[Pos_neg == "Positive",sum(Value)]
	n_1961 = dt_1961_td[Pos_neg == "Negative",sum(Value)]
	p_1994 = dt_1994_td[Pos_neg == "Positive",sum(Value)]
	n_1994 = dt_1994_td[Pos_neg == "Negative",sum(Value)]
	h_adj= total_treemap_height/(max(p_1961,n_1961)+max(p_1994, n_1994))
	y_1961_row = 0.99
	y_1994_row = 0.91-max(p_1961,n_1961)*h_adj
	
	pdf(width=9, height=8, file = paste0(output_dir, "/alloc_t_d.pdf"))
	
	grid.text(gp=gpar(cex=1.25, font=4), x=unit(.01, "npc"), y=unit(.99, "npc"), just=c("left", "top"), sprintf("a) 1961-1994 (Net %0.1f Mha/yr)", p_1961-n_1961))
	grid.text(gp=gpar(cex=1.15), x=unit(.03, "npc"), y=unit(.96, "npc"), just=c("left", "top"), sprintf("Increasing land allocation (%0.1f Mha/yr)", p_1961))
	grid.text(gp=gpar(cex=1.15), x=unit(.53, "npc"), y=unit(.96-(p_1961-n_1961)*h_adj, "npc"), just=c("left", "top"), sprintf("Decreasing land allocation (%0.1f Mha/yr)", n_1961))
	vp_p_1961 <- viewport(just=c("left", "top"), x=0.01, y=0.945, width=0.5, height=p_1961*h_adj)
	vp_n_1961 <- viewport(just=c("left", "top"), x=0.51, y=0.945-(p_1961-n_1961)*h_adj, width=0.5, height=n_1961*h_adj)
	
	grid.text(gp=gpar(cex=1.25, font=4), x=unit(.01, "npc"), y=unit(y_1994_row, "npc"), just=c("left", "top"), sprintf("b) 1994-2011 (Net %0.1f Mha/yr)", p_1994-n_1994))
	grid.text(gp=gpar(cex=1.15), x=unit(.03, "npc"), y=unit(y_1994_row-0.03, "npc"), just=c("left", "top"), sprintf("Increasing land allocation (%0.1f Mha/yr)", p_1994))
	grid.text(gp=gpar(cex=1.15), x=unit(.53, "npc"), y=unit(y_1994_row-0.03-(p_1994-n_1994)*h_adj, "npc"), just=c("left", "top"), sprintf("Reducing land allocation (%0.1f Mha/yr)", n_1994))
	vp_p_1994 <- viewport(just=c("left", "top"), x=0.01, y=y_1994_row-0.045, width=0.5, height=p_1994*h_adj)
	vp_n_1994 <- viewport(just=c("left", "top"), x=0.51, y=y_1994_row-0.045-(p_1994-n_1994)*h_adj, width=0.5, height=n_1994*h_adj)
	
	drawByTypeDriverTreemaps(dt_1961_td, vp_p_1961, vp_n_1961)
	drawByTypeDriverTreemaps(dt_1994_td, vp_p_1994, vp_n_1994)
	dev.off()
}
drawTypeDriverTreemaps()