require(ggplot2)

# Read SSP data
getSsp  = function() {
	ssp_data = fread(paste0(data_dir_root, "/SSP/SspDb_country_data_2013-06-12.csv"), header=TRUE)
	
	ssp_pop = reshape(ssp_data[VARIABLE=="Population"], varying = c("2010", "2015", "2020", "2025", "2030", "2035", "2040", "2045", "2050", "2055", "2060", "2065",
					"2070", "2075", "2080", "2085", "2090", "2095", "2100"), 
			v.names = "population",
			timevar = "Year", 
			times = c(2010, 2015, 2020, 2025, 2030, 2035, 2040, 2045, 2050, 2055, 2060, 2065, 2070, 2075, 2080, 2085, 2090, 2095, 2100), 
			direction = "long")
	
	ssp_gdp = reshape(ssp_data[VARIABLE=="GDP|PPP"], varying = c("2010", "2015", "2020", "2025", "2030", "2035", "2040", "2045", "2050", "2055", "2060", "2065",
					"2070", "2075", "2080", "2085", "2090", "2095", "2100"), 
			v.names = "gdp_ppp",
			timevar = "Year", 
			times = c(2010, 2015, 2020, 2025, 2030, 2035, 2040, 2045, 2050, 2055, 2060, 2065, 2070, 2075, 2080, 2085, 2090, 2095, 2100), 
			direction = "long")
	
	setkey(ssp_gdp, MODEL, SCENARIO, REGION, Year)
	setkey(ssp_pop, MODEL, SCENARIO, REGION, Year)
	
	ssp_dt=ssp_pop[ssp_gdp][,list(Model=MODEL, Scenario=SCENARIO, CountryCode=REGION, Year, gdp_ppp=gdp_ppp*1000, population=population)]
	setkey(ssp_dt, CountryCode)
	
	baseline_gdp = country_data[Year == 2010 & CountryCode != 0]
	setkey(baseline_gdp, CountryCode)
	baseline_gdp_adj = baseline_gdp[ssp_dt[Year == 2010]][,list(CountryCode, Country, Year, Model, Scenario, IncomeGroup, gdp_adj=gdp/gdp_ppp, pop_adj=population/i.population/1000)]
	setkey(baseline_gdp_adj, CountryCode, Model, Scenario)
	setkey(ssp_dt, CountryCode, Model, Scenario)
	ssp_dt[baseline_gdp_adj, c('Country', 'gdp_adj', 'pop_adj') := list(Country, gdp_adj, pop_adj)]
	ssp_dt[, c('gdp', 'population') := list(gdp_ppp * gdp_adj, population * pop_adj)]
	
	ssp_dt$gdp_ppp = NULL
	ssp_dt$gdp_adj = NULL
	ssp_dt$pop_adj = NULL
	ssp_dt$CountryCode=NULL
	
	ssp_dt[Country == "Sudan", Country:="Sudan (former)"]
	
	ssp_dt[!is.na(Country) & Model != "PIK GDP-32"] # remove TWN taiwan (not in country_codes), and PIK GDP-32 seems to be US only
}
ssp = getSsp()


getHistoricDataset  = function() {
#	dt = merge(
#		con_prod_c[Country == "United States of America" & Year %% 10 == 0 & i.Item %in% c("Cereals - Excluding Beer + (Total)", "Fruits - Excluding Wine + (Total)", "Oilcrops + (Total)", 
#						"Pulses + (Total)", "Starchy Roots + (Total)", "Treenuts + (Total)", "Vegetables + (Total)", "Soyabeans", "Sugar cane")],
#		country_data, 
#		by=c("Country", "Year"))[, list(Item, Year, food/population)]
#	
#	setkey(dt, Item, Year)
#	dt	

	c_dt = con_prod_c[i.Item %in% c("Cereals - Excluding Beer + (Total)", "Fruits - Excluding Wine + (Total)", "Oilcrops + (Total)", 
					"Pulses + (Total)", "Starchy Roots + (Total)", "Treenuts + (Total)", "Vegetables + (Total)", "Soyabeans", "Sugar cane"), 
			list(Country, Year, Item = i.Item,
					supply=supply/1000000, 
					net_import=net_import/1000000, 
					waste_rate=waste/(waste+processing+food+feed+other),
					food_rate=(food+processing)/(waste+processing+food+feed+other),
					feed_rate=feed/(waste+processing+food+feed+other),
					other_rate=other/(waste+processing+food+feed+other), 
					prod_area=area/1000000,
					net_area=net_area/1000000)]
	
	m_dt = con_prod_m[, list(Country, Year, Item="meatmilkeggs", 
					supply=supply/1000000,
					net_import=(import-export)/1000000,
					waste_rate=waste/(waste+processing+food), 
					food_rate=(food+processing)/(waste+processing+food),
					feed_rate = 0,
					other_rate = 0,
					prod_area=area/1000000,
					net_area=net_area/1000000)]
		
#	just_meat_dt=consump[Item %in% c("Bovine Meat", "Poultry Meat", "Meat + (Total)", "Milk - Excluding Butter"), list(Country, Year, Item,
#					supply=supply/1000000,
#					net_import=(import-export)/1000000,
#					waste_rate=waste/(waste+processing+food), 
#					food_rate=(food+processing)/(waste+processing+food),
#					feed_rate = 0,
#					other_rate = 0,
#					prod_area=0,
#					net_area=0)]
	
	h_dt=rbind(c_dt, m_dt)
	
	gdp_pop_dt = country_data[, list(Country, Year, gdp, population=population/1000)]
	setkey(gdp_pop_dt, Country, Year)
	h_dt = gdp_pop_dt[h_dt][gdp>0]
	
	country_codes = getCountryCodes()
	ussr_states = c("Armenia", "Azerbaijan", "Belarus", "Estonia", "Georgia", "Kazakhstan", "Kyrgyzstan", "Latvia", 
			"Lithuania", "Republic of Moldova", "Russian Federation", "Tajikistan", "Turkmenistan", "Ukraine", "Uzbekistan")
	country_codes[Country %in% ussr_states, IncomeGroup:="Former USSR"]
	country_codes[Country == "Bermuda", IncomeGroup := "High income: OECD"]
	country_codes[Country == "Maldives", IncomeGroup := "Lower middle income"]

	setkey(h_dt, Country)
	h_dt[,prod := supply-net_import]
	h_dt[prod<0, c('prod', 'supply') := list(0, net_import)] # negative prod due to more imports than supply
	
	h_dt = merge(h_dt, country_codes, by = 'Country')
	h_dt[, c('yield', 'gdpPc', 'cpc', 'food_prod_area') := list(prod/prod_area, gdp/population, food_rate*supply/population, food_rate*prod_area)]
}

histDt = getHistoricDataset()

histYieldsByRegion = histDt[, list(prod_area=sum(prod_area), prod=sum(prod)), by=list(Year, Item, Region, IncomeGroup)]
histYieldsByRegion[, yield:=prod/prod_area]

getYieldFits  = function() {
	fits=data.table(Item="test", Region="test", IncomeGroup="test", a=NA, b=NA, r2=NA, p=NA)
	for (i in unique(histYieldsByRegion$Item)) {
		print (paste(i))
		
		dt_i = histYieldsByRegion[Item == i & prod_area > 0]
		for (r in unique(dt_i$Region)) {
			dt_ir = dt_i[Region == r]
			for (g in unique(dt_i$IncomeGroup)) {
				dt_irg = dt_ir[IncomeGroup == g]
				if (length(dt_irg$yield) > 10) {
					fit1 = lm(yield ~ Year, dt_irg)		
					fits = rbind(fits, 
							data.table(Item=i, Region=r, IncomeGroup=g, a=fit1$coefficients[1], b=fit1$coefficients[2], 
									r2=summary(fit1)$adj.r.squared, p=anova(fit1)$'Pr(>F)'[1]))
				}
			}
		}
	}
	setkey(fits, Item, Region, IncomeGroup)
	fits[!is.na(b)]
}
yield_fits = getYieldFits()

getProjectAllYields  = function() {
	baseProd = histDt[Year == 2010 & prod_area > 0, list(Item, Country, Region, IncomeGroup, baseYear=Year, baseProd=prod, baseProdArea=prod_area, baseYield=prod/prod_area, dummy=1)]
	dt = merge(baseProd, data.table(Year=seq(2010,2100,5), dummy=1), by="dummy", allow.cartesian=TRUE)
	dt[, dummy:= NULL]
	
	dt = merge(dt, yield_fits, by=c("Item", "Region", "IncomeGroup"))
	dt=dt[!is.na(a) & !is.na(b)]    
			
	dt[,projectYield := baseYield + b*(Year-baseYear)]
	dt[projectYield<0, projectYield:=0]
	dt
}
projectedYields = getProjectAllYields()


plotActualYieldScatter = function(item, region, incomeGroup) {
	dt = histYieldsByRegion[Item==item & Region == region & IncomeGroup == incomeGroup]
	xrange = range(dt$Year) 
	yrange = range(0, dt$yield)
	
	ylabel = "yield (t/ha)"
	if (item=="meatmilkeggs") {
		ylabel = "yield (API/ha)"
	}
	
	plot(xrange, yrange, type="n", xlab="Year", ylab=ylabel)
	points (dt$Year, dt$yield)
	
	fit = yield_fits[Item == item & Region == region & IncomeGroup == incomeGroup]
	abline(a=fit[1]$a, b=fit[1]$b, col=2)
	title(paste(item, region, incomeGroup))
}
#plotActualYieldScatter("meatmilkeggs", "Europe & Central Asia", "Former USSR")
#plotActualYieldScatter("Cereals - Excluding Beer + (Total)", "East Asia & Pacific", "High income: OECD")

plotProjectYieldScatter = function(item, region, incomeGroup) {
	hist = histDt[Item==item & Region == region & IncomeGroup == incomeGroup, list(Year, Country, Item, Region, IncomeGroup, prod_area, prod)]
	
	proj = projectedYields[Item==item & Region == region & IncomeGroup == incomeGroup & Year > 2011]
	
	dt = rbind(hist[Year %in% seq(1961, 2011, 2), list(Year, Country, Item, Region, IncomeGroup, prod_area, yield=prod/prod_area, dataType="Historic")],
			proj[,list(Year, Country, Item, Region, IncomeGroup, prod_area=baseProdArea, yield=projectYield, dataType="Projected")])
	
	dt = dt[prod_area>0.0005*dt[Year==2100,sum(prod_area)]]
	
	fit = yield_fits[Item == item & Region == region & IncomeGroup == incomeGroup]
	
	if (item=="meatmilkeggs") ylabel = "yield (API/ha)"
	else ylabel = "yield (t/ha)"
	
	g <- ggplot() 
	g + geom_point(data = dt, aes(x=Year, y=yield, size = prod_area, colour=dataType), alpha=0.5) +
			geom_abline(intercept=fit[1]$a, slope=fit[1]$b, colour="red") +
			labs(title=paste(item, region, incomeGroup), x="Year", y=ylabel) +
			scale_color_discrete(name = "Data Type") +
			scale_size_area(max_size=8, name = "Area (Mha)") + 
			theme_classic()
}

#plotProjectYieldScatter("Cereals - Excluding Beer + (Total)", "East Asia & Pacific", "High income: OECD")





# base consumption
getBaseConsumption  = function() {
	dt1 = histDt[Year == 2010, list(Item, Country, baseYear=Year, 
					baseSupply=supply,
					baseFoodRate=food_rate)]
	
	dt2 = ssp[Year == 2010 & Scenario == "SSP2_v9_130325", list(Country,
			basePop=population, 
			baseGdpPc=gdp/population)]
	setkey(dt1, Country)
	setkey(dt2, Country)
	dt = dt2[dt1]
	dt[, baseCpc := baseSupply/basePop*baseFoodRate]
	dt
}
baseConsumption = getBaseConsumption()


# Fit exponetial curves to consumption data
getCommodityCurves = function() {
	dt = histDt
	dt = dt[population>60 & gdp>1 & cpc > 0 & !is.na(cpc) & Country!="Japan"]
		
	curves=data.table(Item="test", a=NA, b=NA, c=NA, r2=NA, p=NA, fitType=NA)
	
	for (itemName in unique(dt$Item)) {
		dt1 = dt[Item==itemName]
		if (length(dt1$gdpPc) > 10) {
			print (itemName)
			fit1 = lm(cpc ~ log(gdpPc), dt1)
			curves = rbind(curves, data.table(Item=itemName, a=fit1$coefficients[1], b=fit1$coefficients[2], c=0,
							r2=summary(fit1)$adj.r.squared, p=anova(fit1)$'Pr(>F)'[1], fitType="loglinear"))
			
			
			fit2 = lm(cpc ~ log(gdpPc) + I(log(gdpPc)^2), dt1)
			curves = rbind(curves, data.table(Item=itemName, a=fit2$coefficients[1], b=fit2$coefficients[2], c=fit2$coefficients[3],
							r2=summary(fit2)$adj.r.squared, p=anova(fit2)$'Pr(>F)'[1], fitType="kuznets"))
			
			y = dt1[,cpc]
			x = dt1[,gdpPc]
			
			try (fit3 <- nls(y ~ SSlogis(x, a, b, c)))	# nls(y ~ a / (1 + exp((b-x)/c)), start = list(a=1, b= 100, c = 100))
			curves = rbind(curves, data.table(Item=itemName, a=summary(fit3)$coef[1], b=summary(fit3)$coef[2], c=summary(fit3)$coef[3], r2=NA, p=NA, fitType="logistic"))
		}
	}
	curves[!is.na(b)]
}
com_curves = getCommodityCurves()

getProjectedConsumption = function(fitType, gdpPc, a, b, c) {
	if (fitType == "logistic") {
		v = SSlogis(gdpPc, a, b, c)
	}
	else {
		v = a + b*log(gdpPc) + c*log(gdpPc)^2
	}
	as.numeric(v)
}

# Join ssp and baseConsumption
getProjectAllConsumption  = function() {
	setkey(baseConsumption, Country)
	setkey(ssp, Country, Model, Scenario)
	dt=baseConsumption[ssp, allow.cartesian=TRUE]
	dt=dt[!is.na(Item) & baseCpc > 0]    # baseConsumption[Country %in% unique(dt[is.na(Item),Country])] # some countries are not in com_bal
	
	dt[, gdpPc:=gdp/population]
	setkey(dt, Item)
	setkey(com_curves, Item, fitType)
	dt = dt[com_curves, allow.cartesian=TRUE]
	dt=dt[!is.na(a) & !is.na(population)]     # unique(dt[is.na(i),Item]) # some Items not in com_bal + Grenada GRN does not have a projection in some SSP models
	
	z = log(0.1)/8 # choose closing speed so that 90% reached after increase to 7 times size, i.e. 600% increase 
	
	mean_gdpPc=mean(dt$baseGdpPc)
	
	dt[,c('baseExpCpc', 'newExpCpc', 'gapRatio') := list(
					#if (fitType == "logistic") SSlogis(baseGdpPc, a, b, c) else a + b*log(baseGdpPc) + c*log(baseGdpPc)^2,					
					getProjectedConsumption(fitType, baseGdpPc, a, b, c),  # (a+b*log(baseGdpPc)+c*log(baseGdpPc)^2),
					getProjectedConsumption(fitType, gdpPc, a, b, c),  # (a+b*log(gdpPc)+c*log(gdpPc)^2),
					exp((gdpPc-baseGdpPc)/max(mean_gdpPc,baseGdpPc)*z) ), by=list(Model, Scenario, Year, Country, Item, fitType)]

	dt[gapRatio>1, gapRatio:=1] # if gdp drops
	
	dt[,projectedCpc:=(newExpCpc+(baseCpc-baseExpCpc)*gapRatio)]
	dt[projectedCpc<0, projectedCpc:=0]
	dt
}
projectedConsumption = getProjectAllConsumption()



#checks
dt1= projectedConsumption[Item == "Cereals - Excluding Beer + (Total)" & Year==2010 & Model == "OECD Env-Growth" & Scenario == "SSP2_v9_130325"]
dt2 = com_bal[Item == "Cereals - Excluding Beer + (Total)" & Year==2010]
setkey(dt1, Country)
setkey(dt2, Country)
dt1[dt2, list(Country, base=baseCpc* population, proj=projectedCpc*population, actual=sum(food,processing,na.rm=TRUE)/1000000)]
dt2[!Country %in% dt1$Country]


bigCountries = ssp[Year == 2050 & Scenario == "SSP2_v9_130325" & population>120]$Country # 14 of 178 which includes 64% in 2010 of world population and 62% in 2050
smallToLargeCountries = ssp[Year == 2050 & Scenario == "SSP2_v9_130325" & population>20]$Country  # 68 of 178 countries 

countriesToDisplay = ssp[Year == 2010 & Scenario == "SSP2_v9_130325" & population>60]$Country
chinaIndiaUS = c("China", "India", "United States of America")

shortenCountryNames = function (dt) {
	dt[Country=="United States of America", Country := "USA"]
	dt[Country=="United Kingdom", Country := "UK"]
	dt[Country=="Iran (Islamic Republic of)", Country := "Iran"]
	dt[Country=="Russian Federation", Country := "Russia"]
	dt[Country=="Sudan (former)", Country := "Sudan"]
	dt[Country=="Venezuela (Bolivarian Republic of)", Country := "Venezuela"]
	dt[Country=="United Republic of Tanzania", Country := "Tanzania"]
	dt[Country=="Viet Nam", Country := "Vietnam"]
	dt[Country=="United Arab Emirates", Country := "UAE"]
	dt[Country=="Democratic Republic of the Congo", Country := "DR Congo"]
	dt
}

library(scales) 

plotConsumptionScatter = function(item, scenario, year, countries, aFitType, fileName, title, showFit = TRUE, fixColours = FALSE) {
	hist = histDt[Item==item & Country %in% countries, list(Year, Country, Item, gdpPc, cpc, population)]
	min_gdp = min(histDt$gdpPc)
	
	proj = projectedConsumption[Item==item & Scenario == scenario & Year <= year & fitType == aFitType & Country %in% countries]
	max_gbp = 200000 #max(projectedConsumption[Item==item & Scenario == scenario & fitType == aFitType & Country %in% countries]$gdpPc)
	
	dt = rbind(hist[Year %in% seq(1962, 2010, 2), list(Year, Country, Item, gdpPc, cpc, population, dataType="Historic")],
			proj[,list(Year, Country, Item, gdpPc, cpc=projectedCpc, population, dataType="Projected")])
		
	dt = shortenCountryNames(dt)
	
	fit = projectedConsumption[Item == item & Scenario == scenario & fitType == aFitType][1]
	curve = data.table(gdpPc = seq(min_gdp, max_gbp, length=500))
	curve = curve[, list(gdpPc, cpc=getProjectedConsumption(aFitType, gdpPc, fit$a, fit$b, fit$c))][cpc>0]
	
	if (item=="meatmilkeggs") ylabel = "Consumption per capita (API/person)"
	else ylabel = "Consumption per capita (t/person)"
	
	gp = ggplot(data = dt, aes(x=gdpPc, y=cpc, size=population, colour=Country)) +
			scale_x_log10() +
			coord_cartesian(xlim = c(80, max_gbp), ylim = c(0,2.1)) + 
			geom_point(data = dt[dataType== "Historic"], alpha=0.5) + 
			geom_path(alpha=0.5, size=0.5) + 
			labs(title=title) +
			labs(x="GDP PPP (2005 US$/person)", y=ylabel) +
		#	scale_colour_discrete(guide = FALSE) +
			guides(col=guide_legend(ncol=2)) +
			scale_size_area(breaks=c(100, 200, 500, 1000, 50000), max_size=10, name = "Population (millions)")
	
	if (fixColours)
		gp = gp + scale_colour_manual(values=scales::hue_pal()(23)[c(3,9,22)])  #colours for China, India and US if 23 countries in total
				
	if (showFit)
		gp = gp + geom_line(data = curve, aes(x=gdpPc, y=cpc), colour="black", size=0.5)

	gp + theme_classic() + ggsave(file=fileName,width=11,height=7.2)
}

plotConsumptionScatter("meatmilkeggs", "SSP2_v9_130325", 2010, countriesToDisplay, "logistic", "/Users/peteralexander/Documents/LURG/PLUM-V2/charts/animal_hist.pdf", "", FALSE)
plotConsumptionScatter("meatmilkeggs", "SSP2_v9_130325", 2010, countriesToDisplay, "loglinear", "/Users/peteralexander/Documents/LURG/PLUM-V2/charts/animal_hist_loglinear.pdf", "Log linear (y ~ a + b.ln(x))", TRUE)
plotConsumptionScatter("meatmilkeggs", "SSP2_v9_130325", 2010, countriesToDisplay, "kuznets", "/Users/peteralexander/Documents/LURG/PLUM-V2/charts/animal_hist_kuvnets.pdf", "Kuznets (y ~ a + b.ln(x) + c.ln(x)^2)", TRUE)
plotConsumptionScatter("meatmilkeggs", "SSP2_v9_130325", 2010, countriesToDisplay, "logistic", "/Users/peteralexander/Documents/LURG/PLUM-V2/charts/animal_hist_logistic.pdf", "Logistic (y ~ a / (1 + exp((b-x)/c))", TRUE)

for (year in seq(2020, 2100, 10)) {
	plotConsumptionScatter("meatmilkeggs", "SSP2_v9_130325", year, countriesToDisplay, "logistic", paste0("/Users/peteralexander/Documents/LURG/PLUM-V2/charts/animal_proj_", year, ".pdf"), paste0("Logistic: Projected to ", year))
}

plotConsumptionScatter("meatmilkeggs", "SSP2_v9_130325", 2010, chinaIndiaUS, "logistic", "/Users/peteralexander/Documents/LURG/PLUM-V2/charts/animal_3c_hist.pdf", "", FALSE, fixColours =TRUE)
plotConsumptionScatter("meatmilkeggs", "SSP2_v9_130325", 2010, chinaIndiaUS, "logistic", "/Users/peteralexander/Documents/LURG/PLUM-V2/charts/animal_3c_hist_logistic.pdf", "Logistic (y ~ a / (1 + exp((b-x)/c))", TRUE, fixColours =TRUE)
for (year in seq(2020, 2100, 10)) {
	plotConsumptionScatter("meatmilkeggs", "SSP2_v9_130325", year, chinaIndiaUS, "logistic", paste0("/Users/peteralexander/Documents/LURG/PLUM-V2/charts/animal_3c_proj_", year, ".pdf"), paste0("Logistic: Projected to ", year), TRUE, TRUE)
}


#Join projectedProd and projectedConsumption
setkey(projectedYields, Country, Year, Item)
setkey(projectedConsumption, Country, Year, Item)
projectedComBal = projectedYields[projectedConsumption[fitType == "logistic"]]
projectedComBal[is.na(projectedComBal)] = 0
projectedComBal[, projectedProd := projectYield*baseProdArea]
projectedComBal[, projectedSupply := projectedCpc*population/baseFoodRate]
projectedComBal[, projectedNetImport := projectedSupply-projectedProd]

world_exports=projectedComBal[projectedNetImport < 0, list(worldExportArea=-sum(baseProdArea*projectedNetImport/projectedProd), worldExport=-sum(projectedNetImport)), by=list(Model, Scenario, Year, Item)]
world_imports=projectedComBal[projectedNetImport > 0, list(worldImport=sum(projectedNetImport)), by=list(Model, Scenario, Year, Item)]
world_balance=projectedComBal[, list(prod=sum(projectedProd), consump=sum(projectedSupply), surplus=sum(projectedNetImport)), by=list(Model, Scenario, Year, Item)]

setkey(world_imports, Model, Scenario, Year, Item)
setkey(world_exports, Model, Scenario, Year, Item)
setkey(world_balance, Model, Scenario, Year, Item)
world_trade = merge(merge(world_exports, world_imports, all = TRUE), world_balance, all = TRUE)
world_trade[is.na(world_trade)] = 0
world_trade[, avgExportYield := worldExport/worldExportArea]
world_trade[, surplusArea := surplus/avgExportYield]

world_trade[, list(surplusArea=sum(surplusArea)), by=list(Model, Scenario, Year)]


world_trade[Scenario == "SSP2_v9_130325" & Year == 2050]
world_trade[Scenario == "SSP2_v9_130325", list(surplusArea=sum(surplusArea, na.rm=TRUE)), by=list(Model, Scenario, Year)]



#checks
projectedComBal[, diff := projectedSupply-baseNetImport-projectedProd]

projectedComBal[!is.infinite(projectedSupply) & Year == 2010 & Scenario == "SSP2_v9_130325", list(sum(projectedProd), sum(projectedSupply),
				sum(diff), sum(baseNetImport)), by=list(Model, Scenario, Item)]

projectedComBal[Year == 2010 & Scenario == "SSP2_v9_130325" & abs(diff) > 0.05]


d2010 = projectedComBal[Scenario == "SSP2_v9_130325" & Year == 2010 & Item == "meatmilkeggs", list(Country, Year, projectedProd, projectedSupply, projectedNetImport)]
d2050 = projectedComBal[Scenario == "SSP2_v9_130325" & Year == 2050 & Item == "meatmilkeggs", list(Country, Year, projectedProd, projectedSupply, projectedNetImport)]
setkey(d2010, Country)
dt = d2010[d2050]
dt[, importChange := projectedNetImport.1 - projectedNetImport]
dt[importChange > 50][order(importChange, decreasing=TRUE)]


# Draw population chart
hist = country_data[, list(population=sum(population)/1000000), by=Year]
proj = ssp[Model == "OECD Env-Growth", list(population=sum(population, na.rm=TRUE)/1000), by=list(Year, Scenario)]

dt = rbind(hist[, list(Year, Scenario="Historic", population, dataType="Historic")],
		proj[,list(Year, Scenario, population, dataType="Projected")])

ggplot(data = dt, aes(x=Year, y=population, colour=Scenario)) +
		geom_path(alpha=1, size = 0.7) + 
		labs(x="Year", y="Global population (billions)") +
		scale_colour_manual(values=c("black", scales::hue_pal()(5)))  +
		geom_line(data = hist, aes(x=Year, y=population), colour="black", size=1) +
		scale_x_continuous(breaks=seq(1960, 2100, 20)) +
		scale_y_continuous(limits=c(3, 12.5), breaks=seq(3, 12, 1)) +
		theme_classic(base_size = 16) + 
		ggsave(file="/Users/peteralexander/Documents/LURG/PLUM-V2/charts/pop.pdf",width=10,height=6)

# Draw yield increases chart
wheat = crop_prod[Item == "Wheat", list(Crop = "Wheat", area=sum(area/1000000), prod=sum(prod/1000000)), by=list(Year)]
maize = crop_prod[Item == "Maize", list(Crop = "Maize", area=sum(area/1000000), prod=sum(prod/1000000)), by=list(Year)]
rice = crop_prod[Item == "Rice paddy", list(Crop = "Rice", area=sum(area/1000000), prod=sum(prod/1000000)), by=list(Year)]

dt = rbind(wheat, maize, rice)
dt[, yield := prod/area]

ggplot(data = dt, aes(x=Year, y=yield, colour=Crop, shape=Crop)) +
		geom_path(alpha=1, size = 0.7) + 
		geom_point(alpha=1) + 
		labs(x="Year", y="Yield (t/ha)") +
		theme_classic(base_size = 16) + 
		geom_smooth(method="lm", se=FALSE, linetype="dashed") +
		ggsave(file="/Users/peteralexander/Documents/LURG/PLUM-V2/charts/yields.pdf",width=9,height=5.2)

		
