get_usage_change = function(dt, baseYear) {
	setkey(dt, Country)
	dt[dt[Year==baseYear], list(Year, food_nm_a=food_nm_a-i.food_nm_a,
					waste_a=waste_a-i.waste_a, 
					feed_area=feed_area-i.feed_area,
					other_area=other_area-i.other_area,
					meat_a=meat_a-i.meat_a,
					pasture_a=pasture_a-i.pasture_a)]
}

get_annual_change = function(dt) {
	dt[, list(Year, food_nm_a=c(0,diff(food_nm_a)),
					waste_a=c(0,diff(waste_a)), 
					feed_area=c(0,diff(feed_area)),
					other_area=c(0,diff(other_area)),
					meat_a=c(0,diff(meat_a)),
					pasture_a=c(0,diff(pasture_a)))]
}

get_per_capita = function(dt) {
	dt[, list(Year, food_nm_a=1000*food_nm_a/population,
					waste_a=1000*waste_a/population, 
					feed_area= 1000*feed_area/population,
					other_area= 1000*other_area/population,
					meat_a= 1000*meat_a/population),
					pasture_a = 1000*pasture_a/population]
}

get_ma_change = function(dt, n=5) {
	dt = dt[, list(Year, food_nm_a=moving_avg(food_nm_a, n),
					waste_a=moving_avg(waste_a, n), 
					feed_area=moving_avg(feed_area, n),
					other_area=moving_avg(other_area, n),
					meat_a=moving_avg(meat_a, n),
					pasture_a=moving_avg(pasture_a, n))]
	dt[is.na(dt)] = 0
	dt
}


plot_usage = function (dt, titleName, style, yaxisTitle) {
	xrange = range(dt$Year) 
	yrange = range(0, dt$food_nm_a, dt$feed_area, dt$meat_a)
	plot(xrange, yrange, type="n", xlab="Year", ylab=yaxisTitle)
	
	lines(c(1994, 1994), c(-1000, 10000), lty="dashed", lwd=0.5)
	
	lines(dt$Year, dt$food_nm_a, type="o", col=style$colors[1], pch=style$plotchar[1], cex=style$markerSize[1])
	lines(dt$Year, dt$meat_a, type="o", col=style$colors[2], pch=style$plotchar[2], cex=style$markerSize[2])
	lines(dt$Year, dt$feed_area, type="o", col=style$colors[3], pch=style$plotchar[3], cex=style$markerSize[3])
	lines(dt$Year, dt$pasture_a, type="o", col=style$colors[4], pch=style$plotchar[4], cex=style$markerSize[4])
	lines(dt$Year, dt$other_area, type="o", col=style$colors[5], pch=style$plotchar[5], cex=style$markerSize[5])
	lines(dt$Year, dt$waste_a, type="o", col=style$colors[6], pch=style$plotchar[6], cex=style$markerSize[6])
	title(titleName, outer=FALSE, cex=0.9, line=0.6, adj=0)
}

plot_allocation = function(countryName, isPerCapita=FALSE, writeToFile=TRUE) {
	if(writeToFile) pdf(width=11, height=5.5, file="/Users/peteralexander/Documents/LURG/Papers/Future Earth/Charts/allocation_world.pdf")
	
	dt = country_con_prod
	if (countryName %in% country_data$Region) {
		dt = dt[Region == countryName]
	}
	else if (countryName != "World") {
		dt = dt[Country == countryName]
	}
	
	dt = dt[,list(Country ="dummy",
					population=sum(population),
					food_nm_a=sum(food_nm_a),
					waste_a=sum(waste_area),
					other_area=sum(other_area), #not including m_other_area has believed to be hides, etc.
					meat_a=sum(meat_a),
					feed_area=sum(feed_area),
					prod=sum(prod), area=sum(area),
					m_prod=sum(m_prod), 
					m_area = sum(m_area)), 
			by=Year]
	dt[,pasture_a:=meat_a-feed_area]
	
	if (isPerCapita)
		dt = get_per_capita(dt)
	
	style = data.table(titles = c('Crops for human\nconsumption', 'Animal products\n(pasture and feed)           ', 'Animal feed', 'Pasture', 'Bioenergy', 'Waste'),
			colors = c("#006d2c", "#045a8d", "#a6bddb", "#74a9cf", "#54278f", "#fc4e2a"),
			plotchar = c(17,15,3,4,18,16), markerSize=c(1.1, 1.05, 1.1, 1.1, 1.45, 1.1))
	
	layout(matrix(c(1,2,3,4,4,4), ncol=3, byrow=TRUE), heights=c(6, 1.1))
	par(mar=c(4, 4, 2, 1), cex=0.8)
	plot_usage(dt, "a)", style, "Area (Mha)")
	plot_usage(get_usage_change(dt, 1961), "b)", style, "Area change (Mha/yr)")
	plot_usage(get_ma_change(get_annual_change(dt), 10)[Year>1969], "c)", style, "Area change (Mha/yr)")
	#	plot_usage(get_usage_change(dt, 1996)[Year>=1990], "c) Land change: 1996 baseline", style, "Area (M ha)")
	par(mar=c(0,0,0,0))
	plot.new()
	legend(x = "left", inset = 0, legend = style$titles, cex=0.99, col=style$colors, pch=style$plotchar, x.intersp=1.1, lty=1, horiz=TRUE, bty='n')
	if(writeToFile) dev.off()
}
plot_allocation("World")


plot_yield_comp = function(countryName, since = 0, writeToFile=TRUE) {
	if(writeToFile) pdf(width=11, height=5.5, file = "~/Documents/LURG/Papers/Future Earth/Charts/relative_yield.pdf")
	
	dt = country_con_prod
	if (countryName %in% country_data[,Region])
		dt = dt[Region == countryName]
	else if (countryName != "World")
		dt = dt[Country == countryName]
	
	if (since > 0)
		dt = dt[Year>=since]
	
	dt = dt[!is.infinite(con_pc_m),list(m_prod=sum(m_prod),
					m_area=sum(m_area),
					prod=sum(prod),
					area=sum(area),
					population=sum(population),
					con_pc = sum(con_pc*population)/sum(population),
					con_pc_m = sum(con_pc_m*population)/sum(population)),
			by=Year]
	
	dt[, m_yield:=m_prod/m_area]
	dt[, yield:=prod/area]
	dt[, c('m_yield_percent', 'yield_percent', 'population_percent', 'con_pc_percent', 'con_pc_m_percent') := list(
					(m_yield-dt[1]$m_yield)/dt[1]$m_yield*100, 
					(yield-dt[1]$yield)/dt[1]$yield*100,
					(population-dt[1]$population)/dt[1]$population*100,
					(con_pc_m-dt[1]$con_pc_m)/dt[1]$con_pc_m*100,
					(con_pc-dt[1]$con_pc)/dt[1]$con_pc*100)]
	
	dt[, c('m_yield_rate', 'yield_rate') := list(
				(m_yield-c(NA, m_yield[seq_len(.N-1)]))/c(NA, m_yield[seq_len(.N-1)])*100,
				(yield-c(NA, yield[seq_len(.N-1)]))/c(NA, yield[seq_len(.N-1)])*100)]

	style = data.table(titles = c('Animal yield', 'Vegetal yields', 'Population', 'Animal consumption\nper capita', 'Vegetal consumption\nper capita'),
			colors = c("#d73027", "#006837", "gray25", "black", "gray25"),
			plotchar = c(0,1,2,3,4))
	
	layout(matrix(c(1,2), ncol=2, byrow=TRUE), widths=c(2.5, 1))
	par(mar=c(4, 5, 1, 1))
	xrange = range(dt$Year) 
	yrange = range(0, dt$m_yield_percent, dt$yield_percent, dt$population_percent, dt$con_pc_percent, dt$meat_con_percent)
	plot(xrange, yrange, type="n", xlab="Year", ylab="Cumulative change in mean yield (%)")
	
	lines(dt$Year, dt$m_yield_percent, type="o", col=style$colors[1], pch=style$plotchar[1])
	
	dt1 = dt#[Year<1996]
	reg1 = lm(dt1$m_yield_percent ~ dt1$Year)
	abline(reg1, lwd=0.9, col="#d73027", lty=2)
	
	lines(dt$Year, dt$yield_percent, type="o", col=style$colors[2], pch=style$plotchar[2])
	reg1 = lm(dt1$yield_percent ~ dt1$Year)
	abline(reg1, lwd=0.9, col="#006837", lty=2)


#	lines(dt$Year, dt$population_percent, type="o", col=style$colors[3], pch=style$plotchar[3])
#	lines(dt$Year, dt$con_pc_percent, type="o", col=style$colors[4], pch=style$plotchar[4])
#	lines(dt$Year, dt$con_pc_m_percent, type="o", col=style$colors[5], pch=style$plotchar[5])
	
	par(mar=c(2,0,0,0))
	plot.new()
	legend(x = "left",inset = 0, legend = style$titles[1:2], cex=1, col=style$colors[1:2], lty=1, pch=style$plotchar[1:2], y.intersp=6, horiz = FALSE, bty='n')
	if(writeToFile) dev.off()
}

plot_yield_comp("World")


plot_per_capita_alloc = function(countries, writeToFile=TRUE) {
	if(writeToFile) pdf(width=11, height=5.5, file = "~/Documents/LURG/Papers/Future Earth/Charts/percapita_food_area_c.pdf")
	
	dt = country_con_prod[Country %in% countries,list(population=sum(population),
					food_nm_a=sum(food_nm_a),
					waste_a=sum(waste_area),
					other_area=sum(other_area), #not including m_other_area has believed to be hides, etc.
					meat_a=sum(meat_a),
					feed_area=sum(feed_area),
					prod=sum(prod), area=sum(area),
					m_prod=sum(m_prod), 
					m_area = sum(m_area)), 
			by=list(Country, Year)]
	
	dt = dt[, list(Country, Year, food_nm_a=1000*food_nm_a/population,
						waste_a=1000*waste_a/population, 
						feed_area= 1000*feed_area/population,
						other_area= 1000*other_area/population,
						meat_a= 1000*meat_a/population)]
	
	colors = c("gray25", "black", "gray35", "gray45", "gray55", "gray40", "gray30")
	plotchar = c(0,2,1,3,4,5,6)
	
	layout(matrix(c(1,2), ncol=1, byrow=TRUE), heights=c(5, 1))
	par(mar=c(4, 5, 2, 1))
	xrange = range(dt$Year) 
	yrange = range(0, dt$meat_a)
	plot(xrange, yrange, type="n", xlab="Year", ylab="Area per captia\n(ha/person)")
	
	for (i in 1:length(countries) ) {
		dt1 = dt[Country==countries[i]]
		lines(dt1$Year, dt1$meat_a, type="o", col=colors[i], pch=plotchar[i])
	}
	
	par(mar=c(2,0,0,0))
	plot.new()
	legend(x = "left", inset = 0, legend = countries, cex=0.6, col=colors, pch=plotchar, horiz = TRUE, bty='n')
	title("Meat area for some countries", outer=TRUE, line = -1)
	if(writeToFile) dev.off()
}
plot_per_capita_alloc(c("France", "United States of America", "Brazil", "India", "China", "New Zealand", "United Kingdom"))

plot_per_capita_alloc_regions = function(writeToFile=TRUE) {
	if(writeToFile) pdf(width=11, height=5.5, file = "~/Documents/LURG/Papers/Future Earth/Charts/percapita_food_area.pdf")
	setkey(country_con_prod, Country)
	country_codes = getCountryCodes()
	setkey(country_codes, Country)
	
	dt = country_codes[country_con_prod][!is.na(Region),list(Region, population=sum(population),
						food_nm_a=sum(food_nm_a),
						waste_a=sum(waste_area),
						other_area=sum(other_area), #not including m_other_area has believed to be hides, etc.
						meat_a=sum(meat_a),
						feed_area=sum(feed_area),
						prod=sum(prod), area=sum(area),
						m_prod=sum(m_prod), 
						m_area = sum(m_area)), 
				by=list(Region, Year)]
	
	dt2 = dt[, list(Region, Year, food_nm_a=1000*food_nm_a/population,
					waste_a=1000*waste_a/population, 
					feed_area= 1000*feed_area/population,
					other_area= 1000*other_area/population,
					meat_a= 1000*meat_a/population)]
	
	colors = c("gray15", "gray40", "gray20", "gray35",  "gray25", "gray30", "black", 4)
	plotchar = c(0,1,2,3,4,5,6,3)
	
	layout(matrix(c(1,2), ncol=2, byrow=TRUE), widths=c(2.5, 1))
	par(mar=c(4, 5, 1, 1))
	xrange = range(dt2$Year) 
	yrange = range(0, dt2$food_nm_a + dt2$meat_a)
	plot(xrange, yrange, type="n", xlab="Year", ylab="Area per captia\n(ha/person)")
	regions = getRegions()
	
	for (i in 1:length(regions) ) {
		dt1 = dt2[Region==regions[i]]
		lines(dt1$Year, dt1$food_nm_a + dt1$meat_a, type="o", col=colors[i], pch=plotchar[i])
	}
	
	dt1 = dt[,list(food_nm_a=1000*sum(food_nm_a)/sum(population), meat_a=1000*sum(meat_a)/sum(population)), by=Year]
	lines(dt1$Year, dt1$food_nm_a + dt1$meat_a, type="o", col=colors[8], pch=plotchar[8])
	
	par(mar=c(2,0,0,0))
	plot.new()
	legend(x = "left", inset = 0, legend = c(regions, "Global"), cex=1, col=colors, pch=plotchar, lty=1,  y.intersp=3, bty='n')
	#	title("Meat, milk and eggs area per capita, by region", outer=TRUE, line = -1)
	if(writeToFile) dev.off()
}
plot_per_capita_alloc_regions()


if (!require(ggplot2)) {
	install.packages("ggplot2")
}


getTableofDrivers = function(dt, yearTo, limit=20) {
	dt = dt[Year == yearTo]
	dt1 = rbind(
		dt[abs(con_change_area_m) > limit | abs(con_change_area_c) > limit | abs(y_change_area_m) > limit | abs(y_change_area_c) > limit | abs(pop_change_area_m) > limit | abs(pop_change_area_c) > limit,
	 #| (con_change_area_m + con_change_area_c + y_change_area_m + y_change_area_c + pop_change_area_m + pop_change_area_c) > limit,
			list(Country, con_change_area_m, con_change_area_c, y_change_area_m, y_change_area_c, pop_change_area_m, pop_change_area_c)],
	
		dt[!(abs(con_change_area_m) > limit | abs(con_change_area_c) > limit | abs(y_change_area_m) > limit | abs(y_change_area_c) > limit | abs(pop_change_area_m) > limit | abs(pop_change_area_c) > limit),
	#						| (con_change_area_m + con_change_area_c + y_change_area_m + y_change_area_c + pop_change_area_m + pop_change_area_c) > limit),
			list(Country="Rest of the world", con_change_area_m=sum(con_change_area_m), con_change_area_c=sum(con_change_area_c), 
					y_change_area_m=sum(y_change_area_m ), y_change_area_c=sum(y_change_area_c), 
					pop_change_area_m=sum(pop_change_area_m ), pop_change_area_c=sum(pop_change_area_c))]
	)
	dt1
}
getTableofDrivers(country_con_prod1994, 2011)
getTableofDrivers(country_con_prod1961, 1994, 40)


write.table(country_con_prod1994[Year==2011, list(Country, con_change_area_m, con_change_area_c, y_change_area_m, y_change_area_c, pop_change_area_m, pop_change_area_c)], 
		"~/Documents/LURG/Papers/Future Earth/Charts/decomp_land_changes_1994-2011.csv", row.names=FALSE, sep=",")
write.table(country_con_prod1961[Year==2011, list(Country, con_change_area_m, con_change_area_c, y_change_area_m, y_change_area_c, pop_change_area_m, pop_change_area_c)], 
		"~/Documents/LURG/Papers/Future Earth/Charts/decomp_land_changes_1961-2011.csv", row.names=FALSE, sep=",")
