require(ggplot2)

########## Plot fertiliser and yields
plot_fertiliser_and_yield_by_time = function(countryName) {
	cereals_prod = crop_prod[Item=="Cereals Total + (Total)"]
	setkey(cereals_prod, Country, Year)
	cd = copy(country_data)
	cd[cereals_prod, yield_c:=yield]
	
	if (countryName %in% country_data[,Region]) {
		dt = cd[country_data][Region == countryName][!is.na(yield_c) & !is.na(arable) & !is.na(fertiliser_n),list(yield_c=sum(yield_c* arable)/sum(arable), fertiliser_n=sum(fertiliser_n), agri=sum(agri)),by=Year]
	}
	else if (countryName == "World") {
		dt = cd[!is.na(yield_c) & !is.na(arable) & !is.na(fertiliser_n),list(yield_c=sum(yield_c* arable)/sum(arable), fertiliser_n=sum(fertiliser_n), agri=sum(agri)),by=Year]
	}
	else {
		dt = cd[countryName]
	}
	dt = dt[, list(Year, y=yield_c/10000, f=fertiliser_n/agri)]
	
	par(mfrow=c(1,3), oma=c(0,0,1,0))
	plot(dt$Year, dt$y, xlab="Year", ylab="Yield (tonnes/ha)")
	reg1 = lm(dt$y ~ dt$Year)
	abline(reg1, lwd=1, col=2)
	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))
	
	plot(dt$Year, dt$f, xlab="Year", ylab="Fertiliser rate (tonnes/ha)")
	reg1 = lm(dt$f ~ dt$Year)
	abline(reg1, lwd=1, col=2)
	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))

	plot(dt$f, dt$y, xlab="Fertiliser rate (tonnes/ha)", ylab="Yield (tonnes/ha)")
	reg1 = lm(dt$y ~ dt$f)
	abline(reg1, lwd=1, col=2)
	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))

	title(countryName, outer=TRUE)
}
#plot_fertiliser_and_yield_by_time("Nigeria")
#plot_fertiliser_and_yield_by_time("China")
#plot_fertiliser_and_yield_by_time("India")
#plot_fertiliser_and_yield_by_time("France")
#plot_fertiliser_and_yield_by_time("United States of America")
#plot_fertiliser_and_yield_by_time("United Kingdom")
#plot_fertiliser_and_yield_by_time("Brazil")
#plot_fertiliser_and_yield_by_time("Mexico")
#plot_fertiliser_and_yield_by_time("Austrialia")
#plot_fertiliser_and_yield_by_time("World")

plot_fertiliser_and_yield_scatter = function(year) {
	cereals_prod = crop_prod[Item=="Cereals Total + (Total)"]
	setkey(cereals_prod, Country, Year)
	cd = copy(country_data)
	cd[cereals_prod, yield_c:=yield]
	dt = cd[Year==year & !is.na(yield_c) & !is.na(fertiliser_n) & !is.na(agri), list(Country, y=yield_c/10000, f=fertiliser_n/agri)]
	dt = dt[!f>400 & !y>50]
	
	plot(dt$f, dt$y, xlab="Fertiliser rate (tonnes/ha)", ylab="Yield (tonnes/ha)", xlim=c(0, 260), ylim=c(0, 17))
	reg1 = lm(dt$y ~ dt$f)
	abline(reg1, lwd=1, col=2)
	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))
	title(year, outer=FALSE)
}
plot_selected_plot_fertiliser_and_yield_scatters = function() {
	par(mfrow=c(2,3), oma=c(0,0,1,0))
	plot_fertiliser_and_yield_scatter(1970)
	plot_fertiliser_and_yield_scatter(1980)
	plot_fertiliser_and_yield_scatter(1990)
	plot_fertiliser_and_yield_scatter(2000)
	plot_fertiliser_and_yield_scatter(2005)
	plot_fertiliser_and_yield_scatter(2009)
}
plot_selected_plot_fertiliser_and_yield_scatters()

########## Plot feed ratio
plot_feed_ratio_scatter = function(year) {
	par(mfrow=c(2,2), oma=c(0,0,1,0))
	
	cereals = com_bal[Item=="Cereals - Excluding Beer + (Total)"]
	setkey(cereals, Country, Year)
	cereals = cereals[animal_prod[!is.na(feedReq), list(feedReq=sum(feedReq), meat_prod=sum(prod)), by=list(Country, Year)]]
	setkey(cereals, Country, Year)
	cereals[,feedRatio:=feed/feedReq]

	dt = cereals[country_data][Year==year & meat_prod > 1000000][!is.na(feed) & !is.na(feedReq) & !is.na(feedRatio) & !is.na(gdp_pc) & !is.na(fertiliser_n), 
			list(Year, Country, meat_prod, feed=feed/1000000, feedReq= feedReq/1000000, feedRatio = feedRatio * 100, pop_density=0, gdp_pc, perm_pasture,
			pasture=perm_pasture+temp_pasture, perm_pasture_per_meat=perm_pasture/meat_prod*1000)]
	dt[,pasture_intensity:=(feedReq-feed)/pasture]
	dt[,pasture_per_meat:=pasture/meat_prod]
	dt[,non_cereal_demand_per_meat:=(feedReq-feed)/meat_prod]
	dt = dt[pasture>0 & !Country=="Bangladesh"  & !Country == "Saudi Arabia"]
	
	plot(dt$gdp_pc, dt$feedRatio, xlab="GDP per capita (current US$)", ylab="Feed ratio (%)")
	reg1 = lm(dt$feedRatio ~ dt$gdp_pc)
	abline(reg1, lwd=1, col=2)
	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))
	
#	plot(dt$pop_density, dt$feedRatio, xlab="Population density (pop/km2)", ylab="Feed ratio (%)")
#	reg1 = lm(dt$feedRatio ~ dt$pop_density)
#	abline(reg1, lwd=1, col=2)
#	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))
	
	plot(dt$perm_pasture_per_meat, dt$feedRatio, xlab="Permanent pasture per tonne meat (tonnes/ha?)", ylab="Feed ratio (%)")
	reg1 = lm(dt$feedRatio ~ dt$perm_pasture_per_meat)
	abline(reg1, lwd=1, col=2)
	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))
	
	plot(dt$perm_pasture_per_meat, dt$non_cereal_demand_per_meat, xlab="Permanent pasture per tonne meat", ylab="Non-cereal demand per tonne of meat")
	reg1 = lm(dt$non_cereal_demand_per_meat ~ dt$perm_pasture_per_meat)
	abline(reg1, lwd=1, col=2)
	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))
	
	title(year, outer=TRUE)
}
plot_feed_ratio_scatter(2011)


########## Consumption
plot_selected_consumption_by_time = function(countryName) {
			
	commodities = c("Meat + (Total)", "Milk - Excluding Butter + (Total)", "Sugar & Sweeteners + (Total)",
			"Cereals - Excluding Beer + (Total)", "Starchy Roots + (Total)", "Pulses + (Total)")
	
	if (countryName %in% country_data[,Region]) {
		dt = merge(com_bal[Item %in% commodities & Country %in% country_data[Region == countryName]$Country], country_data, by=c('Country', 'Year'))
	}
	else if (countryName == "World") {
		dt = merge(com_bal[Item %in% commodities], country_data, by=c('Country', 'Year'))
	}
	else {
		dt = merge(com_bal[Item %in% commodities & Country== countryName], country_data, by=c('Country', 'Year'))
	}
	dt[is.na(dt)] = 0
	dt = dt[population>0, list(cpc=sum(food+processing)/sum(population)), by=list(Year, Item)]
	dt = merge(dt[Year == 1961], dt, by='Item')[, cpc_change := (cpc.y-cpc.x)/cpc.x*100]
	
	dt = dt[, list(Crop = gsub(" \\+ \\(Total\\)","", Item), Year=Year.y, cpc_change)]
	
	ggplot(data = dt, aes(x=Year, y=cpc_change, colour=Crop, shape = Crop)) +
			geom_path(alpha=1, size = 0.7) + 
			geom_point(alpha=1) + 
			labs(x="Year", y="Change in mean global consumption\nper capita from 1961 (%)") +
			scale_y_continuous(breaks = seq(-40,80,20)) +
			theme_classic(base_size = 13) + 
			theme(legend.title=element_blank()) + 
			theme(panel.background = element_rect(colour = "black", size =1)) + 
			ggsave(file="~/Documents/Future Earth/Charts/consumption_over_time2.pdf",width=11,height=5.5)
	
}

plot_selected_consumption_by_time("World")


plot_consumption_scatter_by_gdp = function(itemName, year, style) {
	setkey(com_bal, Country, Year)
	setkey(country_data, Country, Year)
	dt = country_data[com_bal[Item==itemName & Year==year]]
	dt[population>1000, cpc:=sum(food, na.rm=TRUE)/population, by=list(Country, Item, Year)]
	dt = dt[!is.na(cpc) & gdp_pc > 0]
	
	plot(dt$gdp_pc, dt$cpc, xlab="GDP per capita (US$2011/person)", ylab=paste("Consumption per capita (kg/year)", sep=" "))
	fit1 = lm(cpc ~ log(gdp_pc), dt)
	
	xx <- seq(min(dt$gdp_pc), max(dt$gdp_pc), length=50)
	lines(xx, predict(fit1, data.frame(gdp_pc=xx)), col=2)
#	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(fit1)$adj.r.squared, digits=4)))
	
	ch1=country_data[com_bal[Item==itemName & Country == "China" & Year==1961]][,list(Country, gdp_pc, cpc=food/population)]
	ch2=country_data[com_bal[Item==itemName & Country == "China" & Year==1996]][,list(Country, gdp_pc, cpc=food/population)]
	ch3=dt[Country == "China"]
	ch4=dt[Country == "Brazil"]
	
	points(ch1$gdp_pc, ch1$cpc, col=style$colors[1], pch=style$plotchar[1], cex=1.4)
	points(ch2$gdp_pc, ch2$cpc, col=style$colors[2], pch=style$plotchar[2], cex=1.4)
	points(ch3$gdp_pc, ch3$cpc, col=style$colors[3], pch=style$plotchar[3], cex=1.4)
#	points(ch4$gdp_pc, ch4$cpc, col=style$colors[4], pch=style$plotchar[4], cex=1.4)
	
 	title(gsub("\\+ \\(Total\\)", "", itemName), outer=FALSE)
}
plot_selected_consumption_scatter_by_gdp = function(year, writeToFile=TRUE) {
	if(writeToFile) pdf(width=10, height=8, file = "~/Documents/Future Earth/Charts/consumption_scatter.pdf")
	
	layout(matrix(c(1,2,3,4,5,6,7,7,7), ncol=3, byrow=TRUE), heights=c(5, 5, 1))
	
	par(oma=c(0,0,0,0), mar=c(4,4,4,2))
	
	style = data.table(titles = c("China 1961", "China 1996", "China 2011"),
			colors = c(2,4,3),
			plotchar = c(16,16,16))
	
	plot_consumption_scatter_by_gdp("Meat + (Total)", year, style)
	plot_consumption_scatter_by_gdp("Milk - Excluding Butter + (Total)", year, style)
	plot_consumption_scatter_by_gdp("Sugar & Sweeteners + (Total)", year, style)
	plot_consumption_scatter_by_gdp("Starchy Roots + (Total)", year, style)
	plot_consumption_scatter_by_gdp("Pulses + (Total)", year, style)
	plot_consumption_scatter_by_gdp("Cereals - Excluding Beer + (Total)", year, style)
	par(mar=c(0,0,0,0))
	plot.new()
	
	legend(adj=1, x.intersp=7, x = "center", inset = 0, legend = style$titles, cex=1, col=style$colors, pch=style$plotchar, pt.cex=1.4, horiz=TRUE, bty='n')
	if(writeToFile) dev.off()
}

plot_selected_consumption_scatter_by_gdp(2011)


sum_feed_ratio_data = function(dt) {
	dt[is.na(dt)] = 0

	dt = dt[,
			list(feed = sum(feed)/1000000, feedReq = sum(feedReq)/1000000, feedRatio=sum(feed)/sum(feedReq)*100, 
				gdp=sum(gdp)/1000, population=sum(population)/1000, pop_density=sum(population)/sum(land), gdp_pc=1000*sum(gdp)/sum(population), meat_prod=sum(meat_prod),
				agri=sum(agri)/1000, arable=sum(arable)/1000, forest=sum(forest)/1000, perm_pasture=sum(perm_pasture)/1000,
				pasture=(sum(perm_pasture) + sum(temp_pasture))/1000, land=sum(land)/1000,
				perm_pasture_per_meat=sum(perm_pasture)/sum(meat_prod)*1000, fert=sum(fertiliser_n)/sum(agri), 
				fallow=sum(fallow)/1000, temp_pasture=sum(temp_pasture), perm_crops=sum(perm_crops)/1000, temp_crops=sum(temp_crops)/1000
			), by =Year]
}


# Areas (perm_pasture, forest, arable) and feed ratios for a country
plot_areas_feed_ratio = function(countryName) {
	#feed = com_bal[Item=="Cereals - Excluding Beer + (Total)"]
	feed = con_prod_c[!is.na(feed), list(feed=sum(feed)), by=list(Country, Year)]
	setkey(feed, Country, Year)
	feed = feed[animal_prod[!is.na(feedReq), list(feedReq=sum(feedReq), meat_prod=sum(prod)), by=list(Country, Year)]]
	setkey(feed, Country, Year)
	feed[,feedRatio:=feed/feedReq]
	setkey(country_data, Country, Year)
	
	if (countryName %in% country_data[,Region]) {
		dt = feed[country_data][Region == countryName]
		dt = sum_feed_ratio_data(dt)
	}
	else if (countryName %in% country_data[, IncomeGroup]) {
		dt = feed[country_data][IncomeGroup == countryName]
		dt = sum_feed_ratio_data(dt)
	}
	else if (countryName == "World") {
		dt = feed[country_data]
		dt = sum_feed_ratio_data(dt)
	}
	else {
		dt = feed[country_data[countryName]][!is.na(feed) & !is.na(feedReq) & !is.na(feedRatio),
		list(Year, Country, feed=feed/1000000, feedReq= feedReq/1000000, feedRatio = feedRatio * 100, gdp=gdp/1000, population=population/1000, pop_density, gdp_pc, 
			meat_prod, perm_pasture_per_meat=perm_pasture/meat_prod*1000,
			arable=arable/1000, agri=agri/1000, forest=forest/1000, perm_pasture=perm_pasture/1000, 
			temp_pasture=(temp_pasture)/1000, pasture=(perm_pasture+temp_pasture)/1000, fert=fertiliser_n/agri
		)]
	}
	
	par(mfrow=c(2,3), oma=c(0,0,1,0))
	par(mar=c(4,4,2,4))

	xrange = range(dt$Year) 
	yrange = range(dt$agri,dt$forest)
	plot(xrange, yrange, type="n", xlab="Year", ylab="Area (M ha)")
	colors = rainbow(4)
	plotchar = seq(1,1+4,1)
	points(dt$Year, dt$agri, col=colors[1], pch=plotchar[1])
	points(dt$Year, dt$arable, col=colors[2], pch=plotchar[2])
	points(dt$Year, dt$perm_pasture, col=colors[3], pch=plotchar[3])
	dt1 = dt[!forest == 0]
	points(dt1$Year, dt1$forest, col=colors[4], pch=plotchar[4])
	legend(xrange[1], yrange[2], c("Agricultural", "Arable", "Perm. Pasture", "Forest"), cex=0.8, col=colors, pch=plotchar)
	title("Areas", outer=FALSE)

	yrange = range(dt$feed,dt$feedReq)
	plot(xrange, yrange, type="n", xlab="Year", ylab="Quantity of feed (M tonnes)")
	colors = rainbow(3)
	plotchar = seq(1,1+3,1)
	points(dt$Year, dt$feed, col=colors[1], pch=plotchar[1])
	points(dt$Year, dt$feedReq, col=colors[2], pch=plotchar[2])
	legend(xrange[1], yrange[2], c("Feed used", "All cereal requirement", "Feed ratio"), cex=0.8, col=colors, pch=plotchar)
	par(new=TRUE)
	plot(dt$Year, dt$feedRatio, xaxt="n", yaxt="n", xlab="", ylab="", col=colors[3], pch=plotchar[3]) 
	axis(4)
	mtext("Feed ratio (%)",side=4,line=2,cex=0.7)
	reg1 = lm(dt$feedRatio ~ dt$Year)
	abline(reg1, lwd=1, col=colors[3])
	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))
	title("Animal Feed", outer=FALSE)

	yrange = range(dt$gdp)
	plot(xrange, yrange, type="n", xlab="Year", ylab="GDP (current billions US$)")
	colors = rainbow(3)
	plotchar = seq(1,1+3,1)
	points(dt$Year, dt$gdp, col=colors[1], pch=plotchar[1])
	legend(xrange[1], yrange[2], c("GDP", "Population"), cex=0.8, col=colors, pch=plotchar)
	par(new=TRUE)
	plot(dt$Year, dt$population, xaxt="n", yaxt="n", xlab="", ylab="", col=colors[2], pch=plotchar[2]) 
	axis(4)
	mtext("Population (millions)",side=4,line=2,cex=0.7)
	title("GDP & Population", outer=FALSE)

	plot(dt$pop_density, dt$feedRatio, xlab="Population density (pop/ha)", ylab="Feed ratio (%)")
	reg1 = lm(dt$feedRatio ~ dt$pop_density)
	abline(reg1, lwd=1, col=2)
	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))

	plot(dt$fert, dt$feedRatio, xlab="GDP per capita (current US$)", ylab="Feed ratio (%)")
	reg1 = lm(dt$feedRatio ~ dt$fert)
	abline(reg1, lwd=1, col=2)
	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))
 	
 	plot(dt$perm_pasture_per_meat, dt$feedRatio, xlab="Pasture per meat produced (ha/tonne?)", ylab="Feed ratio (%)")
	reg1 = lm(dt$feedRatio ~ dt$perm_pasture_per_meat)
	abline(reg1, lwd=1, col=2)
	legend("bottomright", bty="n", legend=paste("R2 is", format(summary(reg1)$adj.r.squared, digits=4)))

 	title(countryName, outer=TRUE)
}

plot_areas_feed_ratio("Middle East & North Africa") # correlation - increasing pasture
plot_areas_feed_ratio("Latin America & Caribbean") # correlation - increasing pasture
plot_areas_feed_ratio("Sub-Saharan Africa") # correlation - flat pasture
plot_areas_feed_ratio("South Asia") # correlation - dropping pasture

plot_areas_feed_ratio("Europe & Central Asia") # no corr
plot_areas_feed_ratio("North America") # no corr, flat pasture
plot_areas_feed_ratio("East Asia & Pacific") # no corr, flat/increasing pasture

plot_areas_feed_ratio("Brazil") # significant increase in pasture and arable - not possible in PLUM
plot_areas_feed_ratio("World") # even this shows this effect

plot_areas_feed_ratio("High income: OECD")
plot_areas_feed_ratio("China")






