plot_lu = function (dt, titleName, style, display_x = FALSE) {
	xrange = range(dt$Year) 
	yrange = range(0, dt$agri,dt[!is.na(forest)]$forest, dt$pasture)
	plot(xrange, yrange, type="n", xlab="Year", ylab="Area (M ha)")
	
	lines(dt$Year, dt$agri, type="o", col=style$colors[1], pch=style$plotchar[1])
	lines(dt$Year, dt$arable, type="o", col=style$colors[2], pch=style$plotchar[2])
	dt1 = dt[!is.na(perm_crops)]
	lines(dt1$Year, dt1$perm_crops, type="o", col=style$colors[3], pch=style$plotchar[3])
	lines(dt$Year, dt$pasture, type="o", col=style$colors[4], pch=style$plotchar[4])
	dt1 = dt[!is.na(forest)]
	lines(dt1$Year, dt1$forest, type="o", col=style$colors[5], pch=style$plotchar[5])
	
	if (display_x)
		lines (c(0,3000), c(0,0), type = "l")

	title(titleName, outer=FALSE, cex=0.85, line = 0.5)
}

get_land_use_change = function(dt) {
	dt[, list(Year, Region, agri=agri-dt[! agri==0][1]$agri, arable=arable-dt[!arable==0][1]$arable, forest=forest-dt[!forest==0][1]$forest, 
			pasture=pasture-dt[! pasture==0][1]$pasture, perm_crops= perm_crops-dt[!perm_crops==0][1]$perm_crops, other=other-dt[!other==0][1]$other)]
}

plot_global_land_use = function() {
	dt = country_data[,
			list(Region="World", agri=sum(agri)/1000, arable=sum(arable)/1000, forest=sum(forest)/1000, 
				pasture=(sum(perm_pasture) + sum(temp_pasture))/1000, perm_crops=sum(perm_crops)/1000, other=sum(other)/1000
			), by =Year]
			
	par(mfrow=c(1,3), oma=c(0,0,1,0))
	dt[dt==0] = NA
	
	style = data.table(titles = c("Agricultural", "Arable", "Perm. crops", "Pasture (perm. and temp.)", "Forest"),
			colors = c("gray25", "gray55", "black", "gray45", "gray40"),
			plotchar = c(0,2,1,3,4))
	
	layout(matrix(c(1,2,3,4,4,4), ncol=3, byrow=TRUE), heights=c(6, 1))
	par(mar=c(4, 4, 4, 4))
	
	plot_lu(dt, "Areas", style)
	plot_lu(get_land_use_change(dt), "Cumulative change since 1961", style, TRUE)
	plot_lu(get_land_use_change(dt[Year>=1995]), "Cumulative change since 1995", style, TRUE)
	
	par(mar=c(0,0,0,0))
	plot.new()
	legend(x = "center",inset = 0, legend = style$titles, cex=0.85, col=style$colors, pch=style$plotchar, horiz = TRUE)	
	
	title("Global land-use", outer=TRUE, line = -1)
}
plot_global_land_use()


plot_crop_regional_breakdown = function(dt, cropType, style, display_x = FALSE) {	
	xrange = range(dt$Year) 
	yrange = range(0, dt[!is.na(v)]$v)
	plot(xrange, yrange, type="n", xlab="Year", ylab="Area (M ha)")
	regions = getRegions()
	
	for (i in 1:length(regions) ) {
		dt1 = dt[Region==regions[i]]
		lines(dt1$Year, dt1$v, type="o", col=style$colors[i], pch=style$plotchar[i])
	}
	
	if (display_x)
		lines (c(0,3000), c(0,0), type = "l")
	
	title(cropType, outer=FALSE, cex=0.85, line = 0.5)
}

plot_regional_breakdown = function(showChange = FALSE, since = 0) {	
	dt = country_data[!Region==0,
			list(agri=sum(agri)/1000, arable=sum(arable)/1000, forest=sum(forest)/1000, 
					pasture=(sum(perm_pasture) + sum(temp_pasture))/1000, perm_crops=sum(perm_crops)/1000, other=sum(other)/1000
			), by=list(Region, Year)]
	
	if (since > 0)
		dt = dt[Year>=since]
	
	dt[dt==0] = NA
	setkey(dt, Region)
	
	layout(matrix(c(1,2,3,4,5,5), ncol=2, byrow=TRUE), heights=c(5, 5, 1))
	par(mar=c(4, 4, 4, 4))
		
	style = data.table(regions = c(getRegions()),
			colors = c("gray55", "black", "gray45", "gray40",  "gray50", "gray35", "gray30"),
			plotchar = c(0,2,6,3,1,4,5))
	
	if (showChange) {
		for (i in 1:length(style$regions) ) {
			if (i==1)
				dt1 = get_land_use_change(dt[Region==regions[i]])
			else
				dt1 = rbind(dt1, get_land_use_change(dt[Region==regions[i]]))
		}
		dt = dt1
	}
	
	plot_crop_regional_breakdown(dt[,list(Region, Year, v=pasture)],"Pasture", style, showChange)
	plot_crop_regional_breakdown(dt[,list(Region, Year, v=arable)],"Arable", style, showChange)
	plot_crop_regional_breakdown(dt[,list(Region, Year, v=forest)],"Forest", style, showChange)
	plot_crop_regional_breakdown(dt[,list(Region, Year, v=perm_crops)],"Perm. crop", style, showChange)
	
	par(mar=c(0,0,0,0))
	plot.new()
	legend(x = "center",inset = 0, legend = style$regions, cex=0.85, col=style$colors, pch=style$plotchar, horiz = TRUE)	
	
	if (showChange)
		title("Regional land-use cummulative change", outer=TRUE)
	else
		title("Regional land-use", outer=TRUE, line=-1)
	
}
plot_regional_breakdown()
plot_regional_breakdown(TRUE)
plot_regional_breakdown(TRUE, 1995)
