plot_yield_inter_country_comp = function(countries, since = 0) {
	country_codes = getCountryCodes()
	setkey(country_con_prod, Country)
	setkey(country_codes, Country)
	
	dt = country_codes[country_con_prod]
	if (since > 0)
		dt = dt[Year>=since]
	
	colors = c("gray25", "black", "gray35", "gray45")
	plotchar = c(0,2,1,3)
	
	dt = dt[Country %in% countries, list(m_prod=sum(m_prod), m_area=sum(m_area), prod=sum(prod), area=sum(area)), by=list(Year, Country)]
	dt[, m_yield:=m_prod/m_area]
	dt[, yield:=prod/area]
	
	layout(matrix(c(1,2), ncol=1, byrow=TRUE), heights=c(5, 1))
	par(mar=c(4, 4, 2, 4))
	xrange = range(dt$Year) 
	yrange = range(0, dt$m_yield)
	plot(xrange, yrange, type="n", xlab="Year", ylab="Yield change (MI/ha)")
	
	for (i in 1:length(countries) ) {
		dt1 = dt[Country==countries[i]]
		lines(dt1$Year, dt1$m_yield, type="o", col=colors[i], pch=plotchar[i])
	}
	
	par(mar=c(0,0,0,0))
	plot.new()
	legend(x = "center",inset = 0, legend = countries, cex=0.85, col=colors, pch=plotchar, horiz = TRUE)
	title(paste("Meat yield"), outer=TRUE, line = -1)
	
}

plot_yield_inter_country_comp(c("China", "United States of America", "Brazil", "India"))

plot_yield_by_regions = function() {
	country_codes = getCountryCodes()
	setkey(country_con_prod, Country)
	setkey(country_codes, Country)
	
	dt = country_codes[country_con_prod][!is.na(Region),list(Region, population=sum(population),
					food_nm_a=sum(food_nm_a),
					waste_a=sum(waste_area),
					other_area=sum(other_area), #not including m_other_area has believed to be hides, etc.
					meat_a=sum(meat_a),
					feed_area=sum(feed_area),
					prod=sum(prod),
					area=sum(area),
					m_prod=sum(m_prod), 
					m_area = sum(m_area)), 			
			by=list(Region, Year)]
	
	dt[, m_yield:=m_prod/m_area]
	dt[, yield:=prod/area]
	
	colors = c("gray55", "black", "gray45", "gray40",  "gray50", "gray35", "gray30")
	plotchar = c(0,2,6,3,1,4,5)
	
	layout(matrix(c(1,2), ncol=2, byrow=TRUE), widths=c(5, 2))
	par(mar=c(4, 4, 2, 0))
	xrange = range(dt$Year) 
	yrange = range(0, dt$m_yield)
	plot(xrange, yrange, type="n", xlab="Year", ylab="Yield index (MI/ha)")
	regions = getRegions()
	
	for (i in 1:length(regions) ) {
		dt1 = dt[Region==regions[i]]
		lines(dt1$Year, dt1$m_yield, type="o", col=colors[i], pch=plotchar[i])
	}
	
	par(mar=c(0,0,0,0))
	plot.new()
	legend(x = "center", inset = 0, legend = regions, cex=0.7, col=colors, pch=plotchar)
	title("", outer=TRUE, line = -1)
}
plot_yield_by_regions()