require(data.table)
require(raster)
require(ggplot2)

data_dir_root = "/Users/peteralexander/Documents/LURG/Renewables"

fits1 = fread(file.path(data_dir_root, "feed-in_tariff_installation_report_june_2015_part_1_0.csv"))
fits2 = fread(file.path(data_dir_root, "feed-in_tariff_installation_report_june_2015_part_2_2.csv"))
fits = rbind(fits1, fits2)

setnames(fits, gsub("[ )(]", "", names(fits)))
fits[, PostCodeStub := gsub("([A-Z]+)[0-9]+", "\\1", PostCode)]
scottishPostCodes = unique(fits[CountryName== "Scotland", PostCodeStub])

fits[PostCodeStub %in% scottishPostCodes & CountryName %in% c("Scotland", "UnKnown", "Unknown"), isScotland := TRUE]
fits[is.na(isScotland), isScotland := FALSE]
fits[isScotland == TRUE, length(InstalledCapacitykW), by = TechnologyType]

fits[, commYear := as.numeric(gsub("[0-9]+/[0-9]+/([0-9]*)", "\\1", CommissionedDate))]
fits[, appYear := as.numeric(gsub("[0-9]+/[0-9]+/([0-9]*)", "\\1", ApplicationDate))]



# New 
windbands = c("<1.5kW", "1.5-15kW", "15-100kW", "100-500kW", "0.5-1.5MW", "1.5-5.0MW")
pvbands = c("<4kW", "4-10kW", "10-50kW", "50-150kW", "150-250kW", ">250kW")
banding = data.table(TechnologyType=c(rep("Wind",6), rep("Photovoltaic",6)), 
		bandName = c(windbands, pvbands), 
		lowerkW=c(0, 1.5, 15, 100, 500, 1500, 0, 4, 10, 50, 150, 250),
		upperkW=c(1.5, 15, 100, 500, 1500, 5000, 4, 10, 50, 150, 250, 5000))
banding[, bandName := factor(bandName, levels =  c(windbands, pvbands))]

payments = fread("/Users/peteralexander/Documents/LURG/Renewables/windtarrif.txt")
payments = rbind(payments[,list(type="from", TechnologyType, band=factor(band, c(windbands, pvbands)), date=as.Date(fromDate), tarrif=as.numeric(tarrif))], 
		         payments[,list(type="to", TechnologyType, band=factor(band, c(windbands, pvbands)), date=as.Date(toDate), tarrif=as.numeric(tarrif))])

for (i in 1:length(banding$TechnologyType)) {
	fits[TechnologyType==banding[i]$TechnologyType & InstalledCapacitykW > banding[i]$lowerkW & InstalledCapacitykW <= banding[i]$upperkW, band :=  banding[i]$bandName]
}

summaryDt = fits[, list(InstalledCapacitykW=sum(InstalledCapacitykW), numberOfSchemes=length(InstalledCapacitykW)), by=list(band, appYear, TechnologyType)]
summaryDt[appYear == 2015, InstalledCapacitykW := InstalledCapacitykW*2]

pdf(width=9, height=5, file = "/Users/peteralexander/Downloads/windtarrif.pdf")
ggplot(payments[TechnologyType== "Wind"], aes (x=date, y=tarrif)) + facet_wrap(~ band) + geom_line() + labs(x="Year", y="Tarrif (p/kWh)")
dev.off()

pdf(width=9, height=5, file = "/Users/peteralexander/Downloads/windinstallation.pdf")
ggplot(summaryDt[TechnologyType=="Wind"], aes(x=appYear, y=InstalledCapacitykW/1000)) + facet_wrap(~ band) + geom_bar(stat = "identity") + labs(x="Year", y="Installed Capacity (MW)")
dev.off()

pdf(width=9, height=5, file = "/Users/peteralexander/Downloads/pvtarrif.pdf")
ggplot(payments[TechnologyType== "Photovoltaic"], aes (x=date, y=tarrif)) + facet_wrap(~ band) + geom_line() + labs(x="Year", y="Tarrif (p/kWh)")
dev.off()

pdf(width=9, height=5, file = "/Users/peteralexander/Downloads/pvinstallation.pdf")
ggplot(summaryDt[TechnologyType=="Photovoltaic"], aes(x=appYear, y=InstalledCapacitykW/1000)) + facet_wrap(~ band) + geom_bar(stat = "identity") + labs(x="Year", y="Installed Capacity (MW)")
dev.off()




#windSummary[, appDate := (as.Date(paste0(appYear, "/01/01")))]

summaryDt2 = summaryDt[, list(numberOfSchemes=sum(numberOfSchemes), InstalledCapacitykW=sum(InstalledCapacitykW)), by=list(appYear, TechnologyType)][order(TechnologyType, appYear)]
ggplot(summaryDt2, aes(x=appYear, y=InstalledCapacitykW, colour = TechnologyType)) + geom_line() + scale_y_log10()






pop = fread(file.path(data_dir_root, "population.csv"))
setnames(pop, gsub("[ )(]", "", names(pop)))

pop[,  shortPostCode:=gsub("([A-Z]+[0-9]+) .*", "\\1", PostCode)]
sumPop = pop[,list(pop=sum(as.numeric(gsub(",", "", Allpeople)))), by=shortPostCode]
setnames(sumPop, "shortPostCode", "PostCode")

byPostCode = fits[PostCode != "", list(InstalledCapacitykW=sum(InstalledCapacitykW), numberOfSchemes=length(InstalledCapacitykW)), by=list(PostCode, TechnologyType, isScotland)]
byPostCode = rbind(byPostCode, byPostCode[, list(TechnologyType="Total", InstalledCapacitykW=sum(InstalledCapacitykW), numberOfSchemes = sum(numberOfSchemes)), by=list(PostCode, isScotland)])
byPostCode = byPostCode[order(PostCode)][order(isScotland, decreasing=TRUE)]
byPostCode[, meanCapacity := InstalledCapacitykW/numberOfSchemes]

byPostCodeScot = byPostCode[isScotland==TRUE]
byPostCodeScot = merge(byPostCodeScot, sumPop, by=c('PostCode'))
byPostCodeScot = rbind(byPostCodeScot, data.table(PostCode=c("KW11", "PH30"), TechnologyType="Total", isScotland=TRUE, InstalledCapacitykW=0, numberOfSchemes=0, pop=NaN, meanCapacity=0))
byPostCodeScot[, InstalledCapacityWPerCapita := InstalledCapacitykW/pop * 1000]
byPostCodeScot[, meanCapacity := InstalledCapacitykW/numberOfSchemes]


nationalData = byPostCode[, list(numberOfSchemes=sum(numberOfSchemes), InstalledCapacitykW=sum(InstalledCapacitykW)), by=list(isScotland, TechnologyType)][order(TechnologyType)]
nationalData[, meanCapacity := InstalledCapacitykW/numberOfSchemes]
nationalData[isScotland==TRUE, InstalledCapacityWPerCapita := InstalledCapacitykW/ 5300 ] # 5.3 M in Scotland 2011
nationalData[isScotland==FALSE, InstalledCapacityWPerCapita := InstalledCapacitykW/ (53000 + 3100) ]  # 53.0 M in England  and 3.1 M in Wales 2011

write.table(byPostCode, "/Users/peteralexander/Documents/LURG/Renewables/fits_summary.csv", sep=',', row.names=FALSE, quote=FALSE)
write.table(byPostCodeScot, "/Users/peteralexander/Documents/LURG/Renewables/fits_summary_scotland.csv", sep=',', row.names=FALSE, quote=FALSE)
write.table(nationalData, "/Users/peteralexander/Documents/LURG/Renewables/fits_summary_national.csv", sep=',', row.names=FALSE, quote=FALSE)


#dt = dcast.data.table(byPostCode, PostCode ~ TechnologyType, value.var="numberOfSchemes", fill=0)

dt = dcast.data.table(byPostCodeScot, PostCode ~ TechnologyType, value.var="InstalledCapacityWPerCapita", fill=0)
require(rgdal)
districts = readOGR(dsn=file.path(data_dir_root, "Distribution/Districts.shp"), layer = "Districts")
names(districts) = c("PostCode")
districts@data <- merge(districts@data, dt, by="PostCode", all.x=TRUE)
scotlandData = districts[!is.na(districts$Total), ]

spplot(scotlandData["Total"], at = c(0, 50, 100, 200, 500, 1000, 2000, 5000, 11000), main=list(label="Total FITs: Watts of installed capacity per person",cex=0.9))
spplot(scotlandData["Wind"], at = c(0, 20, 50, 100, 200, 500, 1000, 1700), main=list(label="Wind: Watts of installed capacity per person",cex=0.9))
spplot(scotlandData["Photovoltaic"], at = c(0, 5, 10, 20, 50, 100, 200, 400), main=list(label="Photovoltaic: Watts of installed capacity per person",cex=0.9))
spplot(scotlandData["Hydro"], at = c(0, 50, 100, 200, 500, 1000, 2000, 5000, 11000), main=list(label="Hydro: Watts of installed capacity per person",cex=0.9))






ggplot(fits[CountryName=="Scotland"], aes(InstalledCapacitykW, fill= TechnologyType)) + 
		 		geom_histogram(binwidth=.1, position="dodge") + 
		 		scale_x_log10(limits=c(0.1, 5000), breaks = c(1, 10, 100, 1000, 5000)) + theme(legend.position="bottom")

ggplot(fits[CountryName=="Scotland" & TechnologyType != "Photovoltaic"], aes(InstalledCapacitykW, fill= TechnologyType)) + 
		geom_histogram(binwidth=1, position="dodge") + 
		scale_x_log10(limits=c(0.1, 5000), breaks = c(1, 10, 100, 1000, 5000))


byPostCodeScot[TechnologyType=="Wind"][order(InstalledCapacitykW, decreasing=TRUE)]
byPostCodeScot[TechnologyType=="Photovoltaic"][order(InstalledCapacitykW, decreasing=TRUE)]
byPostCodeScot[TechnologyType=="Hydro"][order(InstalledCapacitykW, decreasing=TRUE)]
byPostCodeScot[TechnologyType=="Micro CHP"][order(InstalledCapacitykW, decreasing=TRUE)]
byPostCodeScot[TechnologyType=="Anaerobic digestion"][order(InstalledCapacitykW, decreasing=TRUE)]

byPostCodeScot[, list(InstalledCapacitykW=sum(InstalledCapacitykW)), by=TechnologyType][order(InstalledCapacitykW, decreasing=TRUE)]



plot(districts[districts$name == "AB52", ])

districts@data$testCol = NULL