# This produces Figure 1 and 2 for 2015 Journal of Biomass and Bioenergy article

if(!require(data.table)){install.packages("data.table")}
if(!require(gridExtra)){install.packages("gridExtra")}
require(ggplot2)

ec_data = fread("~/Documents/PhD/Docs/Biomass\ and\ Bioenergy\ paper/results_for_r.csv")

ec_data = ec_data[, elec_TWh := elec_GWh/1000]

p1 = ggplot(data = ec_data, aes(x=elec_TWh, y=subsidy_M, colour=Farmer_grant, shape=Farmer_grant)) +
		geom_path(alpha=1, size = 0.7) + 
		geom_point(alpha=0.7, size=2.5) + 
		scale_x_continuous(limits=c(0, 30), breaks=seq(0,30,5)) +
		labs(x="Electricity generation (TWh / year)", y="Total subsidy\n(2010 £M / year)", colour = "Farmer support:", shape = "Farmer support:") +
		theme_classic(base_size = 12) +
		theme(legend.text=element_text(size=12))

p2 = ggplot(data = ec_data, aes(x=elec_TWh, y=avg_electricty_sub, colour=Farmer_grant, shape=Farmer_grant)) +
		geom_path(alpha=1, size = 0.7) + 
		geom_point(alpha=0.7, size=2.5) + 
		scale_x_continuous(limits=c(0, 30), breaks=seq(0,30,5)) +
		labs(x="Electricity generation (TWh / year)", y="Average subsidy\n(2010 £ / MWh)") +
		theme_classic(base_size = 12)

p3 = ggplot(data = ec_data, aes(x=elec_TWh, y=mar_elec_sub, colour=Farmer_grant, shape=Farmer_grant)) +
		geom_path(alpha=1, size = 0.7) + 
		geom_point(alpha=0.7, size=2.5) + 
		scale_x_continuous(limits=c(0, 30), breaks=seq(0,30,5)) +
		labs(x="Electricity generation (TWh / year)", y="Marginal subsidy\n(2010 £ / MWh)") +
		theme_classic(base_size = 12)

grid_arrange_shared_legend <- function(...) {
	plots <- list(...)
	g <- ggplotGrob(plots[[1]] + theme(legend.position="bottom"))$grobs
	legend <- g[[which(sapply(g, function(x) x$name) == "guide-box")]]
	lheight <- sum(legend$height)
	grid.arrange(
			do.call(arrangeGrob, lapply(plots, function(x)
								x + theme(legend.position="none"))),
			legend,
			ncol = 1,
			heights = unit.c(unit(1, "npc") - lheight, lheight))
}

pdf("~/Documents/PhD/Docs/Biomass\ and\ Bioenergy\ paper/Figures_v2/figure1.pdf", 8, 11, FALSE)
grid_arrange_shared_legend(p1, p2, p3)
grid.text(gp=gpar(fontsize=17, fontface="bold.italic"), label="A", x=0.02, y=0.985)
grid.text(gp=gpar(fontsize=17, fontface="bold.italic"), label="B", x=0.02, y=0.69)
grid.text(gp=gpar(fontsize=17, fontface="bold.italic"), label="C", x=0.02, y=0.38)
dev.off()

p4 = ggplot(data = ec_data, aes(x=emssions_Mt, y=mar_carbon_px, colour=Farmer_grant, shape=Farmer_grant)) +
		geom_path(alpha=1, size = 0.7) + 
		geom_point(alpha=0.7, size=2.5) + 
		scale_x_continuous(limits=c(0, 25), breaks=seq(0,25,5)) +
		labs(x="Emissions reduction (MtCO2e / year)", y="Marginal carbon abatement cost\n(2010 £ / tCO2e)", colour = "Farmer support:", shape = "Farmer support:") +
		theme_classic(base_size = 12) +
		theme(legend.text=element_text(size=12))
		

pdf("~/Documents/PhD/Docs/Biomass\ and\ Bioenergy\ paper/Figures_v2/figure2.pdf", 8, 4.1, FALSE)
grid_arrange_shared_legend(p4)
dev.off()
